
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 1912
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5)))
 *    ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a')
 *    ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z'))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z'))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z'))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z'))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', 0) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', True) => True
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0)
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'c', 'b')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'c', 'b')
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('i2b8', ('b2i', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search34_0_0 -> 32 in the cache */
   /* search34_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace34_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search35_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace35 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search36_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 115 },
      1,
   } },

   /* replace36 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search37_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 117 },
      1,
   } },

   /* replace37 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search39_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace39 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search40_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace40 -> 122 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search41_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 126, 128 },
      -1,
   } },

   /* replace41_0 -> 124 in the cache */
   /* replace41_1_0 -> 125 in the cache */
   /* replace41_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 124, 130 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search42_0_0 -> 16 in the cache */
   /* search42_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search42_1_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 16, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 132, 134 },
      -1,
   } },

   /* replace42_0 -> 16 in the cache */
   /* replace42_1_0 -> 36 in the cache */
   /* replace42_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 16, 136 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search43_0 -> 0 in the cache */
   /* search43_1 -> 3 in the cache */
   /* search43_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 138, 139 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 140 },
      -1,
   } },

   /* replace43_0 -> 0 in the cache */
   /* replace43_1_0 -> 3 in the cache */
   /* replace43_1_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3, 138 },
      -1,
   } },
   /* replace43_2 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 142, 139 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search44_0 -> 0 in the cache */
   /* search44_1 -> 3 in the cache */
   /* search44_2_0 -> 0 in the cache */
   /* search44_2_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 138 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 144 },
      -1,
   } },

   /* replace44_0 -> 0 in the cache */
   /* replace44_1_0 -> 3 in the cache */
   /* replace44_1_1 -> 138 in the cache */
   /* replace44_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 142 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 148 },
      0,
   } },
   /* search45_1_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 147, 150, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 149, 152 },
      -1,
   } },

   /* replace45_0 -> 147 in the cache */
   /* replace45_1_0 -> 148 in the cache */
   /* replace45_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 148, 150 },
      -1,
   } },
   /* replace45_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 147, 154, 151 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search46_0 -> 147 in the cache */
   /* search46_1_0 -> 148 in the cache */
   /* search46_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 150 },
      0,
   } },
   /* search46_2_0 -> 148 in the cache */
   /* search46_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 147, 156, 157 },
      -1,
   } },

   /* replace46_0 -> 148 in the cache */
   /* replace46_1_0 -> 147 in the cache */
   /* replace46_1_1 -> 150 in the cache */
   /* replace46_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 147, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 148, 159 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search47_0 -> 16 in the cache */
   /* search47_1 -> 36 in the cache */
   /* search47_2_0 -> 16 in the cache */
   /* search47_2_1 -> 133 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 133, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 162 },
      -1,
   } },

   /* replace47_0 -> 16 in the cache */
   /* replace47_1_0 -> 36 in the cache */
   /* replace47_1_1 -> 133 in the cache */
   /* replace47_1 -> 136 in the cache */
   /* replace47_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 136, 161 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search48_0 -> 16 in the cache */
   /* search48_1 -> 36 in the cache */
   /* search48_2_0 -> 16 in the cache */
   /* search48_2_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 133 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 165 },
      -1,
   } },

   /* replace48_0 -> 16 in the cache */
   /* replace48_1_0 -> 36 in the cache */
   /* replace48_1_1 -> 133 in the cache */
   /* replace48_1 -> 136 in the cache */
   /* replace48 -> 137 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search49_0_0 -> 16 in the cache */
   /* search49_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      0,
   } },
   /* search49_1_0 -> 16 in the cache */
   /* search49_1_1 -> 133 in the cache */
   /* search49_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 16, 133, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 167, 168 },
      -1,
   } },

   /* replace49_0 -> 16 in the cache */
   /* replace49_1_0 -> 36 in the cache */
   /* replace49_1_1 -> 133 in the cache */
   /* replace49_1 -> 136 in the cache */
   /* replace49_2 -> 161 in the cache */
   /* replace49 -> 164 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search50_0 -> 16 in the cache */
   /* search50_1_0 -> 36 in the cache */
   /* search50_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 133 },
      0,
   } },
   /* search50_2_0 -> 36 in the cache */
   /* search50_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 36, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 16, 170, 171 },
      -1,
   } },

   /* replace50_0 -> 36 in the cache */
   /* replace50_1_0 -> 16 in the cache */
   /* replace50_1_1 -> 133 in the cache */
   /* replace50_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 36, 173 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search51_0_0 -> 124 in the cache */
   /* search51_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search51_1_0 -> 124 in the cache */
   /* search51_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 175, 176 },
      -1,
   } },

   /* replace51_0 -> 124 in the cache */
   /* replace51_1_0 -> 125 in the cache */
   /* replace51_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 124, 178 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search52_0_0 -> 124 in the cache */
   /* search52_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search52_1_0 -> 124 in the cache */
   /* search52_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 180, 181 },
      -1,
   } },

   /* replace52_0 -> 124 in the cache */
   /* replace52_1_0 -> 125 in the cache */
   /* replace52_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 124, 183 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search53_0_0 -> 124 in the cache */
   /* search53_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search53_1_0 -> 124 in the cache */
   /* search53_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 185, 186 },
      -1,
   } },

   /* replace53_0 -> 124 in the cache */
   /* replace53_1_0 -> 125 in the cache */
   /* replace53_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 124, 188 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search54_0_0 -> 32 in the cache */
   /* search54_0 -> 98 in the cache */
   /* search54_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace54 -> 113 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search55_0_0 -> 32 in the cache */
   /* search55_0 -> 100 in the cache */
   /* search55_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace55 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search56_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search56_1_0 -> 0 in the cache */
   /* search56_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 192, 193 },
      -1,
   } },

   /* replace56 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search57_0 -> 0 in the cache */
   /* search57_1_0_0 -> 0 in the cache */
   /* search57_1_0 -> 192 in the cache */
   /* search57_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 192, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 195 },
      -1,
   } },

   /* replace57 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search58_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search58_1_0 -> 0 in the cache */
   /* search58_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 197, 198 },
      -1,
   } },

   /* replace58 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search59_0 -> 0 in the cache */
   /* search59_1_0_0 -> 0 in the cache */
   /* search59_1_0 -> 197 in the cache */
   /* search59_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 197, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 200 },
      -1,
   } },

   /* replace59 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search60_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search60_1_0_0 -> 32 in the cache */
   /* search60_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 203 },
      -1,
   } },

   /* replace60_0_0 -> 32 in the cache */
   /* replace60_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search61_0 -> 32 in the cache */
   /* search61_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace61 -> 113 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search62_0 -> 11 in the cache */
   /* search62_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 115 },
      -1,
   } },

   /* replace62 -> 115 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search63_0 -> 16 in the cache */
   /* search63_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace63 -> 117 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search64_0 -> 16 in the cache */
   /* search64_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace64 -> 117 in the cache */

   /* ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search65_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 210 },
      -1,
   } },

   /* replace65_0 -> 16 in the cache */
   /* replace65_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 213, 214 },
      -1,
   } },

   /* replace66_0 -> 16 in the cache */
   /* replace66_1 -> 36 in the cache */
   /* replace66 -> 212 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search67_0 -> 16 in the cache */
   /* search67_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* replace67_0 -> 16 in the cache */
   /* replace67_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search68_0 -> 16 in the cache */
   /* search68_1 -> 210 in the cache */
   /* search68_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 210, 133 },
      -1,
   } },

   /* replace68_0 -> 16 in the cache */
   /* replace68_1 -> 36 in the cache */
   /* replace68_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search69_0 -> 213 in the cache */
   /* search69_1 -> 214 in the cache */
   /* search69_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 213, 214, 133 },
      -1,
   } },

   /* replace69_0 -> 16 in the cache */
   /* replace69_1 -> 36 in the cache */
   /* replace69_2 -> 133 in the cache */
   /* replace69 -> 219 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search70_0 -> 16 in the cache */
   /* search70_1 -> 16 in the cache */
   /* search70_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* replace70_0 -> 16 in the cache */
   /* replace70_1 -> 16 in the cache */
   /* replace70_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search71_0 -> 32 in the cache */
   /* search71_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace71 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search72_0 -> 16 in the cache */
   /* search72_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace72 -> 120 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search73_0 -> 16 in the cache */
   /* search73_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace73 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search74_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 226 },
      -1,
   } },

   /* replace74 -> 32 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search75_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 228 },
      -1,
   } },

   /* replace75 -> 16 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search76_0 -> 32 in the cache */
   /* search76_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 226 },
      1,
   } },

   /* replace76 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search77_0 -> 32 in the cache */
   /* search77_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace77 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search78_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 232 },
      -1,
   } },

   /* replace78_0 -> 32 in the cache */
   /* replace78 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search79_0 -> 32 in the cache */
   /* search79_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace79_0 -> 32 in the cache */
   /* replace79 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search80_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search80_1_0 -> 32 in the cache */
   /* search80_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 235, 236 },
      -1,
   } },

   /* replace80_0_0 -> 32 in the cache */
   /* replace80_0 -> 103 in the cache */
   /* replace80_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search81_0_0_0 -> 32 in the cache */
   /* search81_0_0 -> 235 in the cache */
   /* search81_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 235, 32 },
      -1,
   } },
   /* search81_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 239, 32 },
      -1,
   } },

   /* replace81_0_0 -> 32 in the cache */
   /* replace81_0 -> 103 in the cache */
   /* replace81_1 -> 32 in the cache */
   /* replace81 -> 238 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search82_1 -> 0 in the cache */
   /* search82_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 241, 0, 3 },
      -1,
   } },

   /* replace82 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search83_0 -> 115 in the cache */
   /* search83_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 115, 11, 243 },
      1,
   } },

   /* replace83 -> 243 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search84_0 -> 117 in the cache */
   /* search84_1 -> 16 in the cache */
   /* search84_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 117, 16, 36 },
      1,
   } },

   /* replace84 -> 36 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search85_0 -> 117 in the cache */
   /* search85_1 -> 16 in the cache */
   /* search85_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 117, 16, 36 },
      -1,
   } },

   /* replace85_0 -> 117 in the cache */
   /* replace85_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 117, 36 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search86_0 -> 0 in the cache */
   /* search86_1 -> 3 in the cache */
   /* search86_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 241 },
      -1,
   } },

   /* replace86_0 -> 0 in the cache */
   /* replace86_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search87_0 -> 11 in the cache */
   /* search87_1 -> 243 in the cache */
   /* search87_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 115 },
      -1,
   } },

   /* replace87_0 -> 11 in the cache */
   /* replace87_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search88_0 -> 16 in the cache */
   /* search88_1 -> 36 in the cache */
   /* search88_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace88_0 -> 16 in the cache */
   /* replace88_1 -> 36 in the cache */
   /* replace88 -> 212 in the cache */

   /* ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search89_0 -> 16 in the cache */
   /* search89_1 -> 36 in the cache */
   /* search89_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace89_0 -> 16 in the cache */
   /* replace89_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search90_1 -> 0 in the cache */
   /* search90_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 255, 0, 3 },
      -1,
   } },

   /* replace90_0 -> 0 in the cache */
   /* replace90_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search91_0 -> 228 in the cache */
   /* search91_1 -> 16 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 228, 16, 36 },
      -1,
   } },

   /* replace91_0 -> 16 in the cache */
   /* replace91_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search92_1 -> 0 in the cache */
   /* search92_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 260, 0, 3 },
      -1,
   } },

   /* replace92_0_0 -> 0 in the cache */
   /* replace92_0 -> 197 in the cache */
   /* replace92_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 197, 3 },
      -1,
   } },

   /* ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search93_1 -> 16 in the cache */
   /* search93_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 263, 16, 36 },
      -1,
   } },

   /* replace93_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   /* replace93_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 265, 36 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search94_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 267, 268, 127 },
      -1,
   } },

   /* replace94_0_0 -> 124 in the cache */
   /* replace94_0_1 -> 125 in the cache */
   /* replace94_0 -> 126 in the cache */
   /* replace94_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 126, 127 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search95_1 -> 33 in the cache */
   /* search95_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 271, 33, 133 },
      -1,
   } },

   /* replace95_0_0 -> 16 in the cache */
   /* replace95_0_1 -> 36 in the cache */
   /* replace95_0 -> 132 in the cache */
   /* replace95_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 132, 133 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search96_0 -> 0 in the cache */
   /* search96_1 -> 3 in the cache */
   /* search96_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 241 },
      -1,
   } },

   /* replace96 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search97_0 -> 0 in the cache */
   /* search97_1 -> 3 in the cache */
   /* search97_2 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 255 },
      -1,
   } },

   /* replace97 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search98_0 -> 0 in the cache */
   /* search98_1 -> 0 in the cache */
   /* search98_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace98 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search99_0 -> 241 in the cache */
   /* search99_1 -> 0 in the cache */
   /* search99_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 241, 0, 3 },
      -1,
   } },

   /* replace99_0 -> 0 in the cache */
   /* replace99_1 -> 3 in the cache */
   /* replace99 -> 249 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search100_0 -> 124 in the cache */
   /* search100_1_0 -> 124 in the cache */
   /* search100_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 124, 125 },
      0,
   } },
   /* search100_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 124, 278, 127 },
      -1,
   } },

   /* replace100_0_0 -> 125 in the cache */
   /* replace100_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 125, 127 },
      -1,
   } },
   /* replace100_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 280, 124 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search101_0 -> 16 in the cache */
   /* search101_1 -> 120 in the cache */
   /* search101_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace101 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search102_0 -> 16 in the cache */
   /* search102_1 -> 120 in the cache */
   /* search102_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace102 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search103_0 -> 16 in the cache */
   /* search103_1 -> 120 in the cache */
   /* search103_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace103 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search104_0 -> 16 in the cache */
   /* search104_1 -> 120 in the cache */
   /* search104_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace104 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search105_0 -> 16 in the cache */
   /* search105_1 -> 120 in the cache */
   /* search105_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace105 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search106_0 -> 16 in the cache */
   /* search106_1 -> 120 in the cache */
   /* search106_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace106 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search107_0 -> 16 in the cache */
   /* search107_1 -> 120 in the cache */
   /* search107_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace107 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search108_0 -> 16 in the cache */
   /* search108_1 -> 120 in the cache */
   /* search108_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace108 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search109_0 -> 16 in the cache */
   /* search109_1 -> 120 in the cache */
   /* search109_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace109 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search110_0 -> 120 in the cache */
   /* search110_1 -> 16 in the cache */
   /* search110_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace110 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search111_0 -> 16 in the cache */
   /* search111_1 -> 120 in the cache */
   /* search111_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace111 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search112_0 -> 120 in the cache */
   /* search112_1 -> 16 in the cache */
   /* search112_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace112 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search113_0_0 -> 16 in the cache */
   /* search113_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 295, 296 },
      -1,
   } },

   /* replace113_0 -> 16 in the cache */
   /* replace113_1 -> 36 in the cache */
   /* replace113_2_0 -> 133 in the cache */
   /* replace113_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search114_0_0 -> 16 in the cache */
   /* search114_0_1 -> 36 in the cache */
   /* search114_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search114_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 300, 296 },
      -1,
   } },

   /* replace114_0 -> 16 in the cache */
   /* replace114_1 -> 36 in the cache */
   /* replace114_2_0 -> 133 in the cache */
   /* replace114_2_1 -> 161 in the cache */
   /* replace114_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search115_0_0 -> 16 in the cache */
   /* search115_0_1 -> 36 in the cache */
   /* search115_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 294 },
      0,
   } },
   /* search115_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 303, 296 },
      -1,
   } },

   /* replace115_0 -> 16 in the cache */
   /* replace115_1 -> 36 in the cache */
   /* replace115_2_0 -> 133 in the cache */
   /* replace115_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 305 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search116_0_0 -> 16 in the cache */
   /* search116_0_1 -> 36 in the cache */
   /* search116_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search116_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 307, 296 },
      -1,
   } },

   /* replace116_0 -> 16 in the cache */
   /* replace116_1 -> 36 in the cache */
   /* replace116_2_0 -> 133 in the cache */
   /* replace116_2_1 -> 161 in the cache */
   /* replace116_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search117_0_0 -> 16 in the cache */
   /* search117_0_1 -> 36 in the cache */
   /* search117_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search117_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 310, 296 },
      -1,
   } },

   /* replace117_0 -> 16 in the cache */
   /* replace117_1 -> 36 in the cache */
   /* replace117_2_0 -> 133 in the cache */
   /* replace117_2_1 -> 161 in the cache */
   /* replace117_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search118_0_1 -> 36 in the cache */
   /* search118_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search118_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 314, 133 },
      -1,
   } },

   /* replace118_0 -> 16 in the cache */
   /* replace118_1 -> 36 in the cache */
   /* replace118_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search119_0_0 -> 313 in the cache */
   /* search119_0_1 -> 36 in the cache */
   /* search119_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search119_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 317, 133 },
      -1,
   } },

   /* replace119_0 -> 16 in the cache */
   /* replace119_1 -> 36 in the cache */
   /* replace119_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search120_0_0 -> 313 in the cache */
   /* search120_0_1 -> 36 in the cache */
   /* search120_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 313, 36, 120 },
      -1,
   } },
   /* search120_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 320, 133 },
      -1,
   } },

   /* replace120_0 -> 16 in the cache */
   /* replace120_1 -> 36 in the cache */
   /* replace120_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search121_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search121_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 323, 120 },
      -1,
   } },
   /* search121_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 324, 133 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2 -> 133 in the cache */
   /* replace121 -> 322 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search122_0_0 -> 313 in the cache */
   /* search122_0_1 -> 36 in the cache */
   /* search122_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search122_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 326, 133 },
      -1,
   } },

   /* replace122_0 -> 16 in the cache */
   /* replace122_1 -> 36 in the cache */
   /* replace122_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search123_0_0 -> 313 in the cache */
   /* search123_0_1 -> 36 in the cache */
   /* search123_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search123_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 329, 133 },
      -1,
   } },

   /* replace123_0 -> 16 in the cache */
   /* replace123_1 -> 36 in the cache */
   /* replace123_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search124_0 -> 271 in the cache */
   /* search124_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace124_0_0 -> 16 in the cache */
   /* replace124_0_1 -> 36 in the cache */
   /* replace124_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace124_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 334, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search125_0 -> 271 in the cache */
   /* search125_1 -> 33 in the cache */
   /* search125_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace125_0_0 -> 16 in the cache */
   /* replace125_0_1 -> 36 in the cache */
   /* replace125_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace125_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 337, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search126_0 -> 271 in the cache */
   /* search126_1 -> 33 in the cache */
   /* search126_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 271, 33, 332 },
      -1,
   } },

   /* replace126_0_0 -> 16 in the cache */
   /* replace126_0_1 -> 36 in the cache */
   /* replace126_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },
   /* replace126_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 340, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search127_0 -> 271 in the cache */
   /* search127_1 -> 33 in the cache */
   /* search127_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace127_0_0 -> 16 in the cache */
   /* replace127_0_1 -> 36 in the cache */
   /* replace127_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace127_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 343, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search128_0 -> 271 in the cache */
   /* search128_1 -> 33 in the cache */
   /* search128_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace128_0_0 -> 16 in the cache */
   /* replace128_0_1 -> 36 in the cache */
   /* replace128_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace128_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 346, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search129_0 -> 271 in the cache */
   /* search129_1 -> 33 in the cache */
   /* search129_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace129_0_0 -> 16 in the cache */
   /* replace129_0_1 -> 36 in the cache */
   /* replace129_0_2 -> 120 in the cache */
   /* replace129_0 -> 334 in the cache */
   /* replace129_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 334, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search130_0 -> 271 in the cache */
   /* search130_1 -> 33 in the cache */
   /* search130_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace130_0_0 -> 16 in the cache */
   /* replace130_0_1 -> 36 in the cache */
   /* replace130_0_2 -> 120 in the cache */
   /* replace130_0 -> 337 in the cache */
   /* replace130_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 337, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search131_0 -> 271 in the cache */
   /* search131_1 -> 33 in the cache */
   /* search131_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 271, 33, 332 },
      -1,
   } },

   /* replace131_0_0 -> 16 in the cache */
   /* replace131_0_1 -> 36 in the cache */
   /* replace131_0_2 -> 120 in the cache */
   /* replace131_0 -> 340 in the cache */
   /* replace131_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 340, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 271 in the cache */
   /* search132_1 -> 33 in the cache */
   /* search132_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace132_0_0 -> 16 in the cache */
   /* replace132_0_1 -> 36 in the cache */
   /* replace132_0_2 -> 120 in the cache */
   /* replace132_0 -> 343 in the cache */
   /* replace132_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 343, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 271 in the cache */
   /* search133_1 -> 33 in the cache */
   /* search133_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace133_0_0 -> 16 in the cache */
   /* replace133_0_1 -> 36 in the cache */
   /* replace133_0_2 -> 120 in the cache */
   /* replace133_0 -> 346 in the cache */
   /* replace133_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 346, 133 },
      -1,
   } },

   /* ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search134_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 358, 117 },
      -1,
   } },
   /* search134_0_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 359, 117, 360 },
      -1,
   } },
   /* search134_1_0_0 -> 360 in the cache */
   /* search134_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      2, 1,
      { 360, 117 },
      -1,
   } },
   /* search134_1_1 -> 117 in the cache */
   /* search134_1_2 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 362, 117, 358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 361, 363 },
      -1,
   } },

   /* replace134_0 -> 360 in the cache */
   /* replace134_1 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 360, 358 },
      -1,
   } },

   /* ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search135_0 -> 16 in the cache */
   /* search135_1_0_0 -> 16 in the cache */
   /* search135_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 16, 117 },
      -1,
   } },
   /* search135_1_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 366, 117, 367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 16, 368 },
      -1,
   } },

   /* replace135_0 -> 16 in the cache */
   /* replace135_1 -> 36 in the cache */
   /* replace135 -> 254 in the cache */

   /* ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search136_0_0_0 -> 358 in the cache */
   /* search136_0_0_1 -> 117 in the cache */
   /* search136_0_0 -> 359 in the cache */
   /* search136_0_1 -> 117 in the cache */
   /* search136_0_2 -> 360 in the cache */
   /* search136_0 -> 361 in the cache */
   /* search136_1_0_0 -> 360 in the cache */
   /* search136_1_0_1 -> 117 in the cache */
   /* search136_1_0 -> 362 in the cache */
   /* search136_1_1 -> 117 in the cache */
   /* search136_1_2 -> 358 in the cache */
   /* search136_1 -> 363 in the cache */
   /* search136_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 361, 363, 133 },
      -1,
   } },

   /* replace136_0 -> 360 in the cache */
   /* replace136_1 -> 358 in the cache */
   /* replace136_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 360, 358, 133 },
      -1,
   } },

   /* ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search137_0 -> 16 in the cache */
   /* search137_1_0_0 -> 16 in the cache */
   /* search137_1_0_1 -> 117 in the cache */
   /* search137_1_0 -> 366 in the cache */
   /* search137_1_1 -> 117 in the cache */
   /* search137_1_2 -> 367 in the cache */
   /* search137_1 -> 368 in the cache */
   /* search137_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 16, 368, 133 },
      -1,
   } },

   /* replace137_0 -> 16 in the cache */
   /* replace137_1 -> 36 in the cache */
   /* replace137_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search138_0 -> 16 in the cache */
   /* search138_1 -> 36 in the cache */
   /* search138_2 -> 133 in the cache */
   /* search138 -> 316 in the cache */

   /* replace138_0_0_0_0_0 -> 16 in the cache */
   /* replace138_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace138_0_0_0_1_0 -> 36 in the cache */
   /* replace138_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 374, 375 },
      -1,
   } },
   /* replace138_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace138_0_0_1_1_0 -> 36 in the cache */
   /* replace138_0_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 378, 379 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 376, 380 },
      -1,
   } },
   /* replace138_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* replace138_0_1_0_1_0 -> 36 in the cache */
   /* replace138_0_1_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 383, 384 },
      -1,
   } },
   /* replace138_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 386 },
      -1,
   } },
   /* replace138_0_1_1_1_0 -> 36 in the cache */
   /* replace138_0_1_1_1_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 387, 388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 385, 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 381, 390 },
      -1,
   } },
   /* replace138_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 391, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search139_0 -> 16 in the cache */
   /* search139_1 -> 36 in the cache */
   /* search139_2 -> 133 in the cache */
   /* search139 -> 319 in the cache */

   /* replace139_0_0_0_0_0 -> 16 in the cache */
   /* replace139_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace139_0_0_0_1_0 -> 36 in the cache */
   /* replace139_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 393, 394 },
      -1,
   } },
   /* replace139_0_0_1_0_0 -> 16 in the cache */
   /* replace139_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace139_0_0_1_1_0 -> 36 in the cache */
   /* replace139_0_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 396, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 395, 398 },
      -1,
   } },
   /* replace139_0_1_0_0_0 -> 16 in the cache */
   /* replace139_0_1_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* replace139_0_1_0_1_0 -> 36 in the cache */
   /* replace139_0_1_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 400, 401 },
      -1,
   } },
   /* replace139_0_1_1_0_0 -> 16 in the cache */
   /* replace139_0_1_1_0_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 386 },
      -1,
   } },
   /* replace139_0_1_1_1_0 -> 36 in the cache */
   /* replace139_0_1_1_1_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 403, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 402, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 399, 406 },
      -1,
   } },
   /* replace139_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 407, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search140_0 -> 16 in the cache */
   /* search140_1 -> 36 in the cache */
   /* search140_2 -> 133 in the cache */
   /* search140 -> 322 in the cache */

   /* replace140_0_0_0_0_0 -> 16 in the cache */
   /* replace140_0_0_0_0_1 -> 120 in the cache */
   /* replace140_0_0_0_0 -> 374 in the cache */
   /* replace140_0_0_0_1_0 -> 36 in the cache */
   /* replace140_0_0_0_1_1 -> 120 in the cache */
   /* replace140_0_0_0_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 374, 394 },
      -1,
   } },
   /* replace140_0_0_1_0_0 -> 16 in the cache */
   /* replace140_0_0_1_0_1 -> 377 in the cache */
   /* replace140_0_0_1_0 -> 378 in the cache */
   /* replace140_0_0_1_1_0 -> 36 in the cache */
   /* replace140_0_0_1_1_1 -> 377 in the cache */
   /* replace140_0_0_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 378, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 409, 410 },
      -1,
   } },
   /* replace140_0_1_0_0_0 -> 16 in the cache */
   /* replace140_0_1_0_0_1 -> 382 in the cache */
   /* replace140_0_1_0_0 -> 383 in the cache */
   /* replace140_0_1_0_1_0 -> 36 in the cache */
   /* replace140_0_1_0_1_1 -> 382 in the cache */
   /* replace140_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 383, 401 },
      -1,
   } },
   /* replace140_0_1_1_0_0 -> 16 in the cache */
   /* replace140_0_1_1_0_1 -> 386 in the cache */
   /* replace140_0_1_1_0 -> 387 in the cache */
   /* replace140_0_1_1_1_0 -> 36 in the cache */
   /* replace140_0_1_1_1_1 -> 386 in the cache */
   /* replace140_0_1_1_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 387, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 412, 413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 411, 414 },
      -1,
   } },
   /* replace140_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 415, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search141_0 -> 16 in the cache */
   /* search141_1 -> 36 in the cache */
   /* search141_2 -> 133 in the cache */
   /* search141 -> 328 in the cache */

   /* replace141_0_0_0_0 -> 16 in the cache */
   /* replace141_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace141_0_0_1_0 -> 36 in the cache */
   /* replace141_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 417, 418 },
      -1,
   } },
   /* replace141_0_1_0_0 -> 16 in the cache */
   /* replace141_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace141_0_1_1_0 -> 36 in the cache */
   /* replace141_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 420, 421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 419, 422 },
      -1,
   } },
   /* replace141_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 423, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search142_0 -> 16 in the cache */
   /* search142_1 -> 36 in the cache */
   /* search142_2 -> 133 in the cache */
   /* search142 -> 331 in the cache */

   /* replace142_0_0_0_0 -> 16 in the cache */
   /* replace142_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace142_0_0_1_0 -> 36 in the cache */
   /* replace142_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 425, 426 },
      -1,
   } },
   /* replace142_0_1_0_0 -> 16 in the cache */
   /* replace142_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace142_0_1_1_0 -> 36 in the cache */
   /* replace142_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 428, 429 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 427, 430 },
      -1,
   } },
   /* replace142_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 431, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search143_0 -> 16 in the cache */
   /* search143_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 433 },
      -1,
   } },

   /* replace143_0 -> 16 in the cache */
   /* replace143_1 -> 36 in the cache */
   /* replace143_2 -> 133 in the cache */
   /* replace143 -> 319 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search144_0 -> 16 in the cache */
   /* search144_1 -> 36 in the cache */
   /* search144_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace144_0_0_0_0_0 -> 16 in the cache */
   /* replace144_0_0_0_0_1 -> 120 in the cache */
   /* replace144_0_0_0_0 -> 393 in the cache */
   /* replace144_0_0_0_1_0 -> 36 in the cache */
   /* replace144_0_0_0_1_1 -> 120 in the cache */
   /* replace144_0_0_0_1 -> 394 in the cache */
   /* replace144_0_0_0 -> 395 in the cache */
   /* replace144_0_0_1_0_0 -> 16 in the cache */
   /* replace144_0_0_1_0_1 -> 377 in the cache */
   /* replace144_0_0_1_0 -> 396 in the cache */
   /* replace144_0_0_1_1_0 -> 36 in the cache */
   /* replace144_0_0_1_1_1 -> 377 in the cache */
   /* replace144_0_0_1_1 -> 397 in the cache */
   /* replace144_0_0_1 -> 398 in the cache */
   /* replace144_0_0 -> 399 in the cache */
   /* replace144_0_1_0_0_0 -> 16 in the cache */
   /* replace144_0_1_0_0_1 -> 382 in the cache */
   /* replace144_0_1_0_0 -> 400 in the cache */
   /* replace144_0_1_0_1_0 -> 36 in the cache */
   /* replace144_0_1_0_1_1 -> 382 in the cache */
   /* replace144_0_1_0_1 -> 401 in the cache */
   /* replace144_0_1_0 -> 402 in the cache */
   /* replace144_0_1_1_0_0 -> 16 in the cache */
   /* replace144_0_1_1_0_1 -> 386 in the cache */
   /* replace144_0_1_1_0 -> 403 in the cache */
   /* replace144_0_1_1_1_0 -> 36 in the cache */
   /* replace144_0_1_1_1_1 -> 386 in the cache */
   /* replace144_0_1_1_1 -> 404 in the cache */
   /* replace144_0_1_1 -> 405 in the cache */
   /* replace144_0_1 -> 406 in the cache */
   /* replace144_0 -> 407 in the cache */
   /* replace144_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 8,
      { 407, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search145_0 -> 16 in the cache */
   /* search145_1 -> 36 in the cache */
   /* search145_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace145_0_0_0_0_0 -> 16 in the cache */
   /* replace145_0_0_0_0_1 -> 120 in the cache */
   /* replace145_0_0_0_0 -> 374 in the cache */
   /* replace145_0_0_0_1_0 -> 36 in the cache */
   /* replace145_0_0_0_1_1 -> 120 in the cache */
   /* replace145_0_0_0_1 -> 375 in the cache */
   /* replace145_0_0_0 -> 376 in the cache */
   /* replace145_0_0_1_0_0 -> 16 in the cache */
   /* replace145_0_0_1_0_1 -> 377 in the cache */
   /* replace145_0_0_1_0 -> 378 in the cache */
   /* replace145_0_0_1_1_0 -> 36 in the cache */
   /* replace145_0_0_1_1_1 -> 377 in the cache */
   /* replace145_0_0_1_1 -> 379 in the cache */
   /* replace145_0_0_1 -> 380 in the cache */
   /* replace145_0_0 -> 381 in the cache */
   /* replace145_0_1_0_0_0 -> 16 in the cache */
   /* replace145_0_1_0_0_1 -> 382 in the cache */
   /* replace145_0_1_0_0 -> 383 in the cache */
   /* replace145_0_1_0_1_0 -> 36 in the cache */
   /* replace145_0_1_0_1_1 -> 382 in the cache */
   /* replace145_0_1_0_1 -> 384 in the cache */
   /* replace145_0_1_0 -> 385 in the cache */
   /* replace145_0_1_1_0_0 -> 16 in the cache */
   /* replace145_0_1_1_0_1 -> 386 in the cache */
   /* replace145_0_1_1_0 -> 387 in the cache */
   /* replace145_0_1_1_1_0 -> 36 in the cache */
   /* replace145_0_1_1_1_1 -> 386 in the cache */
   /* replace145_0_1_1_1 -> 388 in the cache */
   /* replace145_0_1_1 -> 389 in the cache */
   /* replace145_0_1 -> 390 in the cache */
   /* replace145_0 -> 391 in the cache */
   /* replace145_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 391, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search146_0 -> 16 in the cache */
   /* search146_1 -> 36 in the cache */
   /* search146_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* replace146_0_0_0_0_0 -> 16 in the cache */
   /* replace146_0_0_0_0_1 -> 120 in the cache */
   /* replace146_0_0_0_0 -> 374 in the cache */
   /* replace146_0_0_0_1_0 -> 36 in the cache */
   /* replace146_0_0_0_1_1 -> 120 in the cache */
   /* replace146_0_0_0_1 -> 394 in the cache */
   /* replace146_0_0_0 -> 409 in the cache */
   /* replace146_0_0_1_0_0 -> 16 in the cache */
   /* replace146_0_0_1_0_1 -> 377 in the cache */
   /* replace146_0_0_1_0 -> 378 in the cache */
   /* replace146_0_0_1_1_0 -> 36 in the cache */
   /* replace146_0_0_1_1_1 -> 377 in the cache */
   /* replace146_0_0_1_1 -> 397 in the cache */
   /* replace146_0_0_1 -> 410 in the cache */
   /* replace146_0_0 -> 411 in the cache */
   /* replace146_0_1_0_0_0 -> 16 in the cache */
   /* replace146_0_1_0_0_1 -> 382 in the cache */
   /* replace146_0_1_0_0 -> 383 in the cache */
   /* replace146_0_1_0_1_0 -> 36 in the cache */
   /* replace146_0_1_0_1_1 -> 382 in the cache */
   /* replace146_0_1_0_1 -> 401 in the cache */
   /* replace146_0_1_0 -> 412 in the cache */
   /* replace146_0_1_1_0_0 -> 16 in the cache */
   /* replace146_0_1_1_0_1 -> 386 in the cache */
   /* replace146_0_1_1_0 -> 387 in the cache */
   /* replace146_0_1_1_1_0 -> 36 in the cache */
   /* replace146_0_1_1_1_1 -> 386 in the cache */
   /* replace146_0_1_1_1 -> 404 in the cache */
   /* replace146_0_1_1 -> 413 in the cache */
   /* replace146_0_1 -> 414 in the cache */
   /* replace146_0 -> 415 in the cache */
   /* replace146_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 415, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1 -> 36 in the cache */
   /* search147_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace147_0_0_0_0 -> 16 in the cache */
   /* replace147_0_0_0_1 -> 120 in the cache */
   /* replace147_0_0_0 -> 425 in the cache */
   /* replace147_0_0_1_0 -> 36 in the cache */
   /* replace147_0_0_1_1 -> 120 in the cache */
   /* replace147_0_0_1 -> 426 in the cache */
   /* replace147_0_0 -> 427 in the cache */
   /* replace147_0_1_0_0 -> 16 in the cache */
   /* replace147_0_1_0_1 -> 377 in the cache */
   /* replace147_0_1_0 -> 428 in the cache */
   /* replace147_0_1_1_0 -> 36 in the cache */
   /* replace147_0_1_1_1 -> 377 in the cache */
   /* replace147_0_1_1 -> 429 in the cache */
   /* replace147_0_1 -> 430 in the cache */
   /* replace147_0 -> 431 in the cache */
   /* replace147_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 431, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search148_0 -> 16 in the cache */
   /* search148_1 -> 36 in the cache */
   /* search148_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace148_0_0_0_0 -> 16 in the cache */
   /* replace148_0_0_0_1 -> 120 in the cache */
   /* replace148_0_0_0 -> 417 in the cache */
   /* replace148_0_0_1_0 -> 36 in the cache */
   /* replace148_0_0_1_1 -> 120 in the cache */
   /* replace148_0_0_1 -> 418 in the cache */
   /* replace148_0_0 -> 419 in the cache */
   /* replace148_0_1_0_0 -> 16 in the cache */
   /* replace148_0_1_0_1 -> 377 in the cache */
   /* replace148_0_1_0 -> 420 in the cache */
   /* replace148_0_1_1_0 -> 36 in the cache */
   /* replace148_0_1_1_1 -> 377 in the cache */
   /* replace148_0_1_1 -> 421 in the cache */
   /* replace148_0_1 -> 422 in the cache */
   /* replace148_0 -> 423 in the cache */
   /* replace148_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 423, 133 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search149_0 -> 11 in the cache */
   /* search149_1 -> 243 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 243, 446 },
      -1,
   } },

   /* replace149_0 -> 445 in the cache */
   /* replace149_1 -> 243 in the cache */
   /* replace149_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 243, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search150_0 -> 11 in the cache */
   /* search150_1_0 -> 11 in the cache */
   /* search150_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 449, 450 },
      -1,
   } },

   /* replace150_0_0 -> 243 in the cache */
   /* replace150_0_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 243, 450 },
      -1,
   } },
   /* replace150_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 452, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search151_0_0 -> 11 in the cache */
   /* search151_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 243 },
      0,
   } },
   /* search151_1_0 -> 11 in the cache */
   /* search151_1_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 450 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 454, 455, 456 },
      -1,
   } },

   /* replace151_0_0 -> 243 in the cache */
   /* replace151_0_1 -> 450 in the cache */
   /* replace151_0_2 -> 456 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 450, 456 },
      -1,
   } },
   /* replace151_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 458, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search152_0 -> 11 in the cache */
   /* search152_1_0 -> 11 in the cache */
   /* search152_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 243 },
      0,
   } },
   /* search152_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 460, 450 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace152_0_1 -> 243 in the cache */
   /* replace152_0_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 462, 243, 450 },
      -1,
   } },
   /* replace152_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 463, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search153_0_0 -> 11 in the cache */
   /* search153_0_1_0 -> 462 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 467 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search153_1_1 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 468, 470 },
      -1,
   } },

   /* replace153_0 -> 11 in the cache */
   /* replace153_1 -> 469 in the cache */
   /* replace153_2 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 469, 465 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search154_0_0 -> 11 in the cache */
   /* search154_0_1_0_0 -> 462 in the cache */
   /* search154_0_1_0_1_0 -> 465 in the cache */
   /* search154_0_1_0_1 -> 466 in the cache */
   /* search154_0_1_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 473 },
      -1,
   } },
   /* search154_1_0 -> 469 in the cache */
   /* search154_1_1_0 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 474, 476 },
      -1,
   } },

   /* replace154_0 -> 11 in the cache */
   /* replace154_1 -> 469 in the cache */
   /* replace154_2_0 -> 465 in the cache */
   /* replace154_2 -> 475 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 469, 475 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search155_0 -> 11 in the cache */
   /* search155_1_0 -> 465 in the cache */
   /* search155_1_1_0 -> 469 in the cache */
   /* search155_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 469, 479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 465, 480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 481 },
      -1,
   } },

   /* replace155_0 -> 11 in the cache */
   /* replace155_1 -> 469 in the cache */
   /* replace155_2 -> 465 in the cache */
   /* replace155 -> 472 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search156_0_0 -> 11 in the cache */
   /* search156_0_1_0 -> 462 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 486 },
      -1,
   } },
   /* search156_1_0 -> 469 in the cache */
   /* search156_1_1_0 -> 483 in the cache */
   /* search156_1_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 487, 488 },
      -1,
   } },

   /* replace156_0 -> 483 in the cache */
   /* replace156_1 -> 469 in the cache */
   /* replace156_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 469, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search157_0 -> 11 in the cache */
   /* search157_1_0_0 -> 483 in the cache */
   /* search157_1_0 -> 484 in the cache */
   /* search157_1_1_0 -> 469 in the cache */
   /* search157_1_1_1_0 -> 11 in the cache */
   /* search157_1_1_1 -> 479 in the cache */
   /* search157_1_1 -> 480 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 484, 480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 491 },
      -1,
   } },

   /* replace157_0 -> 483 in the cache */
   /* replace157_1 -> 469 in the cache */
   /* replace157_2 -> 11 in the cache */
   /* replace157 -> 490 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search158_0 -> 11 in the cache */
   /* search158_1_0 -> 462 in the cache */
   /* search158_1_1_0_0 -> 483 in the cache */
   /* search158_1_1_0 -> 484 in the cache */
   /* search158_1_1 -> 485 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 462, 485 },
      -1,
   } },
   /* search158_2_0 -> 469 in the cache */
   /* search158_2_1_0 -> 483 in the cache */
   /* search158_2_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 469, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 11, 493, 494 },
      -1,
   } },

   /* replace158_0 -> 483 in the cache */
   /* replace158_1 -> 469 in the cache */
   /* replace158_2 -> 11 in the cache */
   /* replace158 -> 490 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search159_1_0 -> 483 in the cache */
   /* search159_1 -> 484 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 497 },
      -1,
   } },
   /* search159_2_1_0 -> 483 in the cache */
   /* search159_2_1 -> 484 in the cache */
   /* search159_2_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 498, 484, 497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 496, 484, 499 },
      -1,
   } },

   /* replace159_0 -> 483 in the cache */
   /* replace159_1 -> 496 in the cache */
   /* replace159_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 496, 497 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search160_1_0 -> 243 in the cache */
   /* search160_1_1_0 -> 497 in the cache */
   /* search160_1_1 -> 498 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 243, 498 },
      -1,
   } },
   /* search160_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 503, 504, 497 },
      -1,
   } },

   /* replace160_0 -> 502 in the cache */
   /* replace160_1 -> 243 in the cache */
   /* replace160_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 243, 497 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search161_0_0 -> 502 in the cache */
   /* search161_0 -> 503 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 507 },
      -1,
   } },
   /* search161_1_1 -> 469 in the cache */
   /* search161_1_2 -> 456 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 508, 469, 456 },
      -1,
   } },
   /* search161_2_0 -> 507 in the cache */
   /* search161_2_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 507, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 503, 509, 510 },
      -1,
   } },

   /* replace161_0 -> 502 in the cache */
   /* replace161_1 -> 456 in the cache */
   /* replace161_2_0 -> 507 in the cache */
   /* replace161_2_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 507, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 456, 512 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search162_0 -> 462 in the cache */
   /* search162_1_0_0_0 -> 462 in the cache */
   /* search162_1_0_0_1_0 -> 11 in the cache */
   /* search162_1_0_0_1 -> 479 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 479 },
      -1,
   } },
   /* search162_1_0_1_0 -> 462 in the cache */
   /* search162_1_0_1_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 462, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 514, 516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 462, 518 },
      -1,
   } },

   /* replace162_0 -> 243 in the cache */
   /* replace162_1 -> 462 in the cache */
   /* replace162_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 462, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search163_0 -> 16 in the cache */
   /* search163_1 -> 36 in the cache */
   /* search163_2_0 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 521 },
      -1,
   } },

   /* replace163_0 -> 445 in the cache */
   /* replace163_1 -> 36 in the cache */
   /* replace163_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search164_0 -> 16 in the cache */
   /* search164_1_0 -> 16 in the cache */
   /* search164_1_1 -> 36 in the cache */
   /* search164_1 -> 259 in the cache */
   /* search164_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 259, 133 },
      -1,
   } },

   /* replace164_0_0 -> 36 in the cache */
   /* replace164_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 36, 133 },
      -1,
   } },
   /* replace164_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 525, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search165_0_0 -> 16 in the cache */
   /* search165_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search165_1_0 -> 16 in the cache */
   /* search165_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 133 },
      0,
   } },
   /* search165_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 527, 528, 161 },
      -1,
   } },

   /* replace165_0_0 -> 36 in the cache */
   /* replace165_0_1 -> 133 in the cache */
   /* replace165_0_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 133, 161 },
      -1,
   } },
   /* replace165_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 530, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search166_0 -> 16 in the cache */
   /* search166_1_0 -> 16 in the cache */
   /* search166_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search166_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 532, 133 },
      -1,
   } },

   /* replace166_0_0 -> 228 in the cache */
   /* replace166_0_1 -> 36 in the cache */
   /* replace166_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 228, 36, 133 },
      -1,
   } },
   /* replace166_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 534, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search167_0_0 -> 16 in the cache */
   /* search167_0_1_0 -> 228 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 538 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search167_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 539, 541 },
      -1,
   } },

   /* replace167_0 -> 16 in the cache */
   /* replace167_1 -> 540 in the cache */
   /* replace167_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 540, 536 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search168_0_0 -> 16 in the cache */
   /* search168_0_1_0_0 -> 228 in the cache */
   /* search168_0_1_0_1_0 -> 536 in the cache */
   /* search168_0_1_0_1 -> 537 in the cache */
   /* search168_0_1_0 -> 538 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 544 },
      -1,
   } },
   /* search168_1_0 -> 540 in the cache */
   /* search168_1_1_0 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 546 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 545, 547 },
      -1,
   } },

   /* replace168_0 -> 16 in the cache */
   /* replace168_1 -> 540 in the cache */
   /* replace168_2_0 -> 536 in the cache */
   /* replace168_2 -> 546 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 540, 546 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search169_0 -> 16 in the cache */
   /* search169_1_0 -> 536 in the cache */
   /* search169_1_1_0 -> 540 in the cache */
   /* search169_1_1_1_0 -> 16 in the cache */
   /* search169_1_1_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 540, 265 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 536, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 551 },
      -1,
   } },

   /* replace169_0 -> 16 in the cache */
   /* replace169_1 -> 540 in the cache */
   /* replace169_2 -> 536 in the cache */
   /* replace169 -> 543 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search170_0_0 -> 16 in the cache */
   /* search170_0_1_0 -> 228 in the cache */
   /* search170_0_1_1_0_0 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 555 },
      -1,
   } },
   /* search170_1_0 -> 540 in the cache */
   /* search170_1_1_0 -> 483 in the cache */
   /* search170_1_1 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 556, 557 },
      -1,
   } },

   /* replace170_0 -> 483 in the cache */
   /* replace170_1 -> 540 in the cache */
   /* replace170_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 540, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search171_0 -> 16 in the cache */
   /* search171_1_0_0 -> 483 in the cache */
   /* search171_1_0 -> 553 in the cache */
   /* search171_1_1_0 -> 540 in the cache */
   /* search171_1_1_1_0 -> 16 in the cache */
   /* search171_1_1_1 -> 265 in the cache */
   /* search171_1_1 -> 550 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 553, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 560 },
      -1,
   } },

   /* replace171_0 -> 483 in the cache */
   /* replace171_1 -> 540 in the cache */
   /* replace171_2 -> 16 in the cache */
   /* replace171 -> 559 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search172_0 -> 16 in the cache */
   /* search172_1_0 -> 228 in the cache */
   /* search172_1_1_0_0 -> 483 in the cache */
   /* search172_1_1_0 -> 553 in the cache */
   /* search172_1_1 -> 554 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 228, 554 },
      -1,
   } },
   /* search172_2_0 -> 540 in the cache */
   /* search172_2_1_0 -> 483 in the cache */
   /* search172_2_1 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 540, 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 16, 562, 563 },
      -1,
   } },

   /* replace172_0 -> 483 in the cache */
   /* replace172_1 -> 540 in the cache */
   /* replace172_2 -> 16 in the cache */
   /* replace172 -> 559 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search173_0 -> 358 in the cache */
   /* search173_1_0 -> 483 in the cache */
   /* search173_1 -> 553 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 565 },
      -1,
   } },
   /* search173_2_1_0 -> 483 in the cache */
   /* search173_2_1 -> 553 in the cache */
   /* search173_2_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 566, 553, 565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 358, 553, 567 },
      -1,
   } },

   /* replace173_0 -> 483 in the cache */
   /* replace173_1 -> 358 in the cache */
   /* replace173_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 358, 565 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search174_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search174_1_0 -> 36 in the cache */
   /* search174_1_1_0 -> 565 in the cache */
   /* search174_1_1 -> 566 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 566 },
      -1,
   } },
   /* search174_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 570, 571, 565 },
      -1,
   } },

   /* replace174_0 -> 502 in the cache */
   /* replace174_1 -> 36 in the cache */
   /* replace174_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 36, 565 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search175_0_0 -> 502 in the cache */
   /* search175_0 -> 570 in the cache */
   /* search175_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 360 },
      -1,
   } },
   /* search175_1_1 -> 540 in the cache */
   /* search175_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 574, 540, 161 },
      -1,
   } },
   /* search175_2_0 -> 360 in the cache */
   /* search175_2_1 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 360, 540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 570, 575, 576 },
      -1,
   } },

   /* replace175_0 -> 502 in the cache */
   /* replace175_1 -> 161 in the cache */
   /* replace175_2_0 -> 360 in the cache */
   /* replace175_2_1 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 360, 540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 161, 578 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search176_0 -> 228 in the cache */
   /* search176_1_0_0_0 -> 228 in the cache */
   /* search176_1_0_0_1_0 -> 16 in the cache */
   /* search176_1_0_0_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 265 },
      -1,
   } },
   /* search176_1_0_1_0 -> 228 in the cache */
   /* search176_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 228, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 580, 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 583 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 228, 584 },
      -1,
   } },

   /* replace176_0 -> 36 in the cache */
   /* replace176_1 -> 228 in the cache */
   /* replace176_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 228, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search177_0 -> 21 in the cache */
   /* search177_1 -> 41 in the cache */
   /* search177_2_0 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 587 },
      -1,
   } },

   /* replace177_0 -> 445 in the cache */
   /* replace177_1 -> 41 in the cache */
   /* replace177_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search178_0 -> 21 in the cache */
   /* search178_1_0 -> 21 in the cache */
   /* search178_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 590, 591 },
      -1,
   } },

   /* replace178_0_0 -> 41 in the cache */
   /* replace178_0_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 41, 591 },
      -1,
   } },
   /* replace178_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 593, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search179_0_0 -> 21 in the cache */
   /* search179_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search179_1_0 -> 21 in the cache */
   /* search179_1_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 21, 591 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 595, 596, 597 },
      -1,
   } },

   /* replace179_0_0 -> 41 in the cache */
   /* replace179_0_1 -> 591 in the cache */
   /* replace179_0_2 -> 597 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 591, 597 },
      -1,
   } },
   /* replace179_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 599, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search180_0 -> 21 in the cache */
   /* search180_1_0 -> 21 in the cache */
   /* search180_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search180_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 601, 591 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace180_0_1 -> 41 in the cache */
   /* replace180_0_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 603, 41, 591 },
      -1,
   } },
   /* replace180_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 604, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search181_0_0 -> 21 in the cache */
   /* search181_0_1_0 -> 603 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 608 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search181_1_1 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 609, 611 },
      -1,
   } },

   /* replace181_0 -> 21 in the cache */
   /* replace181_1 -> 610 in the cache */
   /* replace181_2 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 610, 606 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search182_0_0 -> 21 in the cache */
   /* search182_0_1_0_0 -> 603 in the cache */
   /* search182_0_1_0_1_0 -> 606 in the cache */
   /* search182_0_1_0_1 -> 607 in the cache */
   /* search182_0_1_0 -> 608 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 608 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 614 },
      -1,
   } },
   /* search182_1_0 -> 610 in the cache */
   /* search182_1_1_0 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 615, 617 },
      -1,
   } },

   /* replace182_0 -> 21 in the cache */
   /* replace182_1 -> 610 in the cache */
   /* replace182_2_0 -> 606 in the cache */
   /* replace182_2 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 610, 616 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search183_0 -> 21 in the cache */
   /* search183_1_0 -> 606 in the cache */
   /* search183_1_1_0 -> 610 in the cache */
   /* search183_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 610, 620 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 606, 621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 622 },
      -1,
   } },

   /* replace183_0 -> 21 in the cache */
   /* replace183_1 -> 610 in the cache */
   /* replace183_2 -> 606 in the cache */
   /* replace183 -> 613 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search184_0_0 -> 21 in the cache */
   /* search184_0_1_0 -> 603 in the cache */
   /* search184_0_1_1_0_0 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 626 },
      -1,
   } },
   /* search184_1_0 -> 610 in the cache */
   /* search184_1_1_0 -> 483 in the cache */
   /* search184_1_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 627, 628 },
      -1,
   } },

   /* replace184_0 -> 483 in the cache */
   /* replace184_1 -> 610 in the cache */
   /* replace184_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 610, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search185_0 -> 21 in the cache */
   /* search185_1_0_0 -> 483 in the cache */
   /* search185_1_0 -> 624 in the cache */
   /* search185_1_1_0 -> 610 in the cache */
   /* search185_1_1_1_0 -> 21 in the cache */
   /* search185_1_1_1 -> 620 in the cache */
   /* search185_1_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 624, 621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 631 },
      -1,
   } },

   /* replace185_0 -> 483 in the cache */
   /* replace185_1 -> 610 in the cache */
   /* replace185_2 -> 21 in the cache */
   /* replace185 -> 630 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search186_0 -> 21 in the cache */
   /* search186_1_0 -> 603 in the cache */
   /* search186_1_1_0_0 -> 483 in the cache */
   /* search186_1_1_0 -> 624 in the cache */
   /* search186_1_1 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 603, 625 },
      -1,
   } },
   /* search186_2_0 -> 610 in the cache */
   /* search186_2_1_0 -> 483 in the cache */
   /* search186_2_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 610, 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 21, 633, 634 },
      -1,
   } },

   /* replace186_0 -> 483 in the cache */
   /* replace186_1 -> 610 in the cache */
   /* replace186_2 -> 21 in the cache */
   /* replace186 -> 630 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search187_1_0 -> 483 in the cache */
   /* search187_1 -> 624 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 637 },
      -1,
   } },
   /* search187_2_1_0 -> 483 in the cache */
   /* search187_2_1 -> 624 in the cache */
   /* search187_2_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 638, 624, 637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 636, 624, 639 },
      -1,
   } },

   /* replace187_0 -> 483 in the cache */
   /* replace187_1 -> 636 in the cache */
   /* replace187_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 636, 637 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search188_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search188_1_0 -> 41 in the cache */
   /* search188_1_1_0 -> 637 in the cache */
   /* search188_1_1 -> 638 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 638 },
      -1,
   } },
   /* search188_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 642, 643, 637 },
      -1,
   } },

   /* replace188_0 -> 502 in the cache */
   /* replace188_1 -> 41 in the cache */
   /* replace188_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 41, 637 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search189_0_0 -> 502 in the cache */
   /* search189_0 -> 642 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 646 },
      -1,
   } },
   /* search189_1_1 -> 610 in the cache */
   /* search189_1_2 -> 597 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 647, 610, 597 },
      -1,
   } },
   /* search189_2_0 -> 646 in the cache */
   /* search189_2_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 646, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 642, 648, 649 },
      -1,
   } },

   /* replace189_0 -> 502 in the cache */
   /* replace189_1 -> 597 in the cache */
   /* replace189_2_0 -> 646 in the cache */
   /* replace189_2_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 646, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 597, 651 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search190_0 -> 603 in the cache */
   /* search190_1_0_0_0 -> 603 in the cache */
   /* search190_1_0_0_1_0 -> 21 in the cache */
   /* search190_1_0_0_1 -> 620 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 620 },
      -1,
   } },
   /* search190_1_0_1_0 -> 603 in the cache */
   /* search190_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 603, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 653, 655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 656 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 603, 657 },
      -1,
   } },

   /* replace190_0 -> 41 in the cache */
   /* replace190_1 -> 603 in the cache */
   /* replace190_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 603, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search191_0_0 -> 147 in the cache */
   /* search191_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 147, 148 },
      0,
   } },
   /* search191_1_0 -> 147 in the cache */
   /* search191_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 150 },
      0,
   } },
   /* search191_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 660, 661, 151 },
      -1,
   } },

   /* replace191_0_0 -> 148 in the cache */
   /* replace191_0_1 -> 150 in the cache */
   /* replace191_0_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 148, 150, 151 },
      -1,
   } },
   /* replace191_1 -> 147 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 663, 147 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search192_0 -> 0 in the cache */
   /* search192_1 -> 241 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 241, 665 },
      -1,
   } },

   /* replace192_0_0_0 -> 0 in the cache */
   /* replace192_0_0 -> 197 in the cache */
   /* replace192_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 197, 665 },
      -1,
   } },
   /* replace192_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 667, 0 },
      -1,
   } },

   /* ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search193_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace193_0_0 -> 32 in the cache */
   /* replace193_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   /* replace193_1_0_0_0 -> 32 in the cache */
   /* replace193_1_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 103 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 671 },
      -1,
   } },
   /* replace193_2_0_0 -> 32 in the cache */
   /* replace193_2_0 -> 103 in the cache */
   /* replace193_2 -> 671 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 672, 671 },
      -1,
   } },

   /* ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5))) */
   /* search194_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace194_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 32 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 675, 676 },
      -1,
   } },
   /* replace194_1_0_0_0 -> 32 in the cache */
   /* replace194_1_0_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 32, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 678 },
      -1,
   } },
   /* replace194_1_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 679, 226 },
      -1,
   } },
   /* replace194_2_0_0 -> 32 in the cache */
   /* replace194_2_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 32, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 681 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 677, 680, 682 },
      -1,
   } },

   /* ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search195_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace195_0 -> 32 in the cache */
   /* replace195_1_0 -> 32 in the cache */
   /* replace195_1 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 32, 675 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search196_0 -> 32 in the cache */
   /* search196_1_0_0 -> 32 in the cache */
   /* search196_1_0 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 686 },
      -1,
   } },

   /* replace196_0 -> 32 in the cache */
   /* replace196 -> 684 in the cache */

   /* ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search197_0 -> 32 in the cache */
   /* search197 -> 675 in the cache */

   /* replace197_0 -> 32 in the cache */
   /* replace197_1_0 -> 32 in the cache */
   /* replace197_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 32, 684 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search198_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace198_0_0_0 -> 32 in the cache */
   /* replace198_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 690 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search199_0 -> 11 in the cache */
   /* search199_1 -> 243 in the cache */
   /* search199_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 450 },
      -1,
   } },

   /* replace199_0_0 -> 11 in the cache */
   /* replace199_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace199_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 693, 450 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search200_0 -> 16 in the cache */
   /* search200_1 -> 36 in the cache */
   /* search200_2 -> 133 in the cache */
   /* search200 -> 219 in the cache */

   /* replace200_0_0 -> 16 in the cache */
   /* replace200_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace200_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 695, 133 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search201_0 -> 21 in the cache */
   /* search201_1 -> 41 in the cache */
   /* search201_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 591 },
      -1,
   } },

   /* replace201_0_0 -> 21 in the cache */
   /* replace201_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace201_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 698, 591 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search202_0 -> 16 in the cache */
   /* search202_1 -> 36 in the cache */
   /* search202_2 -> 133 in the cache */
   /* search202 -> 373 in the cache */

   /* replace202_0_0 -> 16 in the cache */
   /* replace202_0_1 -> 36 in the cache */
   /* replace202_0 -> 132 in the cache */
   /* replace202_1 -> 133 in the cache */
   /* replace202 -> 273 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search203_0 -> 11 in the cache */
   /* search203_1 -> 243 in the cache */
   /* search203_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 450 },
      -1,
   } },

   /* replace203_0_0 -> 11 in the cache */
   /* replace203_0_1 -> 243 in the cache */
   /* replace203_0 -> 693 in the cache */
   /* replace203_1 -> 450 in the cache */
   /* replace203 -> 694 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search204_0 -> 16 in the cache */
   /* search204_1 -> 36 in the cache */
   /* search204_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace204_0_0 -> 16 in the cache */
   /* replace204_0_1 -> 36 in the cache */
   /* replace204_0 -> 695 in the cache */
   /* replace204_1 -> 133 in the cache */
   /* replace204 -> 696 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search205_0 -> 21 in the cache */
   /* search205_1 -> 41 in the cache */
   /* search205_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 591 },
      -1,
   } },

   /* replace205_0_0 -> 21 in the cache */
   /* replace205_0_1 -> 41 in the cache */
   /* replace205_0 -> 698 in the cache */
   /* replace205_1 -> 591 in the cache */
   /* replace205 -> 699 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search206_0 -> 16 in the cache */
   /* search206_1 -> 36 in the cache */
   /* search206_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace206_0_0 -> 16 in the cache */
   /* replace206_0_1 -> 36 in the cache */
   /* replace206_0 -> 132 in the cache */
   /* replace206_1 -> 133 in the cache */
   /* replace206 -> 273 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 705 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 707, 708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 706, 709 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 710, 711 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 712, 713 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace207_1_0_0_0 -> 707 in the cache */
   /* replace207_1_0_0_1 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 707, 708 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 716, 717 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 718, 719 },
      -1,
   } },
   /* replace207_2_0 -> 717 in the cache */
   /* replace207_2_1 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 717, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 715, 720, 721 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search208_0 -> 0 in the cache */
   /* search208_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace208_0_3 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 724, 725, 726, 255 },
      -1,
   } },
   /* replace208_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 727, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search209_0_0 -> 147 in the cache */
   /* search209_0_1 -> 148 in the cache */
   /* search209_0_2 -> 150 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 147, 148, 150, 729 },
      -1,
   } },
   /* search209_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 730, 151 },
      -1,
   } },

   /* replace209_0_0 -> 147 in the cache */
   /* replace209_0_1 -> 148 in the cache */
   /* replace209_0_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 147, 148, 150 },
      -1,
   } },
   /* replace209_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 732, 151 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search210_0_0 -> 0 in the cache */
   /* search210_0_1 -> 241 in the cache */
   /* search210_0_2 -> 241 in the cache */
   /* search210_0_3 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 241, 241, 241 },
      -1,
   } },
   /* search210_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 734, 3 },
      -1,
   } },

   /* replace210_0 -> 0 in the cache */
   /* replace210_1 -> 3 in the cache */
   /* replace210 -> 249 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search211_0_0 -> 124 in the cache */
   /* search211_0_1 -> 125 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search211_0_3 -> 736 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 124, 125, 736, 736 },
      -1,
   } },
   /* search211_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 737, 127 },
      -1,
   } },

   /* replace211_0_0 -> 124 in the cache */
   /* replace211_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace211_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 739, 127 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search212_0_0 -> 147 in the cache */
   /* search212_0_1 -> 148 in the cache */
   /* search212_0_2 -> 150 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 147, 148, 150, 741 },
      -1,
   } },
   /* search212_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 742, 151 },
      -1,
   } },

   /* replace212_0_0 -> 147 in the cache */
   /* replace212_0_1 -> 148 in the cache */
   /* replace212_0_2 -> 150 in the cache */
   /* replace212_0 -> 732 in the cache */
   /* replace212_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 732, 151 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search213_0_0 -> 0 in the cache */
   /* search213_0_1 -> 241 in the cache */
   /* search213_0_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 241, 241 },
      -1,
   } },
   /* search213_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 745, 3 },
      -1,
   } },

   /* replace213_0 -> 0 in the cache */
   /* replace213_1 -> 3 in the cache */
   /* replace213 -> 249 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search214_0_0 -> 124 in the cache */
   /* search214_0_1 -> 125 in the cache */
   /* search214_0_2 -> 736 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 124, 125, 736 },
      -1,
   } },
   /* search214_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 747, 127 },
      -1,
   } },

   /* replace214_0_0 -> 124 in the cache */
   /* replace214_0_1 -> 125 in the cache */
   /* replace214_0 -> 739 in the cache */
   /* replace214_1 -> 127 in the cache */
   /* replace214 -> 740 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search215_0_0 -> 0 in the cache */
   /* search215_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 241 },
      -1,
   } },
   /* search215_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 749, 3 },
      -1,
   } },

   /* replace215_0 -> 0 in the cache */
   /* replace215_1 -> 3 in the cache */
   /* replace215 -> 249 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search216_0 -> 32 in the cache */
   /* search216_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 32, 226 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 752, 753 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search217_0 -> 0 in the cache */
   /* search217_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace217_0_0 -> 0 in the cache */
   /* replace217_0_1 -> 3 in the cache */
   /* replace217_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search218_0 -> 0 in the cache */
   /* search218_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace218_0_0 -> 0 in the cache */
   /* replace218_0_1 -> 3 in the cache */
   /* replace218_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search219_0 -> 0 in the cache */
   /* search219_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace219_0_0 -> 0 in the cache */
   /* replace219_0_1 -> 3 in the cache */
   /* replace219_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search220_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace220_0 -> 752 in the cache */
   /* replace220_1 -> 753 in the cache */
   /* replace220 -> 754 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 762 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 763 },
      0,
   } },
   /* search221_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 764, 226 },
      -1,
   } },

   /* replace221_0_0 -> 226 in the cache */
   /* replace221_0_1_0 -> 32 in the cache */
   /* replace221_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 226, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 766 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search222_0_0_0 -> 124 in the cache */
   /* search222_0_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 268 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 768, 769 },
      -1,
   } },
   /* search222_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 770, 296 },
      -1,
   } },

   /* replace222_0_0 -> 124 in the cache */
   /* replace222_0_1_0 -> 125 in the cache */
   /* replace222_0_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 125, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 772 },
      -1,
   } },
   /* replace222_1_0 -> 127 in the cache */
   /* replace222_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 773, 774 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search223_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 776 },
      -1,
   } },
   /* search223_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 777, 294 },
      -1,
   } },

   /* replace223_0 -> 0 in the cache */
   /* replace223_1_0 -> 3 in the cache */
   /* replace223_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 779 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search224_0_0 -> 6 in the cache */
   /* search224_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search224_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 781, 294 },
      -1,
   } },

   /* replace224_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 783 },
      -1,
   } },
   /* replace224_0_0_1_0 -> 133 in the cache */
   /* replace224_0_0_1_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 783 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 784, 785 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 786, 787 },
      -1,
   } },
   /* replace224_1_0 -> 6 in the cache */
   /* replace224_1_1_0 -> 36 in the cache */
   /* replace224_1_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 789 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 788, 790, 791 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search225_0_0 -> 6 in the cache */
   /* search225_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search225_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 793, 294 },
      -1,
   } },

   /* replace225_0_0_0_0 -> 36 in the cache */
   /* replace225_0_0_0_1 -> 783 in the cache */
   /* replace225_0_0_0 -> 784 in the cache */
   /* replace225_0_0_1_0 -> 133 in the cache */
   /* replace225_0_0_1_1 -> 783 in the cache */
   /* replace225_0_0_1 -> 785 in the cache */
   /* replace225_0_0 -> 786 in the cache */
   /* replace225_0_1 -> 787 in the cache */
   /* replace225_0 -> 788 in the cache */
   /* replace225_1_0 -> 6 in the cache */
   /* replace225_1_1_0 -> 36 in the cache */
   /* replace225_1_1_1 -> 133 in the cache */
   /* replace225_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 789 },
      -1,
   } },
   /* replace225_2 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 788, 795, 791 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7)) */
   /* search226_0_0 -> 6 in the cache */
   /* search226_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search226_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 797, 294 },
      -1,
   } },

   /* replace226_0 -> 6 in the cache */
   /* replace226_1_0_0_0 -> 36 in the cache */
   /* replace226_1_0_0_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 783 },
      -1,
   } },
   /* replace226_1_0_1_0 -> 133 in the cache */
   /* replace226_1_0_1_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 783 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 799, 800 },
      -1,
   } },
   /* replace226_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 801, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 6, 802 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search227_0_0 -> 11 in the cache */
   /* search227_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search227_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 804, 294 },
      -1,
   } },

   /* replace227_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 806 },
      -1,
   } },
   /* replace227_0_0_1_0 -> 133 in the cache */
   /* replace227_0_0_1_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 806 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 807, 808 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 809, 810 },
      -1,
   } },
   /* replace227_1_0 -> 11 in the cache */
   /* replace227_1_1_0 -> 36 in the cache */
   /* replace227_1_1_1 -> 133 in the cache */
   /* replace227_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 789 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 811, 812, 813 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search228_0_0 -> 11 in the cache */
   /* search228_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search228_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 815, 294 },
      -1,
   } },

   /* replace228_0_0_0_0 -> 36 in the cache */
   /* replace228_0_0_0_1 -> 806 in the cache */
   /* replace228_0_0_0 -> 807 in the cache */
   /* replace228_0_0_1_0 -> 133 in the cache */
   /* replace228_0_0_1_1 -> 806 in the cache */
   /* replace228_0_0_1 -> 808 in the cache */
   /* replace228_0_0 -> 809 in the cache */
   /* replace228_0_1 -> 810 in the cache */
   /* replace228_0 -> 811 in the cache */
   /* replace228_1_0 -> 11 in the cache */
   /* replace228_1_1_0 -> 36 in the cache */
   /* replace228_1_1_1 -> 133 in the cache */
   /* replace228_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 789 },
      -1,
   } },
   /* replace228_2 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 811, 817, 813 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15)) */
   /* search229_0_0 -> 11 in the cache */
   /* search229_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search229_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 819, 294 },
      -1,
   } },

   /* replace229_0 -> 11 in the cache */
   /* replace229_1_0_0_0 -> 36 in the cache */
   /* replace229_1_0_0_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 806 },
      -1,
   } },
   /* replace229_1_0_1_0 -> 133 in the cache */
   /* replace229_1_0_1_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 806 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 821, 822 },
      -1,
   } },
   /* replace229_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 823, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 11, 824 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search230_0_0 -> 16 in the cache */
   /* search230_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search230_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 826, 294 },
      -1,
   } },

   /* replace230_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 828 },
      -1,
   } },
   /* replace230_0_0_1_0 -> 133 in the cache */
   /* replace230_0_0_1_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 829, 830 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 831, 832 },
      -1,
   } },
   /* replace230_1_0 -> 16 in the cache */
   /* replace230_1_1_0 -> 36 in the cache */
   /* replace230_1_1_1 -> 133 in the cache */
   /* replace230_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 789 },
      -1,
   } },
   /* replace230_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 833, 834, 120 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search231_0_0 -> 16 in the cache */
   /* search231_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search231_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 836, 294 },
      -1,
   } },

   /* replace231_0_0_0_0 -> 36 in the cache */
   /* replace231_0_0_0_1 -> 828 in the cache */
   /* replace231_0_0_0 -> 829 in the cache */
   /* replace231_0_0_1_0 -> 133 in the cache */
   /* replace231_0_0_1_1 -> 828 in the cache */
   /* replace231_0_0_1 -> 830 in the cache */
   /* replace231_0_0 -> 831 in the cache */
   /* replace231_0_1 -> 832 in the cache */
   /* replace231_0 -> 833 in the cache */
   /* replace231_1_0 -> 16 in the cache */
   /* replace231_1_1_0 -> 36 in the cache */
   /* replace231_1_1_1 -> 133 in the cache */
   /* replace231_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 789 },
      -1,
   } },
   /* replace231_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 833, 838, 120 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31)) */
   /* search232_0_0 -> 16 in the cache */
   /* search232_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search232_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 840, 294 },
      -1,
   } },

   /* replace232_0 -> 16 in the cache */
   /* replace232_1_0_0_0 -> 36 in the cache */
   /* replace232_1_0_0_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 828 },
      -1,
   } },
   /* replace232_1_0_1_0 -> 133 in the cache */
   /* replace232_1_0_1_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 842, 843 },
      -1,
   } },
   /* replace232_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 844, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 16, 845 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search233_0_0 -> 21 in the cache */
   /* search233_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search233_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 847, 294 },
      -1,
   } },

   /* replace233_0_0_0_0 -> 36 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 849 },
      -1,
   } },
   /* replace233_0_0_1_0 -> 133 in the cache */
   /* replace233_0_0_1_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 850, 851 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 852, 853 },
      -1,
   } },
   /* replace233_1_0 -> 21 in the cache */
   /* replace233_1_1_0 -> 36 in the cache */
   /* replace233_1_1_1 -> 133 in the cache */
   /* replace233_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 789 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 854, 855, 856 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search234_0_0 -> 21 in the cache */
   /* search234_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search234_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 858, 294 },
      -1,
   } },

   /* replace234_0_0_0_0 -> 36 in the cache */
   /* replace234_0_0_0_1 -> 849 in the cache */
   /* replace234_0_0_0 -> 850 in the cache */
   /* replace234_0_0_1_0 -> 133 in the cache */
   /* replace234_0_0_1_1 -> 849 in the cache */
   /* replace234_0_0_1 -> 851 in the cache */
   /* replace234_0_0 -> 852 in the cache */
   /* replace234_0_1 -> 853 in the cache */
   /* replace234_0 -> 854 in the cache */
   /* replace234_1_0 -> 21 in the cache */
   /* replace234_1_1_0 -> 36 in the cache */
   /* replace234_1_1_1 -> 133 in the cache */
   /* replace234_1_1 -> 789 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 789 },
      -1,
   } },
   /* replace234_2 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 854, 860, 856 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63)) */
   /* search235_0_0 -> 21 in the cache */
   /* search235_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search235_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 862, 294 },
      -1,
   } },

   /* replace235_0 -> 21 in the cache */
   /* replace235_1_0_0_0 -> 36 in the cache */
   /* replace235_1_0_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 849 },
      -1,
   } },
   /* replace235_1_0_1_0 -> 133 in the cache */
   /* replace235_1_0_1_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 864, 865 },
      -1,
   } },
   /* replace235_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 866, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 21, 867 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search236_0_0 -> 6 in the cache */
   /* search236_0_1 -> 33 in the cache */
   /* search236_0 -> 793 in the cache */
   /* search236_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 793, 36 },
      -1,
   } },

   /* replace236_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace236_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 870, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 871 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search237_0_0 -> 6 in the cache */
   /* search237_0_1 -> 33 in the cache */
   /* search237_0 -> 797 in the cache */
   /* search237_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 797, 36 },
      -1,
   } },

   /* replace237_0 -> 6 in the cache */
   /* replace237_1_0 -> 870 in the cache */
   /* replace237_1_1 -> 36 in the cache */
   /* replace237_1 -> 871 in the cache */
   /* replace237 -> 872 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search238_0_0 -> 6 in the cache */
   /* search238_0_1 -> 33 in the cache */
   /* search238_0 -> 781 in the cache */
   /* search238_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 781, 36 },
      -1,
   } },

   /* replace238_0 -> 6 in the cache */
   /* replace238_1_0 -> 870 in the cache */
   /* replace238_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 870, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 875 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search239_0_0 -> 11 in the cache */
   /* search239_0_1 -> 33 in the cache */
   /* search239_0 -> 815 in the cache */
   /* search239_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 815, 36 },
      -1,
   } },

   /* replace239_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace239_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 878, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 879 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search240_0_0 -> 11 in the cache */
   /* search240_0_1 -> 33 in the cache */
   /* search240_0 -> 819 in the cache */
   /* search240_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 819, 36 },
      -1,
   } },

   /* replace240_0 -> 11 in the cache */
   /* replace240_1_0 -> 878 in the cache */
   /* replace240_1_1 -> 36 in the cache */
   /* replace240_1 -> 879 in the cache */
   /* replace240 -> 880 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search241_0_0 -> 11 in the cache */
   /* search241_0_1 -> 33 in the cache */
   /* search241_0 -> 804 in the cache */
   /* search241_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 804, 36 },
      -1,
   } },

   /* replace241_0 -> 11 in the cache */
   /* replace241_1_0 -> 878 in the cache */
   /* replace241_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 878, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 883 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search242_0_0 -> 16 in the cache */
   /* search242_0_1 -> 33 in the cache */
   /* search242_0 -> 836 in the cache */
   /* search242_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 836, 36 },
      -1,
   } },

   /* replace242_0 -> 16 in the cache */
   /* replace242_1_0 -> 828 in the cache */
   /* replace242_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 828, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 886 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search243_0_0 -> 16 in the cache */
   /* search243_0_1 -> 33 in the cache */
   /* search243_0 -> 840 in the cache */
   /* search243_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 840, 36 },
      -1,
   } },

   /* replace243_0 -> 16 in the cache */
   /* replace243_1_0 -> 828 in the cache */
   /* replace243_1_1 -> 36 in the cache */
   /* replace243_1 -> 886 in the cache */
   /* replace243 -> 887 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search244_0_0 -> 16 in the cache */
   /* search244_0_1 -> 33 in the cache */
   /* search244_0 -> 826 in the cache */
   /* search244_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 826, 36 },
      -1,
   } },

   /* replace244_0 -> 16 in the cache */
   /* replace244_1_0 -> 828 in the cache */
   /* replace244_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 828, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 890 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search245_0_0 -> 21 in the cache */
   /* search245_0_1 -> 33 in the cache */
   /* search245_0 -> 858 in the cache */
   /* search245_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 858, 36 },
      -1,
   } },

   /* replace245_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace245_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 893, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 894 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search246_0_0 -> 21 in the cache */
   /* search246_0_1 -> 33 in the cache */
   /* search246_0 -> 862 in the cache */
   /* search246_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 862, 36 },
      -1,
   } },

   /* replace246_0 -> 21 in the cache */
   /* replace246_1_0 -> 893 in the cache */
   /* replace246_1_1 -> 36 in the cache */
   /* replace246_1 -> 894 in the cache */
   /* replace246 -> 895 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search247_0_0 -> 21 in the cache */
   /* search247_0_1 -> 33 in the cache */
   /* search247_0 -> 847 in the cache */
   /* search247_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 847, 36 },
      -1,
   } },

   /* replace247_0 -> 21 in the cache */
   /* replace247_1_0 -> 893 in the cache */
   /* replace247_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 893, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 898 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search248_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 900 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 901, 902 },
      -1,
   } },

   /* replace248_0 -> 16 in the cache */
   /* replace248_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search249_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 905 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 906, 907 },
      -1,
   } },

   /* replace249_0 -> 0 in the cache */
   /* replace249_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search250_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 910 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 911, 912 },
      -1,
   } },

   /* replace250_0_0 -> 16 in the cache */
   /* replace250_0_1 -> 912 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 912 },
      -1,
   } },
   /* replace250_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 914, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search251_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 916 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 917, 918 },
      -1,
   } },

   /* replace251_0_0 -> 16 in the cache */
   /* replace251_0_1 -> 918 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 918 },
      -1,
   } },
   /* replace251_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 920, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search252_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 922 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 923, 924 },
      -1,
   } },

   /* replace252_0_0 -> 16 in the cache */
   /* replace252_0_1 -> 924 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 924 },
      -1,
   } },
   /* replace252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 926, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search253_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 928 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 929, 930 },
      -1,
   } },

   /* replace253_0_0 -> 16 in the cache */
   /* replace253_0_1 -> 930 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 930 },
      -1,
   } },
   /* replace253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 932, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search254_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 934 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 935, 936 },
      -1,
   } },

   /* replace254_0_0 -> 16 in the cache */
   /* replace254_0_1 -> 936 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 936 },
      -1,
   } },
   /* replace254_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 938, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search255_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 940 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 941, 942 },
      -1,
   } },

   /* replace255_0_0 -> 16 in the cache */
   /* replace255_0_1 -> 942 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 942 },
      -1,
   } },
   /* replace255_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 944, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search256_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 946 },
      -1,
   } },
   /* search256_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 947, 377 },
      -1,
   } },

   /* replace256_0 -> 16 in the cache */
   /* replace256_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 377 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search257_0_0 -> 16 in the cache */
   /* search257_0_1 -> 377 in the cache */
   /* search257_0 -> 949 in the cache */
   /* search257_1 -> 912 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 949, 912 },
      -1,
   } },

   /* replace257_0 -> 16 in the cache */
   /* replace257_1 -> 377 in the cache */
   /* replace257 -> 949 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search258_0_0 -> 16 in the cache */
   /* search258_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* search258_1 -> 946 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 951, 946 },
      -1,
   } },

   /* replace258_0 -> 16 in the cache */
   /* replace258_1 -> 377 in the cache */
   /* replace258 -> 951 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search259_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 953 },
      -1,
   } },
   /* search259_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 954, 382 },
      -1,
   } },

   /* replace259_0 -> 16 in the cache */
   /* replace259_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 382 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search260_0_0 -> 16 in the cache */
   /* search260_0_1 -> 382 in the cache */
   /* search260_0 -> 956 in the cache */
   /* search260_1 -> 918 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 956, 918 },
      -1,
   } },

   /* replace260_0 -> 16 in the cache */
   /* replace260_1 -> 382 in the cache */
   /* replace260 -> 956 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search261_0_0 -> 16 in the cache */
   /* search261_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* search261_1 -> 953 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 958, 953 },
      -1,
   } },

   /* replace261_0 -> 16 in the cache */
   /* replace261_1 -> 382 in the cache */
   /* replace261 -> 958 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search262_0_0 -> 16 in the cache */
   /* search262_0_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 806 },
      -1,
   } },
   /* search262_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 960, 810 },
      -1,
   } },

   /* replace262_0 -> 16 in the cache */
   /* replace262_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 810 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search263_0_0 -> 16 in the cache */
   /* search263_0_1 -> 810 in the cache */
   /* search263_0 -> 962 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 962, 963 },
      -1,
   } },

   /* replace263_0 -> 16 in the cache */
   /* replace263_1 -> 810 in the cache */
   /* replace263 -> 962 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search264_0_0 -> 16 in the cache */
   /* search264_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 810 },
      -1,
   } },
   /* search264_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 965, 806 },
      -1,
   } },

   /* replace264_0 -> 16 in the cache */
   /* replace264_1 -> 810 in the cache */
   /* replace264 -> 965 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search265_0_0 -> 16 in the cache */
   /* search265_0_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 783 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 967, 968 },
      -1,
   } },

   /* replace265_0 -> 16 in the cache */
   /* replace265_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 968 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search266_0_0 -> 16 in the cache */
   /* search266_0_1 -> 968 in the cache */
   /* search266_0 -> 970 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 970, 971 },
      -1,
   } },

   /* replace266_0 -> 16 in the cache */
   /* replace266_1 -> 968 in the cache */
   /* replace266 -> 970 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search267_0_0 -> 16 in the cache */
   /* search267_0_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 968 },
      -1,
   } },
   /* search267_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 973, 783 },
      -1,
   } },

   /* replace267_0 -> 16 in the cache */
   /* replace267_1 -> 968 in the cache */
   /* replace267 -> 973 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search268_0_0 -> 0 in the cache */
   /* search268_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 776 },
      -1,
   } },
   /* search268_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 975, 294 },
      -1,
   } },

   /* replace268_0_0 -> 0 in the cache */
   /* replace268_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 133 },
      -1,
   } },
   /* replace268_1_0 -> 3 in the cache */
   /* replace268_1_1 -> 133 in the cache */
   /* replace268_1 -> 779 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 977, 779 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search269_0_0 -> 124 in the cache */
   /* search269_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 124, 268 },
      0,
   } },
   /* search269_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 979, 769 },
      -1,
   } },

   /* replace269_0_0 -> 124 in the cache */
   /* replace269_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace269_1_0 -> 125 in the cache */
   /* replace269_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 981, 982 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search270_0_0_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 147, 984 },
      0,
   } },
   /* search270_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 985, 150 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 986, 987 },
      -1,
   } },

   /* replace270_0_0_0 -> 147 in the cache */
   /* replace270_0_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 147, 150 },
      -1,
   } },
   /* replace270_0_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 989, 151 },
      -1,
   } },
   /* replace270_1_0 -> 148 in the cache */
   /* replace270_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 990, 991 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search271_0_0_0 -> 124 in the cache */
   /* search271_0_0_1 -> 268 in the cache */
   /* search271_0_0 -> 979 in the cache */
   /* search271_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 979, 127 },
      0,
   } },
   /* search271_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 993, 296 },
      -1,
   } },

   /* replace271_0_0_0 -> 124 in the cache */
   /* replace271_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace271_0_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 995, 161 },
      -1,
   } },
   /* replace271_1_0 -> 125 in the cache */
   /* replace271_1_1 -> 161 in the cache */
   /* replace271_1 -> 772 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 996, 772 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 998, 999 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1000 },
      -1,
   } },

   /* replace272_0 -> 0 in the cache */
   /* replace272_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search273_0_0 -> 998 in the cache */
   /* search273_0_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 998, 999 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1003 },
      -1,
   } },

   /* replace273_0 -> 0 in the cache */
   /* replace273_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search274_0_0 -> 0 in the cache */
   /* search274_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1006 },
      -1,
   } },

   /* replace274_0 -> 0 in the cache */
   /* replace274_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search275_0_0 -> 0 in the cache */
   /* search275_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1009 },
      -1,
   } },

   /* replace275_0 -> 0 in the cache */
   /* replace275_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search276_0_0 -> 0 in the cache */
   /* search276_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1012 },
      -1,
   } },

   /* replace276_0 -> 0 in the cache */
   /* replace276_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search277_0_0 -> 0 in the cache */
   /* search277_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1015 },
      -1,
   } },

   /* replace277_0 -> 0 in the cache */
   /* replace277_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search278_0_0 -> 0 in the cache */
   /* search278_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1018 },
      -1,
   } },

   /* replace278_0 -> 0 in the cache */
   /* replace278_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search279_0_0 -> 0 in the cache */
   /* search279_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1021 },
      -1,
   } },

   /* replace279_0 -> 0 in the cache */
   /* replace279_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search280_0_0 -> 0 in the cache */
   /* search280_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1024 },
      -1,
   } },

   /* replace280_0 -> 0 in the cache */
   /* replace280_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search281_0_0 -> 0 in the cache */
   /* search281_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1027 },
      -1,
   } },

   /* replace281_0 -> 0 in the cache */
   /* replace281_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search282_0_0 -> 0 in the cache */
   /* search282_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search282_1_0 -> 0 in the cache */
   /* search282_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1030, 1031 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search283_0_0 -> 0 in the cache */
   /* search283_0_1 -> 3 in the cache */
   /* search283_0 -> 1005 in the cache */
   /* search283_1_0 -> 3 in the cache */
   /* search283_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1005, 1034 },
      -1,
   } },

   /* replace283 -> 1033 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search284_0_0 -> 0 in the cache */
   /* search284_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search284_1_0 -> 0 in the cache */
   /* search284_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1036, 1037 },
      -1,
   } },

   /* replace284 -> 1033 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search285_0_0 -> 0 in the cache */
   /* search285_0_1 -> 3 in the cache */
   /* search285_0 -> 1020 in the cache */
   /* search285_1_0 -> 3 in the cache */
   /* search285_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1020, 1039 },
      -1,
   } },

   /* replace285 -> 1033 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search286_0_0 -> 0 in the cache */
   /* search286_0_1 -> 3 in the cache */
   /* search286_0 -> 1023 in the cache */
   /* search286_1_0 -> 3 in the cache */
   /* search286_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1023, 1041 },
      -1,
   } },

   /* replace286 -> 1033 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search287_0_0 -> 0 in the cache */
   /* search287_0 -> 197 in the cache */
   /* search287_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 197, 1043 },
      -1,
   } },

   /* replace287_0 -> 3 in the cache */
   /* replace287_1 -> 0 in the cache */
   /* replace287 -> 1034 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search288_0_0 -> 0 in the cache */
   /* search288_0 -> 197 in the cache */
   /* search288_1_0 -> 3 in the cache */
   /* search288_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 197, 1043 },
      -1,
   } },

   /* replace288_0 -> 3 in the cache */
   /* replace288_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search289_0_0 -> 0 in the cache */
   /* search289_0 -> 197 in the cache */
   /* search289_1_0 -> 3 in the cache */
   /* search289_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 197, 1043 },
      -1,
   } },

   /* replace289_0 -> 3 in the cache */
   /* replace289_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search290_0_0 -> 0 in the cache */
   /* search290_0 -> 197 in the cache */
   /* search290_1_0 -> 3 in the cache */
   /* search290_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 197, 1043 },
      -1,
   } },

   /* replace290_0 -> 3 in the cache */
   /* replace290_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search291_0_0 -> 32 in the cache */
   /* search291_0 -> 98 in the cache */
   /* search291_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 98, 232 },
      -1,
   } },

   /* replace291_0 -> 226 in the cache */
   /* replace291_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search292_0 -> 232 in the cache */
   /* search292_1_0 -> 32 in the cache */
   /* search292_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 232, 98 },
      -1,
   } },

   /* replace292_0 -> 32 in the cache */
   /* replace292_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search293_0_0 -> 32 in the cache */
   /* search293_0 -> 98 in the cache */
   /* search293_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 98, 232 },
      -1,
   } },

   /* replace293_0 -> 226 in the cache */
   /* replace293_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search294_0 -> 232 in the cache */
   /* search294_1_0 -> 32 in the cache */
   /* search294_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 232, 98 },
      -1,
   } },

   /* replace294_0 -> 32 in the cache */
   /* replace294_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search295_0_0 -> 32 in the cache */
   /* search295_0 -> 98 in the cache */
   /* search295_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 232 },
      -1,
   } },

   /* replace295_0 -> 226 in the cache */
   /* replace295_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 226, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search296_0 -> 232 in the cache */
   /* search296_1_0 -> 32 in the cache */
   /* search296_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 232, 98 },
      -1,
   } },

   /* replace296_0 -> 32 in the cache */
   /* replace296_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 226 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1064 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1063, 1065 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace297_1 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1067, 1064 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search298_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1069, 1070 },
      -1,
   } },

   /* replace298_0 -> 0 in the cache */
   /* replace298_1 -> 3 in the cache */
   /* replace298 -> 1002 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search299_0_0 -> 0 in the cache */
   /* search299_0 -> 1069 in the cache */
   /* search299_1 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1069, 1070 },
      -1,
   } },

   /* replace299_0 -> 0 in the cache */
   /* replace299_1 -> 3 in the cache */
   /* replace299 -> 1011 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search300_0_0 -> 0 in the cache */
   /* search300_0 -> 1069 in the cache */
   /* search300_1 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1069, 1070 },
      -1,
   } },

   /* replace300_0 -> 0 in the cache */
   /* replace300_1 -> 3 in the cache */
   /* replace300 -> 1008 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search301_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search301_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1074, 226 },
      -1,
   } },

   /* replace301_0 -> 32 in the cache */
   /* replace301_1 -> 226 in the cache */
   /* replace301 -> 1058 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search302_0 -> 113 in the cache */
   /* search302_1_0 -> 32 in the cache */
   /* search302_1 -> 1074 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 1074 },
      -1,
   } },

   /* replace302_0 -> 113 in the cache */
   /* replace302_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search303_1_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1078, 1079 },
      -1,
   } },

   /* replace303_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search304_0_0_0 -> 715 in the cache */
   /* search304_0_0 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1079 },
      -1,
   } },
   /* search304_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1082, 1078 },
      -1,
   } },

   /* replace304_0 -> 715 in the cache */
   /* replace304 -> 1081 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search305_0_0_0 -> 715 in the cache */
   /* search305_0_0 -> 1079 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1079, 1085 },
      -1,
   } },
   /* search305_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1086, 1078 },
      -1,
   } },

   /* replace305_0 -> 715 in the cache */
   /* replace305_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 715, 1084 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search306_0_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search306_0_2_0 -> 1084 in the cache */
   /* search306_0_2 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1089, 1085 },
      -1,
   } },
   /* search306_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1090, 1078 },
      -1,
   } },

   /* replace306_0 -> 715 in the cache */
   /* replace306_1 -> 1084 in the cache */
   /* replace306 -> 1088 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search307_0_0 -> 715 in the cache */
   /* search307_0 -> 1079 in the cache */
   /* search307_1_0_0 -> 1084 in the cache */
   /* search307_1_0 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1085 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1079, 1092 },
      -1,
   } },

   /* replace307_0 -> 715 in the cache */
   /* replace307_1 -> 1084 in the cache */
   /* replace307 -> 1088 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search308_0_0_0 -> 715 in the cache */
   /* search308_0_0 -> 1079 in the cache */
   /* search308_0_1_0 -> 1084 in the cache */
   /* search308_0_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1079, 1085 },
      -1,
   } },
   /* search308_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1094, 1078 },
      -1,
   } },

   /* replace308_0 -> 715 in the cache */
   /* replace308_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 715, 1084 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search309_0_0 -> 715 in the cache */
   /* search309_0_1_0 -> 1084 in the cache */
   /* search309_0_1 -> 1085 in the cache */
   /* search309_0_2 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1085, 1078 },
      -1,
   } },
   /* search309_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1097, 1078 },
      -1,
   } },

   /* replace309_0 -> 715 in the cache */
   /* replace309_1 -> 1084 in the cache */
   /* replace309 -> 1096 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search310_0_0_0 -> 715 in the cache */
   /* search310_0_0 -> 1079 in the cache */
   /* search310_0_1_0_0 -> 1084 in the cache */
   /* search310_0_1_0 -> 1085 in the cache */
   /* search310_0_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1079, 1092 },
      -1,
   } },
   /* search310_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1099, 1078 },
      -1,
   } },

   /* replace310_0 -> 715 in the cache */
   /* replace310_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 715, 1084 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search311_0_0 -> 715 in the cache */
   /* search311_0 -> 1079 in the cache */
   /* search311_1_0 -> 1084 in the cache */
   /* search311_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1079, 1085 },
      -1,
   } },

   /* replace311_0 -> 715 in the cache */
   /* replace311_1 -> 1084 in the cache */
   /* replace311 -> 1101 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search312_0_0_0 -> 715 in the cache */
   /* search312_0_0 -> 1079 in the cache */
   /* search312_0 -> 1082 in the cache */
   /* search312_1_0_0 -> 1084 in the cache */
   /* search312_1_0 -> 1085 in the cache */
   /* search312_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1082, 1092 },
      -1,
   } },

   /* replace312_0 -> 715 in the cache */
   /* replace312_1 -> 1084 in the cache */
   /* replace312 -> 1101 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search313_0_0_0 -> 715 in the cache */
   /* search313_0_0 -> 1079 in the cache */
   /* search313_0_1_0 -> 1084 in the cache */
   /* search313_0_1 -> 1085 in the cache */
   /* search313_0 -> 1086 in the cache */
   /* search313_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1086, 1078 },
      -1,
   } },

   /* replace313_0_0 -> 715 in the cache */
   /* replace313_0_1 -> 1084 in the cache */
   /* replace313_0 -> 1088 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1088 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search314_0_0 -> 715 in the cache */
   /* search314_0_1 -> 1089 in the cache */
   /* search314_0_2_0 -> 1084 in the cache */
   /* search314_0_2 -> 1085 in the cache */
   /* search314_0 -> 1090 in the cache */
   /* search314_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1090, 1078 },
      -1,
   } },

   /* replace314_0_0 -> 715 in the cache */
   /* replace314_0_1 -> 1084 in the cache */
   /* replace314_0 -> 1088 in the cache */
   /* replace314 -> 1105 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search315_0_0 -> 715 in the cache */
   /* search315_0 -> 1079 in the cache */
   /* search315_1_0_0 -> 1084 in the cache */
   /* search315_1_0 -> 1085 in the cache */
   /* search315_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1079, 1092 },
      -1,
   } },

   /* replace315_0_0 -> 715 in the cache */
   /* replace315_0_1 -> 1084 in the cache */
   /* replace315_0 -> 1088 in the cache */
   /* replace315 -> 1105 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search316_0_0_0 -> 715 in the cache */
   /* search316_0_0 -> 1079 in the cache */
   /* search316_0_1_0 -> 1084 in the cache */
   /* search316_0_1 -> 1085 in the cache */
   /* search316_0 -> 1094 in the cache */
   /* search316_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1094, 1078 },
      -1,
   } },

   /* replace316_0_0 -> 715 in the cache */
   /* replace316_0_1 -> 1084 in the cache */
   /* replace316_0 -> 1096 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1096 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search317_0_0 -> 715 in the cache */
   /* search317_0_1_0 -> 1084 in the cache */
   /* search317_0_1 -> 1085 in the cache */
   /* search317_0_2 -> 1078 in the cache */
   /* search317_0 -> 1097 in the cache */
   /* search317_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1097, 1078 },
      -1,
   } },

   /* replace317_0_0 -> 715 in the cache */
   /* replace317_0_1 -> 1084 in the cache */
   /* replace317_0 -> 1096 in the cache */
   /* replace317 -> 1109 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search318_0_0_0 -> 715 in the cache */
   /* search318_0_0 -> 1079 in the cache */
   /* search318_0_1_0_0 -> 1084 in the cache */
   /* search318_0_1_0 -> 1085 in the cache */
   /* search318_0_1 -> 1092 in the cache */
   /* search318_0 -> 1099 in the cache */
   /* search318_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1099, 1078 },
      -1,
   } },

   /* replace318_0 -> 715 in the cache */
   /* replace318_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 1084 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search319_0_0 -> 715 in the cache */
   /* search319_0 -> 1079 in the cache */
   /* search319_1_0 -> 1084 in the cache */
   /* search319_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1079, 1085 },
      -1,
   } },

   /* replace319_0 -> 715 in the cache */
   /* replace319_1 -> 1084 in the cache */
   /* replace319 -> 1112 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search320_0_0_0 -> 715 in the cache */
   /* search320_0_0 -> 1079 in the cache */
   /* search320_0 -> 1082 in the cache */
   /* search320_1_0_0 -> 1084 in the cache */
   /* search320_1_0 -> 1085 in the cache */
   /* search320_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1082, 1092 },
      -1,
   } },

   /* replace320_0 -> 715 in the cache */
   /* replace320_1 -> 1084 in the cache */
   /* replace320 -> 1112 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search321_0_0_0_0 -> 715 in the cache */
   /* search321_0_0_0 -> 1079 in the cache */
   /* search321_0_0_1_0 -> 1084 in the cache */
   /* search321_0_0_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1079, 1085 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1115 },
      -1,
   } },
   /* search321_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1116, 1078 },
      -1,
   } },

   /* replace321_0 -> 715 in the cache */
   /* replace321_1 -> 1084 in the cache */
   /* replace321 -> 1088 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search322_0 -> 1078 in the cache */
   /* search322_1_0_0 -> 715 in the cache */
   /* search322_1_0 -> 1079 in the cache */
   /* search322_1_1_0 -> 1084 in the cache */
   /* search322_1_1 -> 1085 in the cache */
   /* search322_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1078, 1115 },
      -1,
   } },

   /* replace322_0 -> 715 in the cache */
   /* replace322_1 -> 1084 in the cache */
   /* replace322 -> 1088 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search323_0_0_0_0 -> 715 in the cache */
   /* search323_0_0_0 -> 1079 in the cache */
   /* search323_0_0_1_0 -> 1084 in the cache */
   /* search323_0_0_1 -> 1085 in the cache */
   /* search323_0_0 -> 1115 in the cache */
   /* search323_0 -> 1116 in the cache */
   /* search323_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1116, 1078 },
      -1,
   } },

   /* replace323_0_0 -> 715 in the cache */
   /* replace323_0_1 -> 1084 in the cache */
   /* replace323_0 -> 1088 in the cache */
   /* replace323 -> 1105 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search324_0 -> 1078 in the cache */
   /* search324_1_0_0 -> 715 in the cache */
   /* search324_1_0 -> 1079 in the cache */
   /* search324_1_1_0 -> 1084 in the cache */
   /* search324_1_1 -> 1085 in the cache */
   /* search324_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1078, 1115 },
      -1,
   } },

   /* replace324_0_0 -> 715 in the cache */
   /* replace324_0_1 -> 1084 in the cache */
   /* replace324_0 -> 1088 in the cache */
   /* replace324 -> 1105 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search325_0 -> 32 in the cache */
   /* search325_1_0 -> 32 in the cache */
   /* search325_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace325_0 -> 32 in the cache */
   /* replace325_1 -> 113 in the cache */
   /* replace325 -> 670 in the cache */

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search326_0 -> 32 in the cache */
   /* search326_1_0 -> 32 in the cache */
   /* search326_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace326_0 -> 32 in the cache */
   /* replace326_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1125 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1126, 1128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1124, 1130 },
      -1,
   } },
   /* search327_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1131, 113 },
      -1,
   } },

   /* replace327_0_0 -> 1124 in the cache */
   /* replace327_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1124, 113 },
      -1,
   } },
   /* replace327_1_0 -> 1125 in the cache */
   /* replace327_1_1 -> 1127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1125, 1127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1133, 1134 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search328_0_0 -> 0 in the cache */
   /* search328_0_1 -> 3 in the cache */
   /* search328_0 -> 257 in the cache */
   /* search328_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 257, 0 },
      -1,
   } },

   /* replace328_0 -> 3 in the cache */
   /* replace328_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 241 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search329_0_0 -> 0 in the cache */
   /* search329_0_1 -> 3 in the cache */
   /* search329_0 -> 257 in the cache */
   /* search329_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 257, 0 },
      -1,
   } },

   /* replace329_0 -> 3 in the cache */
   /* replace329_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 241 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search330_0_0 -> 0 in the cache */
   /* search330_0_1 -> 3 in the cache */
   /* search330_0 -> 198 in the cache */
   /* search330_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 198, 0 },
      -1,
   } },

   /* replace330_0 -> 3 in the cache */
   /* replace330_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 241 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search331_0_0 -> 0 in the cache */
   /* search331_0_1 -> 3 in the cache */
   /* search331_0 -> 198 in the cache */
   /* search331_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 198, 0 },
      -1,
   } },

   /* replace331_0 -> 3 in the cache */
   /* replace331_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 241 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search332_0_0 -> 124 in the cache */
   /* search332_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 124, 268 },
      0,
   } },
   /* search332_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1144, 769 },
      -1,
   } },

   /* replace332_0 -> 124 in the cache */
   /* replace332_1_0 -> 127 in the cache */
   /* replace332_1_1_0 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 127, 1146 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1147 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search333_0_0_0 -> 124 in the cache */
   /* search333_0_0_1 -> 268 in the cache */
   /* search333_0_0 -> 1144 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1144 },
      0,
   } },
   /* search333_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1149, 769 },
      -1,
   } },

   /* replace333_0_0_0 -> 127 in the cache */
   /* replace333_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1151 },
      -1,
   } },
   /* replace333_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1152, 124 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search334_0_0 -> 124 in the cache */
   /* search334_0_1 -> 268 in the cache */
   /* search334_0 -> 1144 in the cache */
   /* search334_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1144, 769 },
      -1,
   } },

   /* replace334_0 -> 124 in the cache */
   /* replace334_1_0 -> 127 in the cache */
   /* replace334_1_1_0 -> 125 in the cache */
   /* replace334_1_1 -> 1146 in the cache */
   /* replace334_1 -> 1147 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1147 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search335_0_0_0 -> 124 in the cache */
   /* search335_0_0_1 -> 268 in the cache */
   /* search335_0_0 -> 1144 in the cache */
   /* search335_0 -> 1149 in the cache */
   /* search335_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1149, 769 },
      -1,
   } },

   /* replace335_0_0_0 -> 127 in the cache */
   /* replace335_0_0_1 -> 125 in the cache */
   /* replace335_0_0 -> 1151 in the cache */
   /* replace335_0 -> 1152 in the cache */
   /* replace335_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1152, 124 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search336_0_0 -> 124 in the cache */
   /* search336_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 268 },
      0,
   } },
   /* search336_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1158, 769 },
      -1,
   } },

   /* replace336_0 -> 124 in the cache */
   /* replace336_1_0 -> 127 in the cache */
   /* replace336_1_1_0 -> 125 in the cache */
   /* replace336_1_1 -> 1146 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 1146 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 124, 1160 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search337_0_0_0 -> 124 in the cache */
   /* search337_0_0_1 -> 268 in the cache */
   /* search337_0_0 -> 1158 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1158 },
      0,
   } },
   /* search337_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1162, 769 },
      -1,
   } },

   /* replace337_0_0_0 -> 127 in the cache */
   /* replace337_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1164 },
      -1,
   } },
   /* replace337_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1165, 124 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search338_0_0 -> 124 in the cache */
   /* search338_0_1 -> 268 in the cache */
   /* search338_0 -> 1158 in the cache */
   /* search338_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1158, 769 },
      -1,
   } },

   /* replace338_0 -> 124 in the cache */
   /* replace338_1_0 -> 127 in the cache */
   /* replace338_1_1_0 -> 125 in the cache */
   /* replace338_1_1 -> 1146 in the cache */
   /* replace338_1 -> 1160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 124, 1160 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search339_0_0_0 -> 124 in the cache */
   /* search339_0_0_1 -> 268 in the cache */
   /* search339_0_0 -> 1158 in the cache */
   /* search339_0 -> 1162 in the cache */
   /* search339_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1162, 769 },
      -1,
   } },

   /* replace339_0_0_0 -> 127 in the cache */
   /* replace339_0_0_1 -> 125 in the cache */
   /* replace339_0_0 -> 1164 in the cache */
   /* replace339_0 -> 1165 in the cache */
   /* replace339_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1165, 124 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search340_0_0 -> 0 in the cache */
   /* search340_0_1 -> 3 in the cache */
   /* search340_0 -> 193 in the cache */
   /* search340_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 193, 0 },
      -1,
   } },

   /* replace340_0 -> 3 in the cache */
   /* replace340_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search341_0_0 -> 0 in the cache */
   /* search341_0_1 -> 3 in the cache */
   /* search341_0 -> 193 in the cache */
   /* search341_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 193, 0 },
      -1,
   } },

   /* replace341_0 -> 3 in the cache */
   /* replace341_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search342_0_0 -> 715 in the cache */
   /* search342_0 -> 1079 in the cache */
   /* search342_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1079, 1078 },
      -1,
   } },

   /* replace342_0 -> 715 in the cache */
   /* replace342 -> 1081 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search343_0_0 -> 715 in the cache */
   /* search343_0 -> 1079 in the cache */
   /* search343_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1079, 1078 },
      -1,
   } },

   /* replace343 -> 715 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search344_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 715 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1177, 1178 },
      -1,
   } },

   /* replace344_0 -> 715 in the cache */
   /* replace344 -> 1081 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search345_0_0 -> 715 in the cache */
   /* search345_0 -> 1177 in the cache */
   /* search345_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1177, 1178 },
      -1,
   } },

   /* replace345 -> 715 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search346_0_0 -> 32 in the cache */
   /* search346_0 -> 104 in the cache */
   /* search346_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 104, 1078 },
      -1,
   } },

   /* replace346_0 -> 32 in the cache */
   /* replace346_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search347_0_0 -> 32 in the cache */
   /* search347_0 -> 104 in the cache */
   /* search347_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 104, 1078 },
      -1,
   } },

   /* replace347_0 -> 32 in the cache */
   /* replace347_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search348_0_0 -> 32 in the cache */
   /* search348_0 -> 104 in the cache */
   /* search348_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 104, 1078 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search349_0 -> 1078 in the cache */
   /* search349_1_0 -> 32 in the cache */
   /* search349_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1078, 104 },
      -1,
   } },

   /* replace349_0 -> 61 in the cache */
   /* replace349_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search350_0_0 -> 32 in the cache */
   /* search350_0 -> 104 in the cache */
   /* search350_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 104, 1078 },
      -1,
   } },

   /* replace350 -> 1033 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search351_0 -> 1078 in the cache */
   /* search351_1_0 -> 32 in the cache */
   /* search351_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1078, 104 },
      -1,
   } },

   /* replace351_0 -> 61 in the cache */
   /* replace351_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search352_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search352_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1192, 1078 },
      -1,
   } },

   /* replace352_0 -> 32 in the cache */
   /* replace352_1 -> 61 in the cache */
   /* replace352 -> 1182 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search353_0_0 -> 32 in the cache */
   /* search353_0 -> 1192 in the cache */
   /* search353_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1192, 1078 },
      -1,
   } },

   /* replace353_0 -> 32 in the cache */
   /* replace353_1 -> 61 in the cache */
   /* replace353 -> 1184 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search354_0_0 -> 32 in the cache */
   /* search354_0 -> 1192 in the cache */
   /* search354_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1192, 1078 },
      -1,
   } },

   /* replace354_0 -> 32 in the cache */
   /* replace354_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search355_0 -> 1078 in the cache */
   /* search355_1_0 -> 32 in the cache */
   /* search355_1 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1078, 1192 },
      -1,
   } },

   /* replace355_0 -> 61 in the cache */
   /* replace355_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search356_0_0 -> 32 in the cache */
   /* search356_0 -> 1192 in the cache */
   /* search356_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1192, 1078 },
      -1,
   } },

   /* replace356_0 -> 32 in the cache */
   /* replace356_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search357_0 -> 1078 in the cache */
   /* search357_1_0 -> 32 in the cache */
   /* search357_1 -> 1192 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1078, 1192 },
      -1,
   } },

   /* replace357_0 -> 61 in the cache */
   /* replace357_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search358_0 -> 113 in the cache */
   /* search358_1_0 -> 32 in the cache */
   /* search358_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace358_0 -> 32 in the cache */
   /* replace358_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search359_0_0_0 -> 32 in the cache */
   /* search359_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search359_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1205, 113 },
      -1,
   } },

   /* replace359_0 -> 32 in the cache */
   /* replace359_1 -> 113 in the cache */
   /* replace359 -> 1204 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search360_0 -> 113 in the cache */
   /* search360_1_0 -> 32 in the cache */
   /* search360_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace360_0 -> 32 in the cache */
   /* replace360_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search361_0_0_0 -> 32 in the cache */
   /* search361_0_0 -> 103 in the cache */
   /* search361_0 -> 1205 in the cache */
   /* search361_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1205, 113 },
      -1,
   } },

   /* replace361_0 -> 32 in the cache */
   /* replace361_1 -> 113 in the cache */
   /* replace361 -> 1208 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search362_0_0 -> 32 in the cache */
   /* search362_0_1 -> 113 in the cache */
   /* search362_0 -> 1123 in the cache */
   /* search362_1_0 -> 226 in the cache */
   /* search362_1_1 -> 32 in the cache */
   /* search362_1 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1123, 1056 },
      -1,
   } },

   /* replace362_0 -> 32 in the cache */
   /* replace362_1_0 -> 32 in the cache */
   /* replace362_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 202 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search363_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      0,
   } },
   /* search363_1_0 -> 1084 in the cache */
   /* search363_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1212, 1085 },
      -1,
   } },

   /* replace363_0_0 -> 715 in the cache */
   /* replace363_0_1 -> 1084 in the cache */
   /* replace363_0 -> 1088 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1088 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search364_0_0_0 -> 715 in the cache */
   /* search364_0_0 -> 1212 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1212 },
      0,
   } },
   /* search364_1_0_0 -> 1084 in the cache */
   /* search364_1_0 -> 1085 in the cache */
   /* search364_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1215, 1092 },
      -1,
   } },

   /* replace364_0_0_0 -> 715 in the cache */
   /* replace364_0_0_1 -> 1084 in the cache */
   /* replace364_0_0 -> 1096 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1096 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1217 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search365_0_0 -> 715 in the cache */
   /* search365_0 -> 1212 in the cache */
   /* search365_1_0 -> 1084 in the cache */
   /* search365_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1212, 1085 },
      -1,
   } },

   /* replace365_0_0 -> 715 in the cache */
   /* replace365_0_1 -> 1084 in the cache */
   /* replace365_0 -> 1096 in the cache */
   /* replace365 -> 1217 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search366_0_0_0 -> 715 in the cache */
   /* search366_0_0 -> 1212 in the cache */
   /* search366_0 -> 1215 in the cache */
   /* search366_1_0_0 -> 1084 in the cache */
   /* search366_1_0 -> 1085 in the cache */
   /* search366_1 -> 1092 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1215, 1092 },
      -1,
   } },

   /* replace366_0_0_0 -> 715 in the cache */
   /* replace366_0_0_1 -> 1084 in the cache */
   /* replace366_0_0 -> 1088 in the cache */
   /* replace366_0 -> 1214 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1214 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search367_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search367_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1222, 776 },
      -1,
   } },

   /* replace367_0 -> 715 in the cache */
   /* replace367_1_0 -> 3 in the cache */
   /* replace367_1_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3, 255 },
      -1,
   } },
   /* replace367_2_0 -> 3 in the cache */
   /* replace367_2_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 3, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 1224, 1225 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search368_0_0 -> 0 in the cache */
   /* search368_0_1_0 -> 3 in the cache */
   /* search368_0_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1043 },
      0,
   } },
   /* search368_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1227, 241 },
      -1,
   } },

   /* replace368_0 -> 0 in the cache */
   /* replace368_1 -> 3 in the cache */
   /* replace368 -> 1005 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search369_0_0_0 -> 32 in the cache */
   /* search369_0_0 -> 103 in the cache */
   /* search369_0 -> 1205 in the cache */
   /* search369_1 -> 113 in the cache */
   /* search369 -> 1209 in the cache */

   /* replace369_0 -> 32 in the cache */
   /* replace369_1 -> 113 in the cache */
   /* replace369 -> 1208 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search370_0_0 -> 1067 in the cache */
   /* search370_0_1 -> 1064 in the cache */
   /* search370_0 -> 1068 in the cache */
   /* search370_1 -> 1067 in the cache */
   /* search370_2 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1068, 1067, 1064 },
      -1,
   } },

   /* replace370_0 -> 1064 in the cache */
   /* replace370_1 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1064, 1067 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search371_0_0 -> 0 in the cache */
   /* search371_0_1 -> 3 in the cache */
   /* search371_0 -> 1005 in the cache */
   /* search371_1 -> 3 in the cache */
   /* search371_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1005, 3, 0 },
      -1,
   } },

   /* replace371_0 -> 0 in the cache */
   /* replace371_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search372_0_0 -> 0 in the cache */
   /* search372_0_1 -> 3 in the cache */
   /* search372_0 -> 1002 in the cache */
   /* search372_1 -> 3 in the cache */
   /* search372_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1002, 3, 0 },
      -1,
   } },

   /* replace372_0 -> 0 in the cache */
   /* replace372_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search373_0_0 -> 1067 in the cache */
   /* search373_0_1 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1067, 1064 },
      -1,
   } },
   /* search373_1 -> 1067 in the cache */
   /* search373_2 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1235, 1067, 1064 },
      -1,
   } },

   /* replace373_0 -> 1064 in the cache */
   /* replace373_1 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1064, 1067 },
      -1,
   } },

   /* ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c') */
   /* search374_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search374_1 -> 125 in the cache */
   /* search374_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1238, 125, 127 },
      -1,
   } },

   /* replace374_0_0 -> 32 in the cache */
   /* replace374_0_1 -> 61 in the cache */
   /* replace374_0 -> 1182 in the cache */
   /* replace374_1 -> 125 in the cache */
   /* replace374_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1182, 125, 127 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search375_0_0 -> 715 in the cache */
   /* search375_0 -> 1081 in the cache */
   /* search375_1 -> 125 in the cache */
   /* search375_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1081, 125, 127 },
      -1,
   } },

   /* replace375_0 -> 715 in the cache */
   /* replace375_1 -> 127 in the cache */
   /* replace375_2 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 127, 125 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search376_0 -> 715 in the cache */
   /* search376_1_0 -> 715 in the cache */
   /* search376_1_1 -> 148 in the cache */
   /* search376_1_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 150 },
      -1,
   } },
   /* search376_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1243, 151 },
      -1,
   } },

   /* replace376_0 -> 715 in the cache */
   /* replace376_1 -> 148 in the cache */
   /* replace376_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 151 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search377_0 -> 715 in the cache */
   /* search377_1 -> 148 in the cache */
   /* search377_2_0 -> 715 in the cache */
   /* search377_2_1 -> 150 in the cache */
   /* search377_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 1246 },
      -1,
   } },

   /* replace377_0 -> 715 in the cache */
   /* replace377_1 -> 148 in the cache */
   /* replace377_2 -> 151 in the cache */
   /* replace377 -> 1245 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search378_0 -> 715 in the cache */
   /* search378_1_0 -> 1084 in the cache */
   /* search378_1_1 -> 708 in the cache */
   /* search378_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 708, 717 },
      -1,
   } },
   /* search378_2_0 -> 1084 in the cache */
   /* search378_2_1 -> 708 in the cache */
   /* search378_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 708, 719 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1248, 1249 },
      -1,
   } },

   /* replace378_0 -> 1084 in the cache */
   /* replace378_1 -> 708 in the cache */
   /* replace378_2_0 -> 715 in the cache */
   /* replace378_2_1 -> 717 in the cache */
   /* replace378_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 717, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 708, 1251 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search379_0 -> 715 in the cache */
   /* search379_1_0 -> 1084 in the cache */
   /* search379_1_1 -> 708 in the cache */
   /* search379_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 708, 717 },
      0,
   } },
   /* search379_2_0 -> 1084 in the cache */
   /* search379_2_1 -> 708 in the cache */
   /* search379_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 708, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1253, 1254 },
      -1,
   } },

   /* replace379_0 -> 1084 in the cache */
   /* replace379_1 -> 708 in the cache */
   /* replace379_2_0 -> 715 in the cache */
   /* replace379_2_1 -> 717 in the cache */
   /* replace379_2_2 -> 719 in the cache */
   /* replace379_2 -> 1251 in the cache */
   /* replace379 -> 1252 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search380_0 -> 715 in the cache */
   /* search380_1_0 -> 1084 in the cache */
   /* search380_1_1 -> 150 in the cache */
   /* search380_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 150, 151 },
      -1,
   } },
   /* search380_2_0 -> 1084 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search380_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 1257, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1256, 1258 },
      -1,
   } },

   /* replace380_0 -> 1084 in the cache */
   /* replace380_1_0 -> 715 in the cache */
   /* replace380_1_1 -> 150 in the cache */
   /* replace380_1_2 -> 1257 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 150, 1257 },
      -1,
   } },
   /* replace380_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 1260, 151 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search381_0 -> 715 in the cache */
   /* search381_1_0 -> 1084 in the cache */
   /* search381_1_1 -> 150 in the cache */
   /* search381_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 150, 151 },
      0,
   } },
   /* search381_2_0 -> 1084 in the cache */
   /* search381_2_1 -> 1257 in the cache */
   /* search381_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1084, 1257, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1262, 1263 },
      -1,
   } },

   /* replace381_0 -> 1084 in the cache */
   /* replace381_1_0 -> 715 in the cache */
   /* replace381_1_1 -> 150 in the cache */
   /* replace381_1_2 -> 1257 in the cache */
   /* replace381_1 -> 1260 in the cache */
   /* replace381_2 -> 151 in the cache */
   /* replace381 -> 1261 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search382_0 -> 715 in the cache */
   /* search382_1 -> 1186 in the cache */
   /* search382_2 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1186, 1084 },
      -1,
   } },

   /* replace382_0 -> 715 in the cache */
   /* replace382_1 -> 1084 in the cache */
   /* replace382 -> 1088 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search383_0 -> 715 in the cache */
   /* search383_1 -> 715 in the cache */
   /* search383_2 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 715, 1084 },
      -1,
   } },

   /* replace383_0 -> 715 in the cache */
   /* replace383_1 -> 1084 in the cache */
   /* replace383 -> 1088 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search384_0 -> 715 in the cache */
   /* search384_1 -> 1084 in the cache */
   /* search384_2 -> 1033 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1084, 1033 },
      -1,
   } },

   /* replace384_0 -> 715 in the cache */
   /* replace384_1 -> 1084 in the cache */
   /* replace384 -> 1096 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search385_0 -> 715 in the cache */
   /* search385_1 -> 1084 in the cache */
   /* search385_2 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1084, 715 },
      -1,
   } },

   /* replace385_0 -> 715 in the cache */
   /* replace385_1 -> 1084 in the cache */
   /* replace385 -> 1096 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search386_0 -> 32 in the cache */
   /* search386_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace386 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search387_0 -> 32 in the cache */
   /* search387_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace387 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search388_0 -> 32 in the cache */
   /* search388_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace388 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search389_0 -> 32 in the cache */
   /* search389_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace389 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search390_0 -> 32 in the cache */
   /* search390_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace390 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search391_0 -> 32 in the cache */
   /* search391_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace391 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search392_0 -> 32 in the cache */
   /* search392_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace392 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search393_0 -> 32 in the cache */
   /* search393_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace393 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search394_0 -> 32 in the cache */
   /* search394_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace394 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search395_0 -> 32 in the cache */
   /* search395_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace395 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search396_0_0 -> 0 in the cache */
   /* search396_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search396_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1279, 3 },
      -1,
   } },

   /* replace396_0 -> 0 in the cache */
   /* replace396_1 -> 3 in the cache */
   /* replace396 -> 1232 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search397_0_0 -> 0 in the cache */
   /* search397_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1281, 3 },
      -1,
   } },

   /* replace397_0 -> 0 in the cache */
   /* replace397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search398_0_0 -> 0 in the cache */
   /* search398_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search398_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1284, 3 },
      -1,
   } },

   /* replace398_0 -> 0 in the cache */
   /* replace398_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search399_0_0 -> 0 in the cache */
   /* search399_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search399_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1287, 3 },
      -1,
   } },

   /* replace399_0 -> 0 in the cache */
   /* replace399_1 -> 3 in the cache */
   /* replace399 -> 1234 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search400_0_0 -> 0 in the cache */
   /* search400_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1289, 3 },
      -1,
   } },

   /* replace400_0 -> 0 in the cache */
   /* replace400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search401_0_0 -> 0 in the cache */
   /* search401_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search401_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1292, 3 },
      -1,
   } },

   /* replace401_0 -> 0 in the cache */
   /* replace401_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search402_0_0_0 -> 124 in the cache */
   /* search402_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search402_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1295, 127 },
      -1,
   } },
   /* search402_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1296, 124 },
      -1,
   } },

   /* replace402_0_0 -> 124 in the cache */
   /* replace402_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace402_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1298, 127 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search403_0_0_0 -> 124 in the cache */
   /* search403_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search403_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1300, 127 },
      -1,
   } },
   /* search403_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1301, 124 },
      -1,
   } },

   /* replace403_0_0 -> 124 in the cache */
   /* replace403_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace403_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1303, 127 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search404_0_0_0 -> 124 in the cache */
   /* search404_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search404_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1305, 127 },
      -1,
   } },
   /* search404_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1306, 124 },
      -1,
   } },

   /* replace404_0_0 -> 124 in the cache */
   /* replace404_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace404_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1308, 127 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search405_0_0_0 -> 124 in the cache */
   /* search405_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search405_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1310, 127 },
      -1,
   } },
   /* search405_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1311, 124 },
      -1,
   } },

   /* replace405_0_0 -> 124 in the cache */
   /* replace405_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace405_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1313, 127 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search406_0_0_0 -> 124 in the cache */
   /* search406_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search406_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1315, 127 },
      -1,
   } },
   /* search406_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1316, 124 },
      -1,
   } },

   /* replace406_0_0 -> 124 in the cache */
   /* replace406_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace406_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1318, 127 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search407_0_0_0 -> 124 in the cache */
   /* search407_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search407_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1320, 127 },
      -1,
   } },
   /* search407_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1321, 124 },
      -1,
   } },

   /* replace407_0_0 -> 124 in the cache */
   /* replace407_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace407_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1323, 127 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search408_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search408_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1325, 1326 },
      -1,
   } },

   /* replace408_0 -> 715 in the cache */
   /* replace408_1 -> 1084 in the cache */
   /* replace408 -> 1112 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search409_0_0 -> 715 in the cache */
   /* search409_0 -> 1325 in the cache */
   /* search409_1_0 -> 1084 in the cache */
   /* search409_1 -> 1326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1325, 1326 },
      -1,
   } },

   /* replace409_0 -> 715 in the cache */
   /* replace409_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 1084 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search410_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search410_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1330, 1331 },
      -1,
   } },

   /* replace410_0 -> 715 in the cache */
   /* replace410_1 -> 1084 in the cache */
   /* replace410 -> 1112 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search411_0_0 -> 715 in the cache */
   /* search411_0 -> 1330 in the cache */
   /* search411_1_0 -> 1084 in the cache */
   /* search411_1 -> 1331 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1330, 1331 },
      -1,
   } },

   /* replace411_0 -> 715 in the cache */
   /* replace411_1 -> 1084 in the cache */
   /* replace411 -> 1329 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search412_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search412_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1334, 1335 },
      -1,
   } },

   /* replace412_0 -> 715 in the cache */
   /* replace412_1 -> 1084 in the cache */
   /* replace412 -> 1112 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search413_0_0 -> 715 in the cache */
   /* search413_0 -> 1334 in the cache */
   /* search413_1_0 -> 1084 in the cache */
   /* search413_1 -> 1335 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1334, 1335 },
      -1,
   } },

   /* replace413_0 -> 715 in the cache */
   /* replace413_1 -> 1084 in the cache */
   /* replace413 -> 1329 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search414_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search414_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1338, 1339 },
      -1,
   } },

   /* replace414_0 -> 715 in the cache */
   /* replace414_1 -> 1084 in the cache */
   /* replace414 -> 1112 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search415_0_0 -> 715 in the cache */
   /* search415_0 -> 1338 in the cache */
   /* search415_1_0 -> 1084 in the cache */
   /* search415_1 -> 1339 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1338, 1339 },
      -1,
   } },

   /* replace415_0 -> 715 in the cache */
   /* replace415_1 -> 1084 in the cache */
   /* replace415 -> 1329 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search416_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search416_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1342, 1343 },
      -1,
   } },

   /* replace416_0 -> 715 in the cache */
   /* replace416_1 -> 1084 in the cache */
   /* replace416 -> 1112 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search417_0_0 -> 715 in the cache */
   /* search417_0 -> 1342 in the cache */
   /* search417_1_0 -> 1084 in the cache */
   /* search417_1 -> 1343 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1342, 1343 },
      -1,
   } },

   /* replace417_0 -> 715 in the cache */
   /* replace417_1 -> 1084 in the cache */
   /* replace417 -> 1329 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search418_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search418_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1346, 1347 },
      -1,
   } },

   /* replace418_0 -> 715 in the cache */
   /* replace418_1 -> 1084 in the cache */
   /* replace418 -> 1112 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search419_0_0 -> 715 in the cache */
   /* search419_0 -> 1346 in the cache */
   /* search419_1_0 -> 1084 in the cache */
   /* search419_1 -> 1347 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1346, 1347 },
      -1,
   } },

   /* replace419_0 -> 715 in the cache */
   /* replace419_1 -> 1084 in the cache */
   /* replace419 -> 1329 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search420_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search420_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1350, 1351 },
      -1,
   } },

   /* replace420_0 -> 715 in the cache */
   /* replace420_1 -> 1084 in the cache */
   /* replace420 -> 1112 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search421_0_0 -> 715 in the cache */
   /* search421_0 -> 1350 in the cache */
   /* search421_1_0 -> 1084 in the cache */
   /* search421_1 -> 1351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1350, 1351 },
      -1,
   } },

   /* replace421_0 -> 715 in the cache */
   /* replace421_1 -> 1084 in the cache */
   /* replace421 -> 1329 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search422_0 -> 6 in the cache */
   /* search422_1_0_0 -> 6 in the cache */
   /* search422_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 1355 },
      -1,
   } },

   /* replace422_0 -> 6 in the cache */
   /* replace422_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 6, 791 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search423_0_0 -> 6 in the cache */
   /* search423_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search423_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1358, 791 },
      -1,
   } },

   /* replace423_0 -> 6 in the cache */
   /* replace423_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 791 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search424_0_0 -> 6 in the cache */
   /* search424_0_1 -> 7 in the cache */
   /* search424_0 -> 1358 in the cache */
   /* search424_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1358, 7 },
      -1,
   } },

   /* replace424_0 -> 6 in the cache */
   /* replace424_1 -> 791 in the cache */
   /* replace424 -> 1360 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search425_0_0 -> 6 in the cache */
   /* search425_0_1 -> 7 in the cache */
   /* search425_0 -> 1358 in the cache */
   /* search425_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1358, 791 },
      -1,
   } },

   /* replace425_0 -> 6 in the cache */
   /* replace425_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 791 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search426_0_0 -> 6 in the cache */
   /* search426_0_1 -> 7 in the cache */
   /* search426_0 -> 1358 in the cache */
   /* search426_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1358, 7 },
      -1,
   } },

   /* replace426_0 -> 6 in the cache */
   /* replace426_1 -> 791 in the cache */
   /* replace426 -> 1363 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search427_0_0 -> 6 in the cache */
   /* search427_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search427_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1365, 791 },
      -1,
   } },

   /* replace427_0 -> 6 in the cache */
   /* replace427_1 -> 791 in the cache */
   /* replace427 -> 1363 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search428_0_0 -> 6 in the cache */
   /* search428_0_1 -> 9 in the cache */
   /* search428_0 -> 1365 in the cache */
   /* search428_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1365, 791 },
      -1,
   } },

   /* replace428_0 -> 6 in the cache */
   /* replace428_1 -> 791 in the cache */
   /* replace428 -> 1360 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search429_0_0 -> 6 in the cache */
   /* search429_0_1 -> 9 in the cache */
   /* search429_0 -> 1365 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1365, 1368 },
      -1,
   } },

   /* replace429_0 -> 6 in the cache */
   /* replace429_1 -> 791 in the cache */
   /* replace429 -> 1363 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search430_0_0 -> 6 in the cache */
   /* search430_0_1 -> 9 in the cache */
   /* search430_0 -> 1365 in the cache */
   /* search430_1 -> 1368 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1365, 1368 },
      -1,
   } },

   /* replace430_0 -> 6 in the cache */
   /* replace430_1 -> 791 in the cache */
   /* replace430 -> 1360 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search431_0_0 -> 6 in the cache */
   /* search431_0_1 -> 9 in the cache */
   /* search431_0 -> 1354 in the cache */
   /* search431_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1354, 791 },
      -1,
   } },

   /* replace431_0 -> 6 in the cache */
   /* replace431_1 -> 791 in the cache */
   /* replace431 -> 1363 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search432_0_0 -> 6 in the cache */
   /* search432_0_1 -> 9 in the cache */
   /* search432_0 -> 1354 in the cache */
   /* search432_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1354, 791 },
      -1,
   } },

   /* replace432_0 -> 6 in the cache */
   /* replace432_1 -> 791 in the cache */
   /* replace432 -> 1360 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search433_0_0 -> 6 in the cache */
   /* search433_0_1 -> 9 in the cache */
   /* search433_0 -> 1354 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1354, 1373 },
      -1,
   } },

   /* replace433_0 -> 6 in the cache */
   /* replace433_1 -> 791 in the cache */
   /* replace433 -> 1363 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search434_0_0 -> 6 in the cache */
   /* search434_0_1 -> 9 in the cache */
   /* search434_0 -> 1354 in the cache */
   /* search434_1 -> 1373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1354, 1373 },
      -1,
   } },

   /* replace434_0 -> 6 in the cache */
   /* replace434_1 -> 791 in the cache */
   /* replace434 -> 1360 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search435_0 -> 11 in the cache */
   /* search435_1_0_0 -> 11 in the cache */
   /* search435_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1376 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1377 },
      -1,
   } },

   /* replace435_0 -> 11 in the cache */
   /* replace435_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 11, 813 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search436_0_0 -> 11 in the cache */
   /* search436_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search436_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1380, 813 },
      -1,
   } },

   /* replace436_0 -> 11 in the cache */
   /* replace436_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 813 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search437_0_0 -> 11 in the cache */
   /* search437_0_1 -> 12 in the cache */
   /* search437_0 -> 1380 in the cache */
   /* search437_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1380, 12 },
      -1,
   } },

   /* replace437_0 -> 11 in the cache */
   /* replace437_1 -> 813 in the cache */
   /* replace437 -> 1382 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search438_0_0 -> 11 in the cache */
   /* search438_0_1 -> 12 in the cache */
   /* search438_0 -> 1380 in the cache */
   /* search438_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1380, 813 },
      -1,
   } },

   /* replace438_0 -> 11 in the cache */
   /* replace438_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 813 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search439_0_0 -> 11 in the cache */
   /* search439_0_1 -> 12 in the cache */
   /* search439_0 -> 1380 in the cache */
   /* search439_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1380, 12 },
      -1,
   } },

   /* replace439_0 -> 11 in the cache */
   /* replace439_1 -> 813 in the cache */
   /* replace439 -> 1385 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search440_0_0 -> 11 in the cache */
   /* search440_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search440_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1387, 813 },
      -1,
   } },

   /* replace440_0 -> 11 in the cache */
   /* replace440_1 -> 813 in the cache */
   /* replace440 -> 1385 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search441_0_0 -> 11 in the cache */
   /* search441_0_1 -> 14 in the cache */
   /* search441_0 -> 1387 in the cache */
   /* search441_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1387, 813 },
      -1,
   } },

   /* replace441_0 -> 11 in the cache */
   /* replace441_1 -> 813 in the cache */
   /* replace441 -> 1382 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search442_0_0 -> 11 in the cache */
   /* search442_0_1 -> 14 in the cache */
   /* search442_0 -> 1387 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1387, 1390 },
      -1,
   } },

   /* replace442_0 -> 11 in the cache */
   /* replace442_1 -> 813 in the cache */
   /* replace442 -> 1385 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search443_0_0 -> 11 in the cache */
   /* search443_0_1 -> 14 in the cache */
   /* search443_0 -> 1387 in the cache */
   /* search443_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1387, 1390 },
      -1,
   } },

   /* replace443_0 -> 11 in the cache */
   /* replace443_1 -> 813 in the cache */
   /* replace443 -> 1382 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search444_0_0 -> 11 in the cache */
   /* search444_0_1 -> 14 in the cache */
   /* search444_0 -> 1376 in the cache */
   /* search444_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1376, 813 },
      -1,
   } },

   /* replace444_0 -> 11 in the cache */
   /* replace444_1 -> 813 in the cache */
   /* replace444 -> 1385 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search445_0_0 -> 11 in the cache */
   /* search445_0_1 -> 14 in the cache */
   /* search445_0 -> 1376 in the cache */
   /* search445_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1376, 813 },
      -1,
   } },

   /* replace445_0 -> 11 in the cache */
   /* replace445_1 -> 813 in the cache */
   /* replace445 -> 1382 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search446_0_0 -> 11 in the cache */
   /* search446_0_1 -> 14 in the cache */
   /* search446_0 -> 1376 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1376, 1395 },
      -1,
   } },

   /* replace446_0 -> 11 in the cache */
   /* replace446_1 -> 813 in the cache */
   /* replace446 -> 1385 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search447_0_0 -> 11 in the cache */
   /* search447_0_1 -> 14 in the cache */
   /* search447_0 -> 1376 in the cache */
   /* search447_1 -> 1395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1376, 1395 },
      -1,
   } },

   /* replace447_0 -> 11 in the cache */
   /* replace447_1 -> 813 in the cache */
   /* replace447 -> 1382 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search448_0 -> 16 in the cache */
   /* search448_1_0_0 -> 16 in the cache */
   /* search448_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1399 },
      -1,
   } },

   /* replace448_0 -> 16 in the cache */
   /* replace448_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search449_0_0 -> 16 in the cache */
   /* search449_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search449_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1402, 120 },
      -1,
   } },

   /* replace449_0 -> 16 in the cache */
   /* replace449_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search450_0_0 -> 16 in the cache */
   /* search450_0_1 -> 17 in the cache */
   /* search450_0 -> 1402 in the cache */
   /* search450_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1402, 17 },
      -1,
   } },

   /* replace450_0 -> 16 in the cache */
   /* replace450_1 -> 120 in the cache */
   /* replace450 -> 1404 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search451_0_0 -> 16 in the cache */
   /* search451_0_1 -> 17 in the cache */
   /* search451_0 -> 1402 in the cache */
   /* search451_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1402, 120 },
      -1,
   } },

   /* replace451_0 -> 16 in the cache */
   /* replace451_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search452_0_0 -> 16 in the cache */
   /* search452_0_1 -> 17 in the cache */
   /* search452_0 -> 1402 in the cache */
   /* search452_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1402, 17 },
      -1,
   } },

   /* replace452_0 -> 16 in the cache */
   /* replace452_1 -> 120 in the cache */
   /* replace452 -> 1407 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search453_0_0 -> 16 in the cache */
   /* search453_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search453_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1409, 120 },
      -1,
   } },

   /* replace453_0 -> 16 in the cache */
   /* replace453_1 -> 120 in the cache */
   /* replace453 -> 1407 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search454_0_0 -> 16 in the cache */
   /* search454_0_1 -> 19 in the cache */
   /* search454_0 -> 1409 in the cache */
   /* search454_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1409, 120 },
      -1,
   } },

   /* replace454_0 -> 16 in the cache */
   /* replace454_1 -> 120 in the cache */
   /* replace454 -> 1404 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search455_0_0 -> 16 in the cache */
   /* search455_0_1 -> 19 in the cache */
   /* search455_0 -> 1409 in the cache */
   /* search455_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1409, 377 },
      -1,
   } },

   /* replace455_0 -> 16 in the cache */
   /* replace455_1 -> 120 in the cache */
   /* replace455 -> 1407 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search456_0_0 -> 16 in the cache */
   /* search456_0_1 -> 19 in the cache */
   /* search456_0 -> 1409 in the cache */
   /* search456_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1409, 377 },
      -1,
   } },

   /* replace456_0 -> 16 in the cache */
   /* replace456_1 -> 120 in the cache */
   /* replace456 -> 1404 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search457_0_0 -> 16 in the cache */
   /* search457_0_1 -> 19 in the cache */
   /* search457_0 -> 1398 in the cache */
   /* search457_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1398, 120 },
      -1,
   } },

   /* replace457_0 -> 16 in the cache */
   /* replace457_1 -> 120 in the cache */
   /* replace457 -> 1407 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search458_0_0 -> 16 in the cache */
   /* search458_0_1 -> 19 in the cache */
   /* search458_0 -> 1398 in the cache */
   /* search458_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1398, 120 },
      -1,
   } },

   /* replace458_0 -> 16 in the cache */
   /* replace458_1 -> 120 in the cache */
   /* replace458 -> 1404 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search459_0_0 -> 16 in the cache */
   /* search459_0_1 -> 19 in the cache */
   /* search459_0 -> 1398 in the cache */
   /* search459_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1398, 122 },
      -1,
   } },

   /* replace459_0 -> 16 in the cache */
   /* replace459_1 -> 120 in the cache */
   /* replace459 -> 1407 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search460_0_0 -> 16 in the cache */
   /* search460_0_1 -> 19 in the cache */
   /* search460_0 -> 1398 in the cache */
   /* search460_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1398, 122 },
      -1,
   } },

   /* replace460_0 -> 16 in the cache */
   /* replace460_1 -> 120 in the cache */
   /* replace460 -> 1404 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search461_0 -> 21 in the cache */
   /* search461_1_0_0 -> 21 in the cache */
   /* search461_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 1419 },
      -1,
   } },

   /* replace461_0 -> 21 in the cache */
   /* replace461_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 856 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search462_0_0 -> 21 in the cache */
   /* search462_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search462_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1422, 856 },
      -1,
   } },

   /* replace462_0 -> 21 in the cache */
   /* replace462_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 856 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search463_0_0 -> 21 in the cache */
   /* search463_0_1 -> 22 in the cache */
   /* search463_0 -> 1422 in the cache */
   /* search463_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1422, 22 },
      -1,
   } },

   /* replace463_0 -> 21 in the cache */
   /* replace463_1 -> 856 in the cache */
   /* replace463 -> 1424 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search464_0_0 -> 21 in the cache */
   /* search464_0_1 -> 22 in the cache */
   /* search464_0 -> 1422 in the cache */
   /* search464_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1422, 856 },
      -1,
   } },

   /* replace464_0 -> 21 in the cache */
   /* replace464_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 856 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search465_0_0 -> 21 in the cache */
   /* search465_0_1 -> 22 in the cache */
   /* search465_0 -> 1422 in the cache */
   /* search465_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1422, 22 },
      -1,
   } },

   /* replace465_0 -> 21 in the cache */
   /* replace465_1 -> 856 in the cache */
   /* replace465 -> 1427 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search466_0_0 -> 21 in the cache */
   /* search466_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search466_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1429, 856 },
      -1,
   } },

   /* replace466_0 -> 21 in the cache */
   /* replace466_1 -> 856 in the cache */
   /* replace466 -> 1427 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search467_0_0 -> 21 in the cache */
   /* search467_0_1 -> 24 in the cache */
   /* search467_0 -> 1429 in the cache */
   /* search467_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1429, 856 },
      -1,
   } },

   /* replace467_0 -> 21 in the cache */
   /* replace467_1 -> 856 in the cache */
   /* replace467 -> 1424 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search468_0_0 -> 21 in the cache */
   /* search468_0_1 -> 24 in the cache */
   /* search468_0 -> 1429 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1429, 1432 },
      -1,
   } },

   /* replace468_0 -> 21 in the cache */
   /* replace468_1 -> 856 in the cache */
   /* replace468 -> 1427 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search469_0_0 -> 21 in the cache */
   /* search469_0_1 -> 24 in the cache */
   /* search469_0 -> 1429 in the cache */
   /* search469_1 -> 1432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1429, 1432 },
      -1,
   } },

   /* replace469_0 -> 21 in the cache */
   /* replace469_1 -> 856 in the cache */
   /* replace469 -> 1424 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search470_0_0 -> 21 in the cache */
   /* search470_0_1 -> 24 in the cache */
   /* search470_0 -> 1418 in the cache */
   /* search470_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1418, 856 },
      -1,
   } },

   /* replace470_0 -> 21 in the cache */
   /* replace470_1 -> 856 in the cache */
   /* replace470 -> 1427 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search471_0_0 -> 21 in the cache */
   /* search471_0_1 -> 24 in the cache */
   /* search471_0 -> 1418 in the cache */
   /* search471_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1418, 856 },
      -1,
   } },

   /* replace471_0 -> 21 in the cache */
   /* replace471_1 -> 856 in the cache */
   /* replace471 -> 1424 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search472_0_0 -> 21 in the cache */
   /* search472_0_1 -> 24 in the cache */
   /* search472_0 -> 1418 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1418, 1437 },
      -1,
   } },

   /* replace472_0 -> 21 in the cache */
   /* replace472_1 -> 856 in the cache */
   /* replace472 -> 1427 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search473_0_0 -> 21 in the cache */
   /* search473_0_1 -> 24 in the cache */
   /* search473_0 -> 1418 in the cache */
   /* search473_1 -> 1437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1418, 1437 },
      -1,
   } },

   /* replace473_0 -> 21 in the cache */
   /* replace473_1 -> 856 in the cache */
   /* replace473 -> 1424 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search474_0 -> 32 in the cache */
   /* search474_1_0 -> 32 in the cache */
   /* search474_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace474_0_0 -> 32 in the cache */
   /* replace474_0 -> 103 in the cache */
   /* replace474 -> 1205 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search475_0 -> 32 in the cache */
   /* search475_1_0 -> 32 in the cache */
   /* search475_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace475_0_0 -> 32 in the cache */
   /* replace475_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search476_0 -> 32 in the cache */
   /* search476_1_0_0 -> 32 in the cache */
   /* search476_1_0 -> 103 in the cache */
   /* search476_1 -> 1205 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 1205 },
      -1,
   } },

   /* replace476_0_0 -> 32 in the cache */
   /* replace476_0 -> 103 in the cache */
   /* replace476 -> 1205 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search477_0 -> 32 in the cache */
   /* search477_1_0_0 -> 32 in the cache */
   /* search477_1_0 -> 106 in the cache */
   /* search477_1 -> 1442 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 1442 },
      -1,
   } },

   /* replace477_0_0 -> 32 in the cache */
   /* replace477_0 -> 106 in the cache */
   /* replace477 -> 1442 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search478_0 -> 32 in the cache */
   /* search478_1_0 -> 32 in the cache */
   /* search478_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace478 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search479_0 -> 32 in the cache */
   /* search479_1_0 -> 32 in the cache */
   /* search479_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace479 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search480_0 -> 32 in the cache */
   /* search480_1_0_0 -> 32 in the cache */
   /* search480_1_0 -> 103 in the cache */
   /* search480_1 -> 1205 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 1205 },
      -1,
   } },

   /* replace480 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search481_0 -> 32 in the cache */
   /* search481_1_0_0 -> 32 in the cache */
   /* search481_1_0 -> 106 in the cache */
   /* search481_1 -> 1442 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 1442 },
      -1,
   } },

   /* replace481 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search482_0 -> 32 in the cache */
   /* search482_1_0 -> 32 in the cache */
   /* search482_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace482_0 -> 32 in the cache */
   /* replace482 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search483_0 -> 32 in the cache */
   /* search483_1_0 -> 32 in the cache */
   /* search483_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace483_0 -> 32 in the cache */
   /* replace483 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search484_0 -> 32 in the cache */
   /* search484_1_0 -> 32 in the cache */
   /* search484_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace484_0 -> 32 in the cache */
   /* replace484 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search485_0 -> 32 in the cache */
   /* search485_1_0 -> 32 in the cache */
   /* search485_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace485_0 -> 32 in the cache */
   /* replace485 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search486_0_0 -> 32 in the cache */
   /* search486_0 -> 103 in the cache */
   /* search486_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 103, 113 },
      -1,
   } },

   /* replace486_0 -> 32 in the cache */
   /* replace486 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search487_0_0 -> 32 in the cache */
   /* search487_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search487_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1454, 226 },
      -1,
   } },

   /* replace487_0 -> 32 in the cache */
   /* replace487 -> 202 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search488_0_0 -> 32 in the cache */
   /* search488_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 226 },
      -1,
   } },
   /* search488_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1456, 113 },
      -1,
   } },

   /* replace488_0 -> 32 in the cache */
   /* replace488 -> 202 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search489_0_0 -> 32 in the cache */
   /* search489_0_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 232 },
      -1,
   } },
   /* search489_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1458, 113 },
      -1,
   } },

   /* replace489_0_0_0 -> 32 in the cache */
   /* replace489_0_0 -> 98 in the cache */
   /* replace489_0 -> 203 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 203 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search490_0_0 -> 32 in the cache */
   /* search490_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search490_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1461, 232 },
      -1,
   } },

   /* replace490_0_0_0 -> 32 in the cache */
   /* replace490_0_0 -> 98 in the cache */
   /* replace490_0 -> 203 in the cache */
   /* replace490 -> 1460 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search491_0_0 -> 32 in the cache */
   /* search491_0 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 235 },
      -1,
   } },

   /* replace491_0_0 -> 113 in the cache */
   /* replace491_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1464 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search492_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1466 },
      -1,
   } },

   /* replace492_0 -> 32 in the cache */
   /* replace492 -> 1466 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search493_0 -> 32 in the cache */
   /* search493 -> 202 in the cache */

   /* replace493_0_0 -> 32 in the cache */
   /* replace493_0_1 -> 113 in the cache */
   /* replace493_0 -> 1454 in the cache */
   /* replace493_1 -> 226 in the cache */
   /* replace493 -> 1455 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search494_0_0 -> 32 in the cache */
   /* search494_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 202 },
      -1,
   } },

   /* replace494_0 -> 32 in the cache */
   /* replace494 -> 202 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search495_0_0_0 -> 0 in the cache */
   /* search495_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1469 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1470 },
      -1,
   } },

   /* replace495_0_0_0 -> 0 in the cache */
   /* replace495_0_0 -> 197 in the cache */
   /* replace495_0_1_0 -> 3 in the cache */
   /* replace495_0_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 197, 1043 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1472 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search496_0_0_0 -> 0 in the cache */
   /* search496_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1474 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1475 },
      -1,
   } },

   /* replace496_0_0_0 -> 0 in the cache */
   /* replace496_0_0 -> 197 in the cache */
   /* replace496_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 197, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1477 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search497_0_0_0 -> 16 in the cache */
   /* search497_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1479 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1480 },
      -1,
   } },

   /* replace497_0_0_0 -> 16 in the cache */
   /* replace497_0_0 -> 265 in the cache */
   /* replace497_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 265, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1482 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search498_0_0_0 -> 0 in the cache */
   /* search498_0_0_1 -> 3 in the cache */
   /* search498_0_0 -> 1474 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1474 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1484 },
      -1,
   } },

   /* replace498_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace498_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1486, 1487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1488 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search499_0_0_0_0 -> 124 in the cache */
   /* search499_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search499_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1490, 127 },
      -1,
   } },
   /* search499_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1491, 125 },
      -1,
   } },
   /* search499_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1492, 127 },
      -1,
   } },

   /* replace499_0_0 -> 124 in the cache */
   /* replace499_0_1 -> 125 in the cache */
   /* replace499_0 -> 1298 in the cache */
   /* replace499_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1298, 127 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search500_0_0_0_0 -> 124 in the cache */
   /* search500_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search500_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1495, 127 },
      -1,
   } },
   /* search500_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1496, 125 },
      -1,
   } },
   /* search500_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1497, 127 },
      -1,
   } },

   /* replace500_0_0 -> 124 in the cache */
   /* replace500_0_1 -> 125 in the cache */
   /* replace500_0 -> 1308 in the cache */
   /* replace500_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1308, 127 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search501_0_0_0_0 -> 124 in the cache */
   /* search501_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search501_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1500, 127 },
      -1,
   } },
   /* search501_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1501, 125 },
      -1,
   } },
   /* search501_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1502, 127 },
      -1,
   } },

   /* replace501_0_0 -> 124 in the cache */
   /* replace501_0_1 -> 125 in the cache */
   /* replace501_0 -> 1303 in the cache */
   /* replace501_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1303, 127 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search502_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1505, 1506 },
      -1,
   } },

   /* replace502_0_0 -> 0 in the cache */
   /* replace502_0_1 -> 3 in the cache */
   /* replace502_0 -> 1232 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1232 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search503_0_0 -> 0 in the cache */
   /* search503_0 -> 1505 in the cache */
   /* search503_1 -> 1506 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1505, 1506 },
      -1,
   } },

   /* replace503_0_0 -> 0 in the cache */
   /* replace503_0_1 -> 3 in the cache */
   /* replace503_0 -> 1234 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1234 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search504_0_0_0 -> 1067 in the cache */
   /* search504_0_0_1 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1067, 1064 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1511 },
      -1,
   } },
   /* search504_1 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1512, 1067 },
      -1,
   } },

   /* replace504_0_0 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1067 },
      -1,
   } },
   /* replace504_1_0 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1064 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1514, 1515 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search505_0_0_0 -> 1067 in the cache */
   /* search505_0_0_1 -> 1064 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1067, 1064 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1517 },
      -1,
   } },
   /* search505_1 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1518, 1067 },
      -1,
   } },

   /* replace505_0_0_0 -> 1067 in the cache */
   /* replace505_0_0 -> 1514 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1514 },
      -1,
   } },
   /* replace505_1_0 -> 1064 in the cache */
   /* replace505_1 -> 1515 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1520, 1515 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1522 },
      -1,
   } },
   /* search506_0_1 -> 1506 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1523, 1506 },
      0,
   } },
   /* search506_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1524, 241 },
      -1,
   } },

   /* replace506_0_0_0 -> 0 in the cache */
   /* replace506_0_0 -> 197 in the cache */
   /* replace506_0_1 -> 3 in the cache */
   /* replace506_0 -> 262 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 262 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search507_0_0_0 -> 32 in the cache */
   /* search507_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1527, 1528 },
      -1,
   } },
   /* search507_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1529, 61 },
      -1,
   } },

   /* replace507_0_0 -> 32 in the cache */
   /* replace507_0_1 -> 61 in the cache */
   /* replace507_0 -> 1527 in the cache */
   /* replace507_1 -> 1528 in the cache */
   /* replace507 -> 1529 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search508_0_0 -> 124 in the cache */
   /* search508_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search508_1_0 -> 124 in the cache */
   /* search508_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1531, 1532 },
      -1,
   } },

   /* replace508_0 -> 124 in the cache */
   /* replace508_1_0 -> 125 in the cache */
   /* replace508_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1534 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search509_0_0 -> 0 in the cache */
   /* search509_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 665 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search509_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1537, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1536, 1538 },
      -1,
   } },

   /* replace509_0_0 -> 0 in the cache */
   /* replace509_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace509_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1540, 665 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search510_0_0 -> 124 in the cache */
   /* search510_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search510_1_0 -> 124 in the cache */
   /* search510_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1542, 1543 },
      -1,
   } },

   /* replace510_0 -> 124 in the cache */
   /* replace510_1_0 -> 125 in the cache */
   /* replace510_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1545 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search511_0_0 -> 0 in the cache */
   /* search511_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search511_1_0 -> 1537 in the cache */
   /* search511_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1537, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1547, 1548 },
      -1,
   } },

   /* replace511_0_0 -> 0 in the cache */
   /* replace511_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace511_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1550, 665 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search512_0_0 -> 124 in the cache */
   /* search512_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 268 },
      -1,
   } },
   /* search512_1_0 -> 124 in the cache */
   /* search512_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1552, 1553 },
      -1,
   } },

   /* replace512_0 -> 124 in the cache */
   /* replace512_1_0 -> 125 in the cache */
   /* replace512_1_1 -> 127 in the cache */
   /* replace512_1 -> 1534 in the cache */
   /* replace512 -> 1535 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search513_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1555, 665 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search513_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1557, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1556, 1558 },
      -1,
   } },

   /* replace513_0_0 -> 0 in the cache */
   /* replace513_0_1 -> 1537 in the cache */
   /* replace513_0 -> 1540 in the cache */
   /* replace513_1 -> 665 in the cache */
   /* replace513 -> 1541 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search514_0_0 -> 124 in the cache */
   /* search514_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 268 },
      -1,
   } },
   /* search514_1_0 -> 124 in the cache */
   /* search514_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1560, 1561 },
      -1,
   } },

   /* replace514_0 -> 124 in the cache */
   /* replace514_1_0 -> 125 in the cache */
   /* replace514_1_1 -> 127 in the cache */
   /* replace514_1 -> 1545 in the cache */
   /* replace514 -> 1546 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search515_0_0 -> 1555 in the cache */
   /* search515_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1555, 665 },
      -1,
   } },
   /* search515_1_0 -> 1557 in the cache */
   /* search515_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1557, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1563, 1564 },
      -1,
   } },

   /* replace515_0_0 -> 0 in the cache */
   /* replace515_0_1 -> 1537 in the cache */
   /* replace515_0 -> 1550 in the cache */
   /* replace515_1 -> 665 in the cache */
   /* replace515 -> 1551 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search516_0_0 -> 124 in the cache */
   /* search516_0_1 -> 125 in the cache */
   /* search516_0 -> 1531 in the cache */
   /* search516_1_0 -> 124 in the cache */
   /* search516_1_1 -> 127 in the cache */
   /* search516_1 -> 1532 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1531, 1532 },
      -1,
   } },

   /* replace516_0 -> 124 in the cache */
   /* replace516_1_0 -> 125 in the cache */
   /* replace516_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1567 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search517_0_0 -> 0 in the cache */
   /* search517_0_1 -> 665 in the cache */
   /* search517_0 -> 1536 in the cache */
   /* search517_1_0 -> 1537 in the cache */
   /* search517_1_1 -> 665 in the cache */
   /* search517_1 -> 1538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1536, 1538 },
      -1,
   } },

   /* replace517_0_0 -> 0 in the cache */
   /* replace517_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace517_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1570, 665 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search518_0_0 -> 124 in the cache */
   /* search518_0_1 -> 125 in the cache */
   /* search518_0 -> 1542 in the cache */
   /* search518_1_0 -> 124 in the cache */
   /* search518_1_1 -> 127 in the cache */
   /* search518_1 -> 1543 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1542, 1543 },
      -1,
   } },

   /* replace518_0 -> 124 in the cache */
   /* replace518_1_0 -> 125 in the cache */
   /* replace518_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1573 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search519_0_0 -> 0 in the cache */
   /* search519_0_1 -> 665 in the cache */
   /* search519_0 -> 1547 in the cache */
   /* search519_1_0 -> 1537 in the cache */
   /* search519_1_1 -> 665 in the cache */
   /* search519_1 -> 1548 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1547, 1548 },
      -1,
   } },

   /* replace519_0_0 -> 0 in the cache */
   /* replace519_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace519_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1576, 665 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search520_0_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 1578 },
      -1,
   } },
   /* search520_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 1580 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1579, 1581 },
      -1,
   } },

   /* replace520_0 -> 124 in the cache */
   /* replace520_1_0 -> 125 in the cache */
   /* replace520_1_1 -> 127 in the cache */
   /* replace520_1 -> 1567 in the cache */
   /* replace520 -> 1568 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search521_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1583, 665 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search521_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1585, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1584, 1586 },
      -1,
   } },

   /* replace521_0_0 -> 0 in the cache */
   /* replace521_0_1 -> 1537 in the cache */
   /* replace521_0 -> 1570 in the cache */
   /* replace521_1 -> 665 in the cache */
   /* replace521 -> 1571 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search522_0_0 -> 124 in the cache */
   /* search522_0_1 -> 1578 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 1578 },
      -1,
   } },
   /* search522_1_0 -> 124 in the cache */
   /* search522_1_1 -> 1580 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 1580 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1588, 1589 },
      -1,
   } },

   /* replace522_0 -> 124 in the cache */
   /* replace522_1_0 -> 125 in the cache */
   /* replace522_1_1 -> 127 in the cache */
   /* replace522_1 -> 1573 in the cache */
   /* replace522 -> 1574 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search523_0_0 -> 1583 in the cache */
   /* search523_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1583, 665 },
      -1,
   } },
   /* search523_1_0 -> 1585 in the cache */
   /* search523_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1585, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1591, 1592 },
      -1,
   } },

   /* replace523_0_0 -> 0 in the cache */
   /* replace523_0_1 -> 1537 in the cache */
   /* replace523_0 -> 1576 in the cache */
   /* replace523_1 -> 665 in the cache */
   /* replace523 -> 1577 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search524_0_0 -> 124 in the cache */
   /* search524_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search524_1_0 -> 124 in the cache */
   /* search524_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1594, 1595 },
      -1,
   } },

   /* replace524_0 -> 124 in the cache */
   /* replace524_1_0 -> 125 in the cache */
   /* replace524_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 124, 1597 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search525_0_0 -> 0 in the cache */
   /* search525_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search525_1_0 -> 1537 in the cache */
   /* search525_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1537, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1599, 1600 },
      -1,
   } },

   /* replace525_0_0 -> 0 in the cache */
   /* replace525_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace525_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1602, 665 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search526_0_0 -> 124 in the cache */
   /* search526_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search526_1_0 -> 124 in the cache */
   /* search526_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1604, 1605 },
      -1,
   } },

   /* replace526_0 -> 124 in the cache */
   /* replace526_1_0 -> 125 in the cache */
   /* replace526_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 124, 1607 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search527_0_0 -> 0 in the cache */
   /* search527_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search527_1_0 -> 1537 in the cache */
   /* search527_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1537, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1609, 1610 },
      -1,
   } },

   /* replace527_0_0 -> 0 in the cache */
   /* replace527_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace527_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1612, 665 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search528_0_0 -> 124 in the cache */
   /* search528_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search528_1_0 -> 124 in the cache */
   /* search528_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1614, 1615 },
      -1,
   } },

   /* replace528_0 -> 124 in the cache */
   /* replace528_1_0 -> 125 in the cache */
   /* replace528_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 124, 1617 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search529_0_0 -> 0 in the cache */
   /* search529_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search529_1_0 -> 1537 in the cache */
   /* search529_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1537, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1619, 1620 },
      -1,
   } },

   /* replace529_0_0 -> 0 in the cache */
   /* replace529_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace529_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1622, 665 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search530_0_0 -> 124 in the cache */
   /* search530_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search530_1_0 -> 124 in the cache */
   /* search530_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1624, 1625 },
      -1,
   } },

   /* replace530_0 -> 124 in the cache */
   /* replace530_1_0 -> 125 in the cache */
   /* replace530_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 124, 1627 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search531_0_0 -> 0 in the cache */
   /* search531_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search531_1_0 -> 1537 in the cache */
   /* search531_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1537, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1629, 1630 },
      -1,
   } },

   /* replace531_0_0 -> 0 in the cache */
   /* replace531_0_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1537 },
      -1,
   } },
   /* replace531_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1632, 665 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search532_0_0 -> 124 in the cache */
   /* search532_0_1 -> 125 in the cache */
   /* search532_0 -> 1594 in the cache */
   /* search532_1_0 -> 124 in the cache */
   /* search532_1_1 -> 127 in the cache */
   /* search532_1 -> 1595 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1594, 1595 },
      -1,
   } },

   /* replace532_0 -> 124 in the cache */
   /* replace532_1_0 -> 125 in the cache */
   /* replace532_1_1 -> 127 in the cache */
   /* replace532_1 -> 1607 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 124, 1607 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search533_0_0 -> 0 in the cache */
   /* search533_0_1 -> 665 in the cache */
   /* search533_0 -> 1599 in the cache */
   /* search533_1_0 -> 1537 in the cache */
   /* search533_1_1 -> 665 in the cache */
   /* search533_1 -> 1600 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1599, 1600 },
      -1,
   } },

   /* replace533_0_0 -> 0 in the cache */
   /* replace533_0_1 -> 1537 in the cache */
   /* replace533_0 -> 1612 in the cache */
   /* replace533_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1612, 665 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search534_0_0 -> 124 in the cache */
   /* search534_0_1 -> 125 in the cache */
   /* search534_0 -> 1604 in the cache */
   /* search534_1_0 -> 124 in the cache */
   /* search534_1_1 -> 127 in the cache */
   /* search534_1 -> 1605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1604, 1605 },
      -1,
   } },

   /* replace534_0 -> 124 in the cache */
   /* replace534_1_0 -> 125 in the cache */
   /* replace534_1_1 -> 127 in the cache */
   /* replace534_1 -> 1597 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 124, 1597 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search535_0_0 -> 0 in the cache */
   /* search535_0_1 -> 665 in the cache */
   /* search535_0 -> 1609 in the cache */
   /* search535_1_0 -> 1537 in the cache */
   /* search535_1_1 -> 665 in the cache */
   /* search535_1 -> 1610 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1609, 1610 },
      -1,
   } },

   /* replace535_0_0 -> 0 in the cache */
   /* replace535_0_1 -> 1537 in the cache */
   /* replace535_0 -> 1602 in the cache */
   /* replace535_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1602, 665 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search536_0_0 -> 124 in the cache */
   /* search536_0_1 -> 125 in the cache */
   /* search536_0 -> 1614 in the cache */
   /* search536_1_0 -> 124 in the cache */
   /* search536_1_1 -> 127 in the cache */
   /* search536_1 -> 1615 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1614, 1615 },
      -1,
   } },

   /* replace536_0 -> 124 in the cache */
   /* replace536_1_0 -> 125 in the cache */
   /* replace536_1_1 -> 127 in the cache */
   /* replace536_1 -> 1627 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 124, 1627 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search537_0_0 -> 0 in the cache */
   /* search537_0_1 -> 665 in the cache */
   /* search537_0 -> 1619 in the cache */
   /* search537_1_0 -> 1537 in the cache */
   /* search537_1_1 -> 665 in the cache */
   /* search537_1 -> 1620 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1619, 1620 },
      -1,
   } },

   /* replace537_0_0 -> 0 in the cache */
   /* replace537_0_1 -> 1537 in the cache */
   /* replace537_0 -> 1632 in the cache */
   /* replace537_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1632, 665 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search538_0_0 -> 124 in the cache */
   /* search538_0_1 -> 125 in the cache */
   /* search538_0 -> 1624 in the cache */
   /* search538_1_0 -> 124 in the cache */
   /* search538_1_1 -> 127 in the cache */
   /* search538_1 -> 1625 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1624, 1625 },
      -1,
   } },

   /* replace538_0 -> 124 in the cache */
   /* replace538_1_0 -> 125 in the cache */
   /* replace538_1_1 -> 127 in the cache */
   /* replace538_1 -> 1617 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 124, 1617 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search539_0_0 -> 0 in the cache */
   /* search539_0_1 -> 665 in the cache */
   /* search539_0 -> 1629 in the cache */
   /* search539_1_0 -> 1537 in the cache */
   /* search539_1_1 -> 665 in the cache */
   /* search539_1 -> 1630 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1629, 1630 },
      -1,
   } },

   /* replace539_0_0 -> 0 in the cache */
   /* replace539_0_1 -> 1537 in the cache */
   /* replace539_0 -> 1622 in the cache */
   /* replace539_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1622, 665 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search540_0_0_0 -> 0 in the cache */
   /* search540_0_0_1 -> 665 in the cache */
   /* search540_0_0 -> 1536 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1536, 1650 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search540_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1652, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1651, 1653 },
      -1,
   } },

   /* replace540_0_0_0 -> 0 in the cache */
   /* replace540_0_0_1 -> 1652 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1652 },
      -1,
   } },
   /* replace540_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1655, 665 },
      -1,
   } },
   /* replace540_1 -> 1650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1656, 1650 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search541_0_0_0 -> 0 in the cache */
   /* search541_0_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 665 },
      -1,
   } },
   /* search541_0_1 -> 1650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1658, 1650 },
      0,
   } },
   /* search541_1_0 -> 1652 in the cache */
   /* search541_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1652, 665 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1659, 1660 },
      -1,
   } },

   /* replace541_0_0_0 -> 0 in the cache */
   /* replace541_0_0_1 -> 1652 in the cache */
   /* replace541_0_0 -> 1655 in the cache */
   /* replace541_0_1 -> 665 in the cache */
   /* replace541_0 -> 1656 in the cache */
   /* replace541_1 -> 1650 in the cache */
   /* replace541 -> 1657 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search542_0_0_0 -> 147 in the cache */
   /* search542_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 148 },
      0,
   } },
   /* search542_0_1 -> 1650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1662, 1650 },
      0,
   } },
   /* search542_1_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1663, 1665 },
      -1,
   } },

   /* replace542_0_0 -> 147 in the cache */
   /* replace542_0_1_0 -> 148 in the cache */
   /* replace542_0_1_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 147, 1667 },
      -1,
   } },
   /* replace542_1 -> 1650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1668, 1650 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search543_0_0_0 -> 147 in the cache */
   /* search543_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 148 },
      -1,
   } },
   /* search543_0_1 -> 1650 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1670, 1650 },
      0,
   } },
   /* search543_1_0 -> 147 in the cache */
   /* search543_1_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 1664 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1671, 1672 },
      -1,
   } },

   /* replace543_0_0 -> 147 in the cache */
   /* replace543_0_1_0 -> 148 in the cache */
   /* replace543_0_1_1 -> 1664 in the cache */
   /* replace543_0_1 -> 1667 in the cache */
   /* replace543_0 -> 1668 in the cache */
   /* replace543_1 -> 1650 in the cache */
   /* replace543 -> 1669 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search544_0_0 -> 998 in the cache */
   /* search544_0_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 998, 999 },
      -1,
   } },
   /* search544_1_0 -> 3 in the cache */
   /* search544_1_1 -> 0 in the cache */
   /* search544_1 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1674, 1034 },
      -1,
   } },

   /* replace544_0 -> 0 in the cache */
   /* replace544_1 -> 3 in the cache */
   /* replace544 -> 1008 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search545_0_0 -> 115 in the cache */
   /* search545_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search545_1_0 -> 243 in the cache */
   /* search545_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1676, 1677 },
      -1,
   } },

   /* replace545_0 -> 115 in the cache */
   /* replace545_1_0 -> 11 in the cache */
   /* replace545_1_1_0 -> 243 in the cache */
   /* replace545_1_1 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1679 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search546_0_0 -> 115 in the cache */
   /* search546_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search546_1_0 -> 243 in the cache */
   /* search546_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1681, 1682 },
      -1,
   } },

   /* replace546_0 -> 115 in the cache */
   /* replace546_1_0 -> 11 in the cache */
   /* replace546_1_1_0 -> 243 in the cache */
   /* replace546_1_1 -> 515 in the cache */
   /* replace546_1 -> 1679 in the cache */
   /* replace546 -> 1680 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search547_0_0 -> 115 in the cache */
   /* search547_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search547_1_0 -> 243 in the cache */
   /* search547_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1684, 1685 },
      -1,
   } },

   /* replace547_0 -> 115 in the cache */
   /* replace547_1_0 -> 11 in the cache */
   /* replace547_1_1_0 -> 243 in the cache */
   /* replace547_1_1 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 11, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1687 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search548_0_0 -> 115 in the cache */
   /* search548_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search548_1_0 -> 243 in the cache */
   /* search548_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1689, 1690 },
      -1,
   } },

   /* replace548_0 -> 115 in the cache */
   /* replace548_1_0 -> 11 in the cache */
   /* replace548_1_1_0 -> 243 in the cache */
   /* replace548_1_1 -> 515 in the cache */
   /* replace548_1 -> 1687 in the cache */
   /* replace548 -> 1688 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search549_0_0 -> 115 in the cache */
   /* search549_0_1 -> 11 in the cache */
   /* search549_0 -> 1676 in the cache */
   /* search549_1_0 -> 243 in the cache */
   /* search549_1_1 -> 115 in the cache */
   /* search549_1 -> 1677 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1676, 1677 },
      -1,
   } },

   /* replace549_0 -> 115 in the cache */
   /* replace549_1_0 -> 11 in the cache */
   /* replace549_1_1_0 -> 243 in the cache */
   /* replace549_1_1 -> 515 in the cache */
   /* replace549_1 -> 1687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1687 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search550_0_0 -> 115 in the cache */
   /* search550_0_1 -> 11 in the cache */
   /* search550_0 -> 1681 in the cache */
   /* search550_1_0 -> 243 in the cache */
   /* search550_1_1 -> 115 in the cache */
   /* search550_1 -> 1682 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1681, 1682 },
      -1,
   } },

   /* replace550_0 -> 115 in the cache */
   /* replace550_1_0 -> 11 in the cache */
   /* replace550_1_1_0 -> 243 in the cache */
   /* replace550_1_1 -> 515 in the cache */
   /* replace550_1 -> 1687 in the cache */
   /* replace550 -> 1693 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search551_0_0 -> 115 in the cache */
   /* search551_0_1 -> 11 in the cache */
   /* search551_0 -> 1684 in the cache */
   /* search551_1_0 -> 243 in the cache */
   /* search551_1_1 -> 115 in the cache */
   /* search551_1 -> 1685 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1684, 1685 },
      -1,
   } },

   /* replace551_0 -> 115 in the cache */
   /* replace551_1_0 -> 11 in the cache */
   /* replace551_1_1_0 -> 243 in the cache */
   /* replace551_1_1 -> 515 in the cache */
   /* replace551_1 -> 1679 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1679 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search552_0_0 -> 115 in the cache */
   /* search552_0_1 -> 11 in the cache */
   /* search552_0 -> 1689 in the cache */
   /* search552_1_0 -> 243 in the cache */
   /* search552_1_1 -> 115 in the cache */
   /* search552_1 -> 1690 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1689, 1690 },
      -1,
   } },

   /* replace552_0 -> 115 in the cache */
   /* replace552_1_0 -> 11 in the cache */
   /* replace552_1_1_0 -> 243 in the cache */
   /* replace552_1_1 -> 515 in the cache */
   /* replace552_1 -> 1679 in the cache */
   /* replace552 -> 1696 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search553_0_0 -> 11 in the cache */
   /* search553_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 115 },
      -1,
   } },
   /* search553_1 -> 462 in the cache */
   /* search553_2_0_0_0_0 -> 115 in the cache */
   /* search553_2_0_0_0_1 -> 11 in the cache */
   /* search553_2_0_0_0 -> 1681 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1681 },
      -1,
   } },
   /* search553_2_0_1_0_0_0 -> 11 in the cache */
   /* search553_2_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1700 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1699, 1702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1698, 462, 1704 },
      -1,
   } },

   /* replace553_0_0_0_0 -> 11 in the cache */
   /* replace553_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1706 },
      -1,
   } },
   /* replace553_0_1_0_0_0 -> 11 in the cache */
   /* replace553_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1709 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1707, 1710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1711 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search554_0 -> 715 in the cache */
   /* search554_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 243 },
      0,
   } },
   /* search554_2_0 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1713, 1714 },
      -1,
   } },

   /* replace554_0_0 -> 715 in the cache */
   /* replace554_0_1 -> 243 in the cache */
   /* replace554_0_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 243, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1716 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search555_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1718 },
      -1,
   } },

   /* replace555_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search556_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1721 },
      -1,
   } },

   /* replace556 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search557_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1723 },
      -1,
   } },

   /* replace557 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search558_0_0 -> 11 in the cache */
   /* search558_0 -> 1721 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1721 },
      -1,
   } },

   /* replace558 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search559_0_0 -> 11 in the cache */
   /* search559_0 -> 1723 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1723 },
      -1,
   } },

   /* replace559 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search560_0_0_0 -> 115 in the cache */
   /* search560_0_0_1 -> 11 in the cache */
   /* search560_0_0 -> 1681 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1681 },
      -1,
   } },
   /* search560_1_0_0_0 -> 11 in the cache */
   /* search560_1_0_0_1 -> 115 in the cache */
   /* search560_1_0_0 -> 1700 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1700 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1728 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1727, 1729 },
      -1,
   } },

   /* replace560_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search561_0_0_0 -> 813 in the cache */
   /* search561_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 813, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1732 },
      -1,
   } },
   /* search561_1_0_0_0 -> 11 in the cache */
   /* search561_1_0_0_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 813 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1734 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1735 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1733, 1736 },
      -1,
   } },

   /* replace561_0_0 -> 11 in the cache */
   /* replace561_0 -> 1731 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1731 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search562_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1739 },
      -1,
   } },

   /* replace562 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search563_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1741 },
      -1,
   } },

   /* replace563 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search564_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1743 },
      -1,
   } },

   /* replace564 -> 11 in the cache */

   /* ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search565_0_0 -> 715 in the cache */
   /* search565_0 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1346 },
      -1,
   } },

   /* replace565_0 -> 715 in the cache */
   /* replace565 -> 1342 in the cache */

   /* ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search566_0_0 -> 715 in the cache */
   /* search566_0 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1334 },
      -1,
   } },

   /* replace566_0 -> 715 in the cache */
   /* replace566 -> 1330 in the cache */

   /* ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search567_0_0 -> 715 in the cache */
   /* search567_0 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1334 },
      -1,
   } },

   /* replace567_0 -> 715 in the cache */
   /* replace567 -> 1330 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search568_0_0 -> 11 in the cache */
   /* search568_0 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1739 },
      -1,
   } },

   /* replace568_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search569_0_0 -> 11 in the cache */
   /* search569_0 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1739 },
      -1,
   } },

   /* replace569_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search570_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1752 },
      -1,
   } },

   /* replace570_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search571_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1755 },
      -1,
   } },

   /* replace571_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search572_0_0 -> 11 in the cache */
   /* search572_0 -> 1743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 1743 },
      -1,
   } },

   /* replace572_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search573_0_0 -> 11 in the cache */
   /* search573_0 -> 1741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1741 },
      -1,
   } },

   /* replace573_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search574_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1762 },
      -1,
   } },

   /* replace574 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search575_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1764 },
      -1,
   } },

   /* replace575 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search576_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1766 },
      -1,
   } },

   /* replace576 -> 11 in the cache */

   /* ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a') */
   /* search577_0_0 -> 715 in the cache */
   /* search577_0 -> 1350 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1350 },
      -1,
   } },

   /* replace577_0 -> 715 in the cache */
   /* replace577 -> 1342 in the cache */

   /* ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search578_0_0 -> 715 in the cache */
   /* search578_0 -> 1338 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1338 },
      -1,
   } },

   /* replace578_0 -> 715 in the cache */
   /* replace578 -> 1330 in the cache */

   /* ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search579_0_0 -> 715 in the cache */
   /* search579_0 -> 1338 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1338 },
      -1,
   } },

   /* replace579_0 -> 715 in the cache */
   /* replace579 -> 1330 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search580_0_0 -> 11 in the cache */
   /* search580_0 -> 1762 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1762 },
      -1,
   } },

   /* replace580_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search581_0_0 -> 11 in the cache */
   /* search581_0 -> 1762 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1762 },
      -1,
   } },

   /* replace581_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search582_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1775 },
      -1,
   } },

   /* replace582_0 -> 32 in the cache */
   /* replace582 -> 1754 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search583_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1777 },
      -1,
   } },

   /* replace583_0 -> 32 in the cache */
   /* replace583 -> 1757 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search584_0_0 -> 11 in the cache */
   /* search584_0 -> 1766 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1766 },
      -1,
   } },

   /* replace584_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search585_0_0 -> 11 in the cache */
   /* search585_0 -> 1764 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1764 },
      -1,
   } },

   /* replace585_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search586_0_0 -> 117 in the cache */
   /* search586_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search586_1_0 -> 36 in the cache */
   /* search586_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1783, 1784 },
      -1,
   } },

   /* replace586_0 -> 117 in the cache */
   /* replace586_1_0 -> 16 in the cache */
   /* replace586_1_1_0 -> 36 in the cache */
   /* replace586_1_1 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 16, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1786 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search587_0_0 -> 117 in the cache */
   /* search587_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search587_1_0 -> 36 in the cache */
   /* search587_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1788, 1789 },
      -1,
   } },

   /* replace587_0 -> 117 in the cache */
   /* replace587_1_0 -> 16 in the cache */
   /* replace587_1_1_0 -> 36 in the cache */
   /* replace587_1_1 -> 581 in the cache */
   /* replace587_1 -> 1786 in the cache */
   /* replace587 -> 1787 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search588_0_0 -> 117 in the cache */
   /* search588_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search588_1_0 -> 36 in the cache */
   /* search588_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1791, 1792 },
      -1,
   } },

   /* replace588_0 -> 117 in the cache */
   /* replace588_1_0 -> 16 in the cache */
   /* replace588_1_1_0 -> 36 in the cache */
   /* replace588_1_1 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 16, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1794 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search589_0_0 -> 117 in the cache */
   /* search589_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search589_1_0 -> 36 in the cache */
   /* search589_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1796, 1797 },
      -1,
   } },

   /* replace589_0 -> 117 in the cache */
   /* replace589_1_0 -> 16 in the cache */
   /* replace589_1_1_0 -> 36 in the cache */
   /* replace589_1_1 -> 581 in the cache */
   /* replace589_1 -> 1794 in the cache */
   /* replace589 -> 1795 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search590_0_0 -> 117 in the cache */
   /* search590_0_1 -> 16 in the cache */
   /* search590_0 -> 1783 in the cache */
   /* search590_1_0 -> 36 in the cache */
   /* search590_1_1 -> 117 in the cache */
   /* search590_1 -> 1784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1783, 1784 },
      -1,
   } },

   /* replace590_0 -> 117 in the cache */
   /* replace590_1_0 -> 16 in the cache */
   /* replace590_1_1_0 -> 36 in the cache */
   /* replace590_1_1 -> 581 in the cache */
   /* replace590_1 -> 1794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1794 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search591_0_0 -> 117 in the cache */
   /* search591_0_1 -> 16 in the cache */
   /* search591_0 -> 1788 in the cache */
   /* search591_1_0 -> 36 in the cache */
   /* search591_1_1 -> 117 in the cache */
   /* search591_1 -> 1789 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1788, 1789 },
      -1,
   } },

   /* replace591_0 -> 117 in the cache */
   /* replace591_1_0 -> 16 in the cache */
   /* replace591_1_1_0 -> 36 in the cache */
   /* replace591_1_1 -> 581 in the cache */
   /* replace591_1 -> 1794 in the cache */
   /* replace591 -> 1800 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search592_0_0 -> 117 in the cache */
   /* search592_0_1 -> 16 in the cache */
   /* search592_0 -> 1791 in the cache */
   /* search592_1_0 -> 36 in the cache */
   /* search592_1_1 -> 117 in the cache */
   /* search592_1 -> 1792 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1791, 1792 },
      -1,
   } },

   /* replace592_0 -> 117 in the cache */
   /* replace592_1_0 -> 16 in the cache */
   /* replace592_1_1_0 -> 36 in the cache */
   /* replace592_1_1 -> 581 in the cache */
   /* replace592_1 -> 1786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1786 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search593_0_0 -> 117 in the cache */
   /* search593_0_1 -> 16 in the cache */
   /* search593_0 -> 1796 in the cache */
   /* search593_1_0 -> 36 in the cache */
   /* search593_1_1 -> 117 in the cache */
   /* search593_1 -> 1797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1796, 1797 },
      -1,
   } },

   /* replace593_0 -> 117 in the cache */
   /* replace593_1_0 -> 16 in the cache */
   /* replace593_1_1_0 -> 36 in the cache */
   /* replace593_1_1 -> 581 in the cache */
   /* replace593_1 -> 1786 in the cache */
   /* replace593 -> 1803 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search594_0_0 -> 16 in the cache */
   /* search594_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 117 },
      -1,
   } },
   /* search594_1 -> 228 in the cache */
   /* search594_2_0_0_0_0 -> 117 in the cache */
   /* search594_2_0_0_0_1 -> 16 in the cache */
   /* search594_2_0_0_0 -> 1788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1788 },
      -1,
   } },
   /* search594_2_0_1_0_0_0 -> 16 in the cache */
   /* search594_2_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1806, 1809 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1805, 228, 1811 },
      -1,
   } },

   /* replace594_0_0_0_0 -> 16 in the cache */
   /* replace594_0_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1813 },
      -1,
   } },
   /* replace594_0_1_0_0_0 -> 16 in the cache */
   /* replace594_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1816 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1814, 1817 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1818 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search595_0 -> 715 in the cache */
   /* search595_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search595_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1820, 1821 },
      -1,
   } },

   /* replace595_0_0 -> 715 in the cache */
   /* replace595_0_1 -> 36 in the cache */
   /* replace595_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1823 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search596_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1825 },
      -1,
   } },

   /* replace596_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search597_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1828 },
      -1,
   } },

   /* replace597 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search598_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1830 },
      -1,
   } },

   /* replace598 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search599_0_0 -> 16 in the cache */
   /* search599_0 -> 1828 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1828 },
      -1,
   } },

   /* replace599 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search600_0_0 -> 16 in the cache */
   /* search600_0 -> 1830 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1830 },
      -1,
   } },

   /* replace600 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search601_0_0_0 -> 117 in the cache */
   /* search601_0_0_1 -> 16 in the cache */
   /* search601_0_0 -> 1788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1788 },
      -1,
   } },
   /* search601_1_0_0_0 -> 16 in the cache */
   /* search601_1_0_0_1 -> 117 in the cache */
   /* search601_1_0_0 -> 1807 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1834, 1836 },
      -1,
   } },

   /* replace601_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search602_0_0_0 -> 120 in the cache */
   /* search602_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1839 },
      -1,
   } },
   /* search602_1_0_0_0 -> 16 in the cache */
   /* search602_1_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1842 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1840, 1843 },
      -1,
   } },

   /* replace602_0_0 -> 16 in the cache */
   /* replace602_0 -> 1838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1838 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search603_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1846 },
      -1,
   } },

   /* replace603 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search604_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1848 },
      -1,
   } },

   /* replace604 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search605_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1850 },
      -1,
   } },

   /* replace605 -> 16 in the cache */

   /* ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a') */
   /* search606_0_0 -> 715 in the cache */
   /* search606_0 -> 1350 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1350 },
      -1,
   } },

   /* replace606_0 -> 715 in the cache */
   /* replace606 -> 1346 in the cache */

   /* ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search607_0_0 -> 715 in the cache */
   /* search607_0 -> 1338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1338 },
      -1,
   } },

   /* replace607_0 -> 715 in the cache */
   /* replace607 -> 1334 in the cache */

   /* ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search608_0_0 -> 715 in the cache */
   /* search608_0 -> 1338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1338 },
      -1,
   } },

   /* replace608_0 -> 715 in the cache */
   /* replace608 -> 1334 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search609_0_0 -> 16 in the cache */
   /* search609_0 -> 1846 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1846 },
      -1,
   } },

   /* replace609_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search610_0_0 -> 16 in the cache */
   /* search610_0 -> 1846 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1846 },
      -1,
   } },

   /* replace610_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search611_0_0 -> 32 in the cache */
   /* search611_0 -> 1775 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1775 },
      -1,
   } },

   /* replace611_0 -> 32 in the cache */
   /* replace611 -> 1752 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search612_0_0 -> 32 in the cache */
   /* search612_0 -> 1777 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1777 },
      -1,
   } },

   /* replace612_0 -> 32 in the cache */
   /* replace612 -> 1755 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search613_0_0 -> 16 in the cache */
   /* search613_0 -> 1850 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1850 },
      -1,
   } },

   /* replace613_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search614_0_0 -> 16 in the cache */
   /* search614_0 -> 1848 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1848 },
      -1,
   } },

   /* replace614_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search615_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1865, 21 },
      0,
   } },
   /* search615_1_0 -> 41 in the cache */
   /* search615_1_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1865 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1866, 1867 },
      -1,
   } },

   /* replace615_0 -> 1865 in the cache */
   /* replace615_1_0 -> 21 in the cache */
   /* replace615_1_1_0 -> 41 in the cache */
   /* replace615_1_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 21, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1865, 1869 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search616_0_0 -> 1865 in the cache */
   /* search616_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1865, 21 },
      -1,
   } },
   /* search616_1_0 -> 41 in the cache */
   /* search616_1_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1865 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1871, 1872 },
      -1,
   } },

   /* replace616_0 -> 1865 in the cache */
   /* replace616_1_0 -> 21 in the cache */
   /* replace616_1_1_0 -> 41 in the cache */
   /* replace616_1_1 -> 654 in the cache */
   /* replace616_1 -> 1869 in the cache */
   /* replace616 -> 1870 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search617_0_0 -> 1865 in the cache */
   /* search617_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1865, 21 },
      0,
   } },
   /* search617_1_0 -> 41 in the cache */
   /* search617_1_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1865 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1874, 1875 },
      -1,
   } },

   /* replace617_0 -> 1865 in the cache */
   /* replace617_1_0 -> 21 in the cache */
   /* replace617_1_1_0 -> 41 in the cache */
   /* replace617_1_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 21, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1865, 1877 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search618_0_0 -> 1865 in the cache */
   /* search618_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1865, 21 },
      -1,
   } },
   /* search618_1_0 -> 41 in the cache */
   /* search618_1_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1865 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1879, 1880 },
      -1,
   } },

   /* replace618_0 -> 1865 in the cache */
   /* replace618_1_0 -> 21 in the cache */
   /* replace618_1_1_0 -> 41 in the cache */
   /* replace618_1_1 -> 654 in the cache */
   /* replace618_1 -> 1877 in the cache */
   /* replace618 -> 1878 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search619_0_0 -> 1865 in the cache */
   /* search619_0_1 -> 21 in the cache */
   /* search619_0 -> 1866 in the cache */
   /* search619_1_0 -> 41 in the cache */
   /* search619_1_1 -> 1865 in the cache */
   /* search619_1 -> 1867 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1866, 1867 },
      -1,
   } },

   /* replace619_0 -> 1865 in the cache */
   /* replace619_1_0 -> 21 in the cache */
   /* replace619_1_1_0 -> 41 in the cache */
   /* replace619_1_1 -> 654 in the cache */
   /* replace619_1 -> 1877 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1865, 1877 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search620_0_0 -> 1865 in the cache */
   /* search620_0_1 -> 21 in the cache */
   /* search620_0 -> 1871 in the cache */
   /* search620_1_0 -> 41 in the cache */
   /* search620_1_1 -> 1865 in the cache */
   /* search620_1 -> 1872 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1871, 1872 },
      -1,
   } },

   /* replace620_0 -> 1865 in the cache */
   /* replace620_1_0 -> 21 in the cache */
   /* replace620_1_1_0 -> 41 in the cache */
   /* replace620_1_1 -> 654 in the cache */
   /* replace620_1 -> 1877 in the cache */
   /* replace620 -> 1883 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search621_0_0 -> 1865 in the cache */
   /* search621_0_1 -> 21 in the cache */
   /* search621_0 -> 1874 in the cache */
   /* search621_1_0 -> 41 in the cache */
   /* search621_1_1 -> 1865 in the cache */
   /* search621_1 -> 1875 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1874, 1875 },
      -1,
   } },

   /* replace621_0 -> 1865 in the cache */
   /* replace621_1_0 -> 21 in the cache */
   /* replace621_1_1_0 -> 41 in the cache */
   /* replace621_1_1 -> 654 in the cache */
   /* replace621_1 -> 1869 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1865, 1869 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search622_0_0 -> 1865 in the cache */
   /* search622_0_1 -> 21 in the cache */
   /* search622_0 -> 1879 in the cache */
   /* search622_1_0 -> 41 in the cache */
   /* search622_1_1 -> 1865 in the cache */
   /* search622_1 -> 1880 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1879, 1880 },
      -1,
   } },

   /* replace622_0 -> 1865 in the cache */
   /* replace622_1_0 -> 21 in the cache */
   /* replace622_1_1_0 -> 41 in the cache */
   /* replace622_1_1 -> 654 in the cache */
   /* replace622_1 -> 1869 in the cache */
   /* replace622 -> 1886 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search623_0_0 -> 21 in the cache */
   /* search623_0_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 21, 1865 },
      -1,
   } },
   /* search623_1 -> 603 in the cache */
   /* search623_2_0_0_0_0 -> 1865 in the cache */
   /* search623_2_0_0_0_1 -> 21 in the cache */
   /* search623_2_0_0_0 -> 1871 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1871 },
      -1,
   } },
   /* search623_2_0_1_0_0_0 -> 21 in the cache */
   /* search623_2_0_1_0_0_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1865 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1889, 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1893 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1888, 603, 1894 },
      -1,
   } },

   /* replace623_0_0_0_0 -> 21 in the cache */
   /* replace623_0_0_0_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 21, 1865 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1896 },
      -1,
   } },
   /* replace623_0_1_0_0_0 -> 21 in the cache */
   /* replace623_0_1_0_0_1 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1865 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1898 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1897, 1900 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1901 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search624_0 -> 715 in the cache */
   /* search624_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search624_2_0 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1903, 1904 },
      -1,
   } },

   /* replace624_0_0 -> 715 in the cache */
   /* replace624_0_1 -> 41 in the cache */
   /* replace624_0_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 41, 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1906 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search625_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1908 },
      -1,
   } },

   /* replace625_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search626_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1911 },
      -1,
   } },

   /* replace626 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search627_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1913 },
      -1,
   } },

   /* replace627 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search628_0_0 -> 21 in the cache */
   /* search628_0 -> 1911 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1911 },
      -1,
   } },

   /* replace628 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search629_0_0 -> 21 in the cache */
   /* search629_0 -> 1913 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1913 },
      -1,
   } },

   /* replace629 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search630_0_0_0 -> 1865 in the cache */
   /* search630_0_0_1 -> 21 in the cache */
   /* search630_0_0 -> 1871 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1871 },
      -1,
   } },
   /* search630_1_0_0_0 -> 21 in the cache */
   /* search630_1_0_0_1 -> 1865 in the cache */
   /* search630_1_0_0 -> 1890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1918 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1917, 1919 },
      -1,
   } },

   /* replace630_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search631_0_0_0 -> 856 in the cache */
   /* search631_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 856, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1922 },
      -1,
   } },
   /* search631_1_0_0_0 -> 21 in the cache */
   /* search631_1_0_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1923, 1926 },
      -1,
   } },

   /* replace631_0_0 -> 21 in the cache */
   /* replace631_0 -> 1921 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1921 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search632_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1929 },
      -1,
   } },

   /* replace632_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search633_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1932 },
      -1,
   } },

   /* replace633_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search634_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace634_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search635_0_0 -> 16 in the cache */
   /* search635_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace635_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search636_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1940 },
      -1,
   } },

   /* replace636_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search637_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1943 },
      -1,
   } },

   /* replace637_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search638_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 1946 },
      -1,
   } },

   /* replace638_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search639_0_0 -> 16 in the cache */
   /* search639_0 -> 1946 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1946 },
      -1,
   } },

   /* replace639_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search640_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1951 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1952, 1953 },
      -1,
   } },

   /* replace640_0 -> 11 in the cache */
   /* replace640_1_0 -> 243 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 243, 1955 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 11, 1956 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search641_0_0_0 -> 11 in the cache */
   /* search641_0_0_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1953 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1958 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 1959 },
      -1,
   } },

   /* replace641_0 -> 11 in the cache */
   /* replace641_1_0 -> 243 in the cache */
   /* replace641_1_1 -> 1955 in the cache */
   /* replace641_1 -> 1956 in the cache */
   /* replace641 -> 1957 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search642_0_0_0_0 -> 11 in the cache */
   /* search642_0_0_0 -> 1951 in the cache */
   /* search642_0_0 -> 1952 in the cache */
   /* search642_0_1_0_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1952, 1962 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1963 },
      -1,
   } },

   /* replace642_0_0 -> 11 in the cache */
   /* replace642_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1965 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search643_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1967 },
      -1,
   } },
   /* search643_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1968, 1970 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1971 },
      -1,
   } },

   /* replace643_0_0 -> 16 in the cache */
   /* replace643_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1973 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search644_0_0 -> 0 in the cache */
   /* search644_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search644_1_0 -> 138 in the cache */
   /* search644_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1975, 1976 },
      -1,
   } },

   /* replace644_0_0 -> 0 in the cache */
   /* replace644_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace644_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 1978, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search645_0_0 -> 0 in the cache */
   /* search645_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search645_1_0 -> 138 in the cache */
   /* search645_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1980, 1981 },
      -1,
   } },

   /* replace645_0_0 -> 0 in the cache */
   /* replace645_0_1 -> 138 in the cache */
   /* replace645_0 -> 1978 in the cache */
   /* replace645_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 1978, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search646_0_0 -> 0 in the cache */
   /* search646_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search646_1_0 -> 138 in the cache */
   /* search646_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1984, 1985 },
      -1,
   } },

   /* replace646_0_0 -> 0 in the cache */
   /* replace646_0_1 -> 138 in the cache */
   /* replace646_0 -> 1978 in the cache */
   /* replace646_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 1978, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search647_0_0 -> 0 in the cache */
   /* search647_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search647_1_0 -> 138 in the cache */
   /* search647_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1988, 1989 },
      -1,
   } },

   /* replace647_0_0 -> 0 in the cache */
   /* replace647_0_1 -> 138 in the cache */
   /* replace647_0 -> 1978 in the cache */
   /* replace647_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 1978, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search648_0_0 -> 124 in the cache */
   /* search648_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search648_1_0 -> 127 in the cache */
   /* search648_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1992, 1993 },
      -1,
   } },

   /* replace648_0_0 -> 124 in the cache */
   /* replace648_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace648_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 1995, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search649_0_0 -> 124 in the cache */
   /* search649_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search649_1_0 -> 127 in the cache */
   /* search649_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1997, 1998 },
      -1,
   } },

   /* replace649_0_0 -> 124 in the cache */
   /* replace649_0_1 -> 127 in the cache */
   /* replace649_0 -> 1995 in the cache */
   /* replace649_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 1995, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search650_0_0 -> 124 in the cache */
   /* search650_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search650_1_0 -> 127 in the cache */
   /* search650_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2001, 2002 },
      -1,
   } },

   /* replace650_0_0 -> 124 in the cache */
   /* replace650_0_1 -> 127 in the cache */
   /* replace650_0 -> 1995 in the cache */
   /* replace650_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1995, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search651_0_0_0_0 -> 11 in the cache */
   /* search651_0_0_0 -> 1951 in the cache */
   /* search651_0_0 -> 1952 in the cache */
   /* search651_0_1_0_0 -> 243 in the cache */
   /* search651_0_1_0 -> 1961 in the cache */
   /* search651_0_1 -> 1962 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1952, 1962 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2005 },
      -1,
   } },

   /* replace651_0_0 -> 11 in the cache */
   /* replace651_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2007 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search652_0_0_0_0 -> 16 in the cache */
   /* search652_0_0_0 -> 1967 in the cache */
   /* search652_0_0 -> 1968 in the cache */
   /* search652_0_1_0_0 -> 36 in the cache */
   /* search652_0_1_0 -> 1969 in the cache */
   /* search652_0_1 -> 1970 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1968, 1970 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2009 },
      -1,
   } },

   /* replace652_0_0 -> 16 in the cache */
   /* replace652_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2011 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search653_0_0 -> 0 in the cache */
   /* search653_0_1 -> 776 in the cache */
   /* search653_0 -> 1975 in the cache */
   /* search653_1_0 -> 138 in the cache */
   /* search653_1_1 -> 3 in the cache */
   /* search653_1 -> 1976 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1975, 1976 },
      -1,
   } },

   /* replace653_0_0 -> 0 in the cache */
   /* replace653_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace653_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2014, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search654_0_0 -> 0 in the cache */
   /* search654_0_1 -> 776 in the cache */
   /* search654_0 -> 1980 in the cache */
   /* search654_1_0 -> 138 in the cache */
   /* search654_1_1 -> 3 in the cache */
   /* search654_1 -> 1981 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1980, 1981 },
      -1,
   } },

   /* replace654_0_0 -> 0 in the cache */
   /* replace654_0_1 -> 138 in the cache */
   /* replace654_0 -> 2014 in the cache */
   /* replace654_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2014, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search655_0_0 -> 0 in the cache */
   /* search655_0_1 -> 776 in the cache */
   /* search655_0 -> 1984 in the cache */
   /* search655_1_0 -> 138 in the cache */
   /* search655_1_1 -> 3 in the cache */
   /* search655_1 -> 1985 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1984, 1985 },
      -1,
   } },

   /* replace655_0_0 -> 0 in the cache */
   /* replace655_0_1 -> 138 in the cache */
   /* replace655_0 -> 2014 in the cache */
   /* replace655_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2014, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search656_0_0 -> 0 in the cache */
   /* search656_0_1 -> 776 in the cache */
   /* search656_0 -> 1988 in the cache */
   /* search656_1_0 -> 138 in the cache */
   /* search656_1_1 -> 3 in the cache */
   /* search656_1 -> 1989 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1988, 1989 },
      -1,
   } },

   /* replace656_0_0 -> 0 in the cache */
   /* replace656_0_1 -> 138 in the cache */
   /* replace656_0 -> 2014 in the cache */
   /* replace656_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2014, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search657_0_0 -> 124 in the cache */
   /* search657_0_1 -> 33 in the cache */
   /* search657_0 -> 1992 in the cache */
   /* search657_1_0 -> 127 in the cache */
   /* search657_1_1 -> 36 in the cache */
   /* search657_1 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1992, 1993 },
      -1,
   } },

   /* replace657_0_0 -> 124 in the cache */
   /* replace657_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace657_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2023, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search658_0_0 -> 124 in the cache */
   /* search658_0_1 -> 33 in the cache */
   /* search658_0 -> 1997 in the cache */
   /* search658_1_0 -> 127 in the cache */
   /* search658_1_1 -> 36 in the cache */
   /* search658_1 -> 1998 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1997, 1998 },
      -1,
   } },

   /* replace658_0_0 -> 124 in the cache */
   /* replace658_0_1 -> 127 in the cache */
   /* replace658_0 -> 2023 in the cache */
   /* replace658_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2023, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search659_0_0 -> 124 in the cache */
   /* search659_0_1 -> 33 in the cache */
   /* search659_0 -> 2001 in the cache */
   /* search659_1_0 -> 127 in the cache */
   /* search659_1_1 -> 36 in the cache */
   /* search659_1 -> 2002 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2001, 2002 },
      -1,
   } },

   /* replace659_0_0 -> 124 in the cache */
   /* replace659_0_1 -> 127 in the cache */
   /* replace659_0 -> 2023 in the cache */
   /* replace659_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2023, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search660_0_0_0_0 -> 11 in the cache */
   /* search660_0_0_0 -> 1951 in the cache */
   /* search660_0_0 -> 1952 in the cache */
   /* search660_0_1_0_0 -> 243 in the cache */
   /* search660_0_1_0 -> 1961 in the cache */
   /* search660_0_1 -> 1962 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1952, 1962 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2029 },
      -1,
   } },

   /* replace660_0_0 -> 11 in the cache */
   /* replace660_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2031 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search661_0_0_0_0 -> 16 in the cache */
   /* search661_0_0_0 -> 1967 in the cache */
   /* search661_0_0 -> 1968 in the cache */
   /* search661_0_1_0_0 -> 36 in the cache */
   /* search661_0_1_0 -> 1969 in the cache */
   /* search661_0_1 -> 1970 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1968, 1970 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2033 },
      -1,
   } },

   /* replace661_0_0 -> 16 in the cache */
   /* replace661_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2035 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search662_0_0 -> 0 in the cache */
   /* search662_0_1 -> 776 in the cache */
   /* search662_0 -> 1975 in the cache */
   /* search662_1_0 -> 138 in the cache */
   /* search662_1_1 -> 3 in the cache */
   /* search662_1 -> 1976 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1975, 1976 },
      -1,
   } },

   /* replace662_0_0 -> 0 in the cache */
   /* replace662_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace662_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2038, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search663_0_0 -> 0 in the cache */
   /* search663_0_1 -> 776 in the cache */
   /* search663_0 -> 1980 in the cache */
   /* search663_1_0 -> 138 in the cache */
   /* search663_1_1 -> 3 in the cache */
   /* search663_1 -> 1981 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1980, 1981 },
      -1,
   } },

   /* replace663_0_0 -> 0 in the cache */
   /* replace663_0_1 -> 138 in the cache */
   /* replace663_0 -> 2038 in the cache */
   /* replace663_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2038, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search664_0_0 -> 0 in the cache */
   /* search664_0_1 -> 776 in the cache */
   /* search664_0 -> 1984 in the cache */
   /* search664_1_0 -> 138 in the cache */
   /* search664_1_1 -> 3 in the cache */
   /* search664_1 -> 1985 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1984, 1985 },
      -1,
   } },

   /* replace664_0_0 -> 0 in the cache */
   /* replace664_0_1 -> 138 in the cache */
   /* replace664_0 -> 2038 in the cache */
   /* replace664_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2038, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search665_0_0 -> 0 in the cache */
   /* search665_0_1 -> 776 in the cache */
   /* search665_0 -> 1988 in the cache */
   /* search665_1_0 -> 138 in the cache */
   /* search665_1_1 -> 3 in the cache */
   /* search665_1 -> 1989 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1988, 1989 },
      -1,
   } },

   /* replace665_0_0 -> 0 in the cache */
   /* replace665_0_1 -> 138 in the cache */
   /* replace665_0 -> 2038 in the cache */
   /* replace665_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2038, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search666_0_0 -> 124 in the cache */
   /* search666_0_1 -> 33 in the cache */
   /* search666_0 -> 1992 in the cache */
   /* search666_1_0 -> 127 in the cache */
   /* search666_1_1 -> 36 in the cache */
   /* search666_1 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1992, 1993 },
      -1,
   } },

   /* replace666_0_0 -> 124 in the cache */
   /* replace666_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace666_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2047, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search667_0_0 -> 124 in the cache */
   /* search667_0_1 -> 33 in the cache */
   /* search667_0 -> 1997 in the cache */
   /* search667_1_0 -> 127 in the cache */
   /* search667_1_1 -> 36 in the cache */
   /* search667_1 -> 1998 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1997, 1998 },
      -1,
   } },

   /* replace667_0_0 -> 124 in the cache */
   /* replace667_0_1 -> 127 in the cache */
   /* replace667_0 -> 2047 in the cache */
   /* replace667_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2047, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search668_0_0 -> 124 in the cache */
   /* search668_0_1 -> 33 in the cache */
   /* search668_0 -> 2001 in the cache */
   /* search668_1_0 -> 127 in the cache */
   /* search668_1_1 -> 36 in the cache */
   /* search668_1 -> 2002 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2001, 2002 },
      -1,
   } },

   /* replace668_0_0 -> 124 in the cache */
   /* replace668_0_1 -> 127 in the cache */
   /* replace668_0 -> 2047 in the cache */
   /* replace668_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2047, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search669_0_0 -> 6 in the cache */
   /* search669_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 791 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search669_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2054, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2053, 2055 },
      -1,
   } },

   /* replace669_0_0 -> 6 in the cache */
   /* replace669_0_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 6, 2054 },
      -1,
   } },
   /* replace669_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2057, 791 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search670_0_0 -> 6 in the cache */
   /* search670_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 791 },
      -1,
   } },
   /* search670_1_0 -> 2054 in the cache */
   /* search670_1_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2054, 791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2059, 2060 },
      -1,
   } },

   /* replace670_0_0 -> 6 in the cache */
   /* replace670_0_1 -> 2054 in the cache */
   /* replace670_0 -> 2057 in the cache */
   /* replace670_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2057, 791 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search671_0_0 -> 6 in the cache */
   /* search671_0_1 -> 791 in the cache */
   /* search671_0 -> 2053 in the cache */
   /* search671_1_0 -> 2054 in the cache */
   /* search671_1_1 -> 791 in the cache */
   /* search671_1 -> 2055 in the cache */
   /* search671 -> 2056 in the cache */

   /* replace671_0_0 -> 6 in the cache */
   /* replace671_0_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 6, 2054 },
      -1,
   } },
   /* replace671_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2063, 791 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search672_0_0 -> 6 in the cache */
   /* search672_0_1 -> 791 in the cache */
   /* search672_0 -> 2053 in the cache */
   /* search672_1_0 -> 2054 in the cache */
   /* search672_1_1 -> 791 in the cache */
   /* search672_1 -> 2055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2053, 2055 },
      -1,
   } },

   /* replace672_0_0 -> 6 in the cache */
   /* replace672_0_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 6, 2054 },
      -1,
   } },
   /* replace672_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2066, 791 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search673_0_0 -> 6 in the cache */
   /* search673_0_1 -> 791 in the cache */
   /* search673_0 -> 2059 in the cache */
   /* search673_1_0 -> 2054 in the cache */
   /* search673_1_1 -> 791 in the cache */
   /* search673_1 -> 2060 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2059, 2060 },
      -1,
   } },

   /* replace673_0_0 -> 6 in the cache */
   /* replace673_0_1 -> 2054 in the cache */
   /* replace673_0 -> 2066 in the cache */
   /* replace673_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2066, 791 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search674_0_0 -> 6 in the cache */
   /* search674_0_1 -> 791 in the cache */
   /* search674_0 -> 2059 in the cache */
   /* search674_1_0 -> 2054 in the cache */
   /* search674_1_1 -> 791 in the cache */
   /* search674_1 -> 2060 in the cache */
   /* search674 -> 2061 in the cache */

   /* replace674_0_0 -> 6 in the cache */
   /* replace674_0_1 -> 2054 in the cache */
   /* replace674_0 -> 2063 in the cache */
   /* replace674_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2063, 791 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search675_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2071 },
      -1,
   } },

   /* replace675 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search676_0 -> 6 in the cache */
   /* search676_1_0 -> 9 in the cache */
   /* search676_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 2073 },
      -1,
   } },

   /* replace676_0 -> 6 in the cache */
   /* replace676_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search677_0 -> 6 in the cache */
   /* search677_1_0 -> 9 in the cache */
   /* search677_1_1 -> 36 in the cache */
   /* search677_1 -> 2073 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 6, 2073 },
      -1,
   } },

   /* replace677_0 -> 6 in the cache */
   /* replace677_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search678_0 -> 6 in the cache */
   /* search678_1_0 -> 9 in the cache */
   /* search678_1_1 -> 36 in the cache */
   /* search678_1 -> 2073 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2073 },
      -1,
   } },

   /* replace678_0 -> 6 in the cache */
   /* replace678_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search679_0_0 -> 11 in the cache */
   /* search679_0_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 813 },
      -1,
   } },
   /* search679_1_0 -> 243 in the cache */
   /* search679_1_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 243, 813 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2080, 2081 },
      -1,
   } },

   /* replace679_0_0 -> 11 in the cache */
   /* replace679_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace679_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2083, 813 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search680_0_0 -> 11 in the cache */
   /* search680_0_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 813 },
      -1,
   } },
   /* search680_1_0 -> 243 in the cache */
   /* search680_1_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 243, 813 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2085, 2086 },
      -1,
   } },

   /* replace680_0_0 -> 11 in the cache */
   /* replace680_0_1 -> 243 in the cache */
   /* replace680_0 -> 2083 in the cache */
   /* replace680_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2083, 813 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search681_0_0 -> 11 in the cache */
   /* search681_0_1 -> 813 in the cache */
   /* search681_0 -> 2080 in the cache */
   /* search681_1_0 -> 243 in the cache */
   /* search681_1_1 -> 813 in the cache */
   /* search681_1 -> 2081 in the cache */
   /* search681 -> 2082 in the cache */

   /* replace681_0_0 -> 11 in the cache */
   /* replace681_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace681_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2089, 813 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search682_0_0 -> 11 in the cache */
   /* search682_0_1 -> 813 in the cache */
   /* search682_0 -> 2080 in the cache */
   /* search682_1_0 -> 243 in the cache */
   /* search682_1_1 -> 813 in the cache */
   /* search682_1 -> 2081 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2080, 2081 },
      -1,
   } },

   /* replace682_0_0 -> 11 in the cache */
   /* replace682_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace682_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2092, 813 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search683_0_0 -> 11 in the cache */
   /* search683_0_1 -> 813 in the cache */
   /* search683_0 -> 2085 in the cache */
   /* search683_1_0 -> 243 in the cache */
   /* search683_1_1 -> 813 in the cache */
   /* search683_1 -> 2086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2085, 2086 },
      -1,
   } },

   /* replace683_0_0 -> 11 in the cache */
   /* replace683_0_1 -> 243 in the cache */
   /* replace683_0 -> 2092 in the cache */
   /* replace683_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2092, 813 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search684_0_0 -> 11 in the cache */
   /* search684_0_1 -> 813 in the cache */
   /* search684_0 -> 2085 in the cache */
   /* search684_1_0 -> 243 in the cache */
   /* search684_1_1 -> 813 in the cache */
   /* search684_1 -> 2086 in the cache */
   /* search684 -> 2087 in the cache */

   /* replace684_0_0 -> 11 in the cache */
   /* replace684_0_1 -> 243 in the cache */
   /* replace684_0 -> 2089 in the cache */
   /* replace684_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2089, 813 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search685_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2097 },
      -1,
   } },

   /* replace685 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search686_0 -> 11 in the cache */
   /* search686_1_0 -> 14 in the cache */
   /* search686_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2099 },
      -1,
   } },

   /* replace686_0 -> 11 in the cache */
   /* replace686_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search687_0 -> 11 in the cache */
   /* search687_1_0 -> 14 in the cache */
   /* search687_1_1 -> 36 in the cache */
   /* search687_1 -> 2099 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 2099 },
      -1,
   } },

   /* replace687_0 -> 11 in the cache */
   /* replace687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search688_0 -> 11 in the cache */
   /* search688_1_0 -> 14 in the cache */
   /* search688_1_1 -> 36 in the cache */
   /* search688_1 -> 2099 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2099 },
      -1,
   } },

   /* replace688_0 -> 11 in the cache */
   /* replace688_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search689_0_0 -> 16 in the cache */
   /* search689_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search689_1_0 -> 36 in the cache */
   /* search689_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2106, 2107 },
      -1,
   } },

   /* replace689_0_0 -> 16 in the cache */
   /* replace689_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace689_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2109, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search690_0_0 -> 16 in the cache */
   /* search690_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search690_1_0 -> 36 in the cache */
   /* search690_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2111, 2112 },
      -1,
   } },

   /* replace690_0_0 -> 16 in the cache */
   /* replace690_0_1 -> 36 in the cache */
   /* replace690_0 -> 2109 in the cache */
   /* replace690_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2109, 120 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search691_0_0 -> 16 in the cache */
   /* search691_0_1 -> 120 in the cache */
   /* search691_0 -> 2106 in the cache */
   /* search691_1_0 -> 36 in the cache */
   /* search691_1_1 -> 120 in the cache */
   /* search691_1 -> 2107 in the cache */
   /* search691 -> 2108 in the cache */

   /* replace691_0_0 -> 16 in the cache */
   /* replace691_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace691_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2115, 120 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search692_0_0 -> 16 in the cache */
   /* search692_0_1 -> 120 in the cache */
   /* search692_0 -> 2106 in the cache */
   /* search692_1_0 -> 36 in the cache */
   /* search692_1_1 -> 120 in the cache */
   /* search692_1 -> 2107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2106, 2107 },
      -1,
   } },

   /* replace692_0_0 -> 16 in the cache */
   /* replace692_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace692_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2118, 120 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search693_0_0 -> 16 in the cache */
   /* search693_0_1 -> 120 in the cache */
   /* search693_0 -> 2111 in the cache */
   /* search693_1_0 -> 36 in the cache */
   /* search693_1_1 -> 120 in the cache */
   /* search693_1 -> 2112 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2111, 2112 },
      -1,
   } },

   /* replace693_0_0 -> 16 in the cache */
   /* replace693_0_1 -> 36 in the cache */
   /* replace693_0 -> 2118 in the cache */
   /* replace693_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2118, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search694_0_0 -> 16 in the cache */
   /* search694_0_1 -> 120 in the cache */
   /* search694_0 -> 2111 in the cache */
   /* search694_1_0 -> 36 in the cache */
   /* search694_1_1 -> 120 in the cache */
   /* search694_1 -> 2112 in the cache */
   /* search694 -> 2113 in the cache */

   /* replace694_0_0 -> 16 in the cache */
   /* replace694_0_1 -> 36 in the cache */
   /* replace694_0 -> 2115 in the cache */
   /* replace694_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2115, 120 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search695_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2123 },
      -1,
   } },

   /* replace695 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search696_0 -> 16 in the cache */
   /* search696_1_0 -> 19 in the cache */
   /* search696_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2125 },
      -1,
   } },

   /* replace696_0 -> 16 in the cache */
   /* replace696_1 -> 36 in the cache */
   /* replace696 -> 904 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search697_0 -> 16 in the cache */
   /* search697_1_0 -> 19 in the cache */
   /* search697_1_1 -> 36 in the cache */
   /* search697_1 -> 2125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 16, 2125 },
      -1,
   } },

   /* replace697_0 -> 16 in the cache */
   /* replace697_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search698_0 -> 16 in the cache */
   /* search698_1_0 -> 19 in the cache */
   /* search698_1_1 -> 36 in the cache */
   /* search698_1 -> 2125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2125 },
      -1,
   } },

   /* replace698_0 -> 16 in the cache */
   /* replace698_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search699_0_0 -> 21 in the cache */
   /* search699_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 21, 856 },
      -1,
   } },
   /* search699_1_0 -> 41 in the cache */
   /* search699_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 41, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2131, 2132 },
      -1,
   } },

   /* replace699_0_0 -> 21 in the cache */
   /* replace699_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace699_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2134, 856 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search700_0_0 -> 21 in the cache */
   /* search700_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 21, 856 },
      -1,
   } },
   /* search700_1_0 -> 41 in the cache */
   /* search700_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 41, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2136, 2137 },
      -1,
   } },

   /* replace700_0_0 -> 21 in the cache */
   /* replace700_0_1 -> 41 in the cache */
   /* replace700_0 -> 2134 in the cache */
   /* replace700_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2134, 856 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search701_0_0 -> 21 in the cache */
   /* search701_0_1 -> 856 in the cache */
   /* search701_0 -> 2131 in the cache */
   /* search701_1_0 -> 41 in the cache */
   /* search701_1_1 -> 856 in the cache */
   /* search701_1 -> 2132 in the cache */
   /* search701 -> 2133 in the cache */

   /* replace701_0_0 -> 21 in the cache */
   /* replace701_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace701_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2140, 856 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search702_0_0 -> 21 in the cache */
   /* search702_0_1 -> 856 in the cache */
   /* search702_0 -> 2131 in the cache */
   /* search702_1_0 -> 41 in the cache */
   /* search702_1_1 -> 856 in the cache */
   /* search702_1 -> 2132 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2131, 2132 },
      -1,
   } },

   /* replace702_0_0 -> 21 in the cache */
   /* replace702_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace702_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2143, 856 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search703_0_0 -> 21 in the cache */
   /* search703_0_1 -> 856 in the cache */
   /* search703_0 -> 2136 in the cache */
   /* search703_1_0 -> 41 in the cache */
   /* search703_1_1 -> 856 in the cache */
   /* search703_1 -> 2137 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2136, 2137 },
      -1,
   } },

   /* replace703_0_0 -> 21 in the cache */
   /* replace703_0_1 -> 41 in the cache */
   /* replace703_0 -> 2143 in the cache */
   /* replace703_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2143, 856 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search704_0_0 -> 21 in the cache */
   /* search704_0_1 -> 856 in the cache */
   /* search704_0 -> 2136 in the cache */
   /* search704_1_0 -> 41 in the cache */
   /* search704_1_1 -> 856 in the cache */
   /* search704_1 -> 2137 in the cache */
   /* search704 -> 2138 in the cache */

   /* replace704_0_0 -> 21 in the cache */
   /* replace704_0_1 -> 41 in the cache */
   /* replace704_0 -> 2140 in the cache */
   /* replace704_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2140, 856 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search705_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2148 },
      -1,
   } },

   /* replace705 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search706_0 -> 21 in the cache */
   /* search706_1_0 -> 24 in the cache */
   /* search706_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 2150 },
      -1,
   } },

   /* replace706_0 -> 21 in the cache */
   /* replace706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search707_0 -> 21 in the cache */
   /* search707_1_0 -> 24 in the cache */
   /* search707_1_1 -> 36 in the cache */
   /* search707_1 -> 2150 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 21, 2150 },
      -1,
   } },

   /* replace707_0 -> 21 in the cache */
   /* replace707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search708_0 -> 21 in the cache */
   /* search708_1_0 -> 24 in the cache */
   /* search708_1_1 -> 36 in the cache */
   /* search708_1 -> 2150 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2150 },
      -1,
   } },

   /* replace708_0 -> 21 in the cache */
   /* replace708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search709_0_0 -> 32 in the cache */
   /* search709_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search709_1_0 -> 32 in the cache */
   /* search709_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2157, 2158 },
      -1,
   } },

   /* replace709_0 -> 35 in the cache */
   /* replace709_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search710_0_0 -> 35 in the cache */
   /* search710_0_1 -> 32 in the cache */
   /* search710_0 -> 2160 in the cache */
   /* search710_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2160, 2162 },
      -1,
   } },

   /* replace710_0 -> 2161 in the cache */
   /* replace710_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2161, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search711_0_0 -> 2161 in the cache */
   /* search711_0_1 -> 32 in the cache */
   /* search711_0 -> 2164 in the cache */
   /* search711_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2164, 2166 },
      -1,
   } },

   /* replace711_0 -> 2165 in the cache */
   /* replace711_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2165, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search712_0 -> 715 in the cache */
   /* search712_1_0 -> 715 in the cache */
   /* search712_1_1 -> 1033 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 715, 1033 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 715, 2169 },
      -1,
   } },

   /* replace712 -> 1186 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search713_0 -> 32 in the cache */
   /* search713_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 2171 },
      -1,
   } },

   /* replace713 -> 63 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search714_0_0_0 -> 715 in the cache */
   /* search714_0_0 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1177 },
      -1,
   } },
   /* search714_1_0_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2174 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace714_0 -> 715 in the cache */
   /* replace714_1 -> 1084 in the cache */
   /* replace714 -> 1329 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search715_0_0 -> 715 in the cache */
   /* search715_0_1 -> 1084 in the cache */
   /* search715_0 -> 1329 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1329 },
      -1,
   } },

   /* replace715_0_0 -> 715 in the cache */
   /* replace715_0_1 -> 1084 in the cache */
   /* replace715_0 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1101 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search716_0_0_0_0_0 -> 32 in the cache */
   /* search716_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search716_0_0_0_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2179, 1084 },
      -1,
   } },
   /* search716_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2180, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2181 },
      -1,
   } },
   /* search716_1_0 -> 32 in the cache */
   /* search716_1_1 -> 61 in the cache */
   /* search716_1 -> 1200 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2182, 1200 },
      -1,
   } },

   /* replace716_0_0_0 -> 1084 in the cache */
   /* replace716_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1084, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2184 },
      -1,
   } },
   /* replace716_1_0 -> 32 in the cache */
   /* replace716_1_1 -> 61 in the cache */
   /* replace716_1 -> 1200 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2185, 1200 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search717_0_0_0_0_0 -> 0 in the cache */
   /* search717_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search717_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2187, 86 },
      -1,
   } },
   /* search717_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2188, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2189 },
      -1,
   } },
   /* search717_1_0 -> 0 in the cache */
   /* search717_1_1 -> 86 in the cache */
   /* search717_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2190, 90 },
      -1,
   } },

   /* replace717_0_0_0_0 -> 3 in the cache */
   /* replace717_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace717_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2192, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2193 },
      -1,
   } },
   /* replace717_1_0 -> 0 in the cache */
   /* replace717_1_1 -> 86 in the cache */
   /* replace717_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2194, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search718_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search718_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2197 },
      -1,
   } },

   /* replace718_0 -> 32 in the cache */
   /* replace718_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 2196 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search719_0_0 -> 0 in the cache */
   /* search719_0_1 -> 3 in the cache */
   /* search719_0 -> 1234 in the cache */
   /* search719_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1234, 0 },
      -1,
   } },

   /* replace719_0 -> 3 in the cache */
   /* replace719_1 -> 0 in the cache */
   /* replace719 -> 1034 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search720_0 -> 32 in the cache */
   /* search720_1_0 -> 2196 in the cache */
   /* search720_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2201 },
      -1,
   } },

   /* replace720 -> 1186 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search721_0_0 -> 0 in the cache */
   /* search721_0_1 -> 3 in the cache */
   /* search721_0 -> 1232 in the cache */
   /* search721_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1232, 0 },
      -1,
   } },

   /* replace721 -> 1186 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search722_0 -> 32 in the cache */
   /* search722_1_0 -> 2196 in the cache */
   /* search722_1_1 -> 32 in the cache */
   /* search722_1 -> 2201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2201 },
      -1,
   } },

   /* replace722 -> 1033 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search723_0_0 -> 0 in the cache */
   /* search723_0_1 -> 3 in the cache */
   /* search723_0 -> 1232 in the cache */
   /* search723_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1232, 0 },
      -1,
   } },

   /* replace723 -> 1033 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search724_0 -> 32 in the cache */
   /* search724_1_0 -> 2196 in the cache */
   /* search724_1_1 -> 32 in the cache */
   /* search724_1 -> 2197 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2197 },
      -1,
   } },

   /* replace724_0 -> 32 in the cache */
   /* replace724_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 2196 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search725_0_0 -> 0 in the cache */
   /* search725_0_1 -> 3 in the cache */
   /* search725_0 -> 1234 in the cache */
   /* search725_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1234, 0 },
      -1,
   } },

   /* replace725_0 -> 3 in the cache */
   /* replace725_1 -> 0 in the cache */
   /* replace725 -> 1046 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search726_0 -> 32 in the cache */
   /* search726_1_0 -> 2196 in the cache */
   /* search726_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2209 },
      -1,
   } },

   /* replace726_0 -> 32 in the cache */
   /* replace726_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 2196 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search727_0_0 -> 0 in the cache */
   /* search727_0_1 -> 3 in the cache */
   /* search727_0 -> 1294 in the cache */
   /* search727_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1294, 0 },
      -1,
   } },

   /* replace727_0 -> 3 in the cache */
   /* replace727_1 -> 0 in the cache */
   /* replace727 -> 1039 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search728_0 -> 32 in the cache */
   /* search728_1_0 -> 2196 in the cache */
   /* search728_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2213 },
      -1,
   } },

   /* replace728 -> 1186 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search729_0_0 -> 0 in the cache */
   /* search729_0_1 -> 3 in the cache */
   /* search729_0 -> 1286 in the cache */
   /* search729_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1286, 0 },
      -1,
   } },

   /* replace729 -> 1186 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search730_0 -> 32 in the cache */
   /* search730_1_0 -> 2196 in the cache */
   /* search730_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2216 },
      -1,
   } },

   /* replace730_0 -> 32 in the cache */
   /* replace730_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 2196 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search731_0_0 -> 0 in the cache */
   /* search731_0_1 -> 3 in the cache */
   /* search731_0 -> 1291 in the cache */
   /* search731_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1291, 0 },
      -1,
   } },

   /* replace731_0 -> 3 in the cache */
   /* replace731_1 -> 0 in the cache */
   /* replace731 -> 1041 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search732_0 -> 32 in the cache */
   /* search732_1_0 -> 2196 in the cache */
   /* search732_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2220 },
      -1,
   } },

   /* replace732 -> 1186 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search733_0_0 -> 0 in the cache */
   /* search733_0_1 -> 3 in the cache */
   /* search733_0 -> 1283 in the cache */
   /* search733_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1283, 0 },
      -1,
   } },

   /* replace733 -> 1186 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search734_0 -> 32 in the cache */
   /* search734_1_0 -> 2196 in the cache */
   /* search734_1_1 -> 32 in the cache */
   /* search734_1 -> 2213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2213 },
      -1,
   } },

   /* replace734 -> 1033 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search735_0_0 -> 0 in the cache */
   /* search735_0_1 -> 3 in the cache */
   /* search735_0 -> 1286 in the cache */
   /* search735_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1286, 0 },
      -1,
   } },

   /* replace735 -> 1033 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search736_0 -> 32 in the cache */
   /* search736_1_0 -> 2196 in the cache */
   /* search736_1_1 -> 32 in the cache */
   /* search736_1 -> 2209 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2209 },
      -1,
   } },

   /* replace736_0 -> 32 in the cache */
   /* replace736_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 2196 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search737_0_0 -> 0 in the cache */
   /* search737_0_1 -> 3 in the cache */
   /* search737_0 -> 1294 in the cache */
   /* search737_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1294, 0 },
      -1,
   } },

   /* replace737_0 -> 3 in the cache */
   /* replace737_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search738_0 -> 32 in the cache */
   /* search738_1_0 -> 2196 in the cache */
   /* search738_1_1 -> 32 in the cache */
   /* search738_1 -> 2220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2220 },
      -1,
   } },

   /* replace738 -> 1033 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search739_0_0 -> 0 in the cache */
   /* search739_0_1 -> 3 in the cache */
   /* search739_0 -> 1283 in the cache */
   /* search739_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1283, 0 },
      -1,
   } },

   /* replace739 -> 1033 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search740_0 -> 32 in the cache */
   /* search740_1_0 -> 2196 in the cache */
   /* search740_1_1 -> 32 in the cache */
   /* search740_1 -> 2216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2216 },
      -1,
   } },

   /* replace740_0 -> 32 in the cache */
   /* replace740_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 2196 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search741_0_0 -> 0 in the cache */
   /* search741_0_1 -> 3 in the cache */
   /* search741_0 -> 1291 in the cache */
   /* search741_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1291, 0 },
      -1,
   } },

   /* replace741_0 -> 3 in the cache */
   /* replace741_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search742_0 -> 32 in the cache */
   /* search742_1_0 -> 2196 in the cache */
   /* search742_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2235 },
      -1,
   } },

   /* replace742 -> 1033 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search743_0_0 -> 0 in the cache */
   /* search743_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search743_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2237, 0 },
      -1,
   } },

   /* replace743 -> 1033 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search744_0 -> 32 in the cache */
   /* search744_1_0 -> 2196 in the cache */
   /* search744_1_1 -> 32 in the cache */
   /* search744_1 -> 2235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2235 },
      -1,
   } },

   /* replace744 -> 1186 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search745_0_0 -> 0 in the cache */
   /* search745_0_1 -> 3 in the cache */
   /* search745_0 -> 2237 in the cache */
   /* search745_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2237, 0 },
      -1,
   } },

   /* replace745 -> 1186 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search746_0 -> 267 in the cache */
   /* search746_1_0 -> 268 in the cache */
   /* search746_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 267, 2241 },
      -1,
   } },

   /* replace746_0_0 -> 124 in the cache */
   /* replace746_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace746_1_0 -> 124 in the cache */
   /* replace746_1_1 -> 127 in the cache */
   /* replace746_1 -> 1595 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2243, 1595 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search747_0_0 -> 267 in the cache */
   /* search747_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search747_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2245, 769 },
      -1,
   } },

   /* replace747_0_0 -> 124 in the cache */
   /* replace747_0_1 -> 127 in the cache */
   /* replace747_0 -> 1595 in the cache */
   /* replace747_1_0 -> 125 in the cache */
   /* replace747_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1595, 2247 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search748_0 -> 267 in the cache */
   /* search748_1_0 -> 268 in the cache */
   /* search748_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 267, 2249 },
      -1,
   } },

   /* replace748_0_0 -> 124 in the cache */
   /* replace748_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace748_1_0 -> 124 in the cache */
   /* replace748_1_1 -> 127 in the cache */
   /* replace748_1 -> 1605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2251, 1605 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search749_0_0 -> 267 in the cache */
   /* search749_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search749_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2253, 769 },
      -1,
   } },

   /* replace749_0_0 -> 124 in the cache */
   /* replace749_0_1 -> 127 in the cache */
   /* replace749_0 -> 1605 in the cache */
   /* replace749_1_0 -> 125 in the cache */
   /* replace749_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1605, 2255 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search750_0 -> 267 in the cache */
   /* search750_1_0 -> 268 in the cache */
   /* search750_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 267, 2257 },
      -1,
   } },

   /* replace750_0_0 -> 124 in the cache */
   /* replace750_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace750_1_0 -> 124 in the cache */
   /* replace750_1_1 -> 127 in the cache */
   /* replace750_1 -> 1615 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2259, 1615 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search751_0_0 -> 267 in the cache */
   /* search751_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search751_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2261, 769 },
      -1,
   } },

   /* replace751_0_0 -> 124 in the cache */
   /* replace751_0_1 -> 127 in the cache */
   /* replace751_0 -> 1615 in the cache */
   /* replace751_1_0 -> 125 in the cache */
   /* replace751_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1615, 2263 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search752_0 -> 267 in the cache */
   /* search752_1_0 -> 268 in the cache */
   /* search752_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 267, 2265 },
      -1,
   } },

   /* replace752_0_0 -> 124 in the cache */
   /* replace752_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace752_1_0 -> 124 in the cache */
   /* replace752_1_1 -> 127 in the cache */
   /* replace752_1 -> 1625 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2267, 1625 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search753_0_0 -> 267 in the cache */
   /* search753_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search753_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2269, 769 },
      -1,
   } },

   /* replace753_0_0 -> 124 in the cache */
   /* replace753_0_1 -> 127 in the cache */
   /* replace753_0 -> 1625 in the cache */
   /* replace753_1_0 -> 125 in the cache */
   /* replace753_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1625, 2271 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search754_0 -> 267 in the cache */
   /* search754_1_0 -> 268 in the cache */
   /* search754_1_1 -> 127 in the cache */
   /* search754_1 -> 2249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 267, 2249 },
      -1,
   } },

   /* replace754_0_0 -> 124 in the cache */
   /* replace754_0_1 -> 125 in the cache */
   /* replace754_0 -> 2243 in the cache */
   /* replace754_1_0 -> 124 in the cache */
   /* replace754_1_1 -> 127 in the cache */
   /* replace754_1 -> 1595 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2243, 1595 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search755_0_0 -> 267 in the cache */
   /* search755_0_1 -> 125 in the cache */
   /* search755_0 -> 2253 in the cache */
   /* search755_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2253, 769 },
      -1,
   } },

   /* replace755_0_0 -> 124 in the cache */
   /* replace755_0_1 -> 127 in the cache */
   /* replace755_0 -> 1595 in the cache */
   /* replace755_1_0 -> 125 in the cache */
   /* replace755_1_1 -> 127 in the cache */
   /* replace755_1 -> 2247 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1595, 2247 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search756_0 -> 267 in the cache */
   /* search756_1_0 -> 268 in the cache */
   /* search756_1_1 -> 127 in the cache */
   /* search756_1 -> 2241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 267, 2241 },
      -1,
   } },

   /* replace756_0_0 -> 124 in the cache */
   /* replace756_0_1 -> 125 in the cache */
   /* replace756_0 -> 2251 in the cache */
   /* replace756_1_0 -> 124 in the cache */
   /* replace756_1_1 -> 127 in the cache */
   /* replace756_1 -> 1605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2251, 1605 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search757_0_0 -> 267 in the cache */
   /* search757_0_1 -> 125 in the cache */
   /* search757_0 -> 2245 in the cache */
   /* search757_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2245, 769 },
      -1,
   } },

   /* replace757_0_0 -> 124 in the cache */
   /* replace757_0_1 -> 127 in the cache */
   /* replace757_0 -> 1605 in the cache */
   /* replace757_1_0 -> 125 in the cache */
   /* replace757_1_1 -> 127 in the cache */
   /* replace757_1 -> 2255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1605, 2255 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search758_0 -> 267 in the cache */
   /* search758_1_0 -> 268 in the cache */
   /* search758_1_1 -> 127 in the cache */
   /* search758_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 267, 2265 },
      -1,
   } },

   /* replace758_0_0 -> 124 in the cache */
   /* replace758_0_1 -> 125 in the cache */
   /* replace758_0 -> 2259 in the cache */
   /* replace758_1_0 -> 124 in the cache */
   /* replace758_1_1 -> 127 in the cache */
   /* replace758_1 -> 1615 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2259, 1615 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search759_0_0 -> 267 in the cache */
   /* search759_0_1 -> 125 in the cache */
   /* search759_0 -> 2269 in the cache */
   /* search759_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2269, 769 },
      -1,
   } },

   /* replace759_0_0 -> 124 in the cache */
   /* replace759_0_1 -> 127 in the cache */
   /* replace759_0 -> 1615 in the cache */
   /* replace759_1_0 -> 125 in the cache */
   /* replace759_1_1 -> 127 in the cache */
   /* replace759_1 -> 2263 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1615, 2263 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search760_0 -> 267 in the cache */
   /* search760_1_0 -> 268 in the cache */
   /* search760_1_1 -> 127 in the cache */
   /* search760_1 -> 2257 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 267, 2257 },
      -1,
   } },

   /* replace760_0_0 -> 124 in the cache */
   /* replace760_0_1 -> 125 in the cache */
   /* replace760_0 -> 2267 in the cache */
   /* replace760_1_0 -> 124 in the cache */
   /* replace760_1_1 -> 127 in the cache */
   /* replace760_1 -> 1625 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2267, 1625 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search761_0_0 -> 267 in the cache */
   /* search761_0_1 -> 125 in the cache */
   /* search761_0 -> 2261 in the cache */
   /* search761_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2261, 769 },
      -1,
   } },

   /* replace761_0_0 -> 124 in the cache */
   /* replace761_0_1 -> 127 in the cache */
   /* replace761_0 -> 1625 in the cache */
   /* replace761_1_0 -> 125 in the cache */
   /* replace761_1_1 -> 127 in the cache */
   /* replace761_1 -> 2271 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1625, 2271 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search762_0_0 -> 32 in the cache */
   /* search762_0_1 -> 61 in the cache */
   /* search762_0 -> 1200 in the cache */
   /* search762_1_0_0 -> 32 in the cache */
   /* search762_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2289 },
      -1,
   } },
   /* search762_2_0 -> 32 in the cache */
   /* search762_2_1 -> 36 in the cache */
   /* search762_2 -> 2289 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1200, 2290, 2289 },
      -1,
   } },

   /* replace762_0_0 -> 32 in the cache */
   /* replace762_0_1 -> 36 in the cache */
   /* replace762_0 -> 2289 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2289 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search763_0_0_0 -> 32 in the cache */
   /* search763_0_0 -> 106 in the cache */
   /* search763_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2293 },
      -1,
   } },

   /* replace763_0_0 -> 32 in the cache */
   /* replace763_0 -> 106 in the cache */
   /* replace763_1 -> 36 in the cache */
   /* replace763 -> 2293 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search764_0_0 -> 0 in the cache */
   /* search764_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2295 },
      -1,
   } },

   /* replace764_0 -> 0 in the cache */
   /* replace764_1 -> 3 in the cache */
   /* replace764 -> 2295 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search765_0_0 -> 0 in the cache */
   /* search765_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2297 },
      -1,
   } },

   /* replace765_0 -> 0 in the cache */
   /* replace765_1 -> 3 in the cache */
   /* replace765 -> 2297 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search766_0_0 -> 0 in the cache */
   /* search766_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2299 },
      -1,
   } },

   /* replace766_0 -> 0 in the cache */
   /* replace766_1 -> 3 in the cache */
   /* replace766 -> 2299 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search767_0_0 -> 0 in the cache */
   /* search767_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2301 },
      -1,
   } },

   /* replace767_0 -> 0 in the cache */
   /* replace767_1 -> 3 in the cache */
   /* replace767 -> 2301 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search768_0 -> 0 in the cache */
   /* search768_1 -> 3 in the cache */
   /* search768 -> 2295 in the cache */

   /* replace768_0_0 -> 0 in the cache */
   /* replace768_0_1 -> 3 in the cache */
   /* replace768_0 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1005 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search769_0 -> 0 in the cache */
   /* search769_1 -> 3 in the cache */
   /* search769 -> 2297 in the cache */

   /* replace769_0_0 -> 0 in the cache */
   /* replace769_0_1 -> 3 in the cache */
   /* replace769_0 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1002 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search770_0 -> 0 in the cache */
   /* search770_1 -> 3 in the cache */
   /* search770 -> 2299 in the cache */

   /* replace770_0_0 -> 0 in the cache */
   /* replace770_0_1 -> 3 in the cache */
   /* replace770_0 -> 1011 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1011 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search771_0 -> 0 in the cache */
   /* search771_1 -> 3 in the cache */
   /* search771 -> 2301 in the cache */

   /* replace771_0_0 -> 0 in the cache */
   /* replace771_0_1 -> 3 in the cache */
   /* replace771_0 -> 1008 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1008 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search772_0_0 -> 0 in the cache */
   /* search772_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search772_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2307, 255 },
      -1,
   } },

   /* replace772_0 -> 0 in the cache */
   /* replace772_1 -> 3 in the cache */
   /* replace772 -> 2299 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search773_0_0 -> 0 in the cache */
   /* search773_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search773_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2309, 255 },
      -1,
   } },

   /* replace773_0 -> 0 in the cache */
   /* replace773_1 -> 3 in the cache */
   /* replace773 -> 2301 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search774_0_0 -> 0 in the cache */
   /* search774_0_1 -> 3 in the cache */
   /* search774_0 -> 2295 in the cache */
   /* search774_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2295, 255 },
      -1,
   } },

   /* replace774_0 -> 0 in the cache */
   /* replace774_1 -> 3 in the cache */
   /* replace774 -> 2295 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search775_0_0 -> 0 in the cache */
   /* search775_0_1 -> 3 in the cache */
   /* search775_0 -> 2297 in the cache */
   /* search775_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2297, 255 },
      -1,
   } },

   /* replace775_0 -> 0 in the cache */
   /* replace775_1 -> 3 in the cache */
   /* replace775 -> 2297 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search776_0_0 -> 0 in the cache */
   /* search776_0_1 -> 3 in the cache */
   /* search776_0 -> 2307 in the cache */
   /* search776_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2307, 241 },
      -1,
   } },

   /* replace776_0 -> 0 in the cache */
   /* replace776_1 -> 3 in the cache */
   /* replace776 -> 2299 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search777_0_0 -> 0 in the cache */
   /* search777_0_1 -> 3 in the cache */
   /* search777_0 -> 2309 in the cache */
   /* search777_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2309, 241 },
      -1,
   } },

   /* replace777_0 -> 0 in the cache */
   /* replace777_1 -> 3 in the cache */
   /* replace777 -> 2301 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search778_0_0 -> 0 in the cache */
   /* search778_0_1 -> 3 in the cache */
   /* search778_0 -> 2295 in the cache */
   /* search778_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2295, 241 },
      -1,
   } },

   /* replace778_0 -> 0 in the cache */
   /* replace778_1 -> 3 in the cache */
   /* replace778 -> 2295 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search779_0_0 -> 0 in the cache */
   /* search779_0_1 -> 3 in the cache */
   /* search779_0 -> 2297 in the cache */
   /* search779_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2297, 241 },
      -1,
   } },

   /* replace779_0 -> 0 in the cache */
   /* replace779_1 -> 3 in the cache */
   /* replace779 -> 2297 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search780_0_0 -> 0 in the cache */
   /* search780_0_1 -> 3 in the cache */
   /* search780_0 -> 2307 in the cache */
   /* search780_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2307, 241 },
      -1,
   } },

   /* replace780_0 -> 0 in the cache */
   /* replace780_1 -> 3 in the cache */
   /* replace780 -> 2301 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search781_0_0 -> 0 in the cache */
   /* search781_0_1 -> 3 in the cache */
   /* search781_0 -> 2309 in the cache */
   /* search781_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2309, 241 },
      -1,
   } },

   /* replace781_0 -> 0 in the cache */
   /* replace781_1 -> 3 in the cache */
   /* replace781 -> 2299 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search782_0_0 -> 0 in the cache */
   /* search782_0_1 -> 3 in the cache */
   /* search782_0 -> 2295 in the cache */
   /* search782_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2295, 241 },
      -1,
   } },

   /* replace782_0 -> 0 in the cache */
   /* replace782_1 -> 3 in the cache */
   /* replace782 -> 2297 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search783_0_0 -> 0 in the cache */
   /* search783_0_1 -> 3 in the cache */
   /* search783_0 -> 2297 in the cache */
   /* search783_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2297, 241 },
      -1,
   } },

   /* replace783_0 -> 0 in the cache */
   /* replace783_1 -> 3 in the cache */
   /* replace783 -> 2295 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search784_0_0 -> 0 in the cache */
   /* search784_0_1 -> 3 in the cache */
   /* search784_0 -> 2307 in the cache */
   /* search784_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2307, 255 },
      -1,
   } },

   /* replace784_0 -> 0 in the cache */
   /* replace784_1 -> 3 in the cache */
   /* replace784 -> 2301 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search785_0_0 -> 0 in the cache */
   /* search785_0_1 -> 3 in the cache */
   /* search785_0 -> 2309 in the cache */
   /* search785_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2309, 255 },
      -1,
   } },

   /* replace785_0 -> 0 in the cache */
   /* replace785_1 -> 3 in the cache */
   /* replace785 -> 2299 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search786_0_0 -> 0 in the cache */
   /* search786_0_1 -> 3 in the cache */
   /* search786_0 -> 2295 in the cache */
   /* search786_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2295, 255 },
      -1,
   } },

   /* replace786_0 -> 0 in the cache */
   /* replace786_1 -> 3 in the cache */
   /* replace786 -> 2297 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search787_0_0 -> 0 in the cache */
   /* search787_0_1 -> 3 in the cache */
   /* search787_0 -> 2297 in the cache */
   /* search787_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2297, 255 },
      -1,
   } },

   /* replace787_0 -> 0 in the cache */
   /* replace787_1 -> 3 in the cache */
   /* replace787 -> 2295 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search788_0 -> 16 in the cache */
   /* search788_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2326, 2327 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2329, 2330 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2328, 2331 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search789_0 -> 16 in the cache */
   /* search789_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace789_0_0 -> 16 in the cache */
   /* replace789_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace789_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2334, 117 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search790_0 -> 16 in the cache */
   /* search790_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace790_0_0 -> 16 in the cache */
   /* replace790_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace790_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2337, 117 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search791_0 -> 16 in the cache */
   /* search791_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace791_0_0 -> 2326 in the cache */
   /* replace791_0_1 -> 2327 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2326, 2327 },
      -1,
   } },
   /* replace791_1_0 -> 2329 in the cache */
   /* replace791_1_1 -> 2330 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2329, 2330 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2340, 2341 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search792_0 -> 16 in the cache */
   /* search792_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace792_0_0_0 -> 16 in the cache */
   /* replace792_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace792_0_1_0 -> 16 in the cache */
   /* replace792_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2344, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2346 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search793_0 -> 16 in the cache */
   /* search793_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace793_0_0_0 -> 16 in the cache */
   /* replace793_0_0_1 -> 36 in the cache */
   /* replace793_0_0 -> 2344 in the cache */
   /* replace793_0_1_0 -> 16 in the cache */
   /* replace793_0_1_1 -> 36 in the cache */
   /* replace793_0_1 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2344, 2345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2349 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search794_0 -> 0 in the cache */
   /* search794_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace794_0_0 -> 724 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace794_1_0 -> 725 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2353, 2355 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z')) */
   /* search795_0 -> 0 in the cache */
   /* search795_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace795_0_0_0 -> 724 in the cache */
   /* replace795_0_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace795_0_1_0 -> 725 in the cache */
   /* replace795_0_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2358, 2359 },
      -1,
   } },
   /* replace795_1_0 -> 726 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 726, 2361 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2360, 2362 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search796_0 -> 0 in the cache */
   /* search796_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace796_0_0_0 -> 724 in the cache */
   /* replace796_0_0_1 -> 2352 in the cache */
   /* replace796_0_0 -> 2353 in the cache */
   /* replace796_0_1_0 -> 725 in the cache */
   /* replace796_0_1_1 -> 2354 in the cache */
   /* replace796_0_1 -> 2355 in the cache */
   /* replace796_0 -> 2356 in the cache */
   /* replace796_1_0_0 -> 726 in the cache */
   /* replace796_1_0_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 726, 2361 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2366, 2367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2365, 2368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2356, 2369 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search797_0 -> 0 in the cache */
   /* search797_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace797_0_0 -> 724 in the cache */
   /* replace797_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace797_1_0 -> 725 in the cache */
   /* replace797_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2372, 2373 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z')) */
   /* search798_0 -> 0 in the cache */
   /* search798_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace798_0_0_0 -> 724 in the cache */
   /* replace798_0_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace798_0_1_0 -> 725 in the cache */
   /* replace798_0_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2376, 2377 },
      -1,
   } },
   /* replace798_1_0 -> 726 in the cache */
   /* replace798_1_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 726, 2361 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2378, 2379 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search799_0 -> 0 in the cache */
   /* search799_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace799_0_0_0 -> 724 in the cache */
   /* replace799_0_0_1 -> 2352 in the cache */
   /* replace799_0_0 -> 2372 in the cache */
   /* replace799_0_1_0 -> 725 in the cache */
   /* replace799_0_1_1 -> 2354 in the cache */
   /* replace799_0_1 -> 2373 in the cache */
   /* replace799_0 -> 2374 in the cache */
   /* replace799_1_0_0 -> 726 in the cache */
   /* replace799_1_0_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 726, 2361 },
      -1,
   } },
   /* replace799_1_1_0 -> 2366 in the cache */
   /* replace799_1_1_1 -> 2367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2366, 2367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2382, 2383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2374, 2384 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search800_0 -> 0 in the cache */
   /* search800_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace800_0_0 -> 724 in the cache */
   /* replace800_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace800_1_0 -> 725 in the cache */
   /* replace800_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2387, 2388 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z')) */
   /* search801_0 -> 0 in the cache */
   /* search801_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace801_0_0_0 -> 724 in the cache */
   /* replace801_0_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace801_0_1_0 -> 725 in the cache */
   /* replace801_0_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2391, 2392 },
      -1,
   } },
   /* replace801_1_0 -> 726 in the cache */
   /* replace801_1_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 726, 2361 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2393, 2394 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search802_0 -> 0 in the cache */
   /* search802_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace802_0_0_0 -> 724 in the cache */
   /* replace802_0_0_1 -> 2352 in the cache */
   /* replace802_0_0 -> 2387 in the cache */
   /* replace802_0_1_0 -> 725 in the cache */
   /* replace802_0_1_1 -> 2354 in the cache */
   /* replace802_0_1 -> 2388 in the cache */
   /* replace802_0 -> 2389 in the cache */
   /* replace802_1_0_0 -> 726 in the cache */
   /* replace802_1_0_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 726, 2361 },
      -1,
   } },
   /* replace802_1_1_0 -> 2366 in the cache */
   /* replace802_1_1_1 -> 2367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2366, 2367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2397, 2398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2389, 2399 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search803_0 -> 0 in the cache */
   /* search803_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace803_0_0 -> 724 in the cache */
   /* replace803_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace803_1_0 -> 725 in the cache */
   /* replace803_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2402, 2403 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z')) */
   /* search804_0 -> 0 in the cache */
   /* search804_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace804_0_0_0 -> 724 in the cache */
   /* replace804_0_0_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 724, 2352 },
      -1,
   } },
   /* replace804_0_1_0 -> 725 in the cache */
   /* replace804_0_1_1 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 725, 2354 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2406, 2407 },
      -1,
   } },
   /* replace804_1_0 -> 726 in the cache */
   /* replace804_1_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 726, 2361 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2408, 2409 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search805_0 -> 0 in the cache */
   /* search805_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace805_0_0_0 -> 724 in the cache */
   /* replace805_0_0_1 -> 2352 in the cache */
   /* replace805_0_0 -> 2402 in the cache */
   /* replace805_0_1_0 -> 725 in the cache */
   /* replace805_0_1_1 -> 2354 in the cache */
   /* replace805_0_1 -> 2403 in the cache */
   /* replace805_0 -> 2404 in the cache */
   /* replace805_1_0_0 -> 726 in the cache */
   /* replace805_1_0_1 -> 2361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 726, 2361 },
      -1,
   } },
   /* replace805_1_1_0 -> 2366 in the cache */
   /* replace805_1_1_1 -> 2367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2366, 2367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2412, 2413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2404, 2414 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search806_0_0 -> 32 in the cache */
   /* search806_0 -> 98 in the cache */
   /* search806_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace806_0 -> 32 in the cache */
   /* replace806_1 -> 113 in the cache */
   /* replace806 -> 1204 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search807_0_0 -> 32 in the cache */
   /* search807_0 -> 98 in the cache */
   /* search807_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace807_0 -> 32 in the cache */
   /* replace807_1 -> 113 in the cache */
   /* replace807 -> 1208 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search808_0_0 -> 715 in the cache */
   /* search808_0 -> 1177 in the cache */
   /* search808_1_0 -> 1084 in the cache */
   /* search808_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1177, 2174 },
      -1,
   } },

   /* replace808_0_0 -> 715 in the cache */
   /* replace808_0_1 -> 1084 in the cache */
   /* replace808_0 -> 1096 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1096 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search809_0_0 -> 715 in the cache */
   /* search809_0 -> 1177 in the cache */
   /* search809_1_0 -> 1084 in the cache */
   /* search809_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1177, 2174 },
      -1,
   } },

   /* replace809_0_0 -> 715 in the cache */
   /* replace809_0_1 -> 1084 in the cache */
   /* replace809_0 -> 1096 in the cache */
   /* replace809 -> 2419 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search810_0_0 -> 715 in the cache */
   /* search810_0 -> 1177 in the cache */
   /* search810_1_0 -> 1084 in the cache */
   /* search810_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1177, 2174 },
      -1,
   } },

   /* replace810_0_0 -> 715 in the cache */
   /* replace810_0_1 -> 1084 in the cache */
   /* replace810_0 -> 1088 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1088 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search811_0_0 -> 715 in the cache */
   /* search811_0 -> 1079 in the cache */
   /* search811_1_0 -> 1084 in the cache */
   /* search811_1 -> 1085 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1079, 1085 },
      -1,
   } },

   /* replace811_0_0 -> 715 in the cache */
   /* replace811_0_1 -> 1084 in the cache */
   /* replace811_0 -> 1096 in the cache */
   /* replace811 -> 1217 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search812_0_0_0 -> 715 in the cache */
   /* search812_0_0 -> 1079 in the cache */
   /* search812_0_1_0 -> 1084 in the cache */
   /* search812_0_1 -> 1085 in the cache */
   /* search812_0 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1115 },
      -1,
   } },

   /* replace812_0_0 -> 715 in the cache */
   /* replace812_0_1 -> 1084 in the cache */
   /* replace812_0 -> 1088 in the cache */
   /* replace812 -> 1214 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search813_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2425, 462 },
      -1,
   } },

   /* replace813_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search814_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2428, 228 },
      -1,
   } },

   /* replace814_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search815_0_0_0 -> 715 in the cache */
   /* search815_0_0 -> 1079 in the cache */
   /* search815_0 -> 1082 in the cache */
   /* search815_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1082, 1178 },
      -1,
   } },

   /* replace815 -> 715 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search816_0 -> 32 in the cache */
   /* search816_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace816 -> 1033 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search817_0 -> 32 in the cache */
   /* search817_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace817 -> 1186 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search818_0 -> 32 in the cache */
   /* search818_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace818 -> 1186 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search819_0 -> 32 in the cache */
   /* search819_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace819 -> 1033 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search820_0 -> 32 in the cache */
   /* search820_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace820 -> 1033 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search821_0 -> 32 in the cache */
   /* search821_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace821 -> 1186 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search822_0 -> 32 in the cache */
   /* search822_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace822 -> 1033 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search823_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2439, 32 },
      -1,
   } },

   /* replace823 -> 1186 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search824_0 -> 2439 in the cache */
   /* search824_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 2439, 32 },
      -1,
   } },

   /* replace824 -> 1186 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search825_0 -> 2439 in the cache */
   /* search825_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 2439, 32 },
      -1,
   } },

   /* replace825 -> 1033 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search826_0 -> 32 in the cache */
   /* search826_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace826 -> 32 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search827_0 -> 32 in the cache */
   /* search827_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace827 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search828_0 -> 32 in the cache */
   /* search828_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace828 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search829_0 -> 32 in the cache */
   /* search829_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace829 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search830_0 -> 32 in the cache */
   /* search830_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace830 -> 32 in the cache */

   /* ('ior', 'a', True) => True */
   /* search831_0 -> 715 in the cache */
   /* search831_1 -> 1186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 715, 1186 },
      -1,
   } },

   /* replace831 -> 1186 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search832_0 -> 32 in the cache */
   /* search832_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace832 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search833_0 -> 32 in the cache */
   /* search833_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace833 -> 32 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search834_0_0 -> 32 in the cache */
   /* search834_0 -> 2171 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2171 },
      -1,
   } },

   /* replace834 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search835_0_0 -> 0 in the cache */
   /* search835_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search835_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2452, 3 },
      -1,
   } },

   /* replace835 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search836_0_0 -> 0 in the cache */
   /* search836_0_1 -> 3 in the cache */
   /* search836_0 -> 84 in the cache */
   /* search836_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace836_0 -> 0 in the cache */
   /* replace836_1 -> 3 in the cache */
   /* replace836 -> 2237 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search837_0_0 -> 0 in the cache */
   /* search837_0_1 -> 3 in the cache */
   /* search837_0 -> 84 in the cache */
   /* search837_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace837 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search838_0_0 -> 0 in the cache */
   /* search838_0_1 -> 3 in the cache */
   /* search838_0 -> 2452 in the cache */
   /* search838_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2452, 3 },
      -1,
   } },

   /* replace838_0 -> 0 in the cache */
   /* replace838_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search839_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search839_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2458, 2459 },
      -1,
   } },

   /* replace839_0_0 -> 0 in the cache */
   /* replace839_0_1 -> 3 in the cache */
   /* replace839_0 -> 2237 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2237 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search840_0_0 -> 0 in the cache */
   /* search840_0 -> 2458 in the cache */
   /* search840_1_0 -> 3 in the cache */
   /* search840_1 -> 2459 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2458, 2459 },
      -1,
   } },

   /* replace840_0_0 -> 0 in the cache */
   /* replace840_0_1 -> 3 in the cache */
   /* replace840_0 -> 2457 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2457 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search841_0 -> 1178 in the cache */
   /* search841_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1178, 16 },
      -1,
   } },

   /* replace841 -> 1178 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search842_0 -> 32 in the cache */
   /* search842_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace842 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search843_0 -> 1178 in the cache */
   /* search843_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1178, 16 },
      -1,
   } },

   /* replace843 -> 1178 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search844_0 -> 32 in the cache */
   /* search844_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace844 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search845_0 -> 1178 in the cache */
   /* search845_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1178, 16 },
      -1,
   } },

   /* replace845 -> 1178 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search846_0 -> 32 in the cache */
   /* search846_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace846 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search847_0_0 -> 11 in the cache */
   /* search847_0_1 -> 36 in the cache */
   /* search847_0 -> 2101 in the cache */
   /* search847_1_0 -> 11 in the cache */
   /* search847_1_1_0 -> 810 in the cache */
   /* search847_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 810, 2470 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2101, 2472 },
      -1,
   } },

   /* replace847_0 -> 11 in the cache */
   /* replace847_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search848_0_0 -> 11 in the cache */
   /* search848_0_1 -> 36 in the cache */
   /* search848_0 -> 2101 in the cache */
   /* search848_1_0 -> 11 in the cache */
   /* search848_1_1_0 -> 810 in the cache */
   /* search848_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 810, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2101, 2476 },
      -1,
   } },

   /* replace848_0 -> 11 in the cache */
   /* replace848_1 -> 36 in the cache */
   /* replace848 -> 2474 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search849_0_0 -> 16 in the cache */
   /* search849_0_1 -> 36 in the cache */
   /* search849_0 -> 904 in the cache */
   /* search849_1_0 -> 16 in the cache */
   /* search849_1_1_0 -> 832 in the cache */
   /* search849_1_1_1_0 -> 36 in the cache */
   /* search849_1_1_1 -> 2470 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 832, 2470 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2478 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 904, 2479 },
      -1,
   } },

   /* replace849_0 -> 16 in the cache */
   /* replace849_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search850_0_0 -> 16 in the cache */
   /* search850_0_1 -> 36 in the cache */
   /* search850_0 -> 904 in the cache */
   /* search850_1_0 -> 16 in the cache */
   /* search850_1_1_0 -> 832 in the cache */
   /* search850_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 832, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2482 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 904, 2483 },
      -1,
   } },

   /* replace850_0 -> 16 in the cache */
   /* replace850_1 -> 36 in the cache */
   /* replace850 -> 2481 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search851_0_0 -> 11 in the cache */
   /* search851_0_1 -> 36 in the cache */
   /* search851_0 -> 2105 in the cache */
   /* search851_1_0 -> 11 in the cache */
   /* search851_1_1_0 -> 810 in the cache */
   /* search851_1_1_1_0 -> 36 in the cache */
   /* search851_1_1_1 -> 2470 in the cache */
   /* search851_1_1 -> 2471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2105, 2485 },
      -1,
   } },

   /* replace851_0 -> 11 in the cache */
   /* replace851_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search852_0_0 -> 11 in the cache */
   /* search852_0_1 -> 36 in the cache */
   /* search852_0 -> 2105 in the cache */
   /* search852_1_0 -> 11 in the cache */
   /* search852_1_1_0 -> 810 in the cache */
   /* search852_1_1_1 -> 36 in the cache */
   /* search852_1_1 -> 2475 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2105, 2488 },
      -1,
   } },

   /* replace852_0 -> 11 in the cache */
   /* replace852_1 -> 36 in the cache */
   /* replace852 -> 2487 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search853_0_0 -> 16 in the cache */
   /* search853_0_1 -> 36 in the cache */
   /* search853_0 -> 2130 in the cache */
   /* search853_1_0 -> 16 in the cache */
   /* search853_1_1_0 -> 832 in the cache */
   /* search853_1_1_1_0 -> 36 in the cache */
   /* search853_1_1_1 -> 2470 in the cache */
   /* search853_1_1 -> 2478 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2478 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2130, 2490 },
      -1,
   } },

   /* replace853_0 -> 16 in the cache */
   /* replace853_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search854_0_0 -> 16 in the cache */
   /* search854_0_1 -> 36 in the cache */
   /* search854_0 -> 2130 in the cache */
   /* search854_1_0 -> 16 in the cache */
   /* search854_1_1_0 -> 832 in the cache */
   /* search854_1_1_1 -> 36 in the cache */
   /* search854_1_1 -> 2482 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2482 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2130, 2493 },
      -1,
   } },

   /* replace854_0 -> 16 in the cache */
   /* replace854_1 -> 36 in the cache */
   /* replace854 -> 2492 in the cache */

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search855_0 -> 11 in the cache */
   /* search855_1 -> 36 in the cache */
   /* search855 -> 2474 in the cache */

   /* replace855_0_0 -> 11 in the cache */
   /* replace855_0_1 -> 36 in the cache */
   /* replace855_0 -> 2101 in the cache */
   /* replace855_1_0 -> 11 in the cache */
   /* replace855_1_1_0 -> 810 in the cache */
   /* replace855_1_1_1 -> 36 in the cache */
   /* replace855_1_1 -> 2475 in the cache */
   /* replace855_1 -> 2476 in the cache */
   /* replace855 -> 2477 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search856_0 -> 16 in the cache */
   /* search856_1 -> 36 in the cache */
   /* search856 -> 2481 in the cache */

   /* replace856_0_0 -> 16 in the cache */
   /* replace856_0_1 -> 36 in the cache */
   /* replace856_0 -> 904 in the cache */
   /* replace856_1_0 -> 16 in the cache */
   /* replace856_1_1_0 -> 832 in the cache */
   /* replace856_1_1_1 -> 36 in the cache */
   /* replace856_1_1 -> 2482 in the cache */
   /* replace856_1 -> 2483 in the cache */
   /* replace856 -> 2484 in the cache */

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search857_0 -> 11 in the cache */
   /* search857_1 -> 36 in the cache */
   /* search857 -> 2487 in the cache */

   /* replace857_0_0 -> 11 in the cache */
   /* replace857_0_1 -> 36 in the cache */
   /* replace857_0 -> 2105 in the cache */
   /* replace857_1_0 -> 11 in the cache */
   /* replace857_1_1_0 -> 810 in the cache */
   /* replace857_1_1_1 -> 36 in the cache */
   /* replace857_1_1 -> 2475 in the cache */
   /* replace857_1 -> 2488 in the cache */
   /* replace857 -> 2489 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search858_0 -> 16 in the cache */
   /* search858_1 -> 36 in the cache */
   /* search858 -> 2492 in the cache */

   /* replace858_0_0 -> 16 in the cache */
   /* replace858_0_1 -> 36 in the cache */
   /* replace858_0 -> 2130 in the cache */
   /* replace858_1_0 -> 16 in the cache */
   /* replace858_1_1_0 -> 832 in the cache */
   /* replace858_1_1_1 -> 36 in the cache */
   /* replace858_1_1 -> 2482 in the cache */
   /* replace858_1 -> 2493 in the cache */
   /* replace858 -> 2494 in the cache */

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search859_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 2495 },
      -1,
   } },

   /* replace859 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search860_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2497 },
      -1,
   } },

   /* replace860 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search861_0 -> 0 in the cache */
   /* search861_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace861_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace861_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2500, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2501 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search862_0_0_0 -> 0 in the cache */
   /* search862_0_0 -> 2500 in the cache */
   /* search862_0_1 -> 3 in the cache */
   /* search862_0 -> 2501 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2501 },
      -1,
   } },

   /* replace862_0 -> 0 in the cache */
   /* replace862_1 -> 3 in the cache */
   /* replace862 -> 2499 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search863_0_0_0_0 -> 147 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 147 },
      -1,
   } },
   /* search863_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 2504, 148 },
      -1,
   } },
   /* search863_0_1_0_0 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 150 },
      -1,
   } },
   /* search863_0_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 2506, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 2505, 2507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 2508 },
      -1,
   } },

   /* replace863_0_0 -> 147 in the cache */
   /* replace863_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 147, 148 },
      -1,
   } },
   /* replace863_1_0 -> 150 in the cache */
   /* replace863_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2510, 2511 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search864_0_0_0 -> 32 in the cache */
   /* search864_0_0 -> 2495 in the cache */
   /* search864_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2495, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2513 },
      -1,
   } },

   /* replace864_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search865_0_0_0 -> 32 in the cache */
   /* search865_0_0 -> 2495 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2495, 2516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2517 },
      -1,
   } },

   /* replace865_0 -> 32 in the cache */
   /* replace865_1 -> 32 in the cache */
   /* replace865 -> 236 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search866_0_0_0 -> 32 in the cache */
   /* search866_0_0 -> 2495 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2495, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2520 },
      -1,
   } },

   /* replace866_0_0 -> 32 in the cache */
   /* replace866_0_1 -> 32 in the cache */
   /* replace866_0 -> 236 in the cache */
   /* replace866_1_0 -> 32 in the cache */
   /* replace866_1_1 -> 32 in the cache */
   /* replace866_1 -> 236 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 236, 236 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search867_0 -> 32 in the cache */
   /* search867_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* replace867 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search868_0 -> 32 in the cache */
   /* search868_1 -> 2516 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2516 },
      -1,
   } },

   /* replace868_0 -> 32 in the cache */
   /* replace868_1 -> 32 in the cache */
   /* replace868 -> 236 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search869_0 -> 32 in the cache */
   /* search869_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2519 },
      -1,
   } },

   /* replace869_0_0 -> 32 in the cache */
   /* replace869_0_1 -> 32 in the cache */
   /* replace869_0 -> 236 in the cache */
   /* replace869_1_0 -> 32 in the cache */
   /* replace869_1_1 -> 32 in the cache */
   /* replace869_1 -> 236 in the cache */
   /* replace869 -> 2522 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search870_0 -> 2516 in the cache */
   /* search870_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2516, 32 },
      -1,
   } },

   /* replace870_0 -> 32 in the cache */
   /* replace870 -> 2497 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search871_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2527 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2528, 2529 },
      -1,
   } },

   /* replace871 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search872_0_0_0 -> 32 in the cache */
   /* search872_0_0_1 -> 2527 in the cache */
   /* search872_0_0 -> 2528 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2528 },
      -1,
   } },
   /* search872_1 -> 2529 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2531, 2529 },
      -1,
   } },

   /* replace872_0 -> 32 in the cache */
   /* replace872 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search873_0_0 -> 32 in the cache */
   /* search873_0 -> 2497 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 2497 },
      -1,
   } },

   /* replace873_0_0 -> 676 in the cache */
   /* replace873_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 676, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2534 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search874_0_0 -> 32 in the cache */
   /* search874_0 -> 2497 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2497 },
      -1,
   } },

   /* replace874_0_0 -> 32 in the cache */
   /* replace874_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search875_0_0 -> 32 in the cache */
   /* search875_0 -> 2497 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 2497 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace875_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2539, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2540 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search876_0_0 -> 32 in the cache */
   /* search876_0 -> 2515 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2515 },
      -1,
   } },

   /* replace876_0 -> 676 in the cache */
   /* replace876_1_0 -> 32 in the cache */
   /* replace876_1 -> 2495 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 676, 2495 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search877_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2544 },
      -1,
   } },

   /* replace877_0_0 -> 32 in the cache */
   /* replace877_0 -> 2495 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2495 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search878_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2547 },
      -1,
   } },

   /* replace878_0 -> 2539 in the cache */
   /* replace878_1_0 -> 32 in the cache */
   /* replace878_1 -> 2495 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2539, 2495 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search879_0_0 -> 0 in the cache */
   /* search879_0_1 -> 3 in the cache */
   /* search879_0 -> 2499 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2499 },
      -1,
   } },

   /* replace879_0 -> 3 in the cache */
   /* replace879_1_0 -> 0 in the cache */
   /* replace879_1 -> 2500 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 2500 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search880_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search880_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2552, 2553 },
      -1,
   } },

   /* replace880_0_0 -> 0 in the cache */
   /* replace880_0_1 -> 3 in the cache */
   /* replace880_0 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 257 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search881_0_0 -> 32 in the cache */
   /* search881_0_1 -> 113 in the cache */
   /* search881_0 -> 670 in the cache */
   /* search881_1 -> 113 in the cache */
   /* search881_2_0 -> 32 in the cache */
   /* search881_2 -> 2515 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 113, 2515 },
      -1,
   } },

   /* replace881_0_0 -> 32 in the cache */
   /* replace881_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 2557 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search882_0_0 -> 32 in the cache */
   /* search882_0 -> 2515 in the cache */
   /* search882_1_0 -> 32 in the cache */
   /* search882_1 -> 2515 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 2515, 2515 },
      -1,
   } },

   /* replace882_0 -> 32 in the cache */
   /* replace882 -> 103 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search883_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search883_1_0 -> 16 in the cache */
   /* search883_1 -> 2560 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 2560, 2560 },
      -1,
   } },

   /* replace883_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search884_0 -> 226 in the cache */
   /* search884_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* replace884_0 -> 32 in the cache */
   /* replace884 -> 2544 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search885_0 -> 0 in the cache */
   /* search885_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace885_0 -> 0 in the cache */
   /* replace885_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2565 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search886_0_0 -> 32 in the cache */
   /* search886_0 -> 2544 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2544 },
      -1,
   } },

   /* replace886 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search887_0_0 -> 32 in the cache */
   /* search887_0 -> 2515 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2515 },
      -1,
   } },

   /* replace887_0 -> 32 in the cache */
   /* replace887 -> 2547 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search888_0 -> 32 in the cache */
   /* search888 -> 2515 in the cache */

   /* replace888_0_0 -> 32 in the cache */
   /* replace888_0 -> 2547 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2547 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search889_0_0 -> 32 in the cache */
   /* search889_0 -> 2547 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2547 },
      -1,
   } },

   /* replace889_0 -> 32 in the cache */
   /* replace889 -> 2515 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search890_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace890_0_0_0_0_0_0 -> 2516 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace890_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_0_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2573, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2516, 2575 },
      -1,
   } },
   /* replace890_0_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2576, 226 },
      -1,
   } },
   /* replace890_0_0_0_1_0_0_0 -> 2516 in the cache */
   /* replace890_0_0_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_0_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2578, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2516, 2580 },
      -1,
   } },
   /* replace890_0_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2581, 226 },
      -1,
   } },
   /* replace890_0_0_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace890_0_0_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_0_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2583, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2584 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2516, 2585 },
      -1,
   } },
   /* replace890_0_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2586, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2582, 2588 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2577, 2589 },
      -1,
   } },
   /* replace890_0_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2590, 2519 },
      -1,
   } },
   /* replace890_0_1_0_0_0_0_0 -> 2516 in the cache */
   /* replace890_0_1_0_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_1_0_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2592, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2593 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2516, 2594 },
      -1,
   } },
   /* replace890_0_1_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2595, 226 },
      -1,
   } },
   /* replace890_0_1_0_0_1_0_0_0 -> 2516 in the cache */
   /* replace890_0_1_0_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_1_0_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2597, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2516, 2599 },
      -1,
   } },
   /* replace890_0_1_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2600, 226 },
      -1,
   } },
   /* replace890_0_1_0_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace890_0_1_0_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_1_0_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2602, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2516, 2604 },
      -1,
   } },
   /* replace890_0_1_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2605, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2601, 2607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2596, 2608 },
      -1,
   } },
   /* replace890_0_1_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2609, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2610 },
      -1,
   } },
   /* replace890_0_2_0_0_0_0_0 -> 2516 in the cache */
   /* replace890_0_2_0_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_2_0_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2612, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2613 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2516, 2614 },
      -1,
   } },
   /* replace890_0_2_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2615, 226 },
      -1,
   } },
   /* replace890_0_2_0_0_1_0_0_0 -> 2516 in the cache */
   /* replace890_0_2_0_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_2_0_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2617, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2618 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2516, 2619 },
      -1,
   } },
   /* replace890_0_2_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2620, 226 },
      -1,
   } },
   /* replace890_0_2_0_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace890_0_2_0_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_0_2_0_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2622, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2623 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2516, 2624 },
      -1,
   } },
   /* replace890_0_2_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2625, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2626 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2621, 2627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2616, 2628 },
      -1,
   } },
   /* replace890_0_2_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2629, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2630 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2591, 2611, 2631 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace890_2_0_0_0_0 -> 2516 in the cache */
   /* replace890_2_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_2_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2634, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2635 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2516, 2636 },
      -1,
   } },
   /* replace890_2_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2637, 226 },
      -1,
   } },
   /* replace890_2_0_1_0_0_0 -> 2516 in the cache */
   /* replace890_2_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_2_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2639, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2516, 2641 },
      -1,
   } },
   /* replace890_2_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2642, 226 },
      -1,
   } },
   /* replace890_2_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace890_2_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace890_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 2572, 32 },
      -1,
   } },
   /* replace890_2_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2644, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2516, 2646 },
      -1,
   } },
   /* replace890_2_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2647, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2648 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2643, 2649 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2638, 2650 },
      -1,
   } },
   /* replace890_2_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2651, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2632, 2633, 2652 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search891_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace891_0_0_0_0_0_0 -> 2516 in the cache */
   /* replace891_0_0_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_0_0_0_0_1_0_0 -> 2573 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2573, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2656 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2516, 2657 },
      -1,
   } },
   /* replace891_0_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2658, 226 },
      -1,
   } },
   /* replace891_0_0_0_1_0_0_0 -> 2516 in the cache */
   /* replace891_0_0_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_0_0_1_0_0_1_0_0 -> 2578 in the cache */
   /* replace891_0_0_0_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2578, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2660 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2516, 2661 },
      -1,
   } },
   /* replace891_0_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2662, 226 },
      -1,
   } },
   /* replace891_0_0_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace891_0_0_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_0_0_1_1_0_0_1_0_0 -> 2583 in the cache */
   /* replace891_0_0_0_1_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2583, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2516, 2665 },
      -1,
   } },
   /* replace891_0_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2666, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2667 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2663, 2668 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2659, 2669 },
      -1,
   } },
   /* replace891_0_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2670, 2519 },
      -1,
   } },
   /* replace891_0_1_0_0_0_0_0 -> 2516 in the cache */
   /* replace891_0_1_0_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_1_0_0_0_0_1_0_0 -> 2592 in the cache */
   /* replace891_0_1_0_0_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2592, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2672 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2516, 2673 },
      -1,
   } },
   /* replace891_0_1_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2674, 226 },
      -1,
   } },
   /* replace891_0_1_0_0_1_0_0_0 -> 2516 in the cache */
   /* replace891_0_1_0_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_1_0_0_1_0_0_1_0_0 -> 2597 in the cache */
   /* replace891_0_1_0_0_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2597, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2516, 2677 },
      -1,
   } },
   /* replace891_0_1_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2678, 226 },
      -1,
   } },
   /* replace891_0_1_0_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace891_0_1_0_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_1_0_0_1_1_0_0_1_0_0 -> 2602 in the cache */
   /* replace891_0_1_0_0_1_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2602, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2680 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2516, 2681 },
      -1,
   } },
   /* replace891_0_1_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2682, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2683 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2679, 2684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2675, 2685 },
      -1,
   } },
   /* replace891_0_1_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2686, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2687 },
      -1,
   } },
   /* replace891_0_2_0_0_0_0_0 -> 2516 in the cache */
   /* replace891_0_2_0_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_2_0_0_0_0_1_0_0 -> 2612 in the cache */
   /* replace891_0_2_0_0_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2612, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2516, 2690 },
      -1,
   } },
   /* replace891_0_2_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2691, 226 },
      -1,
   } },
   /* replace891_0_2_0_0_1_0_0_0 -> 2516 in the cache */
   /* replace891_0_2_0_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_2_0_0_1_0_0_1_0_0 -> 2617 in the cache */
   /* replace891_0_2_0_0_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2617, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2693 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2516, 2694 },
      -1,
   } },
   /* replace891_0_2_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2695, 226 },
      -1,
   } },
   /* replace891_0_2_0_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace891_0_2_0_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_0_2_0_0_1_1_0_0_1_0_0 -> 2622 in the cache */
   /* replace891_0_2_0_0_1_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2622, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2516, 2698 },
      -1,
   } },
   /* replace891_0_2_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2699, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2700 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2696, 2701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2692, 2702 },
      -1,
   } },
   /* replace891_0_2_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2703, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2671, 2688, 2705 },
      -1,
   } },
   /* replace891_1 -> 2633 in the cache */
   /* replace891_2_0_0_0_0 -> 2516 in the cache */
   /* replace891_2_0_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_2_0_0_0_1_0_0 -> 2634 in the cache */
   /* replace891_2_0_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2634, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2707 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2516, 2708 },
      -1,
   } },
   /* replace891_2_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2709, 226 },
      -1,
   } },
   /* replace891_2_0_1_0_0_0 -> 2516 in the cache */
   /* replace891_2_0_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_2_0_1_0_0_1_0_0 -> 2639 in the cache */
   /* replace891_2_0_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2639, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2711 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2516, 2712 },
      -1,
   } },
   /* replace891_2_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2713, 226 },
      -1,
   } },
   /* replace891_2_0_1_1_0_0_0 -> 2516 in the cache */
   /* replace891_2_0_1_1_0_0_1_0_0_0 -> 2572 in the cache */
   /* replace891_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace891_2_0_1_1_0_0_1_0_0 -> 2644 in the cache */
   /* replace891_2_0_1_1_0_0_1_0_1 -> 2655 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2644, 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2715 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2516, 2716 },
      -1,
   } },
   /* replace891_2_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2717, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2714, 2719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2710, 2720 },
      -1,
   } },
   /* replace891_2_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2721, 2519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2706, 2633, 2722 },
      -1,
   } },

   /* ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0) */
   /* search892_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace892_0 -> 32 in the cache */
   /* replace892_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ine16,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0) */
   /* search893_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace893_0 -> 32 in the cache */
   /* replace893_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ine32,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0) */
   /* search894_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace894_0 -> 32 in the cache */
   /* replace894_1 -> 61 in the cache */
   /* replace894 -> 1182 in the cache */

   /* ('ieq', 'a', True) => a */
   /* search895_0 -> 715 in the cache */
   /* search895_1 -> 1186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 1186 },
      -1,
   } },

   /* replace895 -> 715 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search896_0 -> 715 in the cache */
   /* search896_1 -> 1186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 1186 },
      3,
   } },

   /* replace896_0 -> 715 in the cache */
   /* replace896 -> 1081 in the cache */

   /* ('ine', 'a', False) => a */
   /* search897_0 -> 715 in the cache */
   /* search897_1 -> 1033 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 1033 },
      -1,
   } },

   /* replace897 -> 715 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search898_0 -> 715 in the cache */
   /* search898_1 -> 1033 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 1033 },
      3,
   } },

   /* replace898_0 -> 715 in the cache */
   /* replace898 -> 1081 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search899_0 -> 715 in the cache */
   /* search899_1 -> 1186 in the cache */
   /* search899_2 -> 1033 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1186, 1033 },
      -1,
   } },

   /* replace899 -> 715 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search900_0 -> 715 in the cache */
   /* search900_1 -> 1033 in the cache */
   /* search900_2 -> 1186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1033, 1186 },
      -1,
   } },

   /* replace900_0 -> 715 in the cache */
   /* replace900 -> 1081 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search901_0 -> 1186 in the cache */
   /* search901_1 -> 1067 in the cache */
   /* search901_2 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1186, 1067, 665 },
      -1,
   } },

   /* replace901 -> 1067 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search902_0 -> 1033 in the cache */
   /* search902_1 -> 1067 in the cache */
   /* search902_2 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1033, 1067, 665 },
      -1,
   } },

   /* replace902 -> 665 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search903_0 -> 715 in the cache */
   /* search903_1 -> 462 in the cache */
   /* search903_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 462, 115 },
      -1,
   } },

   /* replace903_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search904_0 -> 715 in the cache */
   /* search904_1 -> 115 in the cache */
   /* search904_2 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 115, 462 },
      -1,
   } },

   /* replace904_0_0 -> 715 in the cache */
   /* replace904_0 -> 1081 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1081 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search905_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2741, 2742 },
      -1,
   } },

   /* replace905_0_0 -> 715 in the cache */
   /* replace905_0 -> 2738 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2738 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search906_0 -> 715 in the cache */
   /* search906_1 -> 2742 in the cache */
   /* search906_2 -> 2741 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2742, 2741 },
      -1,
   } },

   /* replace906_0_0_0 -> 715 in the cache */
   /* replace906_0_0 -> 1081 in the cache */
   /* replace906_0 -> 2740 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2740 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search907_0 -> 715 in the cache */
   /* search907_1 -> 228 in the cache */
   /* search907_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 228, 117 },
      -1,
   } },

   /* replace907_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search908_0 -> 715 in the cache */
   /* search908_1 -> 117 in the cache */
   /* search908_2 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 117, 228 },
      -1,
   } },

   /* replace908_0_0 -> 715 in the cache */
   /* replace908_0 -> 1081 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1081 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search909_0 -> 715 in the cache */
   /* search909_1 -> 263 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 263, 2751 },
      -1,
   } },

   /* replace909_0_0 -> 715 in the cache */
   /* replace909_0 -> 2748 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2748 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search910_0 -> 715 in the cache */
   /* search910_1 -> 2751 in the cache */
   /* search910_2 -> 263 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2751, 263 },
      -1,
   } },

   /* replace910_0_0_0 -> 715 in the cache */
   /* replace910_0_0 -> 1081 in the cache */
   /* replace910_0 -> 2750 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2750 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search911_0 -> 715 in the cache */
   /* search911_1 -> 603 in the cache */
   /* search911_2 -> 1865 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 603, 1865 },
      -1,
   } },

   /* replace911_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search912_0 -> 715 in the cache */
   /* search912_1 -> 1865 in the cache */
   /* search912_2 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1865, 603 },
      -1,
   } },

   /* replace912_0_0 -> 715 in the cache */
   /* replace912_0 -> 1081 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1081 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search913_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2760, 2761 },
      -1,
   } },

   /* replace913_0_0 -> 715 in the cache */
   /* replace913_0 -> 2757 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2757 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search914_0 -> 715 in the cache */
   /* search914_1 -> 2761 in the cache */
   /* search914_2 -> 2760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2761, 2760 },
      -1,
   } },

   /* replace914_0_0_0 -> 715 in the cache */
   /* replace914_0_0 -> 1081 in the cache */
   /* replace914_0 -> 2759 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2759 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search915_0 -> 715 in the cache */
   /* search915_1 -> 3 in the cache */
   /* search915_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 3, 3 },
      -1,
   } },

   /* replace915 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search916_0 -> 16 in the cache */
   /* search916_1 -> 36 in the cache */
   /* search916_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace916 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search917_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search917_2 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2768, 1178 },
      -1,
   } },

   /* replace917_0_0 -> 715 in the cache */
   /* replace917_0 -> 1177 in the cache */
   /* replace917 -> 2173 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search918_0 -> 715 in the cache */
   /* search918_1 -> 1178 in the cache */
   /* search918_2 -> 2768 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1178, 2768 },
      -1,
   } },

   /* replace918_0_0_0 -> 715 in the cache */
   /* replace918_0_0 -> 1081 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1081 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2771 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search919_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search919_2 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2773, 1178 },
      -1,
   } },

   /* replace919_0 -> 715 in the cache */
   /* replace919 -> 1177 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search920_0 -> 715 in the cache */
   /* search920_1 -> 1178 in the cache */
   /* search920_2 -> 2773 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1178, 2773 },
      -1,
   } },

   /* replace920_0_0 -> 715 in the cache */
   /* replace920_0 -> 1081 in the cache */
   /* replace920 -> 2771 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search921_0_0_0 -> 715 in the cache */
   /* search921_0_0 -> 1177 in the cache */
   /* search921_0 -> 2173 in the cache */
   /* search921_1_0_0 -> 1084 in the cache */
   /* search921_1_0 -> 2174 in the cache */
   /* search921_1 -> 2175 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace921_0_0_0 -> 715 in the cache */
   /* replace921_0_0_1 -> 1084 in the cache */
   /* replace921_0_0 -> 1096 in the cache */
   /* replace921_0 -> 2419 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2419 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search922_0_0_0 -> 715 in the cache */
   /* search922_0_0 -> 1177 in the cache */
   /* search922_0 -> 2173 in the cache */
   /* search922_1_0_0 -> 1084 in the cache */
   /* search922_1_0 -> 2174 in the cache */
   /* search922_1 -> 2175 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace922_0_0_0 -> 715 in the cache */
   /* replace922_0_0_1 -> 1084 in the cache */
   /* replace922_0_0 -> 1088 in the cache */
   /* replace922_0 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2422 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search923_0_0_0 -> 715 in the cache */
   /* search923_0_0 -> 1177 in the cache */
   /* search923_0 -> 2173 in the cache */
   /* search923_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2173, 1178 },
      -1,
   } },

   /* replace923_0 -> 715 in the cache */
   /* replace923 -> 1081 in the cache */

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search924_0_0_0 -> 715 in the cache */
   /* search924_0_0 -> 1177 in the cache */
   /* search924_0 -> 2173 in the cache */
   /* search924_1 -> 2768 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2173, 2768 },
      -1,
   } },

   /* replace924 -> 715 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search925_0_0_0 -> 715 in the cache */
   /* search925_0_0 -> 1177 in the cache */
   /* search925_0 -> 2173 in the cache */
   /* search925_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2173, 1178 },
      -1,
   } },

   /* replace925 -> 715 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search926_0_0_0 -> 715 in the cache */
   /* search926_0_0 -> 1177 in the cache */
   /* search926_0 -> 2173 in the cache */
   /* search926_1 -> 2768 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2173, 2768 },
      -1,
   } },

   /* replace926_0 -> 715 in the cache */
   /* replace926 -> 1081 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search927_0_0_0 -> 715 in the cache */
   /* search927_0_0 -> 1177 in the cache */
   /* search927_0 -> 2173 in the cache */
   /* search927_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2173, 1178 },
      -1,
   } },

   /* replace927_0 -> 715 in the cache */
   /* replace927 -> 1081 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search928_0_0_0 -> 715 in the cache */
   /* search928_0_0 -> 1177 in the cache */
   /* search928_0 -> 2173 in the cache */
   /* search928_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2173, 1178 },
      -1,
   } },

   /* replace928 -> 715 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search929_0 -> 1178 in the cache */
   /* search929_1_0_0 -> 715 in the cache */
   /* search929_1_0 -> 1177 in the cache */
   /* search929_1 -> 2173 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1178, 2173 },
      -1,
   } },

   /* replace929 -> 715 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search930_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2787 },
      -1,
   } },
   /* search930_1 -> 1089 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2788, 1089 },
      -1,
   } },

   /* replace930_0 -> 32 in the cache */
   /* replace930 -> 1466 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search931_0_0_0 -> 32 in the cache */
   /* search931_0_0 -> 2787 in the cache */
   /* search931_0 -> 2788 in the cache */
   /* search931_1 -> 2773 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2788, 2773 },
      -1,
   } },

   /* replace931_0 -> 32 in the cache */
   /* replace931 -> 2787 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search932_0_0_0 -> 715 in the cache */
   /* search932_0_0 -> 1177 in the cache */
   /* search932_0 -> 2173 in the cache */
   /* search932_1_0_0 -> 1084 in the cache */
   /* search932_1_0 -> 2174 in the cache */
   /* search932_1 -> 2175 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace932_0_0_0 -> 715 in the cache */
   /* replace932_0_0_1 -> 1084 in the cache */
   /* replace932_0_0 -> 1096 in the cache */
   /* replace932_0 -> 2419 in the cache */
   /* replace932 -> 2777 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search933_0_0_0 -> 715 in the cache */
   /* search933_0_0 -> 1177 in the cache */
   /* search933_0 -> 2173 in the cache */
   /* search933_1_0_0 -> 1084 in the cache */
   /* search933_1_0 -> 2174 in the cache */
   /* search933_1 -> 2175 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace933_0_0_0 -> 715 in the cache */
   /* replace933_0_0_1 -> 1084 in the cache */
   /* replace933_0_0 -> 1088 in the cache */
   /* replace933_0 -> 2422 in the cache */
   /* replace933 -> 2779 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search934_0_0_0 -> 715 in the cache */
   /* search934_0_0 -> 1177 in the cache */
   /* search934_0 -> 2173 in the cache */
   /* search934_1_0_0 -> 1084 in the cache */
   /* search934_1_0 -> 2174 in the cache */
   /* search934_1 -> 2175 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace934_0_0_0 -> 715 in the cache */
   /* replace934_0_0_1 -> 1084 in the cache */
   /* replace934_0_0 -> 1088 in the cache */
   /* replace934_0 -> 2422 in the cache */
   /* replace934 -> 2779 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search935_0_0_0 -> 715 in the cache */
   /* search935_0_0 -> 1177 in the cache */
   /* search935_0 -> 2173 in the cache */
   /* search935_1_0_0 -> 1084 in the cache */
   /* search935_1_0 -> 2174 in the cache */
   /* search935_1 -> 2175 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2173, 2175 },
      -1,
   } },

   /* replace935_0_0_0 -> 715 in the cache */
   /* replace935_0_0_1 -> 1084 in the cache */
   /* replace935_0_0 -> 1096 in the cache */
   /* replace935_0 -> 2419 in the cache */
   /* replace935 -> 2777 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search936_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 2795 },
      -1,
   } },

   /* replace936 -> 11 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search937_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 2797 },
      -1,
   } },

   /* replace937 -> 16 in the cache */

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search938_0_0 -> 32 in the cache */
   /* search938_0 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 669 },
      -1,
   } },

   /* replace938_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search939_0_0 -> 32 in the cache */
   /* search939_0 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 669 },
      -1,
   } },

   /* replace939_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search940_0_0 -> 32 in the cache */
   /* search940_0 -> 100 in the cache */
   /* search940 -> 111 in the cache */

   /* replace940_0 -> 32 in the cache */
   /* replace940 -> 112 in the cache */

   /* ('i2b', ('iabs', 'a')) => ('i2b', 'a') */
   /* search941_0_0 -> 32 in the cache */
   /* search941_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace941_0 -> 32 in the cache */
   /* replace941 -> 112 in the cache */

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search942_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2804 },
      -1,
   } },

   /* replace942_0 -> 32 in the cache */
   /* replace942_1 -> 113 in the cache */
   /* replace942 -> 1208 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search943_0_0 -> 11 in the cache */
   /* search943_0 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1739 },
      -1,
   } },

   /* replace943 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search944_0_0 -> 11 in the cache */
   /* search944_0 -> 1741 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1741 },
      -1,
   } },

   /* replace944 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search945_0_0 -> 11 in the cache */
   /* search945_0 -> 1743 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1743 },
      -1,
   } },

   /* replace945 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search946_0_0 -> 11 in the cache */
   /* search946_0 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1739 },
      -1,
   } },

   /* replace946_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search947_0_0 -> 11 in the cache */
   /* search947_0 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1739 },
      -1,
   } },

   /* replace947_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search948_0_0 -> 11 in the cache */
   /* search948_0 -> 1741 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1741 },
      -1,
   } },

   /* replace948_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search949_0_0 -> 11 in the cache */
   /* search949_0 -> 1743 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1743 },
      -1,
   } },

   /* replace949_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search950_0_0 -> 715 in the cache */
   /* search950_0 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1346 },
      -1,
   } },

   /* replace950_0 -> 715 in the cache */
   /* replace950 -> 1342 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search951_0_0 -> 715 in the cache */
   /* search951_0 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1334 },
      -1,
   } },

   /* replace951_0 -> 715 in the cache */
   /* replace951 -> 1330 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search952_0_0 -> 715 in the cache */
   /* search952_0 -> 1334 in the cache */
   /* search952 -> 2818 in the cache */

   /* replace952_0 -> 715 in the cache */
   /* replace952 -> 1330 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search953_0_0 -> 715 in the cache */
   /* search953_0 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1346 },
      -1,
   } },

   /* replace953_0 -> 715 in the cache */
   /* replace953 -> 1330 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search954_0_0 -> 715 in the cache */
   /* search954_0 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1346 },
      -1,
   } },

   /* replace954_0 -> 715 in the cache */
   /* replace954 -> 1330 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search955_0_0 -> 715 in the cache */
   /* search955_0 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1334 },
      -1,
   } },

   /* replace955_0 -> 715 in the cache */
   /* replace955 -> 1342 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search956_0_0 -> 715 in the cache */
   /* search956_0 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1334 },
      -1,
   } },

   /* replace956_0 -> 715 in the cache */
   /* replace956 -> 1342 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search957_0_0 -> 16 in the cache */
   /* search957_0 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1935 },
      -1,
   } },

   /* replace957 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search958_0_0 -> 16 in the cache */
   /* search958_0 -> 1946 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1946 },
      -1,
   } },

   /* replace958 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search959_0_0 -> 16 in the cache */
   /* search959_0 -> 1946 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1946 },
      -1,
   } },

   /* replace959 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search960_0_0 -> 16 in the cache */
   /* search960_0 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace960_0 -> 16 in the cache */
   /* replace960 -> 1943 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search961_0_0 -> 16 in the cache */
   /* search961_0 -> 1942 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1942 },
      -1,
   } },

   /* replace961_0 -> 16 in the cache */
   /* replace961 -> 1940 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search962_0_0 -> 16 in the cache */
   /* search962_0 -> 1934 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1934 },
      -1,
   } },

   /* replace962_0 -> 16 in the cache */
   /* replace962 -> 1932 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search963_0_0 -> 16 in the cache */
   /* search963_0 -> 1931 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1931 },
      -1,
   } },

   /* replace963_0 -> 16 in the cache */
   /* replace963 -> 1929 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search964_0_0 -> 16 in the cache */
   /* search964_0 -> 1846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1846 },
      -1,
   } },

   /* replace964 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace965 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search966_0 -> 2831 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace966 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search967_0 -> 2831 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace967 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search968_0 -> 2831 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace968 -> 113 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2836 },
      -1,
   } },

   /* replace969 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search970_0 -> 2836 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2836 },
      -1,
   } },

   /* replace970 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 2839 },
      -1,
   } },

   /* replace971 -> 113 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search972_0 -> 2836 in the cache */
   /* search972_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2836, 226 },
      -1,
   } },

   /* replace972_0 -> 32 in the cache */
   /* replace972 -> 202 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search973_0_0_0_0 -> 32 in the cache */
   /* search973_0_0_0 -> 202 in the cache */
   /* search973_0_0_1_0_0 -> 32 in the cache */
   /* search973_0_0_1_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 202, 2842 },
      -1,
   } },
   /* search973_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 2843, 226 },
      -1,
   } },
   /* search973_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 2844, 113 },
      -1,
   } },

   /* replace973 -> 1033 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search974_0_0_0_0_0 -> 32 in the cache */
   /* search974_0_0_0_0 -> 202 in the cache */
   /* search974_0_0_0_1_0 -> 32 in the cache */
   /* search974_0_0_0_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 202, 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2846 },
      -1,
   } },
   /* search974_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 2847, 226 },
      -1,
   } },
   /* search974_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2848, 113 },
      -1,
   } },

   /* replace974 -> 1033 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search975_0_0_0_0 -> 32 in the cache */
   /* search975_0_0_0 -> 202 in the cache */
   /* search975_0_0_1_0_0 -> 32 in the cache */
   /* search975_0_0_1_0 -> 202 in the cache */
   /* search975_0_0_1 -> 2842 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 202, 2842 },
      -1,
   } },
   /* search975_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 2850, 226 },
      -1,
   } },
   /* search975_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 2851, 113 },
      -1,
   } },

   /* replace975_0_0_0 -> 32 in the cache */
   /* replace975_0_0 -> 202 in the cache */
   /* replace975_0_1_0_0 -> 32 in the cache */
   /* replace975_0_1_0 -> 202 in the cache */
   /* replace975_0_1 -> 2842 in the cache */
   /* replace975_0 -> 2843 in the cache */
   /* replace975_1 -> 226 in the cache */
   /* replace975 -> 2844 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search976_0_0_0_0_0 -> 32 in the cache */
   /* search976_0_0_0_0 -> 202 in the cache */
   /* search976_0_0_0_1_0 -> 32 in the cache */
   /* search976_0_0_0_1 -> 202 in the cache */
   /* search976_0_0_0 -> 2846 in the cache */
   /* search976_0_0 -> 2847 in the cache */
   /* search976_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 2847, 226 },
      -1,
   } },
   /* search976_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 2853, 113 },
      -1,
   } },

   /* replace976_0_0_0_0 -> 32 in the cache */
   /* replace976_0_0_0 -> 202 in the cache */
   /* replace976_0_0_1_0 -> 32 in the cache */
   /* replace976_0_0_1 -> 202 in the cache */
   /* replace976_0_0 -> 2846 in the cache */
   /* replace976_0 -> 2847 in the cache */
   /* replace976_1 -> 226 in the cache */
   /* replace976 -> 2848 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search977_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2855, 113 },
      -1,
   } },

   /* replace977 -> 1186 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search978_0 -> 2855 in the cache */
   /* search978_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2855, 113 },
      -1,
   } },

   /* replace978 -> 1033 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2858, 2859 },
      -1,
   } },

   /* replace979 -> 1186 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2861, 2862 },
      -1,
   } },

   /* replace980 -> 1033 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2864, 2865 },
      -1,
   } },

   /* replace981 -> 1033 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search982_0 -> 1522 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1522, 2867 },
      -1,
   } },

   /* replace982 -> 1033 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2869, 2870 },
      -1,
   } },

   /* replace983 -> 1186 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2872, 2873 },
      -1,
   } },

   /* replace984 -> 1186 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search985_0 -> 2855 in the cache */
   /* search985_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2855, 61 },
      -1,
   } },

   /* replace985 -> 1186 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search986_0 -> 2855 in the cache */
   /* search986_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2855, 61 },
      -1,
   } },

   /* replace986 -> 1033 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search987_0 -> 1522 in the cache */
   /* search987_1 -> 2867 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1522, 2867 },
      -1,
   } },

   /* replace987 -> 1186 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search988_0 -> 2861 in the cache */
   /* search988_1 -> 2862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2861, 2862 },
      -1,
   } },

   /* replace988 -> 1033 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search989_0 -> 2864 in the cache */
   /* search989_1 -> 2865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2864, 2865 },
      -1,
   } },

   /* replace989 -> 1033 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search990_0 -> 1522 in the cache */
   /* search990_1 -> 2867 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1522, 2867 },
      -1,
   } },

   /* replace990 -> 1033 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search991_0 -> 2861 in the cache */
   /* search991_1 -> 2862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2861, 2862 },
      -1,
   } },

   /* replace991 -> 1186 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search992_0 -> 2864 in the cache */
   /* search992_1 -> 2865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2864, 2865 },
      -1,
   } },

   /* replace992 -> 1186 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search993_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 2883 },
      -1,
   } },

   /* replace993 -> 1186 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search994_0 -> 32 in the cache */
   /* search994_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace994 -> 1033 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search995_0_0 -> 16 in the cache */
   /* search995_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace995 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search996_0_0 -> 16 in the cache */
   /* search996_0_1 -> 36 in the cache */
   /* search996_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace996 -> 36 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search997_0_0 -> 16 in the cache */
   /* search997_0_1 -> 36 in the cache */
   /* search997_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace997_0 -> 16 in the cache */
   /* replace997_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search998_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2891 },
      -1,
   } },

   /* replace998 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search999_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 2893 },
      -1,
   } },

   /* replace999 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search1000_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* search1000_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 2895, 2896 },
      -1,
   } },

   /* replace1000 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1001_0_0_0 -> 21 in the cache */
   /* search1001_0_0 -> 2895 in the cache */
   /* search1001_0_1_0 -> 21 in the cache */
   /* search1001_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2895, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2898 },
      -1,
   } },

   /* replace1001 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1002_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2900 },
      -1,
   } },

   /* replace1002 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1003_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 2902 },
      -1,
   } },

   /* replace1003 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1004_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1004_0_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 2904, 1953 },
      -1,
   } },
   /* search1004_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2906, 2907 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2905, 2908 },
      -1,
   } },

   /* replace1004_0 -> 16 in the cache */
   /* replace1004_1_0 -> 243 in the cache */
   /* replace1004_1_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 243, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2910 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1005_0 -> 11 in the cache */
   /* search1005_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 787 },
      -1,
   } },

   /* replace1005_0 -> 11 in the cache */
   /* replace1005_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1390 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1006_0 -> 16 in the cache */
   /* search1006_1 -> 968 in the cache */
   /* search1006 -> 973 in the cache */

   /* replace1006_0 -> 16 in the cache */
   /* replace1006_1 -> 386 in the cache */
   /* replace1006 -> 403 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1007_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2914 },
      -1,
   } },

   /* replace1007_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2916 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1008_0 -> 11 in the cache */
   /* search1008_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 787 },
      -1,
   } },

   /* replace1008_0 -> 11 in the cache */
   /* replace1008_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1390 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1009_0 -> 16 in the cache */
   /* search1009_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 968 },
      -1,
   } },

   /* replace1009_0 -> 16 in the cache */
   /* replace1009_1 -> 386 in the cache */
   /* replace1009 -> 387 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1010_0 -> 21 in the cache */
   /* search1010_1 -> 2914 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 2914 },
      -1,
   } },

   /* replace1010_0 -> 21 in the cache */
   /* replace1010_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2916 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1011_0 -> 1528 in the cache */
   /* search1011_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1528, 32 },
      -1,
   } },

   /* replace1011_0 -> 32 in the cache */
   /* replace1011_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1012_0_0 -> 32 in the cache */
   /* search1012_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2925 },
      -1,
   } },

   /* replace1012_0_0 -> 32 in the cache */
   /* replace1012_0_1 -> 2161 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2927 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1013_0_0 -> 32 in the cache */
   /* search1013_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2929 },
      -1,
   } },

   /* replace1013_0_0 -> 32 in the cache */
   /* replace1013_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2931 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1014_0_0_0 -> 0 in the cache */
   /* search1014_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2933 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2934 },
      -1,
   } },

   /* replace1014_0_0 -> 0 in the cache */
   /* replace1014_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2936 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1015_0_0_0 -> 0 in the cache */
   /* search1015_0_0_1 -> 3 in the cache */
   /* search1015_0_0 -> 2933 in the cache */
   /* search1015_0 -> 2934 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2934 },
      -1,
   } },

   /* replace1015_0_0 -> 0 in the cache */
   /* replace1015_0_1 -> 3 in the cache */
   /* replace1015_0 -> 2933 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2933 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1016_0 -> 16 in the cache */
   /* search1016_1 -> 120 in the cache */
   /* search1016_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 787 },
      -1,
   } },

   /* replace1016_0 -> 16 in the cache */
   /* replace1016_1 -> 120 in the cache */
   /* replace1016 -> 393 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1017_0 -> 16 in the cache */
   /* search1017_1 -> 787 in the cache */
   /* search1017_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 787, 787 },
      -1,
   } },

   /* replace1017_0 -> 16 in the cache */
   /* replace1017_1 -> 377 in the cache */
   /* replace1017 -> 396 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1018_0 -> 16 in the cache */
   /* search1018_1 -> 810 in the cache */
   /* search1018_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 810, 787 },
      -1,
   } },

   /* replace1018_0 -> 16 in the cache */
   /* replace1018_1 -> 382 in the cache */
   /* replace1018 -> 400 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1019_0 -> 16 in the cache */
   /* search1019_1 -> 968 in the cache */
   /* search1019_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 968, 787 },
      -1,
   } },

   /* replace1019_0 -> 16 in the cache */
   /* replace1019_1 -> 386 in the cache */
   /* replace1019 -> 403 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1020_0 -> 16 in the cache */
   /* search1020_1 -> 120 in the cache */
   /* search1020_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 787 },
      -1,
   } },

   /* replace1020_0 -> 16 in the cache */
   /* replace1020_1 -> 120 in the cache */
   /* replace1020 -> 374 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1021_0 -> 16 in the cache */
   /* search1021_1 -> 787 in the cache */
   /* search1021_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 787, 787 },
      -1,
   } },

   /* replace1021_0 -> 16 in the cache */
   /* replace1021_1 -> 377 in the cache */
   /* replace1021 -> 378 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1022_0 -> 16 in the cache */
   /* search1022_1 -> 810 in the cache */
   /* search1022_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 810, 787 },
      -1,
   } },

   /* replace1022_0 -> 16 in the cache */
   /* replace1022_1 -> 382 in the cache */
   /* replace1022 -> 383 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1023_0 -> 16 in the cache */
   /* search1023_1 -> 968 in the cache */
   /* search1023_2 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 968, 787 },
      -1,
   } },

   /* replace1023_0 -> 16 in the cache */
   /* replace1023_1 -> 386 in the cache */
   /* replace1023 -> 387 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1024_0_0 -> 0 in the cache */
   /* search1024_0_1 -> 3 in the cache */
   /* search1024_0 -> 2936 in the cache */
   /* search1024_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2936, 86 },
      -1,
   } },

   /* replace1024_0 -> 0 in the cache */
   /* replace1024_1 -> 3 in the cache */
   /* replace1024 -> 2933 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1025_0_0 -> 0 in the cache */
   /* search1025_0_1 -> 3 in the cache */
   /* search1025_0 -> 2933 in the cache */
   /* search1025_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2933, 86 },
      -1,
   } },

   /* replace1025_0 -> 0 in the cache */
   /* replace1025_1 -> 3 in the cache */
   /* replace1025 -> 2933 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1026_0_0 -> 16 in the cache */
   /* search1026_0_1 -> 810 in the cache */
   /* search1026_0 -> 962 in the cache */
   /* search1026_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 962, 810 },
      -1,
   } },

   /* replace1026_0 -> 16 in the cache */
   /* replace1026_1 -> 120 in the cache */
   /* replace1026 -> 425 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1027_0 -> 16 in the cache */
   /* search1027_1 -> 810 in the cache */
   /* search1027 -> 965 in the cache */

   /* replace1027_0 -> 16 in the cache */
   /* replace1027_1 -> 377 in the cache */
   /* replace1027 -> 428 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1028_0_0 -> 16 in the cache */
   /* search1028_0_1 -> 810 in the cache */
   /* search1028_0 -> 962 in the cache */
   /* search1028_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 962, 810 },
      -1,
   } },

   /* replace1028_0 -> 16 in the cache */
   /* replace1028_1 -> 120 in the cache */
   /* replace1028 -> 417 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1029_0 -> 16 in the cache */
   /* search1029_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 810 },
      -1,
   } },

   /* replace1029_0 -> 16 in the cache */
   /* replace1029_1 -> 377 in the cache */
   /* replace1029 -> 420 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1030_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2953, 32 },
      -1,
   } },

   /* replace1030_0 -> 32 in the cache */
   /* replace1030_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1031_0 -> 16 in the cache */
   /* search1031_1 -> 120 in the cache */
   /* search1031_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 810 },
      -1,
   } },

   /* replace1031_0 -> 16 in the cache */
   /* replace1031_1 -> 120 in the cache */
   /* replace1031 -> 425 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1032_0 -> 16 in the cache */
   /* search1032_1 -> 810 in the cache */
   /* search1032_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 810, 810 },
      -1,
   } },

   /* replace1032_0 -> 16 in the cache */
   /* replace1032_1 -> 377 in the cache */
   /* replace1032 -> 428 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1033_0 -> 16 in the cache */
   /* search1033_1 -> 120 in the cache */
   /* search1033_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 810 },
      -1,
   } },

   /* replace1033_0 -> 16 in the cache */
   /* replace1033_1 -> 120 in the cache */
   /* replace1033 -> 417 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1034_0 -> 16 in the cache */
   /* search1034_1 -> 810 in the cache */
   /* search1034_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 810, 810 },
      -1,
   } },

   /* replace1034_0 -> 16 in the cache */
   /* replace1034_1 -> 377 in the cache */
   /* replace1034 -> 420 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1035_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1035_0_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2960, 968 },
      -1,
   } },
   /* search1035_1_0_0_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2054 },
      -1,
   } },
   /* search1035_1_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2962, 810 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2964 },
      -1,
   } },
   /* search1035_1_1_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2965, 787 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2967 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 2966, 2968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 2963, 2969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2961, 2970 },
      -1,
   } },

   /* replace1035_0_0 -> 2967 in the cache */
   /* replace1035_0_1 -> 2964 in the cache */
   /* replace1035_0_2 -> 2054 in the cache */
   /* replace1035_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2967, 2964, 2054, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 2972 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1036_0_0 -> 0 in the cache */
   /* search1036_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1036_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 2974, 86 },
      -1,
   } },

   /* replace1036_0 -> 0 in the cache */
   /* replace1036_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1037_0_0 -> 0 in the cache */
   /* search1037_0_1 -> 3 in the cache */
   /* search1037_0 -> 2976 in the cache */
   /* search1037_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 2976, 86 },
      -1,
   } },

   /* replace1037_0 -> 0 in the cache */
   /* replace1037_1 -> 3 in the cache */
   /* replace1037 -> 2976 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1038_0 -> 16 in the cache */
   /* search1038_1 -> 36 in the cache */
   /* search1038 -> 2886 in the cache */

   /* replace1038_0_0 -> 16 in the cache */
   /* replace1038_0 -> 1850 in the cache */
   /* replace1038_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1038_1_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2978, 832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1850, 2979 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1039_0 -> 11 in the cache */
   /* search1039_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 243 },
      -1,
   } },

   /* replace1039_0_0 -> 11 in the cache */
   /* replace1039_0 -> 1743 in the cache */
   /* replace1039_1_0_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 243 },
      -1,
   } },
   /* replace1039_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2982, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1743, 2983 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1040_0 -> 21 in the cache */
   /* search1040 -> 2895 in the cache */

   /* replace1040_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1041_0 -> 21 in the cache */
   /* search1041 -> 2896 in the cache */

   /* replace1041_0_0 -> 21 in the cache */
   /* replace1041_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2986 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1042_0 -> 16 in the cache */
   /* search1042 -> 2904 in the cache */

   /* replace1042_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1043_0 -> 16 in the cache */
   /* search1043 -> 2906 in the cache */

   /* replace1043_0_0 -> 16 in the cache */
   /* replace1043_0_1 -> 810 in the cache */
   /* replace1043_0 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 965 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1044_0_0 -> 16 in the cache */
   /* search1044_0_1 -> 806 in the cache */
   /* search1044_0 -> 960 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 960 },
      -1,
   } },

   /* replace1044_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1045_0_0 -> 16 in the cache */
   /* search1045_0_1 -> 806 in the cache */
   /* search1045_0 -> 960 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 960 },
      -1,
   } },

   /* replace1045_0 -> 16 in the cache */
   /* replace1045 -> 2904 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1046_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2993 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 2994 },
      -1,
   } },

   /* replace1046_0 -> 21 in the cache */
   /* replace1046 -> 2895 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1047_0_0 -> 16 in the cache */
   /* search1047_0_1 -> 963 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 963 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 2996 },
      -1,
   } },

   /* replace1047_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1048_0_0 -> 16 in the cache */
   /* search1048_0_1 -> 963 in the cache */
   /* search1048_0 -> 2996 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 2996 },
      -1,
   } },

   /* replace1048_0 -> 16 in the cache */
   /* replace1048 -> 2906 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1049_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 3001 },
      -1,
   } },

   /* replace1049_0 -> 21 in the cache */
   /* replace1049 -> 2896 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1050_0_0 -> 16 in the cache */
   /* search1050_0_1 -> 120 in the cache */
   /* search1050_0 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 425 },
      -1,
   } },

   /* replace1050_0 -> 16 in the cache */
   /* replace1050 -> 2991 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1051_0_0 -> 16 in the cache */
   /* search1051_0_1 -> 377 in the cache */
   /* search1051_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace1051_0 -> 16 in the cache */
   /* replace1051 -> 2998 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1052_0_0 -> 16 in the cache */
   /* search1052_0_1 -> 810 in the cache */
   /* search1052_0 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 965 },
      -1,
   } },

   /* replace1052_0 -> 16 in the cache */
   /* replace1052 -> 2998 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1053_0_0 -> 16 in the cache */
   /* search1053_0_1 -> 120 in the cache */
   /* search1053_0 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 425 },
      -1,
   } },

   /* replace1053_0 -> 16 in the cache */
   /* replace1053 -> 2904 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1054_0_0 -> 16 in the cache */
   /* search1054_0_1 -> 377 in the cache */
   /* search1054_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace1054_0 -> 16 in the cache */
   /* replace1054 -> 2906 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1055_0_0_0 -> 16 in the cache */
   /* search1055_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3008 },
      -1,
   } },
   /* search1055_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3009, 810 },
      -1,
   } },

   /* replace1055_0_0 -> 120 in the cache */
   /* replace1055_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3011 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1056_0_0_0 -> 120 in the cache */
   /* search1056_0_0_1 -> 16 in the cache */
   /* search1056_0_0 -> 3011 in the cache */
   /* search1056_0 -> 3012 in the cache */
   /* search1056_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3012, 810 },
      -1,
   } },

   /* replace1056_0_0 -> 16 in the cache */
   /* replace1056_0_1 -> 120 in the cache */
   /* replace1056_0 -> 3008 in the cache */
   /* replace1056 -> 3009 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1057_0_0_0 -> 16 in the cache */
   /* search1057_0_0_1 -> 120 in the cache */
   /* search1057_0_0 -> 3008 in the cache */
   /* search1057_0 -> 3009 in the cache */
   /* search1057_1_0_0 -> 120 in the cache */
   /* search1057_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3014 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3009, 3015 },
      -1,
   } },

   /* replace1057_0_0 -> 16 in the cache */
   /* replace1057_0_1 -> 36 in the cache */
   /* replace1057_0 -> 2890 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1058_0_0_0 -> 16 in the cache */
   /* search1058_0_0_1 -> 120 in the cache */
   /* search1058_0_0 -> 3008 in the cache */
   /* search1058_0 -> 3009 in the cache */
   /* search1058_1_0_0 -> 120 in the cache */
   /* search1058_1_0_1 -> 36 in the cache */
   /* search1058_1_0 -> 3014 in the cache */
   /* search1058_1 -> 3015 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3009, 3015 },
      -1,
   } },

   /* replace1058_0_0 -> 16 in the cache */
   /* replace1058_0_1 -> 36 in the cache */
   /* replace1058_0 -> 2890 in the cache */
   /* replace1058 -> 3017 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1059_0_0 -> 16 in the cache */
   /* search1059_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1059_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3019, 810 },
      -1,
   } },

   /* replace1059_0 -> 120 in the cache */
   /* replace1059_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1060_0_0 -> 120 in the cache */
   /* search1060_0_1 -> 16 in the cache */
   /* search1060_0 -> 3021 in the cache */
   /* search1060_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3021, 810 },
      -1,
   } },

   /* replace1060_0 -> 16 in the cache */
   /* replace1060_1 -> 120 in the cache */
   /* replace1060 -> 3019 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1061_0_0 -> 120 in the cache */
   /* search1061_0_1 -> 16 in the cache */
   /* search1061_0 -> 3021 in the cache */
   /* search1061_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3021, 377 },
      -1,
   } },

   /* replace1061_0 -> 16 in the cache */
   /* replace1061_1 -> 120 in the cache */
   /* replace1061 -> 3019 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1062_0_0 -> 16 in the cache */
   /* search1062_0_1 -> 120 in the cache */
   /* search1062_0 -> 3019 in the cache */
   /* search1062_1_0 -> 120 in the cache */
   /* search1062_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3019, 3024 },
      -1,
   } },

   /* replace1062_0 -> 16 in the cache */
   /* replace1062_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1063_0_0 -> 16 in the cache */
   /* search1063_0_1 -> 120 in the cache */
   /* search1063_0 -> 3019 in the cache */
   /* search1063_1_0 -> 120 in the cache */
   /* search1063_1_1 -> 36 in the cache */
   /* search1063_1 -> 3024 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3019, 3024 },
      -1,
   } },

   /* replace1063_0 -> 16 in the cache */
   /* replace1063_1 -> 36 in the cache */
   /* replace1063 -> 3026 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1064_0_0 -> 6 in the cache */
   /* search1064_0_1 -> 2054 in the cache */
   /* search1064_0_2 -> 2964 in the cache */
   /* search1064_0_3 -> 2967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 2054, 2964, 2967 },
      -1,
   } },
   /* search1064_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3028, 120 },
      -1,
   } },

   /* replace1064_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1065_0_0 -> 6 in the cache */
   /* search1065_0_1 -> 2054 in the cache */
   /* search1065_0_2 -> 2964 in the cache */
   /* search1065_0_3 -> 2967 in the cache */
   /* search1065_0 -> 3028 in the cache */
   /* search1065_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3028, 377 },
      -1,
   } },

   /* replace1065_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2054 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1066_0_0 -> 6 in the cache */
   /* search1066_0_1 -> 2054 in the cache */
   /* search1066_0_2 -> 2964 in the cache */
   /* search1066_0_3 -> 2967 in the cache */
   /* search1066_0 -> 3028 in the cache */
   /* search1066_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3028, 382 },
      -1,
   } },

   /* replace1066_0 -> 2964 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2964 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1067_0_0 -> 6 in the cache */
   /* search1067_0_1 -> 2054 in the cache */
   /* search1067_0_2 -> 2964 in the cache */
   /* search1067_0_3 -> 2967 in the cache */
   /* search1067_0 -> 3028 in the cache */
   /* search1067_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3028, 386 },
      -1,
   } },

   /* replace1067_0 -> 2967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2967 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1068_0_0 -> 6 in the cache */
   /* search1068_0_1 -> 2054 in the cache */
   /* search1068_0_2 -> 2964 in the cache */
   /* search1068_0_3 -> 2967 in the cache */
   /* search1068_0 -> 3028 in the cache */
   /* search1068_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3028, 120 },
      -1,
   } },

   /* replace1068_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1069_0_0 -> 6 in the cache */
   /* search1069_0_1 -> 2054 in the cache */
   /* search1069_0_2 -> 2964 in the cache */
   /* search1069_0_3 -> 2967 in the cache */
   /* search1069_0 -> 3028 in the cache */
   /* search1069_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3028, 377 },
      -1,
   } },

   /* replace1069_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2054 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1070_0_0 -> 6 in the cache */
   /* search1070_0_1 -> 2054 in the cache */
   /* search1070_0_2 -> 2964 in the cache */
   /* search1070_0_3 -> 2967 in the cache */
   /* search1070_0 -> 3028 in the cache */
   /* search1070_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3028, 382 },
      -1,
   } },

   /* replace1070_0 -> 2964 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2964 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1071_0_0 -> 6 in the cache */
   /* search1071_0_1 -> 2054 in the cache */
   /* search1071_0_2 -> 2964 in the cache */
   /* search1071_0_3 -> 2967 in the cache */
   /* search1071_0 -> 3028 in the cache */
   /* search1071_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3028, 386 },
      -1,
   } },

   /* replace1071_0 -> 2967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2967 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1072_0_0 -> 11 in the cache */
   /* search1072_0_1 -> 787 in the cache */
   /* search1072_0 -> 2912 in the cache */
   /* search1072_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2912, 813 },
      -1,
   } },

   /* replace1072_0 -> 11 in the cache */
   /* replace1072_1 -> 1390 in the cache */
   /* replace1072 -> 2913 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1073_0_0 -> 16 in the cache */
   /* search1073_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 787 },
      -1,
   } },
   /* search1073_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3046, 120 },
      -1,
   } },

   /* replace1073_0 -> 16 in the cache */
   /* replace1073_1 -> 377 in the cache */
   /* replace1073 -> 396 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1074_0_0 -> 16 in the cache */
   /* search1074_0_1 -> 810 in the cache */
   /* search1074_0 -> 965 in the cache */
   /* search1074_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 965, 120 },
      -1,
   } },

   /* replace1074_0 -> 16 in the cache */
   /* replace1074_1 -> 382 in the cache */
   /* replace1074 -> 400 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1075_0_0 -> 16 in the cache */
   /* search1075_0_1 -> 968 in the cache */
   /* search1075_0 -> 973 in the cache */
   /* search1075_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 973, 120 },
      -1,
   } },

   /* replace1075_0 -> 16 in the cache */
   /* replace1075_1 -> 386 in the cache */
   /* replace1075 -> 403 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1076_0_0 -> 21 in the cache */
   /* search1076_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 787 },
      -1,
   } },
   /* search1076_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3050, 856 },
      -1,
   } },

   /* replace1076_0 -> 21 in the cache */
   /* replace1076_1 -> 1432 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1432 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1077_0_0 -> 21 in the cache */
   /* search1077_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 810 },
      -1,
   } },
   /* search1077_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3053, 856 },
      -1,
   } },

   /* replace1077_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3055 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1078_0_0 -> 21 in the cache */
   /* search1078_0_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 968 },
      -1,
   } },
   /* search1078_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3057, 856 },
      -1,
   } },

   /* replace1078_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3059 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1079_0_0 -> 21 in the cache */
   /* search1079_0_1 -> 832 in the cache */
   /* search1079_0 -> 2986 in the cache */
   /* search1079_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2986, 856 },
      -1,
   } },

   /* replace1079_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3062 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1080_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3064 },
      -1,
   } },
   /* search1080_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3065, 856 },
      -1,
   } },

   /* replace1080_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3067 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1081_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3069 },
      -1,
   } },
   /* search1081_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3070, 856 },
      -1,
   } },

   /* replace1081_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3072 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1082_0_0 -> 21 in the cache */
   /* search1082_0_1 -> 2914 in the cache */
   /* search1082_0 -> 2915 in the cache */
   /* search1082_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2915, 856 },
      -1,
   } },

   /* replace1082_0 -> 21 in the cache */
   /* replace1082_1 -> 2916 in the cache */
   /* replace1082 -> 2917 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1083_0_0 -> 11 in the cache */
   /* search1083_0_1 -> 787 in the cache */
   /* search1083_0 -> 2918 in the cache */
   /* search1083_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2918, 813 },
      -1,
   } },

   /* replace1083_0 -> 11 in the cache */
   /* replace1083_1 -> 1390 in the cache */
   /* replace1083 -> 2913 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1084_0_0 -> 16 in the cache */
   /* search1084_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 787 },
      -1,
   } },
   /* search1084_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3076, 120 },
      -1,
   } },

   /* replace1084_0 -> 16 in the cache */
   /* replace1084_1 -> 377 in the cache */
   /* replace1084 -> 396 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1085_0_0 -> 16 in the cache */
   /* search1085_0_1 -> 810 in the cache */
   /* search1085_0 -> 2952 in the cache */
   /* search1085_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2952, 120 },
      -1,
   } },

   /* replace1085_0 -> 16 in the cache */
   /* replace1085_1 -> 382 in the cache */
   /* replace1085 -> 400 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1086_0_0 -> 16 in the cache */
   /* search1086_0_1 -> 968 in the cache */
   /* search1086_0 -> 2920 in the cache */
   /* search1086_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2920, 120 },
      -1,
   } },

   /* replace1086_0 -> 16 in the cache */
   /* replace1086_1 -> 386 in the cache */
   /* replace1086 -> 403 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1087_0_0 -> 21 in the cache */
   /* search1087_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 787 },
      -1,
   } },
   /* search1087_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3080, 856 },
      -1,
   } },

   /* replace1087_0 -> 21 in the cache */
   /* replace1087_1 -> 1432 in the cache */
   /* replace1087 -> 3052 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1088_0_0 -> 21 in the cache */
   /* search1088_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 810 },
      -1,
   } },
   /* search1088_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3082, 856 },
      -1,
   } },

   /* replace1088_0 -> 21 in the cache */
   /* replace1088_1 -> 3055 in the cache */
   /* replace1088 -> 3056 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1089_0_0 -> 21 in the cache */
   /* search1089_0_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 968 },
      -1,
   } },
   /* search1089_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3084, 856 },
      -1,
   } },

   /* replace1089_0 -> 21 in the cache */
   /* replace1089_1 -> 3059 in the cache */
   /* replace1089 -> 3060 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1090_0_0 -> 21 in the cache */
   /* search1090_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 832 },
      -1,
   } },
   /* search1090_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3086, 856 },
      -1,
   } },

   /* replace1090_0 -> 21 in the cache */
   /* replace1090_1 -> 3062 in the cache */
   /* replace1090 -> 3063 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1091_0_0 -> 21 in the cache */
   /* search1091_0_1 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3064 },
      -1,
   } },
   /* search1091_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3088, 856 },
      -1,
   } },

   /* replace1091_0 -> 21 in the cache */
   /* replace1091_1 -> 3067 in the cache */
   /* replace1091 -> 3068 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1092_0_0 -> 21 in the cache */
   /* search1092_0_1 -> 3069 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3069 },
      -1,
   } },
   /* search1092_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3090, 856 },
      -1,
   } },

   /* replace1092_0 -> 21 in the cache */
   /* replace1092_1 -> 3072 in the cache */
   /* replace1092 -> 3073 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1093_0_0 -> 21 in the cache */
   /* search1093_0_1 -> 2914 in the cache */
   /* search1093_0 -> 2921 in the cache */
   /* search1093_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2921, 856 },
      -1,
   } },

   /* replace1093_0 -> 21 in the cache */
   /* replace1093_1 -> 2916 in the cache */
   /* replace1093 -> 2917 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1094_0_0 -> 32 in the cache */
   /* search1094_0_1 -> 35 in the cache */
   /* search1094_0 -> 2925 in the cache */
   /* search1094_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2925, 61 },
      -1,
   } },

   /* replace1094_0 -> 32 in the cache */
   /* replace1094_1 -> 2161 in the cache */
   /* replace1094 -> 2927 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1095_0_0 -> 11 in the cache */
   /* search1095_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 787 },
      -1,
   } },
   /* search1095_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3094, 1390 },
      -1,
   } },

   /* replace1095_0 -> 11 in the cache */
   /* replace1095_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 813 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1096_0_0 -> 16 in the cache */
   /* search1096_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 787 },
      -1,
   } },
   /* search1096_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3097, 386 },
      -1,
   } },

   /* replace1096_0 -> 16 in the cache */
   /* replace1096_1 -> 382 in the cache */
   /* replace1096 -> 400 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1097_0_0 -> 16 in the cache */
   /* search1097_0_1 -> 810 in the cache */
   /* search1097_0 -> 962 in the cache */
   /* search1097_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 962, 386 },
      -1,
   } },

   /* replace1097_0 -> 16 in the cache */
   /* replace1097_1 -> 377 in the cache */
   /* replace1097 -> 396 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1098_0_0 -> 16 in the cache */
   /* search1098_0_1 -> 968 in the cache */
   /* search1098_0 -> 970 in the cache */
   /* search1098_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 970, 386 },
      -1,
   } },

   /* replace1098_0 -> 16 in the cache */
   /* replace1098_1 -> 120 in the cache */
   /* replace1098 -> 393 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1099_0_0 -> 21 in the cache */
   /* search1099_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 787 },
      -1,
   } },
   /* search1099_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3101, 2916 },
      -1,
   } },

   /* replace1099_0 -> 21 in the cache */
   /* replace1099_1 -> 3072 in the cache */
   /* replace1099 -> 3073 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1100_0_0 -> 21 in the cache */
   /* search1100_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 810 },
      -1,
   } },
   /* search1100_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3103, 2916 },
      -1,
   } },

   /* replace1100_0 -> 21 in the cache */
   /* replace1100_1 -> 3067 in the cache */
   /* replace1100 -> 3068 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1101_0_0 -> 21 in the cache */
   /* search1101_0_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 968 },
      -1,
   } },
   /* search1101_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3105, 2916 },
      -1,
   } },

   /* replace1101_0 -> 21 in the cache */
   /* replace1101_1 -> 3062 in the cache */
   /* replace1101 -> 3063 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1102_0_0 -> 21 in the cache */
   /* search1102_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 832 },
      -1,
   } },
   /* search1102_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3107, 2916 },
      -1,
   } },

   /* replace1102_0 -> 21 in the cache */
   /* replace1102_1 -> 3059 in the cache */
   /* replace1102 -> 3060 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1103_0_0 -> 21 in the cache */
   /* search1103_0_1 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3064 },
      -1,
   } },
   /* search1103_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3109, 2916 },
      -1,
   } },

   /* replace1103_0 -> 21 in the cache */
   /* replace1103_1 -> 3055 in the cache */
   /* replace1103 -> 3056 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1104_0_0 -> 21 in the cache */
   /* search1104_0_1 -> 3069 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3069 },
      -1,
   } },
   /* search1104_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3111, 2916 },
      -1,
   } },

   /* replace1104_0 -> 21 in the cache */
   /* replace1104_1 -> 1432 in the cache */
   /* replace1104 -> 3052 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1105_0_0 -> 21 in the cache */
   /* search1105_0_1 -> 2914 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 2914 },
      -1,
   } },
   /* search1105_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3113, 2916 },
      -1,
   } },

   /* replace1105_0 -> 21 in the cache */
   /* replace1105_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 856 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1106_0_0 -> 11 in the cache */
   /* search1106_0_1 -> 787 in the cache */
   /* search1106_0 -> 3094 in the cache */
   /* search1106_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3094, 1390 },
      -1,
   } },

   /* replace1106_0 -> 11 in the cache */
   /* replace1106_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 813 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1107_0_0 -> 16 in the cache */
   /* search1107_0_1 -> 787 in the cache */
   /* search1107_0 -> 3097 in the cache */
   /* search1107_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3097, 386 },
      -1,
   } },

   /* replace1107_0 -> 16 in the cache */
   /* replace1107_1 -> 382 in the cache */
   /* replace1107 -> 383 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1108_0_0 -> 16 in the cache */
   /* search1108_0_1 -> 810 in the cache */
   /* search1108_0 -> 962 in the cache */
   /* search1108_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 962, 386 },
      -1,
   } },

   /* replace1108_0 -> 16 in the cache */
   /* replace1108_1 -> 377 in the cache */
   /* replace1108 -> 378 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1109_0_0 -> 16 in the cache */
   /* search1109_0_1 -> 968 in the cache */
   /* search1109_0 -> 970 in the cache */
   /* search1109_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 970, 386 },
      -1,
   } },

   /* replace1109_0 -> 16 in the cache */
   /* replace1109_1 -> 120 in the cache */
   /* replace1109 -> 374 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1110_0_0 -> 21 in the cache */
   /* search1110_0_1 -> 787 in the cache */
   /* search1110_0 -> 3101 in the cache */
   /* search1110_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3101, 2916 },
      -1,
   } },

   /* replace1110_0 -> 21 in the cache */
   /* replace1110_1 -> 3072 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3072 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1111_0_0 -> 21 in the cache */
   /* search1111_0_1 -> 810 in the cache */
   /* search1111_0 -> 3103 in the cache */
   /* search1111_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3103, 2916 },
      -1,
   } },

   /* replace1111_0 -> 21 in the cache */
   /* replace1111_1 -> 3067 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3067 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1112_0_0 -> 21 in the cache */
   /* search1112_0_1 -> 968 in the cache */
   /* search1112_0 -> 3105 in the cache */
   /* search1112_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3105, 2916 },
      -1,
   } },

   /* replace1112_0 -> 21 in the cache */
   /* replace1112_1 -> 3062 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3062 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1113_0_0 -> 21 in the cache */
   /* search1113_0_1 -> 832 in the cache */
   /* search1113_0 -> 3107 in the cache */
   /* search1113_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3107, 2916 },
      -1,
   } },

   /* replace1113_0 -> 21 in the cache */
   /* replace1113_1 -> 3059 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3059 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1114_0_0 -> 21 in the cache */
   /* search1114_0_1 -> 3064 in the cache */
   /* search1114_0 -> 3109 in the cache */
   /* search1114_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3109, 2916 },
      -1,
   } },

   /* replace1114_0 -> 21 in the cache */
   /* replace1114_1 -> 3055 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3055 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1115_0_0 -> 21 in the cache */
   /* search1115_0_1 -> 3069 in the cache */
   /* search1115_0 -> 3111 in the cache */
   /* search1115_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3111, 2916 },
      -1,
   } },

   /* replace1115_0 -> 21 in the cache */
   /* replace1115_1 -> 1432 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1432 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1116_0_0 -> 21 in the cache */
   /* search1116_0_1 -> 2914 in the cache */
   /* search1116_0 -> 3113 in the cache */
   /* search1116_1 -> 2916 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3113, 2916 },
      -1,
   } },

   /* replace1116_0 -> 21 in the cache */
   /* replace1116_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 856 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1117_0 -> 16 in the cache */
   /* search1117_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* replace1117 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1118_0 -> 16 in the cache */
   /* search1118_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* replace1118 -> 120 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1119_0 -> 0 in the cache */
   /* search1119_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1119_0 -> 0 in the cache */
   /* replace1119_1_0 -> 3 in the cache */
   /* replace1119_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1043 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1120_0 -> 0 in the cache */
   /* search1120_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1120_0 -> 0 in the cache */
   /* replace1120_1_0 -> 3 in the cache */
   /* replace1120_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1121_0 -> 0 in the cache */
   /* search1121_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1121_0_0 -> 0 in the cache */
   /* replace1121_0_1 -> 3 in the cache */
   /* replace1121_0 -> 1023 in the cache */
   /* replace1121_1_0_0 -> 0 in the cache */
   /* replace1121_1_0_1 -> 3 in the cache */
   /* replace1121_1_0 -> 3139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3139 },
      -1,
   } },
   /* replace1121_2_0 -> 0 in the cache */
   /* replace1121_2_1 -> 3 in the cache */
   /* replace1121_2 -> 3139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1023, 3142, 3139 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1122_0 -> 0 in the cache */
   /* search1122_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1122_0_0 -> 0 in the cache */
   /* replace1122_0_1 -> 3 in the cache */
   /* replace1122_0 -> 1020 in the cache */
   /* replace1122_1_0_0 -> 0 in the cache */
   /* replace1122_1_0_1 -> 3 in the cache */
   /* replace1122_1_0 -> 3139 in the cache */
   /* replace1122_1 -> 3142 in the cache */
   /* replace1122_2_0 -> 0 in the cache */
   /* replace1122_2_1 -> 3 in the cache */
   /* replace1122_2 -> 3139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1020, 3142, 3139 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1123_0_0 -> 0 in the cache */
   /* search1123_0 -> 197 in the cache */
   /* search1123_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 197, 3 },
      4,
   } },

   /* replace1123_0_0 -> 0 in the cache */
   /* replace1123_0_1 -> 3 in the cache */
   /* replace1123_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1124_0_0 -> 16 in the cache */
   /* search1124_0 -> 265 in the cache */
   /* search1124_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 265, 36 },
      4,
   } },

   /* replace1124_0_0 -> 16 in the cache */
   /* replace1124_0_1 -> 36 in the cache */
   /* replace1124_0 -> 254 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 254 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1125_0_0 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 124 },
      -1,
   } },
   /* search1125_1_0 -> 125 in the cache */
   /* search1125_1 -> 1146 in the cache */
   /* search1125_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 3150, 1146, 127 },
      -1,
   } },

   /* replace1125_0 -> 124 in the cache */
   /* replace1125_1 -> 125 in the cache */
   /* replace1125_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1126_0_0 -> 16 in the cache */
   /* search1126_0 -> 265 in the cache */
   /* search1126_1_0 -> 36 in the cache */
   /* search1126_1 -> 581 in the cache */
   /* search1126_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 265, 581, 133 },
      -1,
   } },

   /* replace1126_0 -> 16 in the cache */
   /* replace1126_1 -> 36 in the cache */
   /* replace1126_2 -> 133 in the cache */
   /* replace1126 -> 373 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1127_0_0 -> 0 in the cache */
   /* search1127_0 -> 192 in the cache */
   /* search1127_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 192, 3 },
      -1,
   } },

   /* replace1127_0_0 -> 0 in the cache */
   /* replace1127_0_1 -> 3 in the cache */
   /* replace1127_0 -> 909 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 909 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3156, 3157 },
      0,
   } },
   /* search1128_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3158, 769 },
      0,
   } },

   /* replace1128_0_0 -> 124 in the cache */
   /* replace1128_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1128_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3160, 125 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1129_0_0 -> 313 in the cache */
   /* search1129_0_1 -> 323 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 313, 323 },
      0,
   } },
   /* search1129_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3162, 294 },
      0,
   } },

   /* replace1129_0_0 -> 16 in the cache */
   /* replace1129_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 133 },
      -1,
   } },
   /* replace1129_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3164, 36 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1130_0_0 -> 313 in the cache */
   /* search1130_0_1 -> 323 in the cache */
   /* search1130_0 -> 3162 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3162, 3166 },
      0,
   } },

   /* replace1130_0_0 -> 16 in the cache */
   /* replace1130_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 133 },
      -1,
   } },
   /* replace1130_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3168, 36 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1131_0_0 -> 3156 in the cache */
   /* search1131_0_1 -> 3157 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3156, 3157 },
      0,
   } },
   /* search1131_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 3170, 769 },
      0,
   } },

   /* replace1131_0_0 -> 124 in the cache */
   /* replace1131_0_1 -> 127 in the cache */
   /* replace1131_0 -> 981 in the cache */
   /* replace1131_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 981, 125 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3173, 3174 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1132_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3175, 3176, 151 },
      -1,
   } },

   /* replace1132_0_0 -> 147 in the cache */
   /* replace1132_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 150 },
      -1,
   } },
   /* replace1132_1 -> 148 in the cache */
   /* replace1132_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3178, 148, 151 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1133_0_0 -> 313 in the cache */
   /* search1133_0_1 -> 323 in the cache */
   /* search1133_0 -> 3162 in the cache */
   /* search1133_1 -> 294 in the cache */
   /* search1133_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3162, 294, 161 },
      -1,
   } },

   /* replace1133_0_0 -> 16 in the cache */
   /* replace1133_0_1 -> 133 in the cache */
   /* replace1133_0 -> 3164 in the cache */
   /* replace1133_1 -> 36 in the cache */
   /* replace1133_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3164, 36, 161 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1134_0_0 -> 313 in the cache */
   /* search1134_0_1 -> 323 in the cache */
   /* search1134_0 -> 3162 in the cache */
   /* search1134_1 -> 3166 in the cache */
   /* search1134_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3162, 3166, 161 },
      -1,
   } },

   /* replace1134_0_0 -> 16 in the cache */
   /* replace1134_0_1 -> 133 in the cache */
   /* replace1134_0 -> 3168 in the cache */
   /* replace1134_1 -> 36 in the cache */
   /* replace1134_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3168, 36, 161 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1135_0_0 -> 3156 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3156, 3184 },
      0,
   } },
   /* search1135_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3185, 769 },
      0,
   } },

   /* replace1135_0_0 -> 124 in the cache */
   /* replace1135_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1135_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3187, 125 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1136_0_0 -> 3156 in the cache */
   /* search1136_0_1 -> 3157 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3156, 3157 },
      0,
   } },
   /* search1136_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3189, 769 },
      0,
   } },

   /* replace1136_0_0 -> 124 in the cache */
   /* replace1136_0_1 -> 127 in the cache */
   /* replace1136_0 -> 3187 in the cache */
   /* replace1136_1 -> 125 in the cache */
   /* replace1136 -> 3188 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1137_0_0 -> 3173 in the cache */
   /* search1137_0_1 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3173, 148, 3191 },
      0,
   } },
   /* search1137_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3192, 987 },
      0,
   } },

   /* replace1137_0_0 -> 147 in the cache */
   /* replace1137_0_1 -> 148 in the cache */
   /* replace1137_0_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 147, 148, 151 },
      -1,
   } },
   /* replace1137_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3194, 150 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1138_0_0 -> 313 in the cache */
   /* search1138_0_1 -> 36 in the cache */
   /* search1138_0_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 313, 36, 332 },
      0,
   } },
   /* search1138_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3196, 296 },
      0,
   } },

   /* replace1138_0_0 -> 16 in the cache */
   /* replace1138_0_1 -> 36 in the cache */
   /* replace1138_0_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 36, 161 },
      -1,
   } },
   /* replace1138_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3198, 133 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1139_0_0 -> 3156 in the cache */
   /* search1139_0_1 -> 3157 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3156, 3157 },
      0,
   } },
   /* search1139_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3200, 769 },
      0,
   } },

   /* replace1139_0_0 -> 124 in the cache */
   /* replace1139_0_1 -> 127 in the cache */
   /* replace1139_0 -> 995 in the cache */
   /* replace1139_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 995, 125 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1140_0 -> 267 in the cache */
   /* search1140_1_0 -> 3157 in the cache */
   /* search1140_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 267, 3203 },
      -1,
   } },

   /* replace1140_0_0 -> 124 in the cache */
   /* replace1140_0_1 -> 127 in the cache */
   /* replace1140_0 -> 3160 in the cache */
   /* replace1140_1 -> 125 in the cache */
   /* replace1140 -> 3161 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1141_0 -> 271 in the cache */
   /* search1141_1_0 -> 323 in the cache */
   /* search1141_1_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 323, 294 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 271, 3205 },
      -1,
   } },

   /* replace1141_0_0 -> 16 in the cache */
   /* replace1141_0_1 -> 133 in the cache */
   /* replace1141_0 -> 3164 in the cache */
   /* replace1141_1 -> 36 in the cache */
   /* replace1141 -> 3165 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1142_1_0 -> 323 in the cache */
   /* search1142_1_1 -> 294 in the cache */
   /* search1142_1 -> 3205 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3207, 3205 },
      -1,
   } },

   /* replace1142_0_0 -> 16 in the cache */
   /* replace1142_0_1 -> 133 in the cache */
   /* replace1142_0 -> 3168 in the cache */
   /* replace1142_1 -> 36 in the cache */
   /* replace1142 -> 3169 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1143_1_0 -> 3174 in the cache */
   /* search1143_1_1 -> 3176 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3174, 3176 },
      -1,
   } },
   /* search1143_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3209, 3210, 151 },
      -1,
   } },

   /* replace1143_0_0 -> 147 in the cache */
   /* replace1143_0_1 -> 150 in the cache */
   /* replace1143_0 -> 3178 in the cache */
   /* replace1143_1 -> 148 in the cache */
   /* replace1143_2 -> 151 in the cache */
   /* replace1143 -> 3179 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1144_0 -> 271 in the cache */
   /* search1144_1_0 -> 323 in the cache */
   /* search1144_1_1 -> 294 in the cache */
   /* search1144_1 -> 3205 in the cache */
   /* search1144_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 271, 3205, 161 },
      -1,
   } },

   /* replace1144_0_0 -> 16 in the cache */
   /* replace1144_0_1 -> 133 in the cache */
   /* replace1144_0 -> 3164 in the cache */
   /* replace1144_1 -> 36 in the cache */
   /* replace1144_2 -> 161 in the cache */
   /* replace1144 -> 3181 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1145_0 -> 3207 in the cache */
   /* search1145_1_0 -> 323 in the cache */
   /* search1145_1_1 -> 294 in the cache */
   /* search1145_1 -> 3205 in the cache */
   /* search1145_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3207, 3205, 161 },
      -1,
   } },

   /* replace1145_0_0 -> 16 in the cache */
   /* replace1145_0_1 -> 133 in the cache */
   /* replace1145_0 -> 3168 in the cache */
   /* replace1145_1 -> 36 in the cache */
   /* replace1145_2 -> 161 in the cache */
   /* replace1145 -> 3183 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1146_0 -> 267 in the cache */
   /* search1146_1_0 -> 3157 in the cache */
   /* search1146_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 267, 3214 },
      -1,
   } },

   /* replace1146_0_0 -> 124 in the cache */
   /* replace1146_0_1 -> 127 in the cache */
   /* replace1146_0 -> 981 in the cache */
   /* replace1146_1 -> 125 in the cache */
   /* replace1146 -> 3172 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1147_0 -> 267 in the cache */
   /* search1147_1_0 -> 3157 in the cache */
   /* search1147_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 267, 3216 },
      -1,
   } },

   /* replace1147_0_0 -> 124 in the cache */
   /* replace1147_0_1 -> 127 in the cache */
   /* replace1147_0 -> 3187 in the cache */
   /* replace1147_1 -> 125 in the cache */
   /* replace1147 -> 3188 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1148_0 -> 267 in the cache */
   /* search1148_1_0_0 -> 3157 in the cache */
   /* search1148_1_0_1 -> 769 in the cache */
   /* search1148_1_0 -> 3216 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 267, 3218 },
      -1,
   } },

   /* replace1148_0_0 -> 124 in the cache */
   /* replace1148_0_1_0 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 3220 },
      -1,
   } },
   /* replace1148_1_0 -> 125 in the cache */
   /* replace1148_1 -> 1146 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3221, 1146 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1149_0 -> 3209 in the cache */
   /* search1149_1_0 -> 3174 in the cache */
   /* search1149_1_1 -> 3191 in the cache */
   /* search1149_1_2 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3174, 3191, 987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3209, 3223 },
      -1,
   } },

   /* replace1149_0 -> 148 in the cache */
   /* replace1149_1 -> 150 in the cache */
   /* replace1149_2_0 -> 147 in the cache */
   /* replace1149_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 147, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 148, 150, 3225 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1150_0 -> 3209 in the cache */
   /* search1150_1_0_0 -> 3174 in the cache */
   /* search1150_1_0_1 -> 3191 in the cache */
   /* search1150_1_0_2 -> 987 in the cache */
   /* search1150_1_0 -> 3223 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3223 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3209, 3227 },
      -1,
   } },

   /* replace1150_0_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 148 },
      -1,
   } },
   /* replace1150_1 -> 150 in the cache */
   /* replace1150_2_0 -> 147 in the cache */
   /* replace1150_2_1_0 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 147, 3230 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3229, 150, 3231 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1151_0 -> 271 in the cache */
   /* search1151_1_0 -> 323 in the cache */
   /* search1151_1_1 -> 332 in the cache */
   /* search1151_1_2 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 323, 332, 296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 271, 3233 },
      -1,
   } },

   /* replace1151_0 -> 36 in the cache */
   /* replace1151_1 -> 133 in the cache */
   /* replace1151_2_0 -> 16 in the cache */
   /* replace1151_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 36, 133, 3235 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1152_0 -> 271 in the cache */
   /* search1152_1_0_0 -> 323 in the cache */
   /* search1152_1_0_1 -> 332 in the cache */
   /* search1152_1_0_2 -> 296 in the cache */
   /* search1152_1_0 -> 3233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3233 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 271, 3237 },
      -1,
   } },

   /* replace1152_0_0 -> 36 in the cache */
   /* replace1152_0 -> 581 in the cache */
   /* replace1152_1 -> 133 in the cache */
   /* replace1152_2_0 -> 16 in the cache */
   /* replace1152_2_1_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 3239 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 581, 133, 3240 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1153_0 -> 267 in the cache */
   /* search1153_1_0 -> 3157 in the cache */
   /* search1153_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 267, 3242 },
      -1,
   } },

   /* replace1153_0_0 -> 124 in the cache */
   /* replace1153_0_1 -> 127 in the cache */
   /* replace1153_0 -> 995 in the cache */
   /* replace1153_1 -> 125 in the cache */
   /* replace1153 -> 3202 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1154_0 -> 267 in the cache */
   /* search1154_1_0 -> 3157 in the cache */
   /* search1154_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 267, 3244 },
      -1,
   } },

   /* replace1154_0_0 -> 124 in the cache */
   /* replace1154_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1154_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3246, 125 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1155_0 -> 267 in the cache */
   /* search1155_1_0 -> 3157 in the cache */
   /* search1155_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 267, 3248 },
      -1,
   } },

   /* replace1155_0_0 -> 124 in the cache */
   /* replace1155_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1155_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3250, 125 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1156_0 -> 267 in the cache */
   /* search1156_1_0 -> 3157 in the cache */
   /* search1156_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 3157, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 267, 3252 },
      -1,
   } },

   /* replace1156_0_0 -> 124 in the cache */
   /* replace1156_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1156_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 3254, 125 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1157_0_1 -> 3184 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3256, 3184 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3257, 3258 },
      -1,
   } },

   /* replace1157_0_0 -> 124 in the cache */
   /* replace1157_0_1 -> 127 in the cache */
   /* replace1157_0 -> 3187 in the cache */
   /* replace1157_1 -> 125 in the cache */
   /* replace1157 -> 3188 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1158_0_0 -> 0 in the cache */
   /* search1158_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      5,
   } },
   /* search1158_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 3260, 3 },
      -1,
   } },

   /* replace1158 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1159_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1159_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3262, 120 },
      -1,
   } },
   /* search1159_1_0 -> 32 in the cache */
   /* search1159_1 -> 3262 in the cache */
   /* search1159_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3263, 3262, 122 },
      -1,
   } },

   /* replace1159_0 -> 32 in the cache */
   /* replace1159 -> 3262 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1160_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1160_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3265, 120 },
      -1,
   } },
   /* search1160_1_0 -> 16 in the cache */
   /* search1160_1 -> 3265 in the cache */
   /* search1160_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3266, 3265, 122 },
      -1,
   } },

   /* replace1160_0 -> 16 in the cache */
   /* replace1160 -> 3265 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1161_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1161_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3268, 120 },
      -1,
   } },
   /* search1161_1_0 -> 32 in the cache */
   /* search1161_1 -> 3268 in the cache */
   /* search1161_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3269, 3268, 122 },
      -1,
   } },

   /* replace1161_0 -> 32 in the cache */
   /* replace1161 -> 3268 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1162_0_0 -> 32 in the cache */
   /* search1162_0_1 -> 61 in the cache */
   /* search1162_0 -> 1182 in the cache */
   /* search1162_1_0 -> 32 in the cache */
   /* search1162_1 -> 3262 in the cache */
   /* search1162_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1182, 3262, 122 },
      -1,
   } },

   /* replace1162_0 -> 32 in the cache */
   /* replace1162 -> 3262 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1163_0_0 -> 16 in the cache */
   /* search1163_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 120 },
      -1,
   } },
   /* search1163_1_0 -> 16 in the cache */
   /* search1163_1 -> 3265 in the cache */
   /* search1163_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3272, 3265, 122 },
      -1,
   } },

   /* replace1163_0 -> 16 in the cache */
   /* replace1163 -> 3265 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1164_0_0 -> 32 in the cache */
   /* search1164_0_1 -> 61 in the cache */
   /* search1164_0 -> 1182 in the cache */
   /* search1164_1_0 -> 32 in the cache */
   /* search1164_1 -> 3268 in the cache */
   /* search1164_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1182, 3268, 122 },
      -1,
   } },

   /* replace1164_0 -> 32 in the cache */
   /* replace1164 -> 3268 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1165_0_0 -> 16 in the cache */
   /* search1165_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 122 },
      -1,
   } },
   /* search1165_1_0 -> 16 in the cache */
   /* search1165_1 -> 3265 in the cache */
   /* search1165_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3275, 3265, 122 },
      -1,
   } },

   /* replace1165_0 -> 16 in the cache */
   /* replace1165 -> 3265 in the cache */

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1166_0_0 -> 502 in the cache */
   /* search1166_0_1 -> 260 in the cache */
   /* search1166_0_2 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 260, 255 },
      0,
   } },
   /* search1166_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3277, 3 },
      -1,
   } },

   /* replace1166_0 -> 502 in the cache */
   /* replace1166_1_0 -> 3 in the cache */
   /* replace1166_1 -> 1043 in the cache */
   /* replace1166_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 1043, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1167_0_0 -> 502 in the cache */
   /* search1167_0_1 -> 255 in the cache */
   /* search1167_0_2 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 255, 260 },
      0,
   } },
   /* search1167_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3280, 3 },
      -1,
   } },

   /* replace1167_0 -> 502 in the cache */
   /* replace1167_1 -> 3 in the cache */
   /* replace1167_2_0 -> 3 in the cache */
   /* replace1167_2 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 3, 1043 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1168_0_0 -> 502 in the cache */
   /* search1168_0_1 -> 263 in the cache */
   /* search1168_0_2 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 263, 228 },
      0,
   } },
   /* search1168_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3283, 36 },
      -1,
   } },

   /* replace1168_0 -> 502 in the cache */
   /* replace1168_1_0 -> 36 in the cache */
   /* replace1168_1 -> 581 in the cache */
   /* replace1168_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 581, 36 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1169_0_0 -> 502 in the cache */
   /* search1169_0_1 -> 228 in the cache */
   /* search1169_0_2 -> 263 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 228, 263 },
      0,
   } },
   /* search1169_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3286, 36 },
      -1,
   } },

   /* replace1169_0 -> 502 in the cache */
   /* replace1169_1 -> 36 in the cache */
   /* replace1169_2_0 -> 36 in the cache */
   /* replace1169_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 36, 581 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1170_0_0 -> 32 in the cache */
   /* search1170_0_1 -> 113 in the cache */
   /* search1170_0 -> 670 in the cache */
   /* search1170_1_0 -> 32 in the cache */
   /* search1170_1 -> 98 in the cache */
   /* search1170_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 98, 32 },
      -1,
   } },

   /* replace1170_0 -> 32 in the cache */
   /* replace1170 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1171_0 -> 715 in the cache */
   /* search1171_1_0 -> 1084 in the cache */
   /* search1171_1_1 -> 150 in the cache */
   /* search1171_1_2 -> 151 in the cache */
   /* search1171_1 -> 1256 in the cache */
   /* search1171_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1256, 151 },
      -1,
   } },

   /* replace1171_0_0 -> 715 in the cache */
   /* replace1171_0_1 -> 1084 in the cache */
   /* replace1171_0 -> 1096 in the cache */
   /* replace1171_1 -> 150 in the cache */
   /* replace1171_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1096, 150, 151 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1172_0 -> 715 in the cache */
   /* search1172_1 -> 148 in the cache */
   /* search1172_2_0 -> 445 in the cache */
   /* search1172_2_1 -> 148 in the cache */
   /* search1172_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 3292 },
      -1,
   } },

   /* replace1172_0_0 -> 715 in the cache */
   /* replace1172_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 715, 445 },
      -1,
   } },
   /* replace1172_1 -> 148 in the cache */
   /* replace1172_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3294, 148, 151 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1173_0 -> 0 in the cache */
   /* search1173_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1173_0 -> 0 in the cache */
   /* replace1173_1_0 -> 3 in the cache */
   /* replace1173_1_1_0_0 -> 0 in the cache */
   /* replace1173_1_1_0_1 -> 3 in the cache */
   /* replace1173_1_1_0 -> 2564 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2564 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3297 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3298 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1174_0 -> 0 in the cache */
   /* search1174_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1174_0 -> 0 in the cache */
   /* replace1174_1_0 -> 3 in the cache */
   /* replace1174_1_1_0_0 -> 0 in the cache */
   /* replace1174_1_1_0_1 -> 3 in the cache */
   /* replace1174_1_1_0 -> 2564 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2564 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3301 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3302 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1175_0 -> 0 in the cache */
   /* search1175_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1175_0_0_0 -> 0 in the cache */
   /* replace1175_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1175_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3305, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 3306 },
      -1,
   } },

   /* ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1176_0 -> 0 in the cache */
   /* search1176_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1176_0_0 -> 0 in the cache */
   /* replace1176_0_1 -> 3 in the cache */
   /* replace1176_0 -> 1023 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1023 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3310, 3311, 3312, 3313 },
      -1,
   } },

   /* replace1177_0_0 -> 19 in the cache */
   /* replace1177_0_1 -> 3313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3313 },
      -1,
   } },
   /* replace1177_1 -> 3311 in the cache */
   /* replace1177_2_0_0 -> 3313 in the cache */
   /* replace1177_2_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3313, 3312 },
      -1,
   } },
   /* replace1177_2_1 -> 3311 in the cache */
   /* replace1177_2_2 -> 3310 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3316, 3311, 3310 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3315, 3311, 3317 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1178_0 -> 0 in the cache */
   /* search1178_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1178_0_0 -> 0 in the cache */
   /* replace1178_0_1 -> 3 in the cache */
   /* replace1178_0 -> 2452 in the cache */
   /* replace1178_1_0_0 -> 0 in the cache */
   /* replace1178_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1178_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3320, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 2452, 3321 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1179_0 -> 0 in the cache */
   /* search1179_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1179_0_0 -> 0 in the cache */
   /* replace1179_0_1 -> 3 in the cache */
   /* replace1179_0 -> 2452 in the cache */
   /* replace1179_1_0_0 -> 0 in the cache */
   /* replace1179_1_0_1 -> 3 in the cache */
   /* replace1179_1_0 -> 3320 in the cache */
   /* replace1179_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3320, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 2452, 3324 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1180_0 -> 0 in the cache */
   /* search1180_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1180_0_0 -> 0 in the cache */
   /* replace1180_0_1 -> 3 in the cache */
   /* replace1180_0 -> 2237 in the cache */
   /* replace1180_1_0_0 -> 0 in the cache */
   /* replace1180_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1180_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3327, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2237, 3328 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1181_0 -> 0 in the cache */
   /* search1181_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1181_0_0 -> 0 in the cache */
   /* replace1181_0_1 -> 3 in the cache */
   /* replace1181_0 -> 2237 in the cache */
   /* replace1181_1_0_0 -> 0 in the cache */
   /* replace1181_1_0_1 -> 3 in the cache */
   /* replace1181_1_0 -> 3327 in the cache */
   /* replace1181_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3327, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2237, 3331 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1182_0 -> 21 in the cache */
   /* search1182_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1182_0_0 -> 21 in the cache */
   /* replace1182_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1182_1_0_0 -> 21 in the cache */
   /* replace1182_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1182_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3335, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3334, 3336 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1183_0 -> 21 in the cache */
   /* search1183_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1183_0_0 -> 21 in the cache */
   /* replace1183_0_1 -> 41 in the cache */
   /* replace1183_0 -> 3334 in the cache */
   /* replace1183_1_0_0 -> 21 in the cache */
   /* replace1183_1_0_1 -> 41 in the cache */
   /* replace1183_1_0 -> 3335 in the cache */
   /* replace1183_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3335, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3334, 3339 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1184_0 -> 21 in the cache */
   /* search1184_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1184_0_0 -> 21 in the cache */
   /* replace1184_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1184_1_0_0 -> 21 in the cache */
   /* replace1184_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1184_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3343, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3342, 3344 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1185_0 -> 21 in the cache */
   /* search1185_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1185_0_0 -> 21 in the cache */
   /* replace1185_0_1 -> 41 in the cache */
   /* replace1185_0 -> 3342 in the cache */
   /* replace1185_1_0_0 -> 21 in the cache */
   /* replace1185_1_0_1 -> 41 in the cache */
   /* replace1185_1_0 -> 3343 in the cache */
   /* replace1185_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3343, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3342, 3347 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1186_0 -> 21 in the cache */
   /* search1186_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1186_0_0_0 -> 21 in the cache */
   /* replace1186_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1186_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3350, 21 },
      -1,
   } },
   /* replace1186_1 -> 1437 in the cache */
   /* replace1186_2_0 -> 21 in the cache */
   /* replace1186_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3351, 1437, 3352 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1187_0 -> 0 in the cache */
   /* search1187_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1187_0_0_0 -> 0 in the cache */
   /* replace1187_0_0_1 -> 3 in the cache */
   /* replace1187_0_0 -> 3305 in the cache */
   /* replace1187_0_1 -> 0 in the cache */
   /* replace1187_0 -> 3306 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1187_2_0 -> 0 in the cache */
   /* replace1187_2_1 -> 3 in the cache */
   /* replace1187_2 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3306, 3355, 193 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1188_0 -> 0 in the cache */
   /* search1188_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1188_0_0 -> 0 in the cache */
   /* replace1188_0_1 -> 3 in the cache */
   /* replace1188_0 -> 1023 in the cache */
   /* replace1188_1 -> 86 in the cache */
   /* replace1188_2_0 -> 0 in the cache */
   /* replace1188_2_1 -> 3 in the cache */
   /* replace1188_2 -> 3139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1023, 86, 3139 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1189_0 -> 21 in the cache */
   /* search1189_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1189_0_0 -> 21 in the cache */
   /* replace1189_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1189_1 -> 856 in the cache */
   /* replace1189_2_0 -> 21 in the cache */
   /* replace1189_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3360, 856, 3361 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1190_0 -> 21 in the cache */
   /* search1190_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1190_0_0_0_0 -> 21 in the cache */
   /* replace1190_0_0_0_1 -> 856 in the cache */
   /* replace1190_0_0_0 -> 1427 in the cache */
   /* replace1190_0_0_1_0 -> 41 in the cache */
   /* replace1190_0_0_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 41, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1427, 3364 },
      -1,
   } },
   /* replace1190_0_1_0_0 -> 21 in the cache */
   /* replace1190_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1190_0_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3366, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3365, 3367 },
      -1,
   } },
   /* replace1190_1 -> 22 in the cache */
   /* replace1190_2_0_0_0_0 -> 21 in the cache */
   /* replace1190_2_0_0_0_1 -> 856 in the cache */
   /* replace1190_2_0_0_0 -> 1427 in the cache */
   /* replace1190_2_0_0_1_0 -> 41 in the cache */
   /* replace1190_2_0_0_1_1 -> 856 in the cache */
   /* replace1190_2_0_0_1 -> 3364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1427, 3364 },
      -1,
   } },
   /* replace1190_2_0_1_0_0 -> 21 in the cache */
   /* replace1190_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1190_2_0_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3370, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 3369, 3371 },
      -1,
   } },
   /* replace1190_2_1_0 -> 21 in the cache */
   /* replace1190_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3372, 3373, 3374 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 3368, 22, 3375 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1191_0 -> 21 in the cache */
   /* search1191_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1191_0_0_0_0 -> 21 in the cache */
   /* replace1191_0_0_0_1 -> 856 in the cache */
   /* replace1191_0_0_0 -> 1427 in the cache */
   /* replace1191_0_0_1_0 -> 41 in the cache */
   /* replace1191_0_0_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1427, 3378 },
      -1,
   } },
   /* replace1191_0_1_0_0 -> 21 in the cache */
   /* replace1191_0_1_0_1 -> 41 in the cache */
   /* replace1191_0_1_0 -> 3361 in the cache */
   /* replace1191_0_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3361, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3379, 3380 },
      -1,
   } },
   /* replace1191_1 -> 22 in the cache */
   /* replace1191_2_0_0_0_0 -> 21 in the cache */
   /* replace1191_2_0_0_0_1 -> 856 in the cache */
   /* replace1191_2_0_0_0 -> 1427 in the cache */
   /* replace1191_2_0_0_1_0 -> 41 in the cache */
   /* replace1191_2_0_0_1_1 -> 856 in the cache */
   /* replace1191_2_0_0_1 -> 3378 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1427, 3378 },
      -1,
   } },
   /* replace1191_2_0_1_0_0 -> 21 in the cache */
   /* replace1191_2_0_1_0_1 -> 41 in the cache */
   /* replace1191_2_0_1_0 -> 3361 in the cache */
   /* replace1191_2_0_1_1 -> 856 in the cache */
   /* replace1191_2_0_1 -> 3380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 3382, 3380 },
      -1,
   } },
   /* replace1191_2_1_0 -> 21 in the cache */
   /* replace1191_2_1_1 -> 41 in the cache */
   /* replace1191_2_1 -> 3361 in the cache */
   /* replace1191_2_2 -> 3374 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3383, 3361, 3374 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3381, 22, 3384 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1192_0_0 -> 21 in the cache */
   /* search1192_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1192_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3386, 856 },
      -1,
   } },

   /* replace1192_0_0_0 -> 21 in the cache */
   /* replace1192_0_0 -> 2896 in the cache */
   /* replace1192_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2896, 3388 },
      -1,
   } },
   /* replace1192_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3389, 120 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1193_0_0 -> 21 in the cache */
   /* search1193_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1193_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3391, 856 },
      -1,
   } },

   /* replace1193_0_0_0 -> 21 in the cache */
   /* replace1193_0_0 -> 2896 in the cache */
   /* replace1193_0_1_0 -> 41 in the cache */
   /* replace1193_0_1 -> 3388 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2896, 3388 },
      -1,
   } },
   /* replace1193_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3393, 120 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1194_0_0 -> 21 in the cache */
   /* search1194_0_1 -> 41 in the cache */
   /* search1194_0 -> 3386 in the cache */
   /* search1194_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3386, 856 },
      -1,
   } },

   /* replace1194_0_0_0 -> 21 in the cache */
   /* replace1194_0_0 -> 2896 in the cache */
   /* replace1194_0_1_0 -> 41 in the cache */
   /* replace1194_0_1 -> 3388 in the cache */
   /* replace1194_0 -> 3389 in the cache */
   /* replace1194_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3389, 120 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1195_0_0 -> 21 in the cache */
   /* search1195_0_1 -> 41 in the cache */
   /* search1195_0 -> 3391 in the cache */
   /* search1195_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3391, 856 },
      -1,
   } },

   /* replace1195_0_0_0 -> 21 in the cache */
   /* replace1195_0_0 -> 2896 in the cache */
   /* replace1195_0_1_0 -> 41 in the cache */
   /* replace1195_0_1 -> 3388 in the cache */
   /* replace1195_0 -> 3393 in the cache */
   /* replace1195_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3393, 120 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1196_0 -> 21 in the cache */
   /* search1196_1 -> 856 in the cache */
   /* search1196 -> 1427 in the cache */

   /* replace1196_0_0 -> 21 in the cache */
   /* replace1196_0 -> 2896 in the cache */
   /* replace1196_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2896, 120 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1197_0 -> 21 in the cache */
   /* search1197_1 -> 856 in the cache */
   /* search1197 -> 1424 in the cache */

   /* replace1197_0_0 -> 21 in the cache */
   /* replace1197_0 -> 2896 in the cache */
   /* replace1197_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2896, 120 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1198_0 -> 21 in the cache */
   /* search1198_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 21, 856 },
      -1,
   } },

   /* replace1198_0_0_0 -> 21 in the cache */
   /* replace1198_0_0 -> 2895 in the cache */
   /* replace1198_0_1_0 -> 21 in the cache */
   /* replace1198_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 2895, 2896 },
      -1,
   } },
   /* replace1198_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3402, 120 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1199_0 -> 21 in the cache */
   /* search1199_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 21, 856 },
      -1,
   } },

   /* replace1199_0_0_0 -> 21 in the cache */
   /* replace1199_0_0 -> 2895 in the cache */
   /* replace1199_0_1_0 -> 21 in the cache */
   /* replace1199_0_1 -> 2896 in the cache */
   /* replace1199_0 -> 3402 in the cache */
   /* replace1199_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3402, 120 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1200_0 -> 856 in the cache */
   /* search1200_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 856, 21 },
      -1,
   } },

   /* replace1200_0_0_0 -> 21 in the cache */
   /* replace1200_0_0 -> 2895 in the cache */
   /* replace1200_0_1_0 -> 21 in the cache */
   /* replace1200_0_1 -> 2896 in the cache */
   /* replace1200_0 -> 3402 in the cache */
   /* replace1200_1 -> 120 in the cache */
   /* replace1200 -> 3403 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1201_0 -> 3310 in the cache */
   /* search1201_1 -> 3311 in the cache */
   /* search1201_2 -> 3312 in the cache */
   /* search1201_3 -> 3313 in the cache */
   /* search1201 -> 3314 in the cache */

   /* replace1201_0_0 -> 19 in the cache */
   /* replace1201_0_1 -> 3313 in the cache */
   /* replace1201_0 -> 3315 in the cache */
   /* replace1201_1 -> 3311 in the cache */
   /* replace1201_2_0_0 -> 3310 in the cache */
   /* replace1201_2_0_1_0_0_0_0 -> 377 in the cache */
   /* replace1201_2_0_1_0_0_0_1 -> 3313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 377, 3313 },
      -1,
   } },
   /* replace1201_2_0_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3407, 377 },
      -1,
   } },
   /* replace1201_2_0_1_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3408, 3312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3409 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3310, 3410 },
      -1,
   } },
   /* replace1201_2_1_0_0 -> 3311 in the cache */
   /* replace1201_2_1_0_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3311, 3312 },
      -1,
   } },
   /* replace1201_2_1_1_0_0_0 -> 377 in the cache */
   /* replace1201_2_1_1_0_0_1 -> 3313 in the cache */
   /* replace1201_2_1_1_0_0 -> 3407 in the cache */
   /* replace1201_2_1_1_0_1 -> 377 in the cache */
   /* replace1201_2_1_1_0 -> 3408 in the cache */
   /* replace1201_2_1_1_1 -> 3312 in the cache */
   /* replace1201_2_1_1 -> 3409 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 3412, 3409 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3411, 3413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3315, 3311, 3414 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1202_0 -> 3310 in the cache */
   /* search1202_1 -> 3311 in the cache */
   /* search1202_2 -> 3312 in the cache */
   /* search1202_3 -> 3313 in the cache */
   /* search1202 -> 3314 in the cache */

   /* replace1202_0_0 -> 19 in the cache */
   /* replace1202_0_1 -> 3313 in the cache */
   /* replace1202_0 -> 3315 in the cache */
   /* replace1202_1 -> 3311 in the cache */
   /* replace1202_2_0_0 -> 3313 in the cache */
   /* replace1202_2_0_1 -> 3312 in the cache */
   /* replace1202_2_0 -> 3316 in the cache */
   /* replace1202_2_1_0 -> 3311 in the cache */
   /* replace1202_2_1_1 -> 3312 in the cache */
   /* replace1202_2_1 -> 3412 in the cache */
   /* replace1202_2_2 -> 3310 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3316, 3412, 3310 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3315, 3311, 3416 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3418, 3419, 3420 },
      -1,
   } },

   /* replace1203_0_0 -> 19 in the cache */
   /* replace1203_0_1 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3420 },
      -1,
   } },
   /* replace1203_1 -> 3418 in the cache */
   /* replace1203_2_0 -> 3418 in the cache */
   /* replace1203_2_1 -> 3419 in the cache */
   /* replace1203_2_2 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3418, 3419, 3420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3422, 3418, 3423 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1204_0 -> 3418 in the cache */
   /* search1204_1 -> 3419 in the cache */
   /* search1204_2 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3418, 3419, 3420 },
      -1,
   } },

   /* replace1204_0_0 -> 19 in the cache */
   /* replace1204_0_1 -> 3420 in the cache */
   /* replace1204_0 -> 3422 in the cache */
   /* replace1204_1 -> 3418 in the cache */
   /* replace1204_2_0 -> 3418 in the cache */
   /* replace1204_2_1 -> 3419 in the cache */
   /* replace1204_2_2 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3418, 3419, 3420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3422, 3418, 3426 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1205_0 -> 0 in the cache */
   /* search1205_1 -> 3 in the cache */
   /* search1205_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1205_0 -> 0 in the cache */
   /* replace1205_1 -> 3 in the cache */
   /* replace1205 -> 2457 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1206_0 -> 124 in the cache */
   /* search1206_1_0 -> 124 in the cache */
   /* search1206_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 124, 125 },
      -1,
   } },
   /* search1206_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 124, 3429, 127 },
      -1,
   } },

   /* replace1206_0 -> 124 in the cache */
   /* replace1206_1 -> 125 in the cache */
   /* replace1206_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1207_0 -> 3418 in the cache */
   /* search1207_1 -> 3419 in the cache */
   /* search1207_2_0 -> 19 in the cache */
   /* search1207_2_1 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3420 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3418, 3419, 3432 },
      -1,
   } },

   /* replace1207_0 -> 3418 in the cache */
   /* replace1207_1 -> 3419 in the cache */
   /* replace1207_2 -> 3420 in the cache */
   /* replace1207 -> 3426 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1208_0 -> 3418 in the cache */
   /* search1208_1_0 -> 19 in the cache */
   /* search1208_1_1 -> 3419 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3419 },
      -1,
   } },
   /* search1208_2 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3418, 3434, 3420 },
      -1,
   } },

   /* replace1208_0 -> 3418 in the cache */
   /* replace1208_1 -> 3419 in the cache */
   /* replace1208_2 -> 3420 in the cache */
   /* replace1208 -> 3426 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1209_0 -> 3418 in the cache */
   /* search1209_1 -> 3419 in the cache */
   /* search1209_2_0 -> 19 in the cache */
   /* search1209_2_1 -> 3420 in the cache */
   /* search1209_2 -> 3432 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3418, 3419, 3432 },
      -1,
   } },

   /* replace1209_0 -> 3418 in the cache */
   /* replace1209_1 -> 3419 in the cache */
   /* replace1209_2 -> 3420 in the cache */
   /* replace1209 -> 3423 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1210_0 -> 3418 in the cache */
   /* search1210_1_0 -> 19 in the cache */
   /* search1210_1_1 -> 3419 in the cache */
   /* search1210_1 -> 3434 in the cache */
   /* search1210_2 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3418, 3434, 3420 },
      -1,
   } },

   /* replace1210_0 -> 3418 in the cache */
   /* replace1210_1 -> 3419 in the cache */
   /* replace1210_2 -> 3420 in the cache */
   /* replace1210 -> 3423 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1211_1_0 -> 19 in the cache */
   /* search1211_1_1 -> 3419 in the cache */
   /* search1211_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3438, 3434 },
      -1,
   } },

   /* replace1211_0 -> 3438 in the cache */
   /* replace1211_1 -> 3419 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3438, 3419 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1212_0_0 -> 19 in the cache */
   /* search1212_0_1 -> 3438 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3438 },
      -1,
   } },
   /* search1212_1 -> 3419 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3441, 3419 },
      -1,
   } },

   /* replace1212_0 -> 3438 in the cache */
   /* replace1212_1 -> 3419 in the cache */
   /* replace1212 -> 3440 in the cache */

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1213_0 -> 16 in the cache */
   /* search1213_1 -> 36 in the cache */
   /* search1213_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1213 -> 120 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1214_0 -> 16 in the cache */
   /* search1214_1 -> 36 in the cache */
   /* search1214_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1214 -> 120 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1215_0 -> 16 in the cache */
   /* search1215_1 -> 120 in the cache */
   /* search1215_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 33 },
      -1,
   } },

   /* replace1215_0 -> 16 in the cache */
   /* replace1215_1_0 -> 828 in the cache */
   /* replace1215_1_1_0 -> 36 in the cache */
   /* replace1215_1_1 -> 2470 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 828, 2470 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 3446 },
      -1,
   } },

   /* ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1216_0_0_0 -> 16 in the cache */
   /* search1216_0_0_1 -> 36 in the cache */
   /* search1216_0_0_2 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3448 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3449 },
      -1,
   } },

   /* replace1216_0 -> 16 in the cache */
   /* replace1216_1 -> 36 in the cache */
   /* replace1216_2 -> 377 in the cache */
   /* replace1216 -> 3448 in the cache */

   /* ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1217_0_0_0 -> 16 in the cache */
   /* search1217_0_0_1 -> 36 in the cache */
   /* search1217_0_0_2 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3452 },
      -1,
   } },

   /* replace1217_0 -> 16 in the cache */
   /* replace1217_1 -> 36 in the cache */
   /* replace1217_2 -> 377 in the cache */
   /* replace1217 -> 3448 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1218_0_0 -> 16 in the cache */
   /* search1218_0_1 -> 33 in the cache */
   /* search1218_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 294 },
      0,
   } },
   /* search1218_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3454, 120 },
      -1,
   } },

   /* replace1218_0_0 -> 16 in the cache */
   /* replace1218_0_1_0_0 -> 828 in the cache */
   /* replace1218_0_1_0_1_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 828, 3456 },
      -1,
   } },
   /* replace1218_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3457, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3458 },
      -1,
   } },
   /* replace1218_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3459, 120 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1219_0_0 -> 16 in the cache */
   /* search1219_0_1 -> 33 in the cache */
   /* search1219_0_2 -> 294 in the cache */
   /* search1219_0 -> 3454 in the cache */
   /* search1219_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3454, 120 },
      -1,
   } },

   /* replace1219_0_0 -> 16 in the cache */
   /* replace1219_0_1_0_0 -> 828 in the cache */
   /* replace1219_0_1_0_1_0 -> 133 in the cache */
   /* replace1219_0_1_0_1 -> 3456 in the cache */
   /* replace1219_0_1_0 -> 3457 in the cache */
   /* replace1219_0_1_1 -> 36 in the cache */
   /* replace1219_0_1 -> 3458 in the cache */
   /* replace1219_0 -> 3459 in the cache */
   /* replace1219_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3459, 120 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1220_0_0 -> 16 in the cache */
   /* search1220_0_1 -> 33 in the cache */
   /* search1220_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 294 },
      0,
   } },
   /* search1220_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3463, 120 },
      -1,
   } },

   /* replace1220_0_0 -> 16 in the cache */
   /* replace1220_0_1_0_0 -> 828 in the cache */
   /* replace1220_0_1_0_1_0 -> 133 in the cache */
   /* replace1220_0_1_0_1 -> 3456 in the cache */
   /* replace1220_0_1_0 -> 3457 in the cache */
   /* replace1220_0_1_1 -> 36 in the cache */
   /* replace1220_0_1 -> 3458 in the cache */
   /* replace1220_0 -> 3459 in the cache */
   /* replace1220_1 -> 120 in the cache */
   /* replace1220 -> 3460 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1221_0_0 -> 16 in the cache */
   /* search1221_0_1 -> 33 in the cache */
   /* search1221_0_2 -> 294 in the cache */
   /* search1221_0 -> 3463 in the cache */
   /* search1221_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3463, 120 },
      -1,
   } },

   /* replace1221_0_0 -> 16 in the cache */
   /* replace1221_0_1_0_0 -> 828 in the cache */
   /* replace1221_0_1_0_1_0 -> 133 in the cache */
   /* replace1221_0_1_0_1 -> 3456 in the cache */
   /* replace1221_0_1_0 -> 3457 in the cache */
   /* replace1221_0_1_1 -> 36 in the cache */
   /* replace1221_0_1 -> 3458 in the cache */
   /* replace1221_0 -> 3459 in the cache */
   /* replace1221_1 -> 120 in the cache */
   /* replace1221 -> 3462 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1222_0 -> 3418 in the cache */
   /* search1222_1 -> 3419 in the cache */
   /* search1222_2 -> 3420 in the cache */
   /* search1222 -> 3421 in the cache */

   /* replace1222_0_0 -> 120 in the cache */
   /* replace1222_0_1 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 120, 3420 },
      -1,
   } },
   /* replace1222_1 -> 120 in the cache */
   /* replace1222_2_0_0 -> 3418 in the cache */
   /* replace1222_2_0_1_0_0 -> 832 in the cache */
   /* replace1222_2_0_1_0_1 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 832, 3420 },
      -1,
   } },
   /* replace1222_2_0_1_1 -> 3419 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3467, 3419 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3418, 3468 },
      -1,
   } },
   /* replace1222_2_1_0 -> 832 in the cache */
   /* replace1222_2_1_1 -> 3420 in the cache */
   /* replace1222_2_1 -> 3467 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3469, 3467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3466, 120, 3470 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1223_0 -> 3418 in the cache */
   /* search1223_1 -> 3419 in the cache */
   /* search1223_2 -> 3420 in the cache */
   /* search1223 -> 3425 in the cache */

   /* replace1223_0_0 -> 3418 in the cache */
   /* replace1223_0_1 -> 3419 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3418, 3419 },
      -1,
   } },
   /* replace1223_1_0_0 -> 3420 in the cache */
   /* replace1223_1_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3420, 832 },
      -1,
   } },
   /* replace1223_1_1 -> 828 in the cache */
   /* replace1223_1_2_0_0 -> 377 in the cache */
   /* replace1223_1_2_0_1 -> 3420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 377, 3420 },
      -1,
   } },
   /* replace1223_1_2_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3474, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3473, 828, 3475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3472, 3476 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1224_0 -> 3418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 3418 },
      -1,
   } },

   /* replace1224_0_0_0 -> 3418 in the cache */
   /* replace1224_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3418, 120 },
      -1,
   } },
   /* replace1224_0_1_0 -> 3418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3418 },
      -1,
   } },
   /* replace1224_0_2 -> 3418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3479, 3480, 3418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3481 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1225_0 -> 3418 in the cache */
   /* search1225 -> 3478 in the cache */

   /* replace1225_0_0_0 -> 3418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3418 },
      -1,
   } },
   /* replace1225_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3483, 120 },
      -1,
   } },
   /* replace1225_1_0 -> 19 in the cache */
   /* replace1225_1_1_0 -> 3418 in the cache */
   /* replace1225_1_1 -> 3483 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3483 },
      -1,
   } },
   /* replace1225_2_0 -> 3418 in the cache */
   /* replace1225_2 -> 3483 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3484, 3485, 3483 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3487 },
      -1,
   } },

   /* replace1226_0_0_0 -> 3487 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3487 },
      -1,
   } },
   /* replace1226_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3489, 120 },
      -1,
   } },
   /* replace1226_1_0 -> 19 in the cache */
   /* replace1226_1_1_0 -> 3487 in the cache */
   /* replace1226_1_1 -> 3489 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3489 },
      -1,
   } },
   /* replace1226_2_0 -> 3487 in the cache */
   /* replace1226_2 -> 3489 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3490, 3491, 3489 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1227_0 -> 3487 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3487 },
      -1,
   } },

   /* replace1227_0_0 -> 3487 in the cache */
   /* replace1227_0_1_0 -> 3487 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3487, 3494 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 3495 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1228_0 -> 16 in the cache */
   /* search1228_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1228_0_0 -> 16 in the cache */
   /* replace1228_0_1_0_0 -> 386 in the cache */
   /* replace1228_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 386, 36 },
      -1,
   } },
   /* replace1228_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3498, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3499 },
      -1,
   } },
   /* replace1228_1 -> 968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3500, 968 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1229_0 -> 16 in the cache */
   /* search1229_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1229_0_0 -> 16 in the cache */
   /* replace1229_0_1_0 -> 36 in the cache */
   /* replace1229_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3503 },
      -1,
   } },
   /* replace1229_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3504, 783 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1230_0 -> 16 in the cache */
   /* search1230_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1230_0_0 -> 16 in the cache */
   /* replace1230_0_1_0_0 -> 377 in the cache */
   /* replace1230_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 377, 36 },
      -1,
   } },
   /* replace1230_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3507, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3508 },
      -1,
   } },
   /* replace1230_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3509, 810 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1231_0 -> 16 in the cache */
   /* search1231_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1231_0_0 -> 16 in the cache */
   /* replace1231_0_1_0 -> 36 in the cache */
   /* replace1231_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3512 },
      -1,
   } },
   /* replace1231_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3513, 806 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1232_0_0_0_0_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3515 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3517, 3518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3520 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3521 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1233_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1233_0_0_0_0_0 -> 3515 in the cache */
   /* replace1233_0_0_0_0 -> 3517 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3517, 3524 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3527 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1234_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1234_0_0_0_0_0 -> 228 in the cache */
   /* replace1234_0_0_0_0_1_0 -> 263 in the cache */
   /* replace1234_0_0_0_0_1_1 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 263, 3515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 228, 3530 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3531, 3532 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3535 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1235_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1235_0_0_0_0_0 -> 228 in the cache */
   /* replace1235_0_0_0_0_1_0 -> 263 in the cache */
   /* replace1235_0_0_0_0_1_1 -> 3515 in the cache */
   /* replace1235_0_0_0_0_1 -> 3530 in the cache */
   /* replace1235_0_0_0_0 -> 3531 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3531, 3538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3539 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3541 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1236_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1236_0_0_0_0 -> 3515 in the cache */
   /* replace1236_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3515, 120 },
      -1,
   } },
   /* replace1236_0_0_1_0 -> 3515 in the cache */
   /* replace1236_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3515, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3544, 3545 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3546 },
      -1,
   } },
   /* replace1236_1 -> 3518 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3547, 3518 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1237_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1237_0_0_0_0 -> 3515 in the cache */
   /* replace1237_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3515, 120 },
      -1,
   } },
   /* replace1237_0_0_1_0 -> 3515 in the cache */
   /* replace1237_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3515, 377 },
      -1,
   } },
   /* replace1237_0_0_2_0 -> 3515 in the cache */
   /* replace1237_0_0_2_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3515, 382 },
      -1,
   } },
   /* replace1237_0_0_3_0 -> 3515 in the cache */
   /* replace1237_0_0_3_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3515, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3550, 3551, 3552, 3553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3554 },
      -1,
   } },
   /* replace1237_1 -> 3524 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3555, 3524 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1238_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1238_0 -> 228 in the cache */
   /* replace1238_1_0 -> 263 in the cache */
   /* replace1238_1_1_0_0_0_0 -> 3515 in the cache */
   /* replace1238_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3515, 120 },
      -1,
   } },
   /* replace1238_1_1_0_0_1_0 -> 3515 in the cache */
   /* replace1238_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3515, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3558, 3559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3560 },
      -1,
   } },
   /* replace1238_1_1_1 -> 3532 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3561, 3532 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 263, 3562 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 228, 3563 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1239_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3515 },
      -1,
   } },

   /* replace1239_0 -> 228 in the cache */
   /* replace1239_1_0 -> 263 in the cache */
   /* replace1239_1_1_0_0_0_0 -> 3515 in the cache */
   /* replace1239_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3515, 120 },
      -1,
   } },
   /* replace1239_1_1_0_0_1_0 -> 3515 in the cache */
   /* replace1239_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3515, 377 },
      -1,
   } },
   /* replace1239_1_1_0_0_2_0 -> 3515 in the cache */
   /* replace1239_1_1_0_0_2_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3515, 382 },
      -1,
   } },
   /* replace1239_1_1_0_0_3_0 -> 3515 in the cache */
   /* replace1239_1_1_0_0_3_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3515, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3566, 3567, 3568, 3569 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3570 },
      -1,
   } },
   /* replace1239_1_1_1 -> 3538 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3571, 3538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 263, 3572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 228, 3573 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1240_0 -> 16 in the cache */
   /* search1240_1 -> 36 in the cache */
   /* search1240 -> 3026 in the cache */

   /* replace1240_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3575 },
      -1,
   } },
   /* replace1240_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3576, 810 },
      -1,
   } },
   /* replace1240_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3578 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3577, 3579 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1241_0 -> 16 in the cache */
   /* search1241 -> 2991 in the cache */

   /* replace1241_0_0 -> 16 in the cache */
   /* replace1241_0 -> 2988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2988 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1242_0 -> 16 in the cache */
   /* search1242 -> 2998 in the cache */

   /* replace1242_0_0_0 -> 16 in the cache */
   /* replace1242_0_0_1 -> 810 in the cache */
   /* replace1242_0_0 -> 965 in the cache */
   /* replace1242_0 -> 2989 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2989 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1243_0 -> 11 in the cache */
   /* search1243_1 -> 243 in the cache */
   /* search1243 -> 2981 in the cache */

   /* replace1243_0_0_0 -> 243 in the cache */
   /* replace1243_0_0 -> 2982 in the cache */
   /* replace1243_0_1 -> 810 in the cache */
   /* replace1243_0 -> 2983 in the cache */
   /* replace1243_1_0 -> 11 in the cache */
   /* replace1243_1 -> 1743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2983, 1743 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1244_0 -> 16 in the cache */
   /* search1244 -> 2904 in the cache */

   /* replace1244_0 -> 16 in the cache */
   /* replace1244 -> 2988 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1245_0 -> 16 in the cache */
   /* search1245 -> 2906 in the cache */

   /* replace1245_0_0 -> 16 in the cache */
   /* replace1245_0_1 -> 810 in the cache */
   /* replace1245_0 -> 965 in the cache */
   /* replace1245 -> 2989 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1246_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1246_0_0 -> 32 in the cache */
   /* replace1246_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1246_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 3585, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1247_0_0 -> 32 in the cache */
   /* search1247_0_1 -> 63 in the cache */
   /* search1247_0 -> 3585 in the cache */
   /* search1247_1 -> 35 in the cache */
   /* search1247 -> 3586 in the cache */

   /* replace1247_0 -> 32 in the cache */
   /* replace1247 -> 3584 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1248_0_0 -> 32 in the cache */
   /* search1248_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1248_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 3587, 63 },
      -1,
   } },

   /* replace1248_0 -> 32 in the cache */
   /* replace1248 -> 3584 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1249_0 -> 32 in the cache */
   /* search1249 -> 235 in the cache */

   /* replace1249_0_0_0 -> 113 in the cache */
   /* replace1249_0_0_1 -> 32 in the cache */
   /* replace1249_0_0 -> 1464 in the cache */
   /* replace1249_0 -> 1465 in the cache */
   /* replace1249_1_0_0 -> 32 in the cache */
   /* replace1249_1_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 3589 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1465, 3590 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1250_0 -> 0 in the cache */
   /* search1250_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1250_0 -> 0 in the cache */
   /* replace1250_1 -> 3 in the cache */
   /* replace1250 -> 909 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1251_0 -> 16 in the cache */
   /* search1251_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1251_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3594 },
      -1,
   } },
   /* replace1251_1_0 -> 36 in the cache */
   /* replace1251_1_1 -> 3594 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 3594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 3595, 3596 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1252_0 -> 16 in the cache */
   /* search1252_1 -> 36 in the cache */
   /* search1252_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace1252_0_0_0 -> 16 in the cache */
   /* replace1252_0_0_1 -> 3594 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 16, 3594 },
      -1,
   } },
   /* replace1252_0_1_0 -> 36 in the cache */
   /* replace1252_0_1_1 -> 3594 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 36, 3594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 3599, 3600 },
      -1,
   } },
   /* replace1252_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 3601, 133 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1253_0 -> 16 in the cache */
   /* search1253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1253_0 -> 16 in the cache */
   /* replace1253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1254_0 -> 16 in the cache */
   /* search1254_1 -> 36 in the cache */
   /* search1254 -> 3603 in the cache */

   /* replace1254_0 -> 16 in the cache */
   /* replace1254_1 -> 36 in the cache */
   /* replace1254 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1255_0 -> 16 in the cache */
   /* search1255_1 -> 36 in the cache */
   /* search1255_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace1255_0 -> 16 in the cache */
   /* replace1255_1 -> 36 in the cache */
   /* replace1255_2 -> 133 in the cache */
   /* replace1255 -> 3598 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1256_0 -> 16 in the cache */
   /* search1256_1 -> 36 in the cache */
   /* search1256_2 -> 133 in the cache */
   /* search1256 -> 3605 in the cache */

   /* replace1256_0_0 -> 16 in the cache */
   /* replace1256_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1256_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3606, 133 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1257_0 -> 16 in the cache */
   /* search1257_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1257_0 -> 16 in the cache */
   /* replace1257_1 -> 36 in the cache */
   /* replace1257 -> 3593 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1258_0 -> 16 in the cache */
   /* search1258_1 -> 36 in the cache */
   /* search1258 -> 3608 in the cache */

   /* replace1258_0 -> 16 in the cache */
   /* replace1258_1 -> 36 in the cache */
   /* replace1258 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1259_0 -> 16 in the cache */
   /* search1259_1 -> 36 in the cache */
   /* search1259_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1259_0 -> 16 in the cache */
   /* replace1259_1 -> 36 in the cache */
   /* replace1259 -> 3604 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1260_0 -> 16 in the cache */
   /* search1260_1 -> 120 in the cache */
   /* search1260_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 120, 536 },
      -1,
   } },

   /* replace1260 -> 536 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1261_0 -> 16 in the cache */
   /* search1261_1 -> 377 in the cache */
   /* search1261_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 377, 536 },
      -1,
   } },

   /* replace1261_0 -> 16 in the cache */
   /* replace1261_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 536 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1262_0 -> 271 in the cache */
   /* search1262_1 -> 33 in the cache */
   /* search1262_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 271, 33, 133 },
      -1,
   } },

   /* replace1262_0_0 -> 16 in the cache */
   /* replace1262_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1262_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3614, 133 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1263_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3616 },
      -1,
   } },

   /* replace1263_0 -> 16 in the cache */
   /* replace1263_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3618 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1264_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3620 },
      -1,
   } },

   /* replace1264_0_0 -> 16 in the cache */
   /* replace1264_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3622 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3623 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3624 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1265_0 -> 16 in the cache */
   /* search1265_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace1265 -> 120 in the cache */

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1266_0_0 -> 120 in the cache */
   /* search1266_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1266_1 -> 36 in the cache */
   /* search1266_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3627, 36, 133 },
      -1,
   } },

   /* replace1266_0 -> 16 in the cache */
   /* replace1266_1 -> 36 in the cache */
   /* replace1266_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'c', 'b') */
   /* search1267_0_0 -> 16 in the cache */
   /* search1267_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1267_1 -> 36 in the cache */
   /* search1267_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3630, 36, 133 },
      -1,
   } },

   /* replace1267_0 -> 16 in the cache */
   /* replace1267_1 -> 133 in the cache */
   /* replace1267_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1268_0_0 -> 16 in the cache */
   /* search1268_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1268_1 -> 36 in the cache */
   /* search1268_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3633, 36, 133 },
      -1,
   } },

   /* replace1268_0 -> 16 in the cache */
   /* replace1268_1 -> 36 in the cache */
   /* replace1268_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'c', 'b') */
   /* search1269_0_0 -> 120 in the cache */
   /* search1269_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1269_1 -> 36 in the cache */
   /* search1269_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3636, 36, 133 },
      -1,
   } },

   /* replace1269_0 -> 16 in the cache */
   /* replace1269_1 -> 133 in the cache */
   /* replace1269_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search1270_0_0 -> 120 in the cache */
   /* search1270_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1270_1 -> 36 in the cache */
   /* search1270_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3639, 36, 133 },
      -1,
   } },

   /* replace1270_0 -> 16 in the cache */
   /* replace1270_1 -> 36 in the cache */
   /* replace1270_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search1271_0_0 -> 16 in the cache */
   /* search1271_0_1 -> 120 in the cache */
   /* search1271_0 -> 1407 in the cache */
   /* search1271_1 -> 36 in the cache */
   /* search1271_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1407, 36, 133 },
      -1,
   } },

   /* replace1271_0 -> 16 in the cache */
   /* replace1271_1 -> 133 in the cache */
   /* replace1271_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search1272_0_0 -> 16 in the cache */
   /* search1272_0_1 -> 120 in the cache */
   /* search1272_0 -> 1404 in the cache */
   /* search1272_1 -> 36 in the cache */
   /* search1272_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1404, 36, 133 },
      -1,
   } },

   /* replace1272_0 -> 16 in the cache */
   /* replace1272_1 -> 36 in the cache */
   /* replace1272_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search1273_0_0 -> 120 in the cache */
   /* search1273_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1273_1 -> 36 in the cache */
   /* search1273_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3646, 36, 133 },
      -1,
   } },

   /* replace1273_0 -> 16 in the cache */
   /* replace1273_1 -> 133 in the cache */
   /* replace1273_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1274_0_0 -> 120 in the cache */
   /* search1274_0_1 -> 16 in the cache */
   /* search1274_0 -> 1839 in the cache */
   /* search1274_1 -> 36 in the cache */
   /* search1274_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1839, 36, 133 },
      -1,
   } },

   /* replace1274_0 -> 16 in the cache */
   /* replace1274_1 -> 36 in the cache */
   /* replace1274_2 -> 133 in the cache */
   /* replace1274 -> 3629 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'c', 'b') */
   /* search1275_0_0 -> 16 in the cache */
   /* search1275_0_1 -> 120 in the cache */
   /* search1275_0 -> 1841 in the cache */
   /* search1275_1 -> 36 in the cache */
   /* search1275_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1841, 36, 133 },
      -1,
   } },

   /* replace1275_0 -> 16 in the cache */
   /* replace1275_1 -> 133 in the cache */
   /* replace1275_2 -> 36 in the cache */
   /* replace1275 -> 3632 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1276_0_0 -> 16 in the cache */
   /* search1276_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1276_1 -> 36 in the cache */
   /* search1276_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3651, 36, 133 },
      -1,
   } },

   /* replace1276_0 -> 16 in the cache */
   /* replace1276_1 -> 36 in the cache */
   /* replace1276_2 -> 133 in the cache */
   /* replace1276 -> 3635 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'c', 'b') */
   /* search1277_0_0 -> 120 in the cache */
   /* search1277_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1277_1 -> 36 in the cache */
   /* search1277_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3653, 36, 133 },
      -1,
   } },

   /* replace1277_0 -> 16 in the cache */
   /* replace1277_1 -> 133 in the cache */
   /* replace1277_2 -> 36 in the cache */
   /* replace1277 -> 3638 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1278_0 -> 6 in the cache */
   /* search1278_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 2054 },
      -1,
   } },

   /* replace1278_0_0 -> 2054 in the cache */
   /* replace1278_0_1 -> 1368 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2054, 1368 },
      -1,
   } },
   /* replace1278_1_0_0_0 -> 6 in the cache */
   /* replace1278_1_0_0_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 2054 },
      -1,
   } },
   /* replace1278_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3657, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1278_1_2_0 -> 6 in the cache */
   /* replace1278_1_2_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3658, 3659, 3660 },
      -1,
   } },
   /* replace1278_2_0_0 -> 6 in the cache */
   /* replace1278_2_0_1_0 -> 6 in the cache */
   /* replace1278_2_0_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 6, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 6, 3662 },
      -1,
   } },
   /* replace1278_2_1 -> 7 in the cache */
   /* replace1278_2_2_0 -> 6 in the cache */
   /* replace1278_2_2_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 6, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3663, 7, 3664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3656, 3661, 3665 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1279_0 -> 6 in the cache */
   /* search1279_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 2054 },
      -1,
   } },

   /* replace1279_0_0 -> 2054 in the cache */
   /* replace1279_0_1 -> 791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2054, 791 },
      -1,
   } },
   /* replace1279_1_0_0_0 -> 6 in the cache */
   /* replace1279_1_0_0_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 6, 2054 },
      -1,
   } },
   /* replace1279_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3669, 6 },
      -1,
   } },
   /* replace1279_1_1 -> 3659 in the cache */
   /* replace1279_1_2_0 -> 6 in the cache */
   /* replace1279_1_2_1 -> 2054 in the cache */
   /* replace1279_1_2 -> 3669 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3670, 3659, 3669 },
      -1,
   } },
   /* replace1279_2_0_0 -> 6 in the cache */
   /* replace1279_2_0_1_0 -> 6 in the cache */
   /* replace1279_2_0_1_1 -> 2054 in the cache */
   /* replace1279_2_0_1 -> 3669 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3669 },
      -1,
   } },
   /* replace1279_2_1 -> 7 in the cache */
   /* replace1279_2_2_0 -> 6 in the cache */
   /* replace1279_2_2_1 -> 2054 in the cache */
   /* replace1279_2_2 -> 3669 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3672, 7, 3669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3668, 3671, 3673 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1280_0 -> 11 in the cache */
   /* search1280_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* replace1280_0_0 -> 243 in the cache */
   /* replace1280_0_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 243, 1390 },
      -1,
   } },
   /* replace1280_1_0_0_0 -> 11 in the cache */
   /* replace1280_1_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 243 },
      -1,
   } },
   /* replace1280_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3677, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1280_1_2_0 -> 11 in the cache */
   /* replace1280_1_2_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3678, 3679, 3680 },
      -1,
   } },
   /* replace1280_2_0_0 -> 11 in the cache */
   /* replace1280_2_0_1_0 -> 11 in the cache */
   /* replace1280_2_0_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 11, 3682 },
      -1,
   } },
   /* replace1280_2_1 -> 12 in the cache */
   /* replace1280_2_2_0 -> 11 in the cache */
   /* replace1280_2_2_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3683, 12, 3684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3676, 3681, 3685 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1281_0 -> 11 in the cache */
   /* search1281_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 243 },
      -1,
   } },

   /* replace1281_0_0 -> 243 in the cache */
   /* replace1281_0_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 243, 813 },
      -1,
   } },
   /* replace1281_1_0_0_0 -> 11 in the cache */
   /* replace1281_1_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 11, 243 },
      -1,
   } },
   /* replace1281_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3689, 11 },
      -1,
   } },
   /* replace1281_1_1 -> 3679 in the cache */
   /* replace1281_1_2_0 -> 11 in the cache */
   /* replace1281_1_2_1 -> 243 in the cache */
   /* replace1281_1_2 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3690, 3679, 3689 },
      -1,
   } },
   /* replace1281_2_0_0 -> 11 in the cache */
   /* replace1281_2_0_1_0 -> 11 in the cache */
   /* replace1281_2_0_1_1 -> 243 in the cache */
   /* replace1281_2_0_1 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3689 },
      -1,
   } },
   /* replace1281_2_1 -> 12 in the cache */
   /* replace1281_2_2_0 -> 11 in the cache */
   /* replace1281_2_2_1 -> 243 in the cache */
   /* replace1281_2_2 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3692, 12, 3689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3688, 3691, 3693 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1282_0 -> 16 in the cache */
   /* search1282_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1282_0_0 -> 36 in the cache */
   /* replace1282_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   /* replace1282_1_0_0_0 -> 16 in the cache */
   /* replace1282_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1282_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3697, 16 },
      -1,
   } },
   /* replace1282_1_1 -> 946 in the cache */
   /* replace1282_1_2_0 -> 16 in the cache */
   /* replace1282_1_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3698, 946, 3699 },
      -1,
   } },
   /* replace1282_2_0_0 -> 16 in the cache */
   /* replace1282_2_0_1_0 -> 16 in the cache */
   /* replace1282_2_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 16, 3701 },
      -1,
   } },
   /* replace1282_2_1 -> 17 in the cache */
   /* replace1282_2_2_0 -> 16 in the cache */
   /* replace1282_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3702, 17, 3703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3696, 3700, 3704 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1283_0 -> 16 in the cache */
   /* search1283_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1283_0_0 -> 36 in the cache */
   /* replace1283_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   /* replace1283_1_0_0_0 -> 16 in the cache */
   /* replace1283_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1283_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3708, 16 },
      -1,
   } },
   /* replace1283_1_1 -> 946 in the cache */
   /* replace1283_1_2_0 -> 16 in the cache */
   /* replace1283_1_2_1 -> 36 in the cache */
   /* replace1283_1_2 -> 3708 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3709, 946, 3708 },
      -1,
   } },
   /* replace1283_2_0_0 -> 16 in the cache */
   /* replace1283_2_0_1_0 -> 16 in the cache */
   /* replace1283_2_0_1_1 -> 36 in the cache */
   /* replace1283_2_0_1 -> 3708 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3708 },
      -1,
   } },
   /* replace1283_2_1 -> 17 in the cache */
   /* replace1283_2_2_0 -> 16 in the cache */
   /* replace1283_2_2_1 -> 36 in the cache */
   /* replace1283_2_2 -> 3708 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3711, 17, 3708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3707, 3710, 3712 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1284_0 -> 21 in the cache */
   /* search1284_1 -> 41 in the cache */
   /* search1284 -> 3363 in the cache */

   /* replace1284_0_0 -> 41 in the cache */
   /* replace1284_0_1 -> 1432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 1432 },
      -1,
   } },
   /* replace1284_1_0_0_0 -> 21 in the cache */
   /* replace1284_1_0_0_1 -> 41 in the cache */
   /* replace1284_1_0_0 -> 3350 in the cache */
   /* replace1284_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3350, 21 },
      -1,
   } },
   /* replace1284_1_1 -> 3374 in the cache */
   /* replace1284_1_2_0 -> 21 in the cache */
   /* replace1284_1_2_1 -> 41 in the cache */
   /* replace1284_1_2 -> 3352 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3715, 3374, 3352 },
      -1,
   } },
   /* replace1284_2_0_0 -> 21 in the cache */
   /* replace1284_2_0_1_0 -> 21 in the cache */
   /* replace1284_2_0_1_1 -> 41 in the cache */
   /* replace1284_2_0_1 -> 3366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 21, 3366 },
      -1,
   } },
   /* replace1284_2_1 -> 22 in the cache */
   /* replace1284_2_2_0 -> 21 in the cache */
   /* replace1284_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3717, 22, 3718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3714, 3716, 3719 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1285_0 -> 21 in the cache */
   /* search1285_1 -> 41 in the cache */
   /* search1285 -> 3377 in the cache */

   /* replace1285_0_0 -> 41 in the cache */
   /* replace1285_0_1 -> 856 in the cache */
   /* replace1285_0 -> 3364 in the cache */
   /* replace1285_1_0_0_0 -> 21 in the cache */
   /* replace1285_1_0_0_1 -> 41 in the cache */
   /* replace1285_1_0_0 -> 3361 in the cache */
   /* replace1285_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3361, 21 },
      -1,
   } },
   /* replace1285_1_1 -> 3374 in the cache */
   /* replace1285_1_2_0 -> 21 in the cache */
   /* replace1285_1_2_1 -> 41 in the cache */
   /* replace1285_1_2 -> 3361 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3721, 3374, 3361 },
      -1,
   } },
   /* replace1285_2_0_0 -> 21 in the cache */
   /* replace1285_2_0_1_0 -> 21 in the cache */
   /* replace1285_2_0_1_1 -> 41 in the cache */
   /* replace1285_2_0_1 -> 3361 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 3361 },
      -1,
   } },
   /* replace1285_2_1 -> 22 in the cache */
   /* replace1285_2_2_0 -> 21 in the cache */
   /* replace1285_2_2_1 -> 41 in the cache */
   /* replace1285_2_2 -> 3361 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3723, 22, 3361 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3364, 3722, 3724 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1286_0_0_0 -> 0 in the cache */
   /* search1286_0_0_1 -> 3 in the cache */
   /* search1286_0_0 -> 1030 in the cache */
   /* search1286_0_1_0 -> 150 in the cache */
   /* search1286_0_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1030, 3726 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3727 },
      -1,
   } },

   /* replace1286_0_0 -> 0 in the cache */
   /* replace1286_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1286_1_0 -> 150 in the cache */
   /* replace1286_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3729, 3730 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1287_0_0_0 -> 0 in the cache */
   /* search1287_0_0_1 -> 3 in the cache */
   /* search1287_0_0 -> 1030 in the cache */
   /* search1287_0_1_0 -> 150 in the cache */
   /* search1287_0_1_1 -> 151 in the cache */
   /* search1287_0_1 -> 3726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1030, 3726 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3732 },
      -1,
   } },

   /* replace1287_0_0 -> 0 in the cache */
   /* replace1287_0_1 -> 3 in the cache */
   /* replace1287_0 -> 3729 in the cache */
   /* replace1287_1_0 -> 150 in the cache */
   /* replace1287_1_1 -> 151 in the cache */
   /* replace1287_1 -> 3730 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3729, 3730 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1288_0_0_0 -> 0 in the cache */
   /* search1288_0_0_1 -> 3 in the cache */
   /* search1288_0_0 -> 1030 in the cache */
   /* search1288_0_1_0 -> 150 in the cache */
   /* search1288_0_1_1 -> 151 in the cache */
   /* search1288_0_1 -> 3730 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1030, 3730 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3735 },
      -1,
   } },

   /* replace1288_0_0 -> 0 in the cache */
   /* replace1288_0_1 -> 3 in the cache */
   /* replace1288_0 -> 3729 in the cache */
   /* replace1288_1_0 -> 150 in the cache */
   /* replace1288_1_1 -> 151 in the cache */
   /* replace1288_1 -> 3726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3729, 3726 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1289_0_0_0 -> 0 in the cache */
   /* search1289_0_0_1 -> 3 in the cache */
   /* search1289_0_0 -> 1030 in the cache */
   /* search1289_0_1_0 -> 150 in the cache */
   /* search1289_0_1_1 -> 151 in the cache */
   /* search1289_0_1 -> 3730 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1030, 3730 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3738 },
      -1,
   } },

   /* replace1289_0_0 -> 0 in the cache */
   /* replace1289_0_1 -> 3 in the cache */
   /* replace1289_0 -> 3729 in the cache */
   /* replace1289_1_0 -> 150 in the cache */
   /* replace1289_1_1 -> 151 in the cache */
   /* replace1289_1 -> 3726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3729, 3726 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1290_0_0_0 -> 0 in the cache */
   /* search1290_0_0_1 -> 3 in the cache */
   /* search1290_0_0 -> 3729 in the cache */
   /* search1290_0_1_0 -> 150 in the cache */
   /* search1290_0_1_1 -> 151 in the cache */
   /* search1290_0_1 -> 3730 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3729, 3730 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3741 },
      -1,
   } },

   /* replace1290_0_0 -> 0 in the cache */
   /* replace1290_0_1 -> 3 in the cache */
   /* replace1290_0 -> 1030 in the cache */
   /* replace1290_1_0 -> 150 in the cache */
   /* replace1290_1_1 -> 151 in the cache */
   /* replace1290_1 -> 3726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1030, 3726 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1291_0_0_0 -> 0 in the cache */
   /* search1291_0_0_1 -> 3 in the cache */
   /* search1291_0_0 -> 3729 in the cache */
   /* search1291_0_1_0 -> 150 in the cache */
   /* search1291_0_1_1 -> 151 in the cache */
   /* search1291_0_1 -> 3730 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3729, 3730 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3744 },
      -1,
   } },

   /* replace1291_0_0 -> 0 in the cache */
   /* replace1291_0_1 -> 3 in the cache */
   /* replace1291_0 -> 1030 in the cache */
   /* replace1291_1_0 -> 150 in the cache */
   /* replace1291_1_1 -> 151 in the cache */
   /* replace1291_1 -> 3726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1030, 3726 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1292_0_0 -> 715 in the cache */
   /* search1292_0 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 1079 },
      -1,
   } },

   /* replace1292 -> 715 in the cache */

   /* ('i2b1', ('b2i', 'a@1')) => a */
   /* search1293_0_0 -> 715 in the cache */
   /* search1293_0 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 1177 },
      -1,
   } },

   /* replace1293 -> 715 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1294_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_f2b8,
      -1, 0,
      { 3749 },
      -1,
   } },

   /* replace1294 -> 6 in the cache */

   /* ('i2b8', ('b2i', 'a@8')) => a */
   /* search1295_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2b8,
      -1, 0,
      { 3751 },
      -1,
   } },

   /* replace1295 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1296_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2b16,
      -1, 0,
      { 3753 },
      -1,
   } },

   /* replace1296 -> 11 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search1297_0_0 -> 11 in the cache */
   /* search1297_0 -> 2795 in the cache */
   /* search1297 -> 2796 in the cache */

   /* replace1297 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1298_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2b32,
      -1, 0,
      { 3755 },
      -1,
   } },

   /* replace1298 -> 16 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1299_0_0 -> 16 in the cache */
   /* search1299_0 -> 2797 in the cache */
   /* search1299 -> 2798 in the cache */

   /* replace1299 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1300_0_0 -> 32 in the cache */
   /* search1300_0 -> 1466 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1466 },
      -1,
   } },

   /* replace1300_0 -> 32 in the cache */
   /* replace1300 -> 1466 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1301_0_0 -> 32 in the cache */
   /* search1301_0 -> 1466 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1466 },
      -1,
   } },

   /* replace1301_0 -> 32 in the cache */
   /* replace1301 -> 2787 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1302_0_0 -> 32 in the cache */
   /* search1302_0 -> 1466 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1466 },
      -1,
   } },

   /* replace1302_0 -> 32 in the cache */
   /* replace1302 -> 2787 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1303_0_0 -> 32 in the cache */
   /* search1303_0 -> 2787 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 2787 },
      -1,
   } },

   /* replace1303_0 -> 32 in the cache */
   /* replace1303 -> 1466 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1304_0_0 -> 32 in the cache */
   /* search1304_0 -> 2787 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2787 },
      -1,
   } },

   /* replace1304_0 -> 32 in the cache */
   /* replace1304 -> 2787 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1305_0_0 -> 32 in the cache */
   /* search1305_0 -> 2787 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 2787 },
      -1,
   } },

   /* replace1305_0 -> 32 in the cache */
   /* replace1305 -> 1466 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1306_0_0 -> 32 in the cache */
   /* search1306_0 -> 2787 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2787 },
      -1,
   } },

   /* replace1306_0 -> 32 in the cache */
   /* replace1306 -> 2787 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1307_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 715 },
      -1,
   } },

   /* replace1307 -> 715 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1308_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1308 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1309_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1309 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1310_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1310 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1311_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1311 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1312_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 715 },
      -1,
   } },

   /* replace1312 -> 715 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1313_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1313 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1314_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1314 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1315_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1315 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1316_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1316 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1317_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1317 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1318_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1318 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1319_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1319 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1320_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 715 },
      -1,
   } },

   /* replace1320 -> 715 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1321_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1321 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1322_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1322 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1323_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1323 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1324_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3781 },
      -1,
   } },

   /* replace1324_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1325_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1325_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1326_0_0 -> 32 in the cache */
   /* search1326_0 -> 3781 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3781 },
      -1,
   } },

   /* replace1326_0 -> 32 in the cache */
   /* replace1326 -> 3783 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1327_0_0 -> 32 in the cache */
   /* search1327_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1327_0 -> 32 in the cache */
   /* replace1327 -> 3786 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1328_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3789 },
      -1,
   } },

   /* replace1328_0 -> 32 in the cache */
   /* replace1328 -> 3783 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1329_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3791 },
      -1,
   } },

   /* replace1329_0 -> 32 in the cache */
   /* replace1329 -> 3786 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1330_0_0 -> 32 in the cache */
   /* search1330_0 -> 3789 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3789 },
      -1,
   } },

   /* replace1330_0 -> 32 in the cache */
   /* replace1330 -> 3783 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1331_0_0 -> 32 in the cache */
   /* search1331_0 -> 3791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3791 },
      -1,
   } },

   /* replace1331_0 -> 32 in the cache */
   /* replace1331 -> 3786 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1332_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3795 },
      -1,
   } },

   /* replace1332_0 -> 32 in the cache */
   /* replace1332 -> 3783 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1333_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3797 },
      -1,
   } },

   /* replace1333_0 -> 32 in the cache */
   /* replace1333 -> 3786 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1334_0_0 -> 32 in the cache */
   /* search1334_0 -> 3795 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3795 },
      -1,
   } },

   /* replace1334_0 -> 32 in the cache */
   /* replace1334 -> 3783 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1335_0_0 -> 32 in the cache */
   /* search1335_0 -> 3797 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3797 },
      -1,
   } },

   /* replace1335_0 -> 32 in the cache */
   /* replace1335 -> 3786 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1336_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1336_0 -> 32 in the cache */
   /* replace1336 -> 3783 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1337_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1337_0 -> 32 in the cache */
   /* replace1337 -> 3786 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1338_0_0 -> 32 in the cache */
   /* search1338_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1338_0 -> 32 in the cache */
   /* replace1338 -> 3783 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1339_0_0 -> 32 in the cache */
   /* search1339_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1339_0 -> 32 in the cache */
   /* replace1339 -> 3786 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1340_0_0 -> 715 in the cache */
   /* search1340_0 -> 3764 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1340_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1341_0_0 -> 715 in the cache */
   /* search1341_0 -> 3769 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3769 },
      -1,
   } },

   /* replace1341_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1342_0_0 -> 32 in the cache */
   /* search1342_0 -> 3789 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3789 },
      -1,
   } },

   /* replace1342_0 -> 32 in the cache */
   /* replace1342 -> 3781 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1343_0_0 -> 32 in the cache */
   /* search1343_0 -> 3791 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3791 },
      -1,
   } },

   /* replace1343_0 -> 32 in the cache */
   /* replace1343 -> 3784 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1344_0_0 -> 32 in the cache */
   /* search1344_0 -> 3789 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3789 },
      -1,
   } },

   /* replace1344_0 -> 32 in the cache */
   /* replace1344 -> 3781 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1345_0_0 -> 32 in the cache */
   /* search1345_0 -> 3791 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3791 },
      -1,
   } },

   /* replace1345_0 -> 32 in the cache */
   /* replace1345 -> 3784 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1346_0_0 -> 32 in the cache */
   /* search1346_0 -> 3795 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3795 },
      -1,
   } },

   /* replace1346_0 -> 32 in the cache */
   /* replace1346 -> 3781 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1347_0_0 -> 32 in the cache */
   /* search1347_0 -> 3797 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3797 },
      -1,
   } },

   /* replace1347_0 -> 32 in the cache */
   /* replace1347 -> 3784 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1348_0_0 -> 32 in the cache */
   /* search1348_0 -> 3795 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3795 },
      -1,
   } },

   /* replace1348_0 -> 32 in the cache */
   /* replace1348 -> 3781 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1349_0_0 -> 32 in the cache */
   /* search1349_0 -> 3797 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3797 },
      -1,
   } },

   /* replace1349_0 -> 32 in the cache */
   /* replace1349 -> 3784 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1350_0_0 -> 32 in the cache */
   /* search1350_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1350_0 -> 32 in the cache */
   /* replace1350 -> 3781 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1351_0_0 -> 32 in the cache */
   /* search1351_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1351_0 -> 32 in the cache */
   /* replace1351 -> 3784 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1352_0_0 -> 32 in the cache */
   /* search1352_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1352_0 -> 32 in the cache */
   /* replace1352 -> 3781 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1353_0_0 -> 32 in the cache */
   /* search1353_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1353_0 -> 32 in the cache */
   /* replace1353 -> 3784 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1354_0_0 -> 715 in the cache */
   /* search1354_0 -> 3764 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1354_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1355_0_0 -> 715 in the cache */
   /* search1355_0 -> 3769 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3769 },
      -1,
   } },

   /* replace1355_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1356_0_0 -> 715 in the cache */
   /* search1356_0 -> 3808 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3808 },
      -1,
   } },

   /* replace1356_0 -> 715 in the cache */
   /* replace1356 -> 3824 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1357_0_0 -> 715 in the cache */
   /* search1357_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1357_0 -> 715 in the cache */
   /* replace1357 -> 3826 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1358_0_0 -> 6 in the cache */
   /* search1358_0 -> 3765 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3765 },
      -1,
   } },

   /* replace1358_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1359_0_0 -> 6 in the cache */
   /* search1359_0 -> 3770 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3770 },
      -1,
   } },

   /* replace1359_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1360_0_0 -> 32 in the cache */
   /* search1360_0 -> 3795 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3795 },
      -1,
   } },

   /* replace1360_0 -> 32 in the cache */
   /* replace1360 -> 3789 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1361_0_0 -> 32 in the cache */
   /* search1361_0 -> 3797 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3797 },
      -1,
   } },

   /* replace1361_0 -> 32 in the cache */
   /* replace1361 -> 3791 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1362_0_0 -> 32 in the cache */
   /* search1362_0 -> 3795 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3795 },
      -1,
   } },

   /* replace1362_0 -> 32 in the cache */
   /* replace1362 -> 3789 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1363_0_0 -> 32 in the cache */
   /* search1363_0 -> 3797 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3797 },
      -1,
   } },

   /* replace1363_0 -> 32 in the cache */
   /* replace1363 -> 3791 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1364_0_0 -> 32 in the cache */
   /* search1364_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1364_0 -> 32 in the cache */
   /* replace1364 -> 3789 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1365_0_0 -> 32 in the cache */
   /* search1365_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1365_0 -> 32 in the cache */
   /* replace1365 -> 3791 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1366_0_0 -> 32 in the cache */
   /* search1366_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1366_0 -> 32 in the cache */
   /* replace1366 -> 3789 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1367_0_0 -> 32 in the cache */
   /* search1367_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1367_0 -> 32 in the cache */
   /* replace1367 -> 3791 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1368_0_0 -> 715 in the cache */
   /* search1368_0 -> 3764 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1368_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1369_0_0 -> 715 in the cache */
   /* search1369_0 -> 3769 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3769 },
      -1,
   } },

   /* replace1369_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1370_0_0 -> 715 in the cache */
   /* search1370_0 -> 3808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3808 },
      -1,
   } },

   /* replace1370_0 -> 715 in the cache */
   /* replace1370 -> 3842 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1371_0_0 -> 715 in the cache */
   /* search1371_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1371_0 -> 715 in the cache */
   /* replace1371 -> 3844 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1372_0_0 -> 6 in the cache */
   /* search1372_0 -> 3765 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3765 },
      -1,
   } },

   /* replace1372_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1373_0_0 -> 6 in the cache */
   /* search1373_0 -> 3770 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3770 },
      -1,
   } },

   /* replace1373_0 -> 6 in the cache */
   /* replace1373 -> 2960 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1374_0_0 -> 715 in the cache */
   /* search1374_0 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3824 },
      -1,
   } },

   /* replace1374_0 -> 715 in the cache */
   /* replace1374 -> 3842 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1375_0_0 -> 715 in the cache */
   /* search1375_0 -> 3826 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3826 },
      -1,
   } },

   /* replace1375_0 -> 715 in the cache */
   /* replace1375 -> 3844 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1376_0_0 -> 6 in the cache */
   /* search1376_0 -> 3830 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3830 },
      -1,
   } },

   /* replace1376_0 -> 6 in the cache */
   /* replace1376 -> 3848 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1377_0_0 -> 6 in the cache */
   /* search1377_0 -> 3832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3832 },
      -1,
   } },

   /* replace1377_0 -> 6 in the cache */
   /* replace1377 -> 2960 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1378_0_0 -> 11 in the cache */
   /* search1378_0 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3766 },
      -1,
   } },

   /* replace1378_0 -> 11 in the cache */
   /* replace1378 -> 1741 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1379_0_0 -> 11 in the cache */
   /* search1379_0 -> 3771 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3771 },
      -1,
   } },

   /* replace1379_0 -> 11 in the cache */
   /* replace1379 -> 1743 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1380_0_0 -> 32 in the cache */
   /* search1380_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1380_0 -> 32 in the cache */
   /* replace1380 -> 3795 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1381_0_0 -> 32 in the cache */
   /* search1381_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1381_0 -> 32 in the cache */
   /* replace1381 -> 3797 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1382_0_0 -> 32 in the cache */
   /* search1382_0 -> 3801 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3801 },
      -1,
   } },

   /* replace1382_0 -> 32 in the cache */
   /* replace1382 -> 3795 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1383_0_0 -> 32 in the cache */
   /* search1383_0 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3803 },
      -1,
   } },

   /* replace1383_0 -> 32 in the cache */
   /* replace1383 -> 3797 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1384_0_0 -> 715 in the cache */
   /* search1384_0 -> 3764 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1384_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1385_0_0 -> 715 in the cache */
   /* search1385_0 -> 3769 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3769 },
      -1,
   } },

   /* replace1385_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1386_0_0 -> 715 in the cache */
   /* search1386_0 -> 3808 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3808 },
      -1,
   } },

   /* replace1386_0 -> 715 in the cache */
   /* replace1386 -> 3861 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1387_0_0 -> 715 in the cache */
   /* search1387_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1387_0 -> 715 in the cache */
   /* replace1387 -> 3863 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1388_0_0 -> 6 in the cache */
   /* search1388_0 -> 3765 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3765 },
      -1,
   } },

   /* replace1388_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1389_0_0 -> 6 in the cache */
   /* search1389_0 -> 3770 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3770 },
      -1,
   } },

   /* replace1389_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1390_0_0 -> 715 in the cache */
   /* search1390_0 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3824 },
      -1,
   } },

   /* replace1390_0 -> 715 in the cache */
   /* replace1390 -> 3861 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1391_0_0 -> 715 in the cache */
   /* search1391_0 -> 3826 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3826 },
      -1,
   } },

   /* replace1391_0 -> 715 in the cache */
   /* replace1391 -> 3863 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1392_0_0 -> 6 in the cache */
   /* search1392_0 -> 3830 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3830 },
      -1,
   } },

   /* replace1392_0 -> 6 in the cache */
   /* replace1392 -> 3867 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1393_0_0 -> 6 in the cache */
   /* search1393_0 -> 3832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3832 },
      -1,
   } },

   /* replace1393_0 -> 6 in the cache */
   /* replace1393 -> 3869 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1394_0_0 -> 11 in the cache */
   /* search1394_0 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3766 },
      -1,
   } },

   /* replace1394_0 -> 11 in the cache */
   /* replace1394 -> 1764 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1395_0_0 -> 11 in the cache */
   /* search1395_0 -> 3771 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3771 },
      -1,
   } },

   /* replace1395_0 -> 11 in the cache */
   /* replace1395 -> 1766 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1396_0_0 -> 715 in the cache */
   /* search1396_0 -> 3842 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3842 },
      -1,
   } },

   /* replace1396_0 -> 715 in the cache */
   /* replace1396 -> 3861 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1397_0_0 -> 715 in the cache */
   /* search1397_0 -> 3844 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3844 },
      -1,
   } },

   /* replace1397_0 -> 715 in the cache */
   /* replace1397 -> 3863 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1398_0_0 -> 6 in the cache */
   /* search1398_0 -> 3848 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3848 },
      -1,
   } },

   /* replace1398_0 -> 6 in the cache */
   /* replace1398 -> 3867 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1399_0_0 -> 6 in the cache */
   /* search1399_0 -> 2960 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2960 },
      -1,
   } },

   /* replace1399_0 -> 6 in the cache */
   /* replace1399 -> 3869 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1400_0_0 -> 11 in the cache */
   /* search1400_0 -> 1741 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 1741 },
      -1,
   } },

   /* replace1400_0 -> 11 in the cache */
   /* replace1400 -> 1764 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1401_0_0 -> 11 in the cache */
   /* search1401_0 -> 1743 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1743 },
      -1,
   } },

   /* replace1401_0 -> 11 in the cache */
   /* replace1401 -> 1766 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1402_0_0 -> 16 in the cache */
   /* search1402_0 -> 3767 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3767 },
      -1,
   } },

   /* replace1402_0 -> 16 in the cache */
   /* replace1402 -> 1848 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1403_0_0 -> 16 in the cache */
   /* search1403_0 -> 3772 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3772 },
      -1,
   } },

   /* replace1403_0 -> 16 in the cache */
   /* replace1403 -> 1850 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1404_0_0 -> 16 in the cache */
   /* search1404_0_1 -> 36 in the cache */
   /* search1404_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace1404_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1405_0_0 -> 16 in the cache */
   /* search1405_0_1 -> 36 in the cache */
   /* search1405_0 -> 2886 in the cache */
   /* search1405 -> 3884 in the cache */

   /* replace1405_0 -> 16 in the cache */
   /* replace1405 -> 3885 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1406_0_0 -> 16 in the cache */
   /* search1406_0_1 -> 36 in the cache */
   /* search1406_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace1406_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1407_0_0 -> 16 in the cache */
   /* search1407_0_1 -> 36 in the cache */
   /* search1407_0 -> 2886 in the cache */
   /* search1407 -> 3886 in the cache */

   /* replace1407_0 -> 16 in the cache */
   /* replace1407 -> 3887 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1408_0_0 -> 16 in the cache */
   /* search1408_0_1 -> 36 in the cache */
   /* search1408_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace1408_0 -> 16 in the cache */
   /* replace1408 -> 3767 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1409_0_0 -> 16 in the cache */
   /* search1409_0_1 -> 36 in the cache */
   /* search1409_0 -> 2886 in the cache */
   /* search1409 -> 3888 in the cache */

   /* replace1409_0 -> 16 in the cache */
   /* replace1409 -> 3767 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1410_0_0 -> 16 in the cache */
   /* search1410_0_1 -> 36 in the cache */
   /* search1410_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace1410_0 -> 16 in the cache */
   /* replace1410 -> 1967 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1411_0_0 -> 16 in the cache */
   /* search1411_0_1 -> 36 in the cache */
   /* search1411_0 -> 2886 in the cache */
   /* search1411 -> 3889 in the cache */

   /* replace1411_0 -> 16 in the cache */
   /* replace1411 -> 1967 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1412_0_0 -> 16 in the cache */
   /* search1412_0_1 -> 36 in the cache */
   /* search1412_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace1412_0 -> 16 in the cache */
   /* replace1412 -> 2988 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1413_0_0 -> 16 in the cache */
   /* search1413_0_1 -> 36 in the cache */
   /* search1413_0 -> 2886 in the cache */
   /* search1413 -> 3890 in the cache */

   /* replace1413_0 -> 16 in the cache */
   /* replace1413 -> 2988 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1414_0_0 -> 16 in the cache */
   /* search1414_0_1 -> 36 in the cache */
   /* search1414_0 -> 2886 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2886 },
      -1,
   } },

   /* replace1414_0 -> 16 in the cache */
   /* replace1414 -> 3772 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1415_0_0 -> 16 in the cache */
   /* search1415_0_1 -> 36 in the cache */
   /* search1415_0 -> 2886 in the cache */
   /* search1415 -> 3891 in the cache */

   /* replace1415_0 -> 16 in the cache */
   /* replace1415 -> 3772 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1416_0_0 -> 6 in the cache */
   /* search1416_0 -> 3830 in the cache */
   /* search1416_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3830, 3892 },
      -1,
   } },

   /* replace1416_0 -> 6 in the cache */
   /* replace1416_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 3894 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1417_0_0 -> 6 in the cache */
   /* search1417_0 -> 3830 in the cache */
   /* search1417_1_0 -> 2054 in the cache */
   /* search1417_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3830, 3892 },
      -1,
   } },

   /* replace1417_0 -> 6 in the cache */
   /* replace1417_1_0 -> 2054 in the cache */
   /* replace1417_1 -> 3894 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 3894 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1418_0_0 -> 6 in the cache */
   /* search1418_0 -> 3830 in the cache */
   /* search1418_1_0 -> 2054 in the cache */
   /* search1418_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3830, 3892 },
      -1,
   } },

   /* replace1418_0 -> 6 in the cache */
   /* replace1418_1_0 -> 2054 in the cache */
   /* replace1418_1 -> 3894 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3894 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1419_0_0 -> 6 in the cache */
   /* search1419_0 -> 3830 in the cache */
   /* search1419_1_0 -> 2054 in the cache */
   /* search1419_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3830, 3892 },
      -1,
   } },

   /* replace1419_0 -> 6 in the cache */
   /* replace1419_1_0 -> 2054 in the cache */
   /* replace1419_1 -> 3894 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3894 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3902 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3903, 3905 },
      -1,
   } },

   /* replace1420_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* replace1420_1 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3907, 3904 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1421_0_0 -> 3902 in the cache */
   /* search1421_0 -> 3903 in the cache */
   /* search1421_1_0 -> 3904 in the cache */
   /* search1421_1 -> 3905 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3903, 3905 },
      -1,
   } },

   /* replace1421_0_0 -> 3902 in the cache */
   /* replace1421_0 -> 3907 in the cache */
   /* replace1421_1 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3907, 3904 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1422_0_0 -> 6 in the cache */
   /* search1422_0 -> 3830 in the cache */
   /* search1422_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3830, 1953 },
      -1,
   } },

   /* replace1422_0_0 -> 6 in the cache */
   /* replace1422_0_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3912 },
      -1,
   } },
   /* replace1422_1_0_0_0 -> 243 in the cache */
   /* replace1422_1_0_0 -> 3912 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3912 },
      -1,
   } },
   /* replace1422_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3914, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3913, 3915 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1423_0_0 -> 6 in the cache */
   /* search1423_0 -> 3830 in the cache */
   /* search1423_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3830, 1953 },
      -1,
   } },

   /* replace1423_0_0 -> 6 in the cache */
   /* replace1423_0_1_0 -> 243 in the cache */
   /* replace1423_0_1 -> 3912 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3912 },
      -1,
   } },
   /* replace1423_1_0_0_0 -> 243 in the cache */
   /* replace1423_1_0_0 -> 3912 in the cache */
   /* replace1423_1_0 -> 3914 in the cache */
   /* replace1423_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 3914, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3918, 3919 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1424_0_0 -> 6 in the cache */
   /* search1424_0 -> 3830 in the cache */
   /* search1424_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3830, 1953 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1424_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3922, 243 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1424_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3924, 243 },
      -1,
   } },
   /* replace1424_1_1_0 -> 6 in the cache */
   /* replace1424_1_1_1_0 -> 243 in the cache */
   /* replace1424_1_1_1 -> 3912 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3912 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3925, 3926 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3923, 3927 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1425_1_0 -> 2054 in the cache */
   /* search1425_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3929, 3892 },
      -1,
   } },

   /* replace1425_0_0 -> 11 in the cache */
   /* replace1425_0_1 -> 3924 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3924 },
      -1,
   } },
   /* replace1425_1_0_0 -> 11 in the cache */
   /* replace1425_1_0_1 -> 3922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3922 },
      -1,
   } },
   /* replace1425_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1425_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3933, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3932, 3934 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3931, 3935 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1426_0_0 -> 6 in the cache */
   /* search1426_0 -> 3830 in the cache */
   /* search1426_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3830, 1953 },
      -1,
   } },

   /* replace1426_0_0 -> 3924 in the cache */
   /* replace1426_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3924, 243 },
      -1,
   } },
   /* replace1426_1_0_0 -> 3922 in the cache */
   /* replace1426_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3922, 243 },
      -1,
   } },
   /* replace1426_1_1_0 -> 6 in the cache */
   /* replace1426_1_1_1_0 -> 243 in the cache */
   /* replace1426_1_1_1 -> 3912 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3912 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3939, 3940 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3938, 3941 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1427_0 -> 3929 in the cache */
   /* search1427_1_0 -> 2054 in the cache */
   /* search1427_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3929, 3892 },
      -1,
   } },

   /* replace1427_0_0 -> 11 in the cache */
   /* replace1427_0_1 -> 3922 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3922 },
      -1,
   } },
   /* replace1427_1_0_0 -> 11 in the cache */
   /* replace1427_1_0_1 -> 3924 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3924 },
      -1,
   } },
   /* replace1427_1_1_0_0 -> 11 in the cache */
   /* replace1427_1_1_0 -> 3933 in the cache */
   /* replace1427_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3933, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3945, 3946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3944, 3947 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1428_0_0 -> 6 in the cache */
   /* search1428_0 -> 3848 in the cache */
   /* search1428_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3848, 3949 },
      -1,
   } },

   /* replace1428_0 -> 6 in the cache */
   /* replace1428_1_0 -> 2054 in the cache */
   /* replace1428_1 -> 3894 in the cache */
   /* replace1428 -> 3895 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1429_0_0 -> 6 in the cache */
   /* search1429_0 -> 3848 in the cache */
   /* search1429_1_0 -> 2054 in the cache */
   /* search1429_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3848, 3949 },
      -1,
   } },

   /* replace1429_0 -> 6 in the cache */
   /* replace1429_1_0 -> 2054 in the cache */
   /* replace1429_1 -> 3894 in the cache */
   /* replace1429 -> 3897 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1430_0_0 -> 6 in the cache */
   /* search1430_0 -> 3848 in the cache */
   /* search1430_1_0 -> 2054 in the cache */
   /* search1430_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3848, 3949 },
      -1,
   } },

   /* replace1430_0 -> 6 in the cache */
   /* replace1430_1_0 -> 2054 in the cache */
   /* replace1430_1 -> 3894 in the cache */
   /* replace1430 -> 3899 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1431_0_0 -> 6 in the cache */
   /* search1431_0 -> 3848 in the cache */
   /* search1431_1_0 -> 2054 in the cache */
   /* search1431_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3848, 3949 },
      -1,
   } },

   /* replace1431_0 -> 6 in the cache */
   /* replace1431_1_0 -> 2054 in the cache */
   /* replace1431_1 -> 3894 in the cache */
   /* replace1431 -> 3901 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1432_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1432_1_0 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3954, 3955 },
      -1,
   } },

   /* replace1432_0_0 -> 3902 in the cache */
   /* replace1432_0 -> 3907 in the cache */
   /* replace1432_1 -> 3904 in the cache */
   /* replace1432 -> 3908 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1433_0_0 -> 3902 in the cache */
   /* search1433_0 -> 3954 in the cache */
   /* search1433_1_0 -> 3904 in the cache */
   /* search1433_1 -> 3955 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3954, 3955 },
      -1,
   } },

   /* replace1433_0_0 -> 3902 in the cache */
   /* replace1433_0 -> 3907 in the cache */
   /* replace1433_1 -> 3904 in the cache */
   /* replace1433 -> 3910 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1434_0_0 -> 6 in the cache */
   /* search1434_0 -> 3848 in the cache */
   /* search1434_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3848, 33 },
      -1,
   } },

   /* replace1434_0_0 -> 6 in the cache */
   /* replace1434_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3959 },
      -1,
   } },
   /* replace1434_1_0_0_0 -> 36 in the cache */
   /* replace1434_1_0_0 -> 3959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3959 },
      -1,
   } },
   /* replace1434_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3961, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3960, 3962 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1435_0_0 -> 6 in the cache */
   /* search1435_0 -> 3848 in the cache */
   /* search1435_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3848, 33 },
      -1,
   } },

   /* replace1435_0_0 -> 6 in the cache */
   /* replace1435_0_1_0 -> 36 in the cache */
   /* replace1435_0_1 -> 3959 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3959 },
      -1,
   } },
   /* replace1435_1_0_0_0 -> 36 in the cache */
   /* replace1435_1_0_0 -> 3959 in the cache */
   /* replace1435_1_0 -> 3961 in the cache */
   /* replace1435_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 3961, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3965, 3966 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1436_0_0 -> 6 in the cache */
   /* search1436_0 -> 3848 in the cache */
   /* search1436_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3848, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1436_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3969, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1436_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3971, 36 },
      -1,
   } },
   /* replace1436_1_1_0 -> 6 in the cache */
   /* replace1436_1_1_1_0 -> 36 in the cache */
   /* replace1436_1_1_1 -> 3959 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3959 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3972, 3973 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3970, 3974 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1437_0 -> 271 in the cache */
   /* search1437_1_0 -> 2054 in the cache */
   /* search1437_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 271, 3949 },
      -1,
   } },

   /* replace1437_0_0 -> 16 in the cache */
   /* replace1437_0_1 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3971 },
      -1,
   } },
   /* replace1437_1_0_0 -> 16 in the cache */
   /* replace1437_1_0_1 -> 3969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3969 },
      -1,
   } },
   /* replace1437_1_1_0_0 -> 16 in the cache */
   /* replace1437_1_1_0 -> 3885 in the cache */
   /* replace1437_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3885, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3978, 3979 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3977, 3980 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1438_0_0 -> 6 in the cache */
   /* search1438_0 -> 3848 in the cache */
   /* search1438_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3848, 33 },
      -1,
   } },

   /* replace1438_0_0 -> 3971 in the cache */
   /* replace1438_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3971, 36 },
      -1,
   } },
   /* replace1438_1_0_0 -> 3969 in the cache */
   /* replace1438_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3969, 36 },
      -1,
   } },
   /* replace1438_1_1_0 -> 6 in the cache */
   /* replace1438_1_1_1_0 -> 36 in the cache */
   /* replace1438_1_1_1 -> 3959 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3959 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3984, 3985 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3983, 3986 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1439_0 -> 271 in the cache */
   /* search1439_1_0 -> 2054 in the cache */
   /* search1439_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 271, 3949 },
      -1,
   } },

   /* replace1439_0_0 -> 16 in the cache */
   /* replace1439_0_1 -> 3969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3969 },
      -1,
   } },
   /* replace1439_1_0_0 -> 16 in the cache */
   /* replace1439_1_0_1 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3971 },
      -1,
   } },
   /* replace1439_1_1_0_0 -> 16 in the cache */
   /* replace1439_1_1_0 -> 3885 in the cache */
   /* replace1439_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3885, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3990, 3991 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3989, 3992 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1440_0_0 -> 6 in the cache */
   /* search1440_0 -> 3867 in the cache */
   /* search1440_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3867, 3994 },
      -1,
   } },

   /* replace1440_0 -> 6 in the cache */
   /* replace1440_1_0 -> 2054 in the cache */
   /* replace1440_1 -> 3894 in the cache */
   /* replace1440 -> 3895 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1441_0_0 -> 6 in the cache */
   /* search1441_0 -> 3867 in the cache */
   /* search1441_1_0 -> 2054 in the cache */
   /* search1441_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3867, 3994 },
      -1,
   } },

   /* replace1441_0 -> 6 in the cache */
   /* replace1441_1_0 -> 2054 in the cache */
   /* replace1441_1 -> 3894 in the cache */
   /* replace1441 -> 3897 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1442_0_0 -> 6 in the cache */
   /* search1442_0 -> 3867 in the cache */
   /* search1442_1_0 -> 2054 in the cache */
   /* search1442_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3867, 3994 },
      -1,
   } },

   /* replace1442_0 -> 6 in the cache */
   /* replace1442_1_0 -> 2054 in the cache */
   /* replace1442_1 -> 3894 in the cache */
   /* replace1442 -> 3899 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1443_0_0 -> 6 in the cache */
   /* search1443_0 -> 3867 in the cache */
   /* search1443_1_0 -> 2054 in the cache */
   /* search1443_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3867, 3994 },
      -1,
   } },

   /* replace1443_0 -> 6 in the cache */
   /* replace1443_1_0 -> 2054 in the cache */
   /* replace1443_1 -> 3894 in the cache */
   /* replace1443 -> 3901 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1444_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1444_1_0 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3999, 4000 },
      -1,
   } },

   /* replace1444_0_0 -> 3902 in the cache */
   /* replace1444_0 -> 3907 in the cache */
   /* replace1444_1 -> 3904 in the cache */
   /* replace1444 -> 3908 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1445_0_0 -> 3902 in the cache */
   /* search1445_0 -> 3999 in the cache */
   /* search1445_1_0 -> 3904 in the cache */
   /* search1445_1 -> 4000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3999, 4000 },
      -1,
   } },

   /* replace1445_0_0 -> 3902 in the cache */
   /* replace1445_0 -> 3907 in the cache */
   /* replace1445_1 -> 3904 in the cache */
   /* replace1445 -> 3910 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1446_0_0 -> 6 in the cache */
   /* search1446_0 -> 3867 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3867, 4003 },
      -1,
   } },

   /* replace1446_0_0 -> 6 in the cache */
   /* replace1446_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4005 },
      -1,
   } },
   /* replace1446_1_0_0_0 -> 41 in the cache */
   /* replace1446_1_0_0 -> 4005 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4005 },
      -1,
   } },
   /* replace1446_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4007, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4006, 4008 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1447_0_0 -> 6 in the cache */
   /* search1447_0 -> 3867 in the cache */
   /* search1447_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3867, 4003 },
      -1,
   } },

   /* replace1447_0_0 -> 6 in the cache */
   /* replace1447_0_1_0 -> 41 in the cache */
   /* replace1447_0_1 -> 4005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4005 },
      -1,
   } },
   /* replace1447_1_0_0_0 -> 41 in the cache */
   /* replace1447_1_0_0 -> 4005 in the cache */
   /* replace1447_1_0 -> 4007 in the cache */
   /* replace1447_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4007, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4011, 4012 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1448_0_0 -> 6 in the cache */
   /* search1448_0 -> 3867 in the cache */
   /* search1448_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3867, 4003 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1448_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4015, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1448_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4017, 41 },
      -1,
   } },
   /* replace1448_1_1_0 -> 6 in the cache */
   /* replace1448_1_1_1_0 -> 41 in the cache */
   /* replace1448_1_1_1 -> 4005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4005 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4018, 4019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4016, 4020 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1449_1_0 -> 2054 in the cache */
   /* search1449_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4022, 3994 },
      -1,
   } },

   /* replace1449_0_0 -> 21 in the cache */
   /* replace1449_0_1 -> 4017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4017 },
      -1,
   } },
   /* replace1449_1_0_0 -> 21 in the cache */
   /* replace1449_1_0_1 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4015 },
      -1,
   } },
   /* replace1449_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1449_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4026, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4025, 4027 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4024, 4028 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1450_0_0 -> 6 in the cache */
   /* search1450_0 -> 3867 in the cache */
   /* search1450_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3867, 4003 },
      -1,
   } },

   /* replace1450_0_0 -> 4017 in the cache */
   /* replace1450_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4017, 41 },
      -1,
   } },
   /* replace1450_1_0_0 -> 4015 in the cache */
   /* replace1450_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4015, 41 },
      -1,
   } },
   /* replace1450_1_1_0 -> 6 in the cache */
   /* replace1450_1_1_1_0 -> 41 in the cache */
   /* replace1450_1_1_1 -> 4005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4005 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4032, 4033 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4031, 4034 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1451_0 -> 4022 in the cache */
   /* search1451_1_0 -> 2054 in the cache */
   /* search1451_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4022, 3994 },
      -1,
   } },

   /* replace1451_0_0 -> 21 in the cache */
   /* replace1451_0_1 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4015 },
      -1,
   } },
   /* replace1451_1_0_0 -> 21 in the cache */
   /* replace1451_1_0_1 -> 4017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4017 },
      -1,
   } },
   /* replace1451_1_1_0_0 -> 21 in the cache */
   /* replace1451_1_1_0 -> 4026 in the cache */
   /* replace1451_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4026, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4038, 4039 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4037, 4040 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1452_0_0 -> 11 in the cache */
   /* search1452_0 -> 1741 in the cache */
   /* search1452_1_0 -> 2054 in the cache */
   /* search1452_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1741, 3949 },
      -1,
   } },

   /* replace1452_0 -> 11 in the cache */
   /* replace1452_1_0 -> 2054 in the cache */
   /* replace1452_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 3892 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1453_0_0 -> 11 in the cache */
   /* search1453_0 -> 1741 in the cache */
   /* search1453_1_0 -> 2054 in the cache */
   /* search1453_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1741, 3949 },
      -1,
   } },

   /* replace1453_0 -> 11 in the cache */
   /* replace1453_1_0 -> 2054 in the cache */
   /* replace1453_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 3892 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1454_0_0 -> 11 in the cache */
   /* search1454_0 -> 1741 in the cache */
   /* search1454_1_0 -> 2054 in the cache */
   /* search1454_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1741, 3949 },
      -1,
   } },

   /* replace1454_0 -> 11 in the cache */
   /* replace1454_1_0 -> 2054 in the cache */
   /* replace1454_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3892 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1455_0_0 -> 11 in the cache */
   /* search1455_0 -> 1741 in the cache */
   /* search1455_1_0 -> 2054 in the cache */
   /* search1455_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1741, 3949 },
      -1,
   } },

   /* replace1455_0 -> 11 in the cache */
   /* replace1455_1_0 -> 2054 in the cache */
   /* replace1455_1 -> 3892 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3892 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1456_0_0 -> 3902 in the cache */
   /* search1456_0 -> 3954 in the cache */
   /* search1456_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3954, 4050 },
      -1,
   } },

   /* replace1456_0_0 -> 3902 in the cache */
   /* replace1456_0 -> 3903 in the cache */
   /* replace1456_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3903, 507 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1457_0_0 -> 3902 in the cache */
   /* search1457_0 -> 3954 in the cache */
   /* search1457_1_0 -> 507 in the cache */
   /* search1457_1 -> 4050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3954, 4050 },
      -1,
   } },

   /* replace1457_0_0 -> 3902 in the cache */
   /* replace1457_0 -> 3903 in the cache */
   /* replace1457_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3903, 507 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1458_0_0 -> 11 in the cache */
   /* search1458_0 -> 1741 in the cache */
   /* search1458_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1741, 4055 },
      -1,
   } },

   /* replace1458_0 -> 11 in the cache */
   /* replace1458_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4057 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1459_0_0 -> 11 in the cache */
   /* search1459_0 -> 1741 in the cache */
   /* search1459_1_0 -> 243 in the cache */
   /* search1459_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1741, 4055 },
      -1,
   } },

   /* replace1459_0 -> 11 in the cache */
   /* replace1459_1_0 -> 243 in the cache */
   /* replace1459_1 -> 4057 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4057 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1460_0_0 -> 11 in the cache */
   /* search1460_0 -> 1741 in the cache */
   /* search1460_1_0 -> 243 in the cache */
   /* search1460_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1741, 4055 },
      -1,
   } },

   /* replace1460_0 -> 11 in the cache */
   /* replace1460_1_0 -> 243 in the cache */
   /* replace1460_1 -> 4057 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4057 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1461_0_0 -> 11 in the cache */
   /* search1461_0 -> 1741 in the cache */
   /* search1461_1_0 -> 243 in the cache */
   /* search1461_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1741, 4055 },
      -1,
   } },

   /* replace1461_0 -> 11 in the cache */
   /* replace1461_1_0 -> 243 in the cache */
   /* replace1461_1 -> 4057 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4057 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1462_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1462_1_0 -> 507 in the cache */
   /* search1462_1 -> 4050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4065, 4050 },
      -1,
   } },

   /* replace1462_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1462_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4067, 507 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1463_0_0 -> 496 in the cache */
   /* search1463_0 -> 4065 in the cache */
   /* search1463_1_0 -> 507 in the cache */
   /* search1463_1 -> 4050 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4065, 4050 },
      -1,
   } },

   /* replace1463_0_0 -> 496 in the cache */
   /* replace1463_0 -> 4067 in the cache */
   /* replace1463_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4067, 507 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1464_0_0 -> 11 in the cache */
   /* search1464_0 -> 1741 in the cache */
   /* search1464_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1741, 33 },
      -1,
   } },

   /* replace1464_0_0 -> 11 in the cache */
   /* replace1464_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4072 },
      -1,
   } },
   /* replace1464_1_0_0_0 -> 36 in the cache */
   /* replace1464_1_0_0 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4072 },
      -1,
   } },
   /* replace1464_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4074, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4073, 4075 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1465_0_0 -> 11 in the cache */
   /* search1465_0 -> 1741 in the cache */
   /* search1465_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1741, 33 },
      -1,
   } },

   /* replace1465_0_0 -> 11 in the cache */
   /* replace1465_0_1_0 -> 36 in the cache */
   /* replace1465_0_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4072 },
      -1,
   } },
   /* replace1465_1_0_0_0 -> 36 in the cache */
   /* replace1465_1_0_0 -> 4072 in the cache */
   /* replace1465_1_0 -> 4074 in the cache */
   /* replace1465_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4074, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4078, 4079 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1466_0_0 -> 11 in the cache */
   /* search1466_0 -> 1741 in the cache */
   /* search1466_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1741, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1466_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4082, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1466_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4084, 36 },
      -1,
   } },
   /* replace1466_1_1_0 -> 11 in the cache */
   /* replace1466_1_1_1_0 -> 36 in the cache */
   /* replace1466_1_1_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4072 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4085, 4086 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4083, 4087 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1467_0 -> 271 in the cache */
   /* search1467_1_0 -> 243 in the cache */
   /* search1467_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 271, 4055 },
      -1,
   } },

   /* replace1467_0_0 -> 16 in the cache */
   /* replace1467_0_1 -> 4084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4084 },
      -1,
   } },
   /* replace1467_1_0_0 -> 16 in the cache */
   /* replace1467_1_0_1 -> 4082 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4082 },
      -1,
   } },
   /* replace1467_1_1_0_0 -> 16 in the cache */
   /* replace1467_1_1_0 -> 3887 in the cache */
   /* replace1467_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3887, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4091, 4092 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4090, 4093 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1468_0_0 -> 11 in the cache */
   /* search1468_0 -> 1741 in the cache */
   /* search1468_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1741, 33 },
      -1,
   } },

   /* replace1468_0_0 -> 4084 in the cache */
   /* replace1468_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4084, 36 },
      -1,
   } },
   /* replace1468_1_0_0 -> 4082 in the cache */
   /* replace1468_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4082, 36 },
      -1,
   } },
   /* replace1468_1_1_0 -> 11 in the cache */
   /* replace1468_1_1_1_0 -> 36 in the cache */
   /* replace1468_1_1_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4072 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4097, 4098 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4096, 4099 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1469_0 -> 271 in the cache */
   /* search1469_1_0 -> 243 in the cache */
   /* search1469_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 271, 4055 },
      -1,
   } },

   /* replace1469_0_0 -> 16 in the cache */
   /* replace1469_0_1 -> 4082 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4082 },
      -1,
   } },
   /* replace1469_1_0_0 -> 16 in the cache */
   /* replace1469_1_0_1 -> 4084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4084 },
      -1,
   } },
   /* replace1469_1_1_0_0 -> 16 in the cache */
   /* replace1469_1_1_0 -> 3887 in the cache */
   /* replace1469_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3887, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4103, 4104 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4102, 4105 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1470_0_0 -> 11 in the cache */
   /* search1470_0 -> 1764 in the cache */
   /* search1470_1_0 -> 2054 in the cache */
   /* search1470_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1764, 3994 },
      -1,
   } },

   /* replace1470_0 -> 11 in the cache */
   /* replace1470_1_0 -> 2054 in the cache */
   /* replace1470_1 -> 3892 in the cache */
   /* replace1470 -> 4043 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1471_0_0 -> 11 in the cache */
   /* search1471_0 -> 1764 in the cache */
   /* search1471_1_0 -> 2054 in the cache */
   /* search1471_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1764, 3994 },
      -1,
   } },

   /* replace1471_0 -> 11 in the cache */
   /* replace1471_1_0 -> 2054 in the cache */
   /* replace1471_1 -> 3892 in the cache */
   /* replace1471 -> 4045 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1472_0_0 -> 11 in the cache */
   /* search1472_0 -> 1764 in the cache */
   /* search1472_1_0 -> 2054 in the cache */
   /* search1472_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1764, 3994 },
      -1,
   } },

   /* replace1472_0 -> 11 in the cache */
   /* replace1472_1_0 -> 2054 in the cache */
   /* replace1472_1 -> 3892 in the cache */
   /* replace1472 -> 4047 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1473_0_0 -> 11 in the cache */
   /* search1473_0 -> 1764 in the cache */
   /* search1473_1_0 -> 2054 in the cache */
   /* search1473_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1764, 3994 },
      -1,
   } },

   /* replace1473_0 -> 11 in the cache */
   /* replace1473_1_0 -> 2054 in the cache */
   /* replace1473_1 -> 3892 in the cache */
   /* replace1473 -> 4049 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1474_0_0 -> 3902 in the cache */
   /* search1474_0 -> 3999 in the cache */
   /* search1474_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3999, 4111 },
      -1,
   } },

   /* replace1474_0_0 -> 3902 in the cache */
   /* replace1474_0 -> 3903 in the cache */
   /* replace1474_1 -> 507 in the cache */
   /* replace1474 -> 4052 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1475_0_0 -> 3902 in the cache */
   /* search1475_0 -> 3999 in the cache */
   /* search1475_1_0 -> 507 in the cache */
   /* search1475_1 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3999, 4111 },
      -1,
   } },

   /* replace1475_0_0 -> 3902 in the cache */
   /* replace1475_0 -> 3903 in the cache */
   /* replace1475_1 -> 507 in the cache */
   /* replace1475 -> 4054 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1476_0_0 -> 11 in the cache */
   /* search1476_0 -> 1764 in the cache */
   /* search1476_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1764, 4114 },
      -1,
   } },

   /* replace1476_0 -> 11 in the cache */
   /* replace1476_1_0 -> 243 in the cache */
   /* replace1476_1 -> 4057 in the cache */
   /* replace1476 -> 4058 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1477_0_0 -> 11 in the cache */
   /* search1477_0 -> 1764 in the cache */
   /* search1477_1_0 -> 243 in the cache */
   /* search1477_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1764, 4114 },
      -1,
   } },

   /* replace1477_0 -> 11 in the cache */
   /* replace1477_1_0 -> 243 in the cache */
   /* replace1477_1 -> 4057 in the cache */
   /* replace1477 -> 4060 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1478_0_0 -> 11 in the cache */
   /* search1478_0 -> 1764 in the cache */
   /* search1478_1_0 -> 243 in the cache */
   /* search1478_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1764, 4114 },
      -1,
   } },

   /* replace1478_0 -> 11 in the cache */
   /* replace1478_1_0 -> 243 in the cache */
   /* replace1478_1 -> 4057 in the cache */
   /* replace1478 -> 4062 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1479_0_0 -> 11 in the cache */
   /* search1479_0 -> 1764 in the cache */
   /* search1479_1_0 -> 243 in the cache */
   /* search1479_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1764, 4114 },
      -1,
   } },

   /* replace1479_0 -> 11 in the cache */
   /* replace1479_1_0 -> 243 in the cache */
   /* replace1479_1 -> 4057 in the cache */
   /* replace1479 -> 4064 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1480_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1480_1_0 -> 507 in the cache */
   /* search1480_1 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4119, 4111 },
      -1,
   } },

   /* replace1480_0_0 -> 496 in the cache */
   /* replace1480_0 -> 4067 in the cache */
   /* replace1480_1 -> 507 in the cache */
   /* replace1480 -> 4068 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1481_0_0 -> 496 in the cache */
   /* search1481_0 -> 4119 in the cache */
   /* search1481_1_0 -> 507 in the cache */
   /* search1481_1 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4119, 4111 },
      -1,
   } },

   /* replace1481_0_0 -> 496 in the cache */
   /* replace1481_0 -> 4067 in the cache */
   /* replace1481_1 -> 507 in the cache */
   /* replace1481 -> 4070 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1482_0_0 -> 11 in the cache */
   /* search1482_0 -> 1764 in the cache */
   /* search1482_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1764, 4003 },
      -1,
   } },

   /* replace1482_0_0 -> 11 in the cache */
   /* replace1482_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4123 },
      -1,
   } },
   /* replace1482_1_0_0_0 -> 41 in the cache */
   /* replace1482_1_0_0 -> 4123 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4123 },
      -1,
   } },
   /* replace1482_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4125, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4124, 4126 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1483_0_0 -> 11 in the cache */
   /* search1483_0 -> 1764 in the cache */
   /* search1483_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1764, 4003 },
      -1,
   } },

   /* replace1483_0_0 -> 11 in the cache */
   /* replace1483_0_1_0 -> 41 in the cache */
   /* replace1483_0_1 -> 4123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4123 },
      -1,
   } },
   /* replace1483_1_0_0_0 -> 41 in the cache */
   /* replace1483_1_0_0 -> 4123 in the cache */
   /* replace1483_1_0 -> 4125 in the cache */
   /* replace1483_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4125, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4129, 4130 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1484_0_0 -> 11 in the cache */
   /* search1484_0 -> 1764 in the cache */
   /* search1484_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1764, 4003 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1484_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4133, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1484_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4135, 41 },
      -1,
   } },
   /* replace1484_1_1_0 -> 11 in the cache */
   /* replace1484_1_1_1_0 -> 41 in the cache */
   /* replace1484_1_1_1 -> 4123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4123 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4136, 4137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4134, 4138 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1485_0 -> 4022 in the cache */
   /* search1485_1_0 -> 243 in the cache */
   /* search1485_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4022, 4114 },
      -1,
   } },

   /* replace1485_0_0 -> 21 in the cache */
   /* replace1485_0_1 -> 4135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4135 },
      -1,
   } },
   /* replace1485_1_0_0 -> 21 in the cache */
   /* replace1485_1_0_1 -> 4133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4133 },
      -1,
   } },
   /* replace1485_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1485_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4143, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4142, 4144 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4141, 4145 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1486_0_0 -> 11 in the cache */
   /* search1486_0 -> 1764 in the cache */
   /* search1486_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1764, 4003 },
      -1,
   } },

   /* replace1486_0_0 -> 4135 in the cache */
   /* replace1486_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4135, 41 },
      -1,
   } },
   /* replace1486_1_0_0 -> 4133 in the cache */
   /* replace1486_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4133, 41 },
      -1,
   } },
   /* replace1486_1_1_0 -> 11 in the cache */
   /* replace1486_1_1_1_0 -> 41 in the cache */
   /* replace1486_1_1_1 -> 4123 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4123 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4149, 4150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4148, 4151 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1487_0 -> 4022 in the cache */
   /* search1487_1_0 -> 243 in the cache */
   /* search1487_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4022, 4114 },
      -1,
   } },

   /* replace1487_0_0 -> 21 in the cache */
   /* replace1487_0_1 -> 4133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4133 },
      -1,
   } },
   /* replace1487_1_0_0 -> 21 in the cache */
   /* replace1487_1_0_1 -> 4135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4135 },
      -1,
   } },
   /* replace1487_1_1_0_0 -> 21 in the cache */
   /* replace1487_1_1_0 -> 4143 in the cache */
   /* replace1487_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4143, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4155, 4156 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4154, 4157 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1488_0_0 -> 16 in the cache */
   /* search1488_0 -> 1848 in the cache */
   /* search1488_1_0 -> 2054 in the cache */
   /* search1488_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1848, 3994 },
      -1,
   } },

   /* replace1488_0 -> 16 in the cache */
   /* replace1488_1_0 -> 2054 in the cache */
   /* replace1488_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3949 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1489_0_0 -> 16 in the cache */
   /* search1489_0 -> 1848 in the cache */
   /* search1489_1_0 -> 2054 in the cache */
   /* search1489_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1848, 3994 },
      -1,
   } },

   /* replace1489_0 -> 16 in the cache */
   /* replace1489_1_0 -> 2054 in the cache */
   /* replace1489_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3949 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1490_0_0 -> 16 in the cache */
   /* search1490_0 -> 1848 in the cache */
   /* search1490_1_0 -> 2054 in the cache */
   /* search1490_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1848, 3994 },
      -1,
   } },

   /* replace1490_0 -> 16 in the cache */
   /* replace1490_1_0 -> 2054 in the cache */
   /* replace1490_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3949 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1491_0_0 -> 16 in the cache */
   /* search1491_0 -> 1848 in the cache */
   /* search1491_1_0 -> 2054 in the cache */
   /* search1491_1 -> 3994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1848, 3994 },
      -1,
   } },

   /* replace1491_0 -> 16 in the cache */
   /* replace1491_1_0 -> 2054 in the cache */
   /* replace1491_1 -> 3949 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3949 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1492_0_0 -> 3902 in the cache */
   /* search1492_0 -> 3999 in the cache */
   /* search1492_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3999, 4167 },
      -1,
   } },

   /* replace1492_0_0 -> 3902 in the cache */
   /* replace1492_0 -> 3954 in the cache */
   /* replace1492_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3954, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1493_0_0 -> 3902 in the cache */
   /* search1493_0 -> 3999 in the cache */
   /* search1493_1_0 -> 360 in the cache */
   /* search1493_1 -> 4167 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3999, 4167 },
      -1,
   } },

   /* replace1493_0_0 -> 3902 in the cache */
   /* replace1493_0 -> 3954 in the cache */
   /* replace1493_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3954, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1494_0_0 -> 16 in the cache */
   /* search1494_0 -> 1848 in the cache */
   /* search1494_1_0 -> 243 in the cache */
   /* search1494_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1848, 4114 },
      -1,
   } },

   /* replace1494_0 -> 16 in the cache */
   /* replace1494_1_0 -> 243 in the cache */
   /* replace1494_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4055 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1495_0_0 -> 16 in the cache */
   /* search1495_0 -> 1848 in the cache */
   /* search1495_1_0 -> 243 in the cache */
   /* search1495_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1848, 4114 },
      -1,
   } },

   /* replace1495_0 -> 16 in the cache */
   /* replace1495_1_0 -> 243 in the cache */
   /* replace1495_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4055 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1496_0_0 -> 16 in the cache */
   /* search1496_0 -> 1848 in the cache */
   /* search1496_1_0 -> 243 in the cache */
   /* search1496_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1848, 4114 },
      -1,
   } },

   /* replace1496_0 -> 16 in the cache */
   /* replace1496_1_0 -> 243 in the cache */
   /* replace1496_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4055 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1497_0_0 -> 16 in the cache */
   /* search1497_0 -> 1848 in the cache */
   /* search1497_1_0 -> 243 in the cache */
   /* search1497_1 -> 4114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1848, 4114 },
      -1,
   } },

   /* replace1497_0 -> 16 in the cache */
   /* replace1497_1_0 -> 243 in the cache */
   /* replace1497_1 -> 4055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4055 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1498_0_0 -> 496 in the cache */
   /* search1498_0 -> 4119 in the cache */
   /* search1498_1_0 -> 360 in the cache */
   /* search1498_1 -> 4167 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4119, 4167 },
      -1,
   } },

   /* replace1498_0_0 -> 496 in the cache */
   /* replace1498_0 -> 4065 in the cache */
   /* replace1498_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4065, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1499_0_0 -> 496 in the cache */
   /* search1499_0 -> 4119 in the cache */
   /* search1499_1_0 -> 360 in the cache */
   /* search1499_1 -> 4167 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4119, 4167 },
      -1,
   } },

   /* replace1499_0_0 -> 496 in the cache */
   /* replace1499_0 -> 4065 in the cache */
   /* replace1499_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4065, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1500_0_0 -> 16 in the cache */
   /* search1500_0 -> 1848 in the cache */
   /* search1500_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1848, 4184 },
      -1,
   } },

   /* replace1500_0 -> 16 in the cache */
   /* replace1500_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4186 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1501_0_0 -> 16 in the cache */
   /* search1501_0 -> 1848 in the cache */
   /* search1501_1_0 -> 36 in the cache */
   /* search1501_1 -> 4184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1848, 4184 },
      -1,
   } },

   /* replace1501_0 -> 16 in the cache */
   /* replace1501_1_0 -> 36 in the cache */
   /* replace1501_1 -> 4186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4186 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1502_0_0 -> 16 in the cache */
   /* search1502_0 -> 1848 in the cache */
   /* search1502_1_0 -> 36 in the cache */
   /* search1502_1 -> 4184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1848, 4184 },
      -1,
   } },

   /* replace1502_0 -> 16 in the cache */
   /* replace1502_1_0 -> 36 in the cache */
   /* replace1502_1 -> 4186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4186 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1503_0_0 -> 16 in the cache */
   /* search1503_0 -> 1848 in the cache */
   /* search1503_1_0 -> 36 in the cache */
   /* search1503_1 -> 4184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1848, 4184 },
      -1,
   } },

   /* replace1503_0 -> 16 in the cache */
   /* replace1503_1_0 -> 36 in the cache */
   /* replace1503_1 -> 4186 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4186 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1504_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1504_1_0 -> 360 in the cache */
   /* search1504_1 -> 4167 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4194, 4167 },
      -1,
   } },

   /* replace1504_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1504_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4196, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1505_0_0 -> 358 in the cache */
   /* search1505_0 -> 4194 in the cache */
   /* search1505_1_0 -> 360 in the cache */
   /* search1505_1 -> 4167 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4194, 4167 },
      -1,
   } },

   /* replace1505_0_0 -> 358 in the cache */
   /* replace1505_0 -> 4196 in the cache */
   /* replace1505_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4196, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1506_0_0 -> 16 in the cache */
   /* search1506_0 -> 1848 in the cache */
   /* search1506_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1848, 4003 },
      -1,
   } },

   /* replace1506_0_0 -> 16 in the cache */
   /* replace1506_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4201 },
      -1,
   } },
   /* replace1506_1_0_0_0 -> 41 in the cache */
   /* replace1506_1_0_0 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4201 },
      -1,
   } },
   /* replace1506_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4203, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4202, 4204 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1507_0_0 -> 16 in the cache */
   /* search1507_0 -> 1848 in the cache */
   /* search1507_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1848, 4003 },
      -1,
   } },

   /* replace1507_0_0 -> 16 in the cache */
   /* replace1507_0_1_0 -> 41 in the cache */
   /* replace1507_0_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4201 },
      -1,
   } },
   /* replace1507_1_0_0_0 -> 41 in the cache */
   /* replace1507_1_0_0 -> 4201 in the cache */
   /* replace1507_1_0 -> 4203 in the cache */
   /* replace1507_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4203, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4207, 4208 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1508_0_0 -> 16 in the cache */
   /* search1508_0 -> 1848 in the cache */
   /* search1508_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1848, 4003 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1508_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4211, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1508_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4213, 41 },
      -1,
   } },
   /* replace1508_1_1_0 -> 16 in the cache */
   /* replace1508_1_1_1_0 -> 41 in the cache */
   /* replace1508_1_1_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4214, 4215 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4212, 4216 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1509_0 -> 4022 in the cache */
   /* search1509_1_0 -> 36 in the cache */
   /* search1509_1 -> 4184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4022, 4184 },
      -1,
   } },

   /* replace1509_0_0 -> 21 in the cache */
   /* replace1509_0_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4213 },
      -1,
   } },
   /* replace1509_1_0_0 -> 21 in the cache */
   /* replace1509_1_0_1 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4211 },
      -1,
   } },
   /* replace1509_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1509_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4221, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4220, 4222 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4219, 4223 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1510_0_0 -> 16 in the cache */
   /* search1510_0 -> 1848 in the cache */
   /* search1510_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1848, 4003 },
      -1,
   } },

   /* replace1510_0_0 -> 4213 in the cache */
   /* replace1510_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4213, 41 },
      -1,
   } },
   /* replace1510_1_0_0 -> 4211 in the cache */
   /* replace1510_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4211, 41 },
      -1,
   } },
   /* replace1510_1_1_0 -> 16 in the cache */
   /* replace1510_1_1_1_0 -> 41 in the cache */
   /* replace1510_1_1_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4227, 4228 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4226, 4229 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1511_0 -> 4022 in the cache */
   /* search1511_1_0 -> 36 in the cache */
   /* search1511_1 -> 4184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4022, 4184 },
      -1,
   } },

   /* replace1511_0_0 -> 21 in the cache */
   /* replace1511_0_1 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4211 },
      -1,
   } },
   /* replace1511_1_0_0 -> 21 in the cache */
   /* replace1511_1_0_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4213 },
      -1,
   } },
   /* replace1511_1_1_0_0 -> 21 in the cache */
   /* replace1511_1_1_0 -> 4221 in the cache */
   /* replace1511_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4221, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4233, 4234 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4232, 4235 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1512_0_0 -> 6 in the cache */
   /* search1512_0 -> 3832 in the cache */
   /* search1512_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3832, 4237 },
      -1,
   } },

   /* replace1512_0 -> 6 in the cache */
   /* replace1512_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4239 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1513_0_0 -> 6 in the cache */
   /* search1513_0 -> 3832 in the cache */
   /* search1513_1_0 -> 2054 in the cache */
   /* search1513_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3832, 4237 },
      -1,
   } },

   /* replace1513_0 -> 6 in the cache */
   /* replace1513_1_0 -> 2054 in the cache */
   /* replace1513_1 -> 4239 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4239 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1514_0_0 -> 6 in the cache */
   /* search1514_0 -> 3832 in the cache */
   /* search1514_1_0 -> 2054 in the cache */
   /* search1514_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3832, 4237 },
      -1,
   } },

   /* replace1514_0 -> 6 in the cache */
   /* replace1514_1_0 -> 2054 in the cache */
   /* replace1514_1 -> 4239 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4239 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1515_0_0 -> 6 in the cache */
   /* search1515_0 -> 3832 in the cache */
   /* search1515_1_0 -> 2054 in the cache */
   /* search1515_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3832, 4237 },
      -1,
   } },

   /* replace1515_0 -> 6 in the cache */
   /* replace1515_1_0 -> 2054 in the cache */
   /* replace1515_1 -> 4239 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4239 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1516_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1516_1_0 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4247, 4248 },
      -1,
   } },

   /* replace1516_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* replace1516_1 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4250, 3904 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1517_0_0 -> 3902 in the cache */
   /* search1517_0 -> 4247 in the cache */
   /* search1517_1_0 -> 3904 in the cache */
   /* search1517_1 -> 4248 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4247, 4248 },
      -1,
   } },

   /* replace1517_0_0 -> 3902 in the cache */
   /* replace1517_0 -> 4250 in the cache */
   /* replace1517_1 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4250, 3904 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1518_0_0 -> 6 in the cache */
   /* search1518_0 -> 3832 in the cache */
   /* search1518_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3832, 1953 },
      -1,
   } },

   /* replace1518_0_0 -> 6 in the cache */
   /* replace1518_0_1_0 -> 243 in the cache */
   /* replace1518_0_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 1961 },
      -1,
   } },
   /* replace1518_1_0_0_0 -> 243 in the cache */
   /* replace1518_1_0_0 -> 1961 in the cache */
   /* replace1518_1_0 -> 1962 in the cache */
   /* replace1518_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 1962, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4255, 4256 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1519_0_0 -> 6 in the cache */
   /* search1519_0 -> 3832 in the cache */
   /* search1519_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3832, 1953 },
      -1,
   } },

   /* replace1519_0_0 -> 6 in the cache */
   /* replace1519_0_1_0 -> 243 in the cache */
   /* replace1519_0_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 1961 },
      -1,
   } },
   /* replace1519_1_0_0_0 -> 243 in the cache */
   /* replace1519_1_0_0 -> 1961 in the cache */
   /* replace1519_1_0 -> 1962 in the cache */
   /* replace1519_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 1962, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4259, 4260 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1520_0_0 -> 6 in the cache */
   /* search1520_0 -> 3832 in the cache */
   /* search1520_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3832, 1953 },
      -1,
   } },

   /* replace1520_0_0 -> 813 in the cache */
   /* replace1520_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 813, 243 },
      -1,
   } },
   /* replace1520_1_0_0 -> 1955 in the cache */
   /* replace1520_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1955, 243 },
      -1,
   } },
   /* replace1520_1_1_0 -> 6 in the cache */
   /* replace1520_1_1_1_0 -> 243 in the cache */
   /* replace1520_1_1_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4264, 4265 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4263, 4266 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1521_0 -> 3929 in the cache */
   /* search1521_1_0 -> 2054 in the cache */
   /* search1521_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3929, 4237 },
      -1,
   } },

   /* replace1521_0_0 -> 11 in the cache */
   /* replace1521_0_1 -> 1955 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 1955 },
      -1,
   } },
   /* replace1521_1_0_0 -> 11 in the cache */
   /* replace1521_1_0_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 813 },
      -1,
   } },
   /* replace1521_1_1_0_0 -> 11 in the cache */
   /* replace1521_1_1_0 -> 1951 in the cache */
   /* replace1521_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1951, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4270, 4271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4269, 4272 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1522_0_0 -> 6 in the cache */
   /* search1522_0 -> 3832 in the cache */
   /* search1522_1 -> 1953 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3832, 1953 },
      -1,
   } },

   /* replace1522_0_0 -> 1955 in the cache */
   /* replace1522_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1955, 243 },
      -1,
   } },
   /* replace1522_1_0_0 -> 813 in the cache */
   /* replace1522_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 813, 243 },
      -1,
   } },
   /* replace1522_1_1_0 -> 6 in the cache */
   /* replace1522_1_1_1_0 -> 243 in the cache */
   /* replace1522_1_1_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4276, 4277 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4275, 4278 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1523_0 -> 3929 in the cache */
   /* search1523_1_0 -> 2054 in the cache */
   /* search1523_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3929, 4237 },
      -1,
   } },

   /* replace1523_0_0 -> 11 in the cache */
   /* replace1523_0_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 813 },
      -1,
   } },
   /* replace1523_1_0_0 -> 11 in the cache */
   /* replace1523_1_0_1 -> 1955 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 1955 },
      -1,
   } },
   /* replace1523_1_1_0_0 -> 11 in the cache */
   /* replace1523_1_1_0 -> 1951 in the cache */
   /* replace1523_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1951, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4282, 4283 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4281, 4284 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1524_0_0 -> 6 in the cache */
   /* search1524_0 -> 2960 in the cache */
   /* search1524_1_0 -> 2054 in the cache */
   /* search1524_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2960, 2962 },
      -1,
   } },

   /* replace1524_0 -> 6 in the cache */
   /* replace1524_1_0 -> 2054 in the cache */
   /* replace1524_1 -> 4239 in the cache */
   /* replace1524 -> 4240 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1525_0_0 -> 6 in the cache */
   /* search1525_0 -> 2960 in the cache */
   /* search1525_1_0 -> 2054 in the cache */
   /* search1525_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2960, 2962 },
      -1,
   } },

   /* replace1525_0 -> 6 in the cache */
   /* replace1525_1_0 -> 2054 in the cache */
   /* replace1525_1 -> 4239 in the cache */
   /* replace1525 -> 4242 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1526_0_0 -> 6 in the cache */
   /* search1526_0 -> 2960 in the cache */
   /* search1526_1_0 -> 2054 in the cache */
   /* search1526_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2960, 2962 },
      -1,
   } },

   /* replace1526_0 -> 6 in the cache */
   /* replace1526_1_0 -> 2054 in the cache */
   /* replace1526_1 -> 4239 in the cache */
   /* replace1526 -> 4244 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1527_0_0 -> 6 in the cache */
   /* search1527_0 -> 2960 in the cache */
   /* search1527_1_0 -> 2054 in the cache */
   /* search1527_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2960, 2962 },
      -1,
   } },

   /* replace1527_0 -> 6 in the cache */
   /* replace1527_1_0 -> 2054 in the cache */
   /* replace1527_1 -> 4239 in the cache */
   /* replace1527 -> 4246 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1528_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1528_1_0 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4290, 4291 },
      -1,
   } },

   /* replace1528_0_0 -> 3902 in the cache */
   /* replace1528_0 -> 4250 in the cache */
   /* replace1528_1 -> 3904 in the cache */
   /* replace1528 -> 4251 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1529_0_0 -> 3902 in the cache */
   /* search1529_0 -> 4290 in the cache */
   /* search1529_1_0 -> 3904 in the cache */
   /* search1529_1 -> 4291 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4290, 4291 },
      -1,
   } },

   /* replace1529_0_0 -> 3902 in the cache */
   /* replace1529_0 -> 4250 in the cache */
   /* replace1529_1 -> 3904 in the cache */
   /* replace1529 -> 4253 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1530_0_0 -> 6 in the cache */
   /* search1530_0 -> 2960 in the cache */
   /* search1530_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2960, 33 },
      -1,
   } },

   /* replace1530_0_0 -> 6 in the cache */
   /* replace1530_0_1_0 -> 36 in the cache */
   /* replace1530_0_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 1969 },
      -1,
   } },
   /* replace1530_1_0_0_0 -> 36 in the cache */
   /* replace1530_1_0_0 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1969 },
      -1,
   } },
   /* replace1530_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4296, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4295, 4297 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1531_0_0 -> 6 in the cache */
   /* search1531_0 -> 2960 in the cache */
   /* search1531_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2960, 33 },
      -1,
   } },

   /* replace1531_0_0 -> 6 in the cache */
   /* replace1531_0_1_0 -> 36 in the cache */
   /* replace1531_0_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 1969 },
      -1,
   } },
   /* replace1531_1_0_0_0 -> 36 in the cache */
   /* replace1531_1_0_0 -> 1969 in the cache */
   /* replace1531_1_0 -> 4296 in the cache */
   /* replace1531_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4296, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4300, 4301 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1532_0_0 -> 6 in the cache */
   /* search1532_0 -> 2960 in the cache */
   /* search1532_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2960, 33 },
      -1,
   } },

   /* replace1532_0_0 -> 120 in the cache */
   /* replace1532_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1532_1_0_0 -> 783 in the cache */
   /* replace1532_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 783, 36 },
      -1,
   } },
   /* replace1532_1_1_0 -> 6 in the cache */
   /* replace1532_1_1_1_0 -> 36 in the cache */
   /* replace1532_1_1_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 1969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4305, 4306 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4304, 4307 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1533_0 -> 271 in the cache */
   /* search1533_1_0 -> 2054 in the cache */
   /* search1533_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 271, 2962 },
      -1,
   } },

   /* replace1533_0_0 -> 16 in the cache */
   /* replace1533_0_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 783 },
      -1,
   } },
   /* replace1533_1_0_0 -> 16 in the cache */
   /* replace1533_1_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1533_1_1_0_0 -> 16 in the cache */
   /* replace1533_1_1_0 -> 1967 in the cache */
   /* replace1533_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1967, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4311, 4312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4310, 4313 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1534_0_0 -> 6 in the cache */
   /* search1534_0 -> 2960 in the cache */
   /* search1534_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2960, 33 },
      -1,
   } },

   /* replace1534_0_0 -> 783 in the cache */
   /* replace1534_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 783, 36 },
      -1,
   } },
   /* replace1534_1_0_0 -> 120 in the cache */
   /* replace1534_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1534_1_1_0 -> 6 in the cache */
   /* replace1534_1_1_1_0 -> 36 in the cache */
   /* replace1534_1_1_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 1969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4317, 4318 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4316, 4319 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1535_0 -> 271 in the cache */
   /* search1535_1_0 -> 2054 in the cache */
   /* search1535_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 271, 2962 },
      -1,
   } },

   /* replace1535_0_0 -> 16 in the cache */
   /* replace1535_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1535_1_0_0 -> 16 in the cache */
   /* replace1535_1_0_1 -> 783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 783 },
      -1,
   } },
   /* replace1535_1_1_0_0 -> 16 in the cache */
   /* replace1535_1_1_0 -> 1967 in the cache */
   /* replace1535_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1967, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4323, 4324 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4322, 4325 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1536_0_0 -> 6 in the cache */
   /* search1536_0 -> 3869 in the cache */
   /* search1536_1_0 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3869, 4327 },
      -1,
   } },

   /* replace1536_0 -> 6 in the cache */
   /* replace1536_1_0 -> 2054 in the cache */
   /* replace1536_1 -> 4239 in the cache */
   /* replace1536 -> 4240 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1537_0_0 -> 6 in the cache */
   /* search1537_0 -> 3869 in the cache */
   /* search1537_1_0 -> 2054 in the cache */
   /* search1537_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3869, 4327 },
      -1,
   } },

   /* replace1537_0 -> 6 in the cache */
   /* replace1537_1_0 -> 2054 in the cache */
   /* replace1537_1 -> 4239 in the cache */
   /* replace1537 -> 4242 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1538_0_0 -> 6 in the cache */
   /* search1538_0 -> 3869 in the cache */
   /* search1538_1_0 -> 2054 in the cache */
   /* search1538_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3869, 4327 },
      -1,
   } },

   /* replace1538_0 -> 6 in the cache */
   /* replace1538_1_0 -> 2054 in the cache */
   /* replace1538_1 -> 4239 in the cache */
   /* replace1538 -> 4244 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1539_0_0 -> 6 in the cache */
   /* search1539_0 -> 3869 in the cache */
   /* search1539_1_0 -> 2054 in the cache */
   /* search1539_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3869, 4327 },
      -1,
   } },

   /* replace1539_0 -> 6 in the cache */
   /* replace1539_1_0 -> 2054 in the cache */
   /* replace1539_1 -> 4239 in the cache */
   /* replace1539 -> 4246 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1540_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1540_1_0 -> 3904 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4332, 4333 },
      -1,
   } },

   /* replace1540_0_0 -> 3902 in the cache */
   /* replace1540_0 -> 4250 in the cache */
   /* replace1540_1 -> 3904 in the cache */
   /* replace1540 -> 4251 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1541_0_0 -> 3902 in the cache */
   /* search1541_0 -> 4332 in the cache */
   /* search1541_1_0 -> 3904 in the cache */
   /* search1541_1 -> 4333 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4332, 4333 },
      -1,
   } },

   /* replace1541_0_0 -> 3902 in the cache */
   /* replace1541_0 -> 4250 in the cache */
   /* replace1541_1 -> 3904 in the cache */
   /* replace1541 -> 4253 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1542_0_0 -> 6 in the cache */
   /* search1542_0 -> 3869 in the cache */
   /* search1542_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3869, 4003 },
      -1,
   } },

   /* replace1542_0_0 -> 6 in the cache */
   /* replace1542_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4337 },
      -1,
   } },
   /* replace1542_1_0_0_0 -> 41 in the cache */
   /* replace1542_1_0_0 -> 4337 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4337 },
      -1,
   } },
   /* replace1542_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4339, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4338, 4340 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1543_0_0 -> 6 in the cache */
   /* search1543_0 -> 3869 in the cache */
   /* search1543_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3869, 4003 },
      -1,
   } },

   /* replace1543_0_0 -> 6 in the cache */
   /* replace1543_0_1_0 -> 41 in the cache */
   /* replace1543_0_1 -> 4337 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4337 },
      -1,
   } },
   /* replace1543_1_0_0_0 -> 41 in the cache */
   /* replace1543_1_0_0 -> 4337 in the cache */
   /* replace1543_1_0 -> 4339 in the cache */
   /* replace1543_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4339, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4343, 4344 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1544_0_0 -> 6 in the cache */
   /* search1544_0 -> 3869 in the cache */
   /* search1544_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3869, 4003 },
      -1,
   } },

   /* replace1544_0_0 -> 856 in the cache */
   /* replace1544_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 856, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1544_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4348, 41 },
      -1,
   } },
   /* replace1544_1_1_0 -> 6 in the cache */
   /* replace1544_1_1_1_0 -> 41 in the cache */
   /* replace1544_1_1_1 -> 4337 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4337 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4349, 4350 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4347, 4351 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1545_0 -> 4022 in the cache */
   /* search1545_1_0 -> 2054 in the cache */
   /* search1545_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4022, 4327 },
      -1,
   } },

   /* replace1545_0_0 -> 21 in the cache */
   /* replace1545_0_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4348 },
      -1,
   } },
   /* replace1545_1_0_0 -> 21 in the cache */
   /* replace1545_1_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 856 },
      -1,
   } },
   /* replace1545_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1545_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4356, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4355, 4357 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4354, 4358 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1546_0_0 -> 6 in the cache */
   /* search1546_0 -> 3869 in the cache */
   /* search1546_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3869, 4003 },
      -1,
   } },

   /* replace1546_0_0 -> 4348 in the cache */
   /* replace1546_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4348, 41 },
      -1,
   } },
   /* replace1546_1_0_0 -> 856 in the cache */
   /* replace1546_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 856, 41 },
      -1,
   } },
   /* replace1546_1_1_0 -> 6 in the cache */
   /* replace1546_1_1_1_0 -> 41 in the cache */
   /* replace1546_1_1_1 -> 4337 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4337 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4362, 4363 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4361, 4364 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1547_0 -> 4022 in the cache */
   /* search1547_1_0 -> 2054 in the cache */
   /* search1547_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4022, 4327 },
      -1,
   } },

   /* replace1547_0_0 -> 21 in the cache */
   /* replace1547_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 856 },
      -1,
   } },
   /* replace1547_1_0_0 -> 21 in the cache */
   /* replace1547_1_0_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4348 },
      -1,
   } },
   /* replace1547_1_1_0_0 -> 21 in the cache */
   /* replace1547_1_1_0 -> 4356 in the cache */
   /* replace1547_1_1_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4356, 2054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4368, 4369 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4367, 4370 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1548_0_0 -> 11 in the cache */
   /* search1548_0 -> 1743 in the cache */
   /* search1548_1_0 -> 2054 in the cache */
   /* search1548_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1743, 2962 },
      -1,
   } },

   /* replace1548_0 -> 11 in the cache */
   /* replace1548_1_0 -> 2054 in the cache */
   /* replace1548_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4237 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1549_0_0 -> 11 in the cache */
   /* search1549_0 -> 1743 in the cache */
   /* search1549_1_0 -> 2054 in the cache */
   /* search1549_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1743, 2962 },
      -1,
   } },

   /* replace1549_0 -> 11 in the cache */
   /* replace1549_1_0 -> 2054 in the cache */
   /* replace1549_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4237 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1550_0_0 -> 11 in the cache */
   /* search1550_0 -> 1743 in the cache */
   /* search1550_1_0 -> 2054 in the cache */
   /* search1550_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1743, 2962 },
      -1,
   } },

   /* replace1550_0 -> 11 in the cache */
   /* replace1550_1_0 -> 2054 in the cache */
   /* replace1550_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4237 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1551_0_0 -> 11 in the cache */
   /* search1551_0 -> 1743 in the cache */
   /* search1551_1_0 -> 2054 in the cache */
   /* search1551_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1743, 2962 },
      -1,
   } },

   /* replace1551_0 -> 11 in the cache */
   /* replace1551_1_0 -> 2054 in the cache */
   /* replace1551_1 -> 4237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4237 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1552_0_0 -> 3902 in the cache */
   /* search1552_0 -> 4290 in the cache */
   /* search1552_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4290, 4380 },
      -1,
   } },

   /* replace1552_0_0 -> 3902 in the cache */
   /* replace1552_0 -> 4247 in the cache */
   /* replace1552_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4247, 507 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1553_0_0 -> 3902 in the cache */
   /* search1553_0 -> 4290 in the cache */
   /* search1553_1_0 -> 507 in the cache */
   /* search1553_1 -> 4380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4290, 4380 },
      -1,
   } },

   /* replace1553_0_0 -> 3902 in the cache */
   /* replace1553_0 -> 4247 in the cache */
   /* replace1553_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4247, 507 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1554_0_0 -> 11 in the cache */
   /* search1554_0 -> 1743 in the cache */
   /* search1554_1_0 -> 243 in the cache */
   /* search1554_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1743, 2982 },
      -1,
   } },

   /* replace1554_0 -> 11 in the cache */
   /* replace1554_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4386 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1555_0_0 -> 11 in the cache */
   /* search1555_0 -> 1743 in the cache */
   /* search1555_1_0 -> 243 in the cache */
   /* search1555_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1743, 2982 },
      -1,
   } },

   /* replace1555_0 -> 11 in the cache */
   /* replace1555_1_0 -> 243 in the cache */
   /* replace1555_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4386 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1556_0_0 -> 11 in the cache */
   /* search1556_0 -> 1743 in the cache */
   /* search1556_1_0 -> 243 in the cache */
   /* search1556_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1743, 2982 },
      -1,
   } },

   /* replace1556_0 -> 11 in the cache */
   /* replace1556_1_0 -> 243 in the cache */
   /* replace1556_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4386 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1557_0_0 -> 11 in the cache */
   /* search1557_0 -> 1743 in the cache */
   /* search1557_1_0 -> 243 in the cache */
   /* search1557_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1743, 2982 },
      -1,
   } },

   /* replace1557_0 -> 11 in the cache */
   /* replace1557_1_0 -> 243 in the cache */
   /* replace1557_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4386 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1558_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1558_1_0 -> 507 in the cache */
   /* search1558_1 -> 4380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4394, 4380 },
      -1,
   } },

   /* replace1558_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1558_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4396, 507 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1559_0_0 -> 496 in the cache */
   /* search1559_0 -> 4394 in the cache */
   /* search1559_1_0 -> 507 in the cache */
   /* search1559_1 -> 4380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4394, 4380 },
      -1,
   } },

   /* replace1559_0_0 -> 496 in the cache */
   /* replace1559_0 -> 4396 in the cache */
   /* replace1559_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4396, 507 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1560_0_0 -> 11 in the cache */
   /* search1560_0 -> 1743 in the cache */
   /* search1560_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1743, 33 },
      -1,
   } },

   /* replace1560_0_0 -> 11 in the cache */
   /* replace1560_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4401 },
      -1,
   } },
   /* replace1560_1_0_0_0 -> 36 in the cache */
   /* replace1560_1_0_0 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4401 },
      -1,
   } },
   /* replace1560_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4403, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4402, 4404 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1561_0_0 -> 11 in the cache */
   /* search1561_0 -> 1743 in the cache */
   /* search1561_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1743, 33 },
      -1,
   } },

   /* replace1561_0_0 -> 11 in the cache */
   /* replace1561_0_1_0 -> 36 in the cache */
   /* replace1561_0_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4401 },
      -1,
   } },
   /* replace1561_1_0_0_0 -> 36 in the cache */
   /* replace1561_1_0_0 -> 4401 in the cache */
   /* replace1561_1_0 -> 4403 in the cache */
   /* replace1561_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4403, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4407, 4408 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1562_0_0 -> 11 in the cache */
   /* search1562_0 -> 1743 in the cache */
   /* search1562_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1743, 33 },
      -1,
   } },

   /* replace1562_0_0 -> 120 in the cache */
   /* replace1562_0_1 -> 36 in the cache */
   /* replace1562_0 -> 4304 in the cache */
   /* replace1562_1_0_0 -> 806 in the cache */
   /* replace1562_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 806, 36 },
      -1,
   } },
   /* replace1562_1_1_0 -> 11 in the cache */
   /* replace1562_1_1_1_0 -> 36 in the cache */
   /* replace1562_1_1_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4411, 4412 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4304, 4413 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1563_0 -> 271 in the cache */
   /* search1563_1_0 -> 243 in the cache */
   /* search1563_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 271, 2982 },
      -1,
   } },

   /* replace1563_0_0 -> 16 in the cache */
   /* replace1563_0_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 806 },
      -1,
   } },
   /* replace1563_1_0_0 -> 16 in the cache */
   /* replace1563_1_0_1 -> 120 in the cache */
   /* replace1563_1_0 -> 4311 in the cache */
   /* replace1563_1_1_0_0 -> 16 in the cache */
   /* replace1563_1_1_0 -> 2988 in the cache */
   /* replace1563_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2988, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4311, 4417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4416, 4418 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1564_0_0 -> 11 in the cache */
   /* search1564_0 -> 1743 in the cache */
   /* search1564_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1743, 33 },
      -1,
   } },

   /* replace1564_0_0 -> 806 in the cache */
   /* replace1564_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 806, 36 },
      -1,
   } },
   /* replace1564_1_0_0 -> 120 in the cache */
   /* replace1564_1_0_1 -> 36 in the cache */
   /* replace1564_1_0 -> 4317 in the cache */
   /* replace1564_1_1_0 -> 11 in the cache */
   /* replace1564_1_1_1_0 -> 36 in the cache */
   /* replace1564_1_1_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4317, 4422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4421, 4423 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1565_0 -> 271 in the cache */
   /* search1565_1_0 -> 243 in the cache */
   /* search1565_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 271, 2982 },
      -1,
   } },

   /* replace1565_0_0 -> 16 in the cache */
   /* replace1565_0_1 -> 120 in the cache */
   /* replace1565_0 -> 4322 in the cache */
   /* replace1565_1_0_0 -> 16 in the cache */
   /* replace1565_1_0_1 -> 806 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 806 },
      -1,
   } },
   /* replace1565_1_1_0_0 -> 16 in the cache */
   /* replace1565_1_1_0 -> 2988 in the cache */
   /* replace1565_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2988, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4426, 4427 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4322, 4428 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1566_0_0 -> 11 in the cache */
   /* search1566_0 -> 1766 in the cache */
   /* search1566_1_0 -> 2054 in the cache */
   /* search1566_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1766, 4327 },
      -1,
   } },

   /* replace1566_0 -> 11 in the cache */
   /* replace1566_1_0 -> 2054 in the cache */
   /* replace1566_1 -> 4237 in the cache */
   /* replace1566 -> 4373 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1567_0_0 -> 11 in the cache */
   /* search1567_0 -> 1766 in the cache */
   /* search1567_1_0 -> 2054 in the cache */
   /* search1567_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1766, 4327 },
      -1,
   } },

   /* replace1567_0 -> 11 in the cache */
   /* replace1567_1_0 -> 2054 in the cache */
   /* replace1567_1 -> 4237 in the cache */
   /* replace1567 -> 4375 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1568_0_0 -> 11 in the cache */
   /* search1568_0 -> 1766 in the cache */
   /* search1568_1_0 -> 2054 in the cache */
   /* search1568_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1766, 4327 },
      -1,
   } },

   /* replace1568_0 -> 11 in the cache */
   /* replace1568_1_0 -> 2054 in the cache */
   /* replace1568_1 -> 4237 in the cache */
   /* replace1568 -> 4377 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1569_0_0 -> 11 in the cache */
   /* search1569_0 -> 1766 in the cache */
   /* search1569_1_0 -> 2054 in the cache */
   /* search1569_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1766, 4327 },
      -1,
   } },

   /* replace1569_0 -> 11 in the cache */
   /* replace1569_1_0 -> 2054 in the cache */
   /* replace1569_1 -> 4237 in the cache */
   /* replace1569 -> 4379 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1570_0_0 -> 3902 in the cache */
   /* search1570_0 -> 4332 in the cache */
   /* search1570_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4332, 4434 },
      -1,
   } },

   /* replace1570_0_0 -> 3902 in the cache */
   /* replace1570_0 -> 4247 in the cache */
   /* replace1570_1 -> 507 in the cache */
   /* replace1570 -> 4382 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1571_0_0 -> 3902 in the cache */
   /* search1571_0 -> 4332 in the cache */
   /* search1571_1_0 -> 507 in the cache */
   /* search1571_1 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4332, 4434 },
      -1,
   } },

   /* replace1571_0_0 -> 3902 in the cache */
   /* replace1571_0 -> 4247 in the cache */
   /* replace1571_1 -> 507 in the cache */
   /* replace1571 -> 4384 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1572_0_0 -> 11 in the cache */
   /* search1572_0 -> 1766 in the cache */
   /* search1572_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1766, 4437 },
      -1,
   } },

   /* replace1572_0 -> 11 in the cache */
   /* replace1572_1_0 -> 243 in the cache */
   /* replace1572_1 -> 4386 in the cache */
   /* replace1572 -> 4387 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1573_0_0 -> 11 in the cache */
   /* search1573_0 -> 1766 in the cache */
   /* search1573_1_0 -> 243 in the cache */
   /* search1573_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1766, 4437 },
      -1,
   } },

   /* replace1573_0 -> 11 in the cache */
   /* replace1573_1_0 -> 243 in the cache */
   /* replace1573_1 -> 4386 in the cache */
   /* replace1573 -> 4389 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1574_0_0 -> 11 in the cache */
   /* search1574_0 -> 1766 in the cache */
   /* search1574_1_0 -> 243 in the cache */
   /* search1574_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1766, 4437 },
      -1,
   } },

   /* replace1574_0 -> 11 in the cache */
   /* replace1574_1_0 -> 243 in the cache */
   /* replace1574_1 -> 4386 in the cache */
   /* replace1574 -> 4391 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1575_0_0 -> 11 in the cache */
   /* search1575_0 -> 1766 in the cache */
   /* search1575_1_0 -> 243 in the cache */
   /* search1575_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1766, 4437 },
      -1,
   } },

   /* replace1575_0 -> 11 in the cache */
   /* replace1575_1_0 -> 243 in the cache */
   /* replace1575_1 -> 4386 in the cache */
   /* replace1575 -> 4393 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1576_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1576_1_0 -> 507 in the cache */
   /* search1576_1 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4442, 4434 },
      -1,
   } },

   /* replace1576_0_0 -> 496 in the cache */
   /* replace1576_0 -> 4396 in the cache */
   /* replace1576_1 -> 507 in the cache */
   /* replace1576 -> 4397 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1577_0_0 -> 496 in the cache */
   /* search1577_0 -> 4442 in the cache */
   /* search1577_1_0 -> 507 in the cache */
   /* search1577_1 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4442, 4434 },
      -1,
   } },

   /* replace1577_0_0 -> 496 in the cache */
   /* replace1577_0 -> 4396 in the cache */
   /* replace1577_1 -> 507 in the cache */
   /* replace1577 -> 4399 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1578_0_0 -> 11 in the cache */
   /* search1578_0 -> 1766 in the cache */
   /* search1578_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1766, 4003 },
      -1,
   } },

   /* replace1578_0_0 -> 11 in the cache */
   /* replace1578_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4446 },
      -1,
   } },
   /* replace1578_1_0_0_0 -> 41 in the cache */
   /* replace1578_1_0_0 -> 4446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4446 },
      -1,
   } },
   /* replace1578_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4448, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4447, 4449 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1579_0_0 -> 11 in the cache */
   /* search1579_0 -> 1766 in the cache */
   /* search1579_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1766, 4003 },
      -1,
   } },

   /* replace1579_0_0 -> 11 in the cache */
   /* replace1579_0_1_0 -> 41 in the cache */
   /* replace1579_0_1 -> 4446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4446 },
      -1,
   } },
   /* replace1579_1_0_0_0 -> 41 in the cache */
   /* replace1579_1_0_0 -> 4446 in the cache */
   /* replace1579_1_0 -> 4448 in the cache */
   /* replace1579_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4448, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4452, 4453 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1580_0_0 -> 11 in the cache */
   /* search1580_0 -> 1766 in the cache */
   /* search1580_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1766, 4003 },
      -1,
   } },

   /* replace1580_0_0 -> 856 in the cache */
   /* replace1580_0_1 -> 41 in the cache */
   /* replace1580_0 -> 4347 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1580_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4456, 41 },
      -1,
   } },
   /* replace1580_1_1_0 -> 11 in the cache */
   /* replace1580_1_1_1_0 -> 41 in the cache */
   /* replace1580_1_1_1 -> 4446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4457, 4458 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4347, 4459 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1581_0 -> 4022 in the cache */
   /* search1581_1_0 -> 243 in the cache */
   /* search1581_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4022, 4437 },
      -1,
   } },

   /* replace1581_0_0 -> 21 in the cache */
   /* replace1581_0_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4456 },
      -1,
   } },
   /* replace1581_1_0_0 -> 21 in the cache */
   /* replace1581_1_0_1 -> 856 in the cache */
   /* replace1581_1_0 -> 4355 in the cache */
   /* replace1581_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1581_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4463, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4355, 4464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4462, 4465 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1582_0_0 -> 11 in the cache */
   /* search1582_0 -> 1766 in the cache */
   /* search1582_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1766, 4003 },
      -1,
   } },

   /* replace1582_0_0 -> 4456 in the cache */
   /* replace1582_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4456, 41 },
      -1,
   } },
   /* replace1582_1_0_0 -> 856 in the cache */
   /* replace1582_1_0_1 -> 41 in the cache */
   /* replace1582_1_0 -> 4362 in the cache */
   /* replace1582_1_1_0 -> 11 in the cache */
   /* replace1582_1_1_1_0 -> 41 in the cache */
   /* replace1582_1_1_1 -> 4446 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4362, 4469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4468, 4470 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1583_0 -> 4022 in the cache */
   /* search1583_1_0 -> 243 in the cache */
   /* search1583_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4022, 4437 },
      -1,
   } },

   /* replace1583_0_0 -> 21 in the cache */
   /* replace1583_0_1 -> 856 in the cache */
   /* replace1583_0 -> 4367 in the cache */
   /* replace1583_1_0_0 -> 21 in the cache */
   /* replace1583_1_0_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4456 },
      -1,
   } },
   /* replace1583_1_1_0_0 -> 21 in the cache */
   /* replace1583_1_1_0 -> 4463 in the cache */
   /* replace1583_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4463, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4473, 4474 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4367, 4475 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1584_0_0 -> 16 in the cache */
   /* search1584_0 -> 1850 in the cache */
   /* search1584_1_0 -> 2054 in the cache */
   /* search1584_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1850, 4327 },
      -1,
   } },

   /* replace1584_0 -> 16 in the cache */
   /* replace1584_1_0 -> 2054 in the cache */
   /* replace1584_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2962 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1585_0_0 -> 16 in the cache */
   /* search1585_0 -> 1850 in the cache */
   /* search1585_1_0 -> 2054 in the cache */
   /* search1585_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1850, 4327 },
      -1,
   } },

   /* replace1585_0 -> 16 in the cache */
   /* replace1585_1_0 -> 2054 in the cache */
   /* replace1585_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 2962 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1586_0_0 -> 16 in the cache */
   /* search1586_0 -> 1850 in the cache */
   /* search1586_1_0 -> 2054 in the cache */
   /* search1586_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1850, 4327 },
      -1,
   } },

   /* replace1586_0 -> 16 in the cache */
   /* replace1586_1_0 -> 2054 in the cache */
   /* replace1586_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 2962 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1587_0_0 -> 16 in the cache */
   /* search1587_0 -> 1850 in the cache */
   /* search1587_1_0 -> 2054 in the cache */
   /* search1587_1 -> 4327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1850, 4327 },
      -1,
   } },

   /* replace1587_0 -> 16 in the cache */
   /* replace1587_1_0 -> 2054 in the cache */
   /* replace1587_1 -> 2962 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 2962 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1588_0_0 -> 3902 in the cache */
   /* search1588_0 -> 4332 in the cache */
   /* search1588_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4332, 4485 },
      -1,
   } },

   /* replace1588_0_0 -> 3902 in the cache */
   /* replace1588_0 -> 4290 in the cache */
   /* replace1588_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4290, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1589_0_0 -> 3902 in the cache */
   /* search1589_0 -> 4332 in the cache */
   /* search1589_1_0 -> 360 in the cache */
   /* search1589_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4332, 4485 },
      -1,
   } },

   /* replace1589_0_0 -> 3902 in the cache */
   /* replace1589_0 -> 4290 in the cache */
   /* replace1589_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4290, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1590_0_0 -> 16 in the cache */
   /* search1590_0 -> 1850 in the cache */
   /* search1590_1_0 -> 243 in the cache */
   /* search1590_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1850, 4437 },
      -1,
   } },

   /* replace1590_0 -> 16 in the cache */
   /* replace1590_1_0 -> 243 in the cache */
   /* replace1590_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2982 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1591_0_0 -> 16 in the cache */
   /* search1591_0 -> 1850 in the cache */
   /* search1591_1_0 -> 243 in the cache */
   /* search1591_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1850, 4437 },
      -1,
   } },

   /* replace1591_0 -> 16 in the cache */
   /* replace1591_1_0 -> 243 in the cache */
   /* replace1591_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 2982 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1592_0_0 -> 16 in the cache */
   /* search1592_0 -> 1850 in the cache */
   /* search1592_1_0 -> 243 in the cache */
   /* search1592_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1850, 4437 },
      -1,
   } },

   /* replace1592_0 -> 16 in the cache */
   /* replace1592_1_0 -> 243 in the cache */
   /* replace1592_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 2982 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1593_0_0 -> 16 in the cache */
   /* search1593_0 -> 1850 in the cache */
   /* search1593_1_0 -> 243 in the cache */
   /* search1593_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1850, 4437 },
      -1,
   } },

   /* replace1593_0 -> 16 in the cache */
   /* replace1593_1_0 -> 243 in the cache */
   /* replace1593_1 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 2982 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1594_0_0 -> 496 in the cache */
   /* search1594_0 -> 4442 in the cache */
   /* search1594_1_0 -> 360 in the cache */
   /* search1594_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4442, 4485 },
      -1,
   } },

   /* replace1594_0_0 -> 496 in the cache */
   /* replace1594_0 -> 4394 in the cache */
   /* replace1594_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4394, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1595_0_0 -> 496 in the cache */
   /* search1595_0 -> 4442 in the cache */
   /* search1595_1_0 -> 360 in the cache */
   /* search1595_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4442, 4485 },
      -1,
   } },

   /* replace1595_0_0 -> 496 in the cache */
   /* replace1595_0 -> 4394 in the cache */
   /* replace1595_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4394, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1596_0_0 -> 16 in the cache */
   /* search1596_0 -> 1850 in the cache */
   /* search1596_1_0 -> 36 in the cache */
   /* search1596_1 -> 2978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1850, 2978 },
      -1,
   } },

   /* replace1596_0 -> 16 in the cache */
   /* replace1596_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4503 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1597_0_0 -> 16 in the cache */
   /* search1597_0 -> 1850 in the cache */
   /* search1597_1_0 -> 36 in the cache */
   /* search1597_1 -> 2978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1850, 2978 },
      -1,
   } },

   /* replace1597_0 -> 16 in the cache */
   /* replace1597_1_0 -> 36 in the cache */
   /* replace1597_1 -> 4503 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4503 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1598_0_0 -> 16 in the cache */
   /* search1598_0 -> 1850 in the cache */
   /* search1598_1_0 -> 36 in the cache */
   /* search1598_1 -> 2978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1850, 2978 },
      -1,
   } },

   /* replace1598_0 -> 16 in the cache */
   /* replace1598_1_0 -> 36 in the cache */
   /* replace1598_1 -> 4503 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4503 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1599_0_0 -> 16 in the cache */
   /* search1599_0 -> 1850 in the cache */
   /* search1599_1_0 -> 36 in the cache */
   /* search1599_1 -> 2978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1850, 2978 },
      -1,
   } },

   /* replace1599_0 -> 16 in the cache */
   /* replace1599_1_0 -> 36 in the cache */
   /* replace1599_1 -> 4503 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4503 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1600_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1600_1_0 -> 360 in the cache */
   /* search1600_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4511, 4485 },
      -1,
   } },

   /* replace1600_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1600_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4513, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1601_0_0 -> 358 in the cache */
   /* search1601_0 -> 4511 in the cache */
   /* search1601_1_0 -> 360 in the cache */
   /* search1601_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4511, 4485 },
      -1,
   } },

   /* replace1601_0_0 -> 358 in the cache */
   /* replace1601_0 -> 4513 in the cache */
   /* replace1601_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4513, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1602_0_0 -> 16 in the cache */
   /* search1602_0 -> 1850 in the cache */
   /* search1602_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1850, 4003 },
      -1,
   } },

   /* replace1602_0_0 -> 16 in the cache */
   /* replace1602_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4518 },
      -1,
   } },
   /* replace1602_1_0_0_0 -> 41 in the cache */
   /* replace1602_1_0_0 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4518 },
      -1,
   } },
   /* replace1602_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4520, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4519, 4521 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1603_0_0 -> 16 in the cache */
   /* search1603_0 -> 1850 in the cache */
   /* search1603_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1850, 4003 },
      -1,
   } },

   /* replace1603_0_0 -> 16 in the cache */
   /* replace1603_0_1_0 -> 41 in the cache */
   /* replace1603_0_1 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4518 },
      -1,
   } },
   /* replace1603_1_0_0_0 -> 41 in the cache */
   /* replace1603_1_0_0 -> 4518 in the cache */
   /* replace1603_1_0 -> 4520 in the cache */
   /* replace1603_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4520, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4524, 4525 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1604_0_0 -> 16 in the cache */
   /* search1604_0 -> 1850 in the cache */
   /* search1604_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1850, 4003 },
      -1,
   } },

   /* replace1604_0_0 -> 856 in the cache */
   /* replace1604_0_1 -> 41 in the cache */
   /* replace1604_0 -> 4347 in the cache */
   /* replace1604_1_0_0 -> 2993 in the cache */
   /* replace1604_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2993, 41 },
      -1,
   } },
   /* replace1604_1_1_0 -> 16 in the cache */
   /* replace1604_1_1_1_0 -> 41 in the cache */
   /* replace1604_1_1_1 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4528, 4529 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4347, 4530 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1605_0 -> 4022 in the cache */
   /* search1605_1_0 -> 36 in the cache */
   /* search1605_1 -> 2978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4022, 2978 },
      -1,
   } },

   /* replace1605_0_0 -> 21 in the cache */
   /* replace1605_0_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 2993 },
      -1,
   } },
   /* replace1605_1_0_0 -> 21 in the cache */
   /* replace1605_1_0_1 -> 856 in the cache */
   /* replace1605_1_0 -> 4355 in the cache */
   /* replace1605_1_1_0_0 -> 21 in the cache */
   /* replace1605_1_1_0 -> 2985 in the cache */
   /* replace1605_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2985, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4355, 4534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4533, 4535 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1606_0_0 -> 16 in the cache */
   /* search1606_0 -> 1850 in the cache */
   /* search1606_1 -> 4003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1850, 4003 },
      -1,
   } },

   /* replace1606_0_0 -> 2993 in the cache */
   /* replace1606_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2993, 41 },
      -1,
   } },
   /* replace1606_1_0_0 -> 856 in the cache */
   /* replace1606_1_0_1 -> 41 in the cache */
   /* replace1606_1_0 -> 4362 in the cache */
   /* replace1606_1_1_0 -> 16 in the cache */
   /* replace1606_1_1_1_0 -> 41 in the cache */
   /* replace1606_1_1_1 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4362, 4539 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4538, 4540 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1607_0 -> 4022 in the cache */
   /* search1607_1_0 -> 36 in the cache */
   /* search1607_1 -> 2978 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4022, 2978 },
      -1,
   } },

   /* replace1607_0_0 -> 21 in the cache */
   /* replace1607_0_1 -> 856 in the cache */
   /* replace1607_0 -> 4367 in the cache */
   /* replace1607_1_0_0 -> 21 in the cache */
   /* replace1607_1_0_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 2993 },
      -1,
   } },
   /* replace1607_1_1_0_0 -> 21 in the cache */
   /* replace1607_1_1_0 -> 2985 in the cache */
   /* replace1607_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2985, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4543, 4544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4367, 4545 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1608_0_0 -> 11 in the cache */
   /* search1608_0 -> 1739 in the cache */
   /* search1608_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1739, 4547 },
      -1,
   } },

   /* replace1608_0 -> 11 in the cache */
   /* replace1608_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 4549 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1609_0_0 -> 11 in the cache */
   /* search1609_0 -> 1739 in the cache */
   /* search1609_1_0 -> 243 in the cache */
   /* search1609_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1739, 4547 },
      -1,
   } },

   /* replace1609_0 -> 11 in the cache */
   /* replace1609_1_0 -> 243 in the cache */
   /* replace1609_1 -> 4549 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 4549 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1610_0_0 -> 11 in the cache */
   /* search1610_0 -> 1739 in the cache */
   /* search1610_1_0 -> 243 in the cache */
   /* search1610_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1739, 4547 },
      -1,
   } },

   /* replace1610_0 -> 11 in the cache */
   /* replace1610_1_0 -> 243 in the cache */
   /* replace1610_1 -> 4549 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 4549 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1611_0_0 -> 11 in the cache */
   /* search1611_0 -> 1739 in the cache */
   /* search1611_1_0 -> 243 in the cache */
   /* search1611_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1739, 4547 },
      -1,
   } },

   /* replace1611_0 -> 11 in the cache */
   /* replace1611_1_0 -> 243 in the cache */
   /* replace1611_1 -> 4549 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 4549 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1612_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1612_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4557, 4558 },
      -1,
   } },

   /* replace1612_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1612_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4560, 507 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1613_0_0 -> 496 in the cache */
   /* search1613_0 -> 4557 in the cache */
   /* search1613_1_0 -> 507 in the cache */
   /* search1613_1 -> 4558 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4557, 4558 },
      -1,
   } },

   /* replace1613_0_0 -> 496 in the cache */
   /* replace1613_0 -> 4560 in the cache */
   /* replace1613_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4560, 507 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1614_0_0 -> 11 in the cache */
   /* search1614_0 -> 1762 in the cache */
   /* search1614_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1762, 4564 },
      -1,
   } },

   /* replace1614_0 -> 11 in the cache */
   /* replace1614_1_0 -> 243 in the cache */
   /* replace1614_1 -> 4549 in the cache */
   /* replace1614 -> 4550 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1615_0_0 -> 11 in the cache */
   /* search1615_0 -> 1762 in the cache */
   /* search1615_1_0 -> 243 in the cache */
   /* search1615_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1762, 4564 },
      -1,
   } },

   /* replace1615_0 -> 11 in the cache */
   /* replace1615_1_0 -> 243 in the cache */
   /* replace1615_1 -> 4549 in the cache */
   /* replace1615 -> 4552 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1616_0_0 -> 11 in the cache */
   /* search1616_0 -> 1762 in the cache */
   /* search1616_1_0 -> 243 in the cache */
   /* search1616_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1762, 4564 },
      -1,
   } },

   /* replace1616_0 -> 11 in the cache */
   /* replace1616_1_0 -> 243 in the cache */
   /* replace1616_1 -> 4549 in the cache */
   /* replace1616 -> 4554 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1617_0_0 -> 11 in the cache */
   /* search1617_0 -> 1762 in the cache */
   /* search1617_1_0 -> 243 in the cache */
   /* search1617_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1762, 4564 },
      -1,
   } },

   /* replace1617_0 -> 11 in the cache */
   /* replace1617_1_0 -> 243 in the cache */
   /* replace1617_1 -> 4549 in the cache */
   /* replace1617 -> 4556 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1618_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1618_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4569, 4570 },
      -1,
   } },

   /* replace1618_0_0 -> 496 in the cache */
   /* replace1618_0 -> 4560 in the cache */
   /* replace1618_1 -> 507 in the cache */
   /* replace1618 -> 4561 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1619_0_0 -> 496 in the cache */
   /* search1619_0 -> 4569 in the cache */
   /* search1619_1_0 -> 507 in the cache */
   /* search1619_1 -> 4570 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4569, 4570 },
      -1,
   } },

   /* replace1619_0_0 -> 496 in the cache */
   /* replace1619_0 -> 4560 in the cache */
   /* replace1619_1 -> 507 in the cache */
   /* replace1619 -> 4563 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1620_0_0 -> 16 in the cache */
   /* search1620_0 -> 1846 in the cache */
   /* search1620_1_0 -> 243 in the cache */
   /* search1620_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1846, 4564 },
      -1,
   } },

   /* replace1620_0 -> 16 in the cache */
   /* replace1620_1_0 -> 243 in the cache */
   /* replace1620_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4547 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1621_0_0 -> 16 in the cache */
   /* search1621_0 -> 1846 in the cache */
   /* search1621_1_0 -> 243 in the cache */
   /* search1621_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1846, 4564 },
      -1,
   } },

   /* replace1621_0 -> 16 in the cache */
   /* replace1621_1_0 -> 243 in the cache */
   /* replace1621_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4547 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1622_0_0 -> 16 in the cache */
   /* search1622_0 -> 1846 in the cache */
   /* search1622_1_0 -> 243 in the cache */
   /* search1622_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1846, 4564 },
      -1,
   } },

   /* replace1622_0 -> 16 in the cache */
   /* replace1622_1_0 -> 243 in the cache */
   /* replace1622_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4547 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1623_0_0 -> 16 in the cache */
   /* search1623_0 -> 1846 in the cache */
   /* search1623_1_0 -> 243 in the cache */
   /* search1623_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1846, 4564 },
      -1,
   } },

   /* replace1623_0 -> 16 in the cache */
   /* replace1623_1_0 -> 243 in the cache */
   /* replace1623_1 -> 4547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4547 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1624_0_0 -> 496 in the cache */
   /* search1624_0 -> 4569 in the cache */
   /* search1624_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4569, 4581 },
      -1,
   } },

   /* replace1624_0_0 -> 496 in the cache */
   /* replace1624_0 -> 4557 in the cache */
   /* replace1624_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4557, 360 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1625_0_0 -> 496 in the cache */
   /* search1625_0 -> 4569 in the cache */
   /* search1625_1_0 -> 360 in the cache */
   /* search1625_1 -> 4581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4569, 4581 },
      -1,
   } },

   /* replace1625_0_0 -> 496 in the cache */
   /* replace1625_0 -> 4557 in the cache */
   /* replace1625_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4557, 360 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1626_0_0 -> 16 in the cache */
   /* search1626_0 -> 1846 in the cache */
   /* search1626_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1846, 4586 },
      -1,
   } },

   /* replace1626_0 -> 16 in the cache */
   /* replace1626_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4588 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1627_0_0 -> 16 in the cache */
   /* search1627_0 -> 1846 in the cache */
   /* search1627_1_0 -> 36 in the cache */
   /* search1627_1 -> 4586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1846, 4586 },
      -1,
   } },

   /* replace1627_0 -> 16 in the cache */
   /* replace1627_1_0 -> 36 in the cache */
   /* replace1627_1 -> 4588 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4588 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1628_0_0 -> 16 in the cache */
   /* search1628_0 -> 1846 in the cache */
   /* search1628_1_0 -> 36 in the cache */
   /* search1628_1 -> 4586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1846, 4586 },
      -1,
   } },

   /* replace1628_0 -> 16 in the cache */
   /* replace1628_1_0 -> 36 in the cache */
   /* replace1628_1 -> 4588 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4588 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1629_0_0 -> 16 in the cache */
   /* search1629_0 -> 1846 in the cache */
   /* search1629_1_0 -> 36 in the cache */
   /* search1629_1 -> 4586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1846, 4586 },
      -1,
   } },

   /* replace1629_0 -> 16 in the cache */
   /* replace1629_1_0 -> 36 in the cache */
   /* replace1629_1 -> 4588 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4588 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1630_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1630_1_0 -> 360 in the cache */
   /* search1630_1 -> 4581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4596, 4581 },
      -1,
   } },

   /* replace1630_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1630_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4598, 360 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1631_0_0 -> 358 in the cache */
   /* search1631_0 -> 4596 in the cache */
   /* search1631_1_0 -> 360 in the cache */
   /* search1631_1 -> 4581 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4596, 4581 },
      -1,
   } },

   /* replace1631_0_0 -> 358 in the cache */
   /* replace1631_0 -> 4598 in the cache */
   /* replace1631_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4598, 360 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1632_0_0 -> 21 in the cache */
   /* search1632_0_1 -> 2993 in the cache */
   /* search1632_0 -> 2994 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 2994 },
      -1,
   } },

   /* replace1632_0 -> 21 in the cache */
   /* replace1632 -> 2985 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1633_0_0 -> 16 in the cache */
   /* search1633_0_1 -> 806 in the cache */
   /* search1633_0 -> 960 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 960 },
      -1,
   } },

   /* replace1633_0 -> 16 in the cache */
   /* replace1633 -> 2988 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1634_0_0 -> 21 in the cache */
   /* search1634_0_1 -> 4456 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4456 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 4604 },
      -1,
   } },

   /* replace1634_0 -> 21 in the cache */
   /* replace1634 -> 4463 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1635_0_0 -> 11 in the cache */
   /* search1635_0_1 -> 1955 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1955 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4606 },
      -1,
   } },

   /* replace1635_0 -> 11 in the cache */
   /* replace1635 -> 1951 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1636_0_0 -> 16 in the cache */
   /* search1636_0_1 -> 783 in the cache */
   /* search1636_0 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 967 },
      -1,
   } },

   /* replace1636_0 -> 16 in the cache */
   /* replace1636 -> 1967 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1637_0_0 -> 21 in the cache */
   /* search1637_0_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4348 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4609 },
      -1,
   } },

   /* replace1637_0 -> 21 in the cache */
   /* replace1637 -> 4356 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1638_0_0 -> 11 in the cache */
   /* search1638_0 -> 1951 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1951 },
      6,
   } },

   /* replace1638 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1639_0 -> 11 in the cache */
   /* search1639_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 813 },
      6,
   } },

   /* replace1639 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1640_0 -> 502 in the cache */
   /* search1640_1_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4613 },
      -1,
   } },
   /* search1640_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4614, 469 },
      6,
   } },

   /* replace1640_0 -> 502 in the cache */
   /* replace1640_1 -> 507 in the cache */
   /* replace1640_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 507, 469 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1641_0 -> 502 in the cache */
   /* search1641_1_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4617 },
      -1,
   } },
   /* search1641_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4618, 469 },
      6,
   } },

   /* replace1641_0 -> 502 in the cache */
   /* replace1641_1 -> 507 in the cache */
   /* replace1641_2 -> 469 in the cache */
   /* replace1641 -> 4616 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1642_0 -> 502 in the cache */
   /* search1642_1_0 -> 507 in the cache */
   /* search1642_1_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 507, 813 },
      -1,
   } },
   /* search1642_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4620, 469 },
      6,
   } },

   /* replace1642_0 -> 502 in the cache */
   /* replace1642_1 -> 507 in the cache */
   /* replace1642_2 -> 469 in the cache */
   /* replace1642 -> 4616 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1643_0_0_0 -> 11 in the cache */
   /* search1643_0_0 -> 1951 in the cache */
   /* search1643_0 -> 1952 in the cache */
   /* search1643_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1952, 243 },
      6,
   } },

   /* replace1643_0 -> 11 in the cache */
   /* replace1643_1 -> 243 in the cache */
   /* replace1643 -> 3677 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1644_0_0_0 -> 11 in the cache */
   /* search1644_0_0 -> 3933 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3933 },
      -1,
   } },
   /* search1644_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4623, 243 },
      6,
   } },

   /* replace1644_0 -> 11 in the cache */
   /* replace1644_1 -> 243 in the cache */
   /* replace1644 -> 3677 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1645_0_0 -> 11 in the cache */
   /* search1645_0_1 -> 813 in the cache */
   /* search1645_0 -> 3096 in the cache */
   /* search1645_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3096, 243 },
      6,
   } },

   /* replace1645_0 -> 11 in the cache */
   /* replace1645_1 -> 243 in the cache */
   /* replace1645 -> 3677 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1646_0_0_0 -> 11 in the cache */
   /* search1646_0_0 -> 1951 in the cache */
   /* search1646_0 -> 1952 in the cache */
   /* search1646_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1952, 243 },
      6,
   } },

   /* replace1646_0 -> 11 in the cache */
   /* replace1646_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1647_0_0_0 -> 11 in the cache */
   /* search1647_0_0 -> 3933 in the cache */
   /* search1647_0 -> 4623 in the cache */
   /* search1647_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4623, 243 },
      6,
   } },

   /* replace1647_0 -> 11 in the cache */
   /* replace1647_1 -> 243 in the cache */
   /* replace1647 -> 4627 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1648_0_0 -> 11 in the cache */
   /* search1648_0_1 -> 813 in the cache */
   /* search1648_0 -> 3096 in the cache */
   /* search1648_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3096, 243 },
      6,
   } },

   /* replace1648_0 -> 11 in the cache */
   /* replace1648_1 -> 243 in the cache */
   /* replace1648 -> 4627 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1649_0_0_0 -> 11 in the cache */
   /* search1649_0_0 -> 1951 in the cache */
   /* search1649_0 -> 1952 in the cache */
   /* search1649_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1952, 243 },
      6,
   } },

   /* replace1649_0 -> 11 in the cache */
   /* replace1649_1 -> 243 in the cache */
   /* replace1649 -> 1965 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1650_0_0_0 -> 11 in the cache */
   /* search1650_0_0 -> 3933 in the cache */
   /* search1650_0 -> 4623 in the cache */
   /* search1650_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4623, 243 },
      6,
   } },

   /* replace1650_0 -> 11 in the cache */
   /* replace1650_1 -> 243 in the cache */
   /* replace1650 -> 1965 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1651_0_0 -> 11 in the cache */
   /* search1651_0_1 -> 813 in the cache */
   /* search1651_0 -> 3096 in the cache */
   /* search1651_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3096, 243 },
      6,
   } },

   /* replace1651_0 -> 11 in the cache */
   /* replace1651_1 -> 243 in the cache */
   /* replace1651 -> 1965 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1652_0_0_0 -> 11 in the cache */
   /* search1652_0_0 -> 1951 in the cache */
   /* search1652_0 -> 1952 in the cache */
   /* search1652_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1952, 243 },
      6,
   } },

   /* replace1652_0 -> 11 in the cache */
   /* replace1652_1 -> 243 in the cache */
   /* replace1652 -> 2007 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1653_0_0_0 -> 11 in the cache */
   /* search1653_0_0 -> 3933 in the cache */
   /* search1653_0 -> 4623 in the cache */
   /* search1653_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4623, 243 },
      6,
   } },

   /* replace1653_0 -> 11 in the cache */
   /* replace1653_1 -> 243 in the cache */
   /* replace1653 -> 2007 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1654_0_0 -> 11 in the cache */
   /* search1654_0_1 -> 813 in the cache */
   /* search1654_0 -> 3096 in the cache */
   /* search1654_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3096, 243 },
      6,
   } },

   /* replace1654_0 -> 11 in the cache */
   /* replace1654_1 -> 243 in the cache */
   /* replace1654 -> 2007 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1655_0_0_0 -> 11 in the cache */
   /* search1655_0_0 -> 1951 in the cache */
   /* search1655_0 -> 1952 in the cache */
   /* search1655_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1952, 243 },
      6,
   } },

   /* replace1655_0 -> 11 in the cache */
   /* replace1655_1 -> 243 in the cache */
   /* replace1655 -> 2031 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1656_0_0_0 -> 11 in the cache */
   /* search1656_0_0 -> 3933 in the cache */
   /* search1656_0 -> 4623 in the cache */
   /* search1656_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4623, 243 },
      6,
   } },

   /* replace1656_0 -> 11 in the cache */
   /* replace1656_1 -> 243 in the cache */
   /* replace1656 -> 2031 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1657_0_0 -> 11 in the cache */
   /* search1657_0_1 -> 813 in the cache */
   /* search1657_0 -> 3096 in the cache */
   /* search1657_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3096, 243 },
      6,
   } },

   /* replace1657_0 -> 11 in the cache */
   /* replace1657_1 -> 243 in the cache */
   /* replace1657 -> 2031 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1658_0_0 -> 11 in the cache */
   /* search1658_0 -> 1951 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1951 },
      6,
   } },

   /* replace1658 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1659_0 -> 11 in the cache */
   /* search1659_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 813 },
      6,
   } },

   /* replace1659 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1660_0 -> 502 in the cache */
   /* search1660_1_0_0 -> 507 in the cache */
   /* search1660_1_0 -> 4613 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4613 },
      -1,
   } },
   /* search1660_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4641, 469 },
      6,
   } },

   /* replace1660_0 -> 502 in the cache */
   /* replace1660_1 -> 507 in the cache */
   /* replace1660_2 -> 469 in the cache */
   /* replace1660 -> 4616 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1661_0 -> 502 in the cache */
   /* search1661_1_0_0 -> 507 in the cache */
   /* search1661_1_0 -> 4617 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4617 },
      -1,
   } },
   /* search1661_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4643, 469 },
      6,
   } },

   /* replace1661_0 -> 502 in the cache */
   /* replace1661_1 -> 507 in the cache */
   /* replace1661_2 -> 469 in the cache */
   /* replace1661 -> 4616 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1662_0 -> 502 in the cache */
   /* search1662_1_0 -> 507 in the cache */
   /* search1662_1_1 -> 813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 507, 813 },
      -1,
   } },
   /* search1662_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4645, 469 },
      6,
   } },

   /* replace1662_0 -> 502 in the cache */
   /* replace1662_1 -> 507 in the cache */
   /* replace1662_2 -> 469 in the cache */
   /* replace1662 -> 4616 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1663_0_0_0 -> 11 in the cache */
   /* search1663_0_0 -> 1951 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1951 },
      -1,
   } },
   /* search1663_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4647, 243 },
      6,
   } },

   /* replace1663_0 -> 11 in the cache */
   /* replace1663_1 -> 243 in the cache */
   /* replace1663 -> 3677 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1664_0_0_0 -> 11 in the cache */
   /* search1664_0_0 -> 3933 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3933 },
      -1,
   } },
   /* search1664_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4649, 243 },
      6,
   } },

   /* replace1664_0 -> 11 in the cache */
   /* replace1664_1 -> 243 in the cache */
   /* replace1664 -> 3677 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1665_0_0 -> 11 in the cache */
   /* search1665_0_1 -> 813 in the cache */
   /* search1665_0 -> 3117 in the cache */
   /* search1665_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3117, 243 },
      6,
   } },

   /* replace1665_0 -> 11 in the cache */
   /* replace1665_1 -> 243 in the cache */
   /* replace1665 -> 3677 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1666_0_0_0 -> 11 in the cache */
   /* search1666_0_0 -> 1951 in the cache */
   /* search1666_0 -> 4647 in the cache */
   /* search1666_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4647, 243 },
      6,
   } },

   /* replace1666_0 -> 11 in the cache */
   /* replace1666_1 -> 243 in the cache */
   /* replace1666 -> 4627 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1667_0_0_0 -> 11 in the cache */
   /* search1667_0_0 -> 3933 in the cache */
   /* search1667_0 -> 4649 in the cache */
   /* search1667_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4649, 243 },
      6,
   } },

   /* replace1667_0 -> 11 in the cache */
   /* replace1667_1 -> 243 in the cache */
   /* replace1667 -> 4627 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1668_0_0 -> 11 in the cache */
   /* search1668_0_1 -> 813 in the cache */
   /* search1668_0 -> 3117 in the cache */
   /* search1668_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3117, 243 },
      6,
   } },

   /* replace1668_0 -> 11 in the cache */
   /* replace1668_1 -> 243 in the cache */
   /* replace1668 -> 4627 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1669_0_0_0 -> 11 in the cache */
   /* search1669_0_0 -> 1951 in the cache */
   /* search1669_0 -> 4647 in the cache */
   /* search1669_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4647, 243 },
      6,
   } },

   /* replace1669_0 -> 11 in the cache */
   /* replace1669_1 -> 243 in the cache */
   /* replace1669 -> 1965 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1670_0_0_0 -> 11 in the cache */
   /* search1670_0_0 -> 3933 in the cache */
   /* search1670_0 -> 4649 in the cache */
   /* search1670_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4649, 243 },
      6,
   } },

   /* replace1670_0 -> 11 in the cache */
   /* replace1670_1 -> 243 in the cache */
   /* replace1670 -> 1965 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1671_0_0 -> 11 in the cache */
   /* search1671_0_1 -> 813 in the cache */
   /* search1671_0 -> 3117 in the cache */
   /* search1671_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3117, 243 },
      6,
   } },

   /* replace1671_0 -> 11 in the cache */
   /* replace1671_1 -> 243 in the cache */
   /* replace1671 -> 1965 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1672_0_0_0 -> 11 in the cache */
   /* search1672_0_0 -> 1951 in the cache */
   /* search1672_0 -> 4647 in the cache */
   /* search1672_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4647, 243 },
      6,
   } },

   /* replace1672_0 -> 11 in the cache */
   /* replace1672_1 -> 243 in the cache */
   /* replace1672 -> 2007 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1673_0_0_0 -> 11 in the cache */
   /* search1673_0_0 -> 3933 in the cache */
   /* search1673_0 -> 4649 in the cache */
   /* search1673_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4649, 243 },
      6,
   } },

   /* replace1673_0 -> 11 in the cache */
   /* replace1673_1 -> 243 in the cache */
   /* replace1673 -> 2007 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1674_0_0 -> 11 in the cache */
   /* search1674_0_1 -> 813 in the cache */
   /* search1674_0 -> 3117 in the cache */
   /* search1674_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3117, 243 },
      6,
   } },

   /* replace1674_0 -> 11 in the cache */
   /* replace1674_1 -> 243 in the cache */
   /* replace1674 -> 2007 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1675_0_0_0 -> 11 in the cache */
   /* search1675_0_0 -> 1951 in the cache */
   /* search1675_0 -> 4647 in the cache */
   /* search1675_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4647, 243 },
      6,
   } },

   /* replace1675_0 -> 11 in the cache */
   /* replace1675_1 -> 243 in the cache */
   /* replace1675 -> 2031 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1676_0_0_0 -> 11 in the cache */
   /* search1676_0_0 -> 3933 in the cache */
   /* search1676_0 -> 4649 in the cache */
   /* search1676_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4649, 243 },
      6,
   } },

   /* replace1676_0 -> 11 in the cache */
   /* replace1676_1 -> 243 in the cache */
   /* replace1676 -> 2031 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1677_0_0 -> 11 in the cache */
   /* search1677_0_1 -> 813 in the cache */
   /* search1677_0 -> 3117 in the cache */
   /* search1677_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3117, 243 },
      6,
   } },

   /* replace1677_0 -> 11 in the cache */
   /* replace1677_1 -> 243 in the cache */
   /* replace1677 -> 2031 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1678_0_0 -> 16 in the cache */
   /* search1678_0 -> 1967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1967 },
      6,
   } },

   /* replace1678 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1679_0 -> 16 in the cache */
   /* search1679_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1679 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1680_0 -> 502 in the cache */
   /* search1680_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4666 },
      -1,
   } },
   /* search1680_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4667, 540 },
      6,
   } },

   /* replace1680_0 -> 502 in the cache */
   /* replace1680_1 -> 360 in the cache */
   /* replace1680_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 360, 540 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1681_0 -> 502 in the cache */
   /* search1681_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4670 },
      -1,
   } },
   /* search1681_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4671, 540 },
      6,
   } },

   /* replace1681_0 -> 502 in the cache */
   /* replace1681_1 -> 360 in the cache */
   /* replace1681_2 -> 540 in the cache */
   /* replace1681 -> 4669 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1682_0 -> 502 in the cache */
   /* search1682_1_0 -> 360 in the cache */
   /* search1682_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1682_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4673, 540 },
      6,
   } },

   /* replace1682_0 -> 502 in the cache */
   /* replace1682_1 -> 360 in the cache */
   /* replace1682_2 -> 540 in the cache */
   /* replace1682 -> 4669 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1683_0_0_0 -> 16 in the cache */
   /* search1683_0_0 -> 1967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1967 },
      -1,
   } },
   /* search1683_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4675, 36 },
      6,
   } },

   /* replace1683_0 -> 16 in the cache */
   /* replace1683_1 -> 36 in the cache */
   /* replace1683 -> 3697 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1684_0_0_0 -> 16 in the cache */
   /* search1684_0_0 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3885 },
      -1,
   } },
   /* search1684_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4677, 36 },
      6,
   } },

   /* replace1684_0 -> 16 in the cache */
   /* replace1684_1 -> 36 in the cache */
   /* replace1684 -> 3697 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1685_0_0 -> 16 in the cache */
   /* search1685_0_1 -> 120 in the cache */
   /* search1685_0 -> 393 in the cache */
   /* search1685_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1685_0 -> 16 in the cache */
   /* replace1685_1 -> 36 in the cache */
   /* replace1685 -> 3697 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1686_0_0_0 -> 16 in the cache */
   /* search1686_0_0 -> 1967 in the cache */
   /* search1686_0 -> 4675 in the cache */
   /* search1686_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4675, 36 },
      6,
   } },

   /* replace1686_0 -> 16 in the cache */
   /* replace1686_1 -> 36 in the cache */
   /* replace1686 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1687_0_0_0 -> 16 in the cache */
   /* search1687_0_0 -> 3885 in the cache */
   /* search1687_0 -> 4677 in the cache */
   /* search1687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4677, 36 },
      6,
   } },

   /* replace1687_0 -> 16 in the cache */
   /* replace1687_1 -> 36 in the cache */
   /* replace1687 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1688_0_0 -> 16 in the cache */
   /* search1688_0_1 -> 120 in the cache */
   /* search1688_0 -> 393 in the cache */
   /* search1688_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1688_0 -> 16 in the cache */
   /* replace1688_1 -> 36 in the cache */
   /* replace1688 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1689_0_0_0 -> 16 in the cache */
   /* search1689_0_0 -> 1967 in the cache */
   /* search1689_0 -> 4675 in the cache */
   /* search1689_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4675, 36 },
      6,
   } },

   /* replace1689_0 -> 16 in the cache */
   /* replace1689_1 -> 36 in the cache */
   /* replace1689 -> 1973 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1690_0_0_0 -> 16 in the cache */
   /* search1690_0_0 -> 3885 in the cache */
   /* search1690_0 -> 4677 in the cache */
   /* search1690_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4677, 36 },
      6,
   } },

   /* replace1690_0 -> 16 in the cache */
   /* replace1690_1 -> 36 in the cache */
   /* replace1690 -> 1973 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1691_0_0 -> 16 in the cache */
   /* search1691_0_1 -> 120 in the cache */
   /* search1691_0 -> 393 in the cache */
   /* search1691_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1691_0 -> 16 in the cache */
   /* replace1691_1 -> 36 in the cache */
   /* replace1691 -> 1973 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1692_0_0_0 -> 16 in the cache */
   /* search1692_0_0 -> 1967 in the cache */
   /* search1692_0 -> 4675 in the cache */
   /* search1692_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4675, 36 },
      6,
   } },

   /* replace1692_0 -> 16 in the cache */
   /* replace1692_1 -> 36 in the cache */
   /* replace1692 -> 2011 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1693_0_0_0 -> 16 in the cache */
   /* search1693_0_0 -> 3885 in the cache */
   /* search1693_0 -> 4677 in the cache */
   /* search1693_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4677, 36 },
      6,
   } },

   /* replace1693_0 -> 16 in the cache */
   /* replace1693_1 -> 36 in the cache */
   /* replace1693 -> 2011 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1694_0_0 -> 16 in the cache */
   /* search1694_0_1 -> 120 in the cache */
   /* search1694_0 -> 393 in the cache */
   /* search1694_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1694_0 -> 16 in the cache */
   /* replace1694_1 -> 36 in the cache */
   /* replace1694 -> 2011 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1695_0_0_0 -> 16 in the cache */
   /* search1695_0_0 -> 1967 in the cache */
   /* search1695_0 -> 4675 in the cache */
   /* search1695_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4675, 36 },
      6,
   } },

   /* replace1695_0 -> 16 in the cache */
   /* replace1695_1 -> 36 in the cache */
   /* replace1695 -> 2035 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1696_0_0_0 -> 16 in the cache */
   /* search1696_0_0 -> 3885 in the cache */
   /* search1696_0 -> 4677 in the cache */
   /* search1696_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4677, 36 },
      6,
   } },

   /* replace1696_0 -> 16 in the cache */
   /* replace1696_1 -> 36 in the cache */
   /* replace1696 -> 2035 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1697_0_0 -> 16 in the cache */
   /* search1697_0_1 -> 120 in the cache */
   /* search1697_0 -> 393 in the cache */
   /* search1697_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1697_0 -> 16 in the cache */
   /* replace1697_1 -> 36 in the cache */
   /* replace1697 -> 2035 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1698_0_0 -> 16 in the cache */
   /* search1698_0 -> 1967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1967 },
      6,
   } },

   /* replace1698 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1699_0 -> 16 in the cache */
   /* search1699_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1699 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1700_0 -> 502 in the cache */
   /* search1700_1_0_0 -> 360 in the cache */
   /* search1700_1_0 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4666 },
      -1,
   } },
   /* search1700_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4694, 540 },
      6,
   } },

   /* replace1700_0 -> 502 in the cache */
   /* replace1700_1 -> 360 in the cache */
   /* replace1700_2 -> 540 in the cache */
   /* replace1700 -> 4669 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1701_0 -> 502 in the cache */
   /* search1701_1_0_0 -> 360 in the cache */
   /* search1701_1_0 -> 4670 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4670 },
      -1,
   } },
   /* search1701_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4696, 540 },
      6,
   } },

   /* replace1701_0 -> 502 in the cache */
   /* replace1701_1 -> 360 in the cache */
   /* replace1701_2 -> 540 in the cache */
   /* replace1701 -> 4669 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1702_0 -> 502 in the cache */
   /* search1702_1_0 -> 360 in the cache */
   /* search1702_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1702_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4698, 540 },
      6,
   } },

   /* replace1702_0 -> 502 in the cache */
   /* replace1702_1 -> 360 in the cache */
   /* replace1702_2 -> 540 in the cache */
   /* replace1702 -> 4669 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1703_0_0_0 -> 16 in the cache */
   /* search1703_0_0 -> 1967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1967 },
      -1,
   } },
   /* search1703_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4700, 36 },
      6,
   } },

   /* replace1703_0 -> 16 in the cache */
   /* replace1703_1 -> 36 in the cache */
   /* replace1703 -> 3697 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1704_0_0_0 -> 16 in the cache */
   /* search1704_0_0 -> 3885 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3885 },
      -1,
   } },
   /* search1704_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4702, 36 },
      6,
   } },

   /* replace1704_0 -> 16 in the cache */
   /* replace1704_1 -> 36 in the cache */
   /* replace1704 -> 3697 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1705_0_0 -> 16 in the cache */
   /* search1705_0_1 -> 120 in the cache */
   /* search1705_0 -> 374 in the cache */
   /* search1705_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1705_0 -> 16 in the cache */
   /* replace1705_1 -> 36 in the cache */
   /* replace1705 -> 3697 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1706_0_0_0 -> 16 in the cache */
   /* search1706_0_0 -> 1967 in the cache */
   /* search1706_0 -> 4700 in the cache */
   /* search1706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4700, 36 },
      6,
   } },

   /* replace1706_0 -> 16 in the cache */
   /* replace1706_1 -> 36 in the cache */
   /* replace1706 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1707_0_0_0 -> 16 in the cache */
   /* search1707_0_0 -> 3885 in the cache */
   /* search1707_0 -> 4702 in the cache */
   /* search1707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4702, 36 },
      6,
   } },

   /* replace1707_0 -> 16 in the cache */
   /* replace1707_1 -> 36 in the cache */
   /* replace1707 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1708_0_0 -> 16 in the cache */
   /* search1708_0_1 -> 120 in the cache */
   /* search1708_0 -> 374 in the cache */
   /* search1708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1708_0 -> 16 in the cache */
   /* replace1708_1 -> 36 in the cache */
   /* replace1708 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1709_0_0_0 -> 16 in the cache */
   /* search1709_0_0 -> 1967 in the cache */
   /* search1709_0 -> 4700 in the cache */
   /* search1709_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4700, 36 },
      6,
   } },

   /* replace1709_0 -> 16 in the cache */
   /* replace1709_1 -> 36 in the cache */
   /* replace1709 -> 1973 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1710_0_0_0 -> 16 in the cache */
   /* search1710_0_0 -> 3885 in the cache */
   /* search1710_0 -> 4702 in the cache */
   /* search1710_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4702, 36 },
      6,
   } },

   /* replace1710_0 -> 16 in the cache */
   /* replace1710_1 -> 36 in the cache */
   /* replace1710 -> 1973 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1711_0_0 -> 16 in the cache */
   /* search1711_0_1 -> 120 in the cache */
   /* search1711_0 -> 374 in the cache */
   /* search1711_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1711_0 -> 16 in the cache */
   /* replace1711_1 -> 36 in the cache */
   /* replace1711 -> 1973 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1712_0_0_0 -> 16 in the cache */
   /* search1712_0_0 -> 1967 in the cache */
   /* search1712_0 -> 4700 in the cache */
   /* search1712_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4700, 36 },
      6,
   } },

   /* replace1712_0 -> 16 in the cache */
   /* replace1712_1 -> 36 in the cache */
   /* replace1712 -> 2011 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1713_0_0_0 -> 16 in the cache */
   /* search1713_0_0 -> 3885 in the cache */
   /* search1713_0 -> 4702 in the cache */
   /* search1713_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4702, 36 },
      6,
   } },

   /* replace1713_0 -> 16 in the cache */
   /* replace1713_1 -> 36 in the cache */
   /* replace1713 -> 2011 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1714_0_0 -> 16 in the cache */
   /* search1714_0_1 -> 120 in the cache */
   /* search1714_0 -> 374 in the cache */
   /* search1714_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1714_0 -> 16 in the cache */
   /* replace1714_1 -> 36 in the cache */
   /* replace1714 -> 2011 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1715_0_0_0 -> 16 in the cache */
   /* search1715_0_0 -> 1967 in the cache */
   /* search1715_0 -> 4700 in the cache */
   /* search1715_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4700, 36 },
      6,
   } },

   /* replace1715_0 -> 16 in the cache */
   /* replace1715_1 -> 36 in the cache */
   /* replace1715 -> 2035 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1716_0_0_0 -> 16 in the cache */
   /* search1716_0_0 -> 3885 in the cache */
   /* search1716_0 -> 4702 in the cache */
   /* search1716_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4702, 36 },
      6,
   } },

   /* replace1716_0 -> 16 in the cache */
   /* replace1716_1 -> 36 in the cache */
   /* replace1716 -> 2035 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1717_0_0 -> 16 in the cache */
   /* search1717_0_1 -> 120 in the cache */
   /* search1717_0 -> 374 in the cache */
   /* search1717_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1717_0 -> 16 in the cache */
   /* replace1717_1 -> 36 in the cache */
   /* replace1717 -> 2035 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1718_0_0 -> 16 in the cache */
   /* search1718_0 -> 2988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2988 },
      7,
   } },

   /* replace1718 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1719_0 -> 16 in the cache */
   /* search1719_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1719 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1720_0 -> 502 in the cache */
   /* search1720_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4719 },
      -1,
   } },
   /* search1720_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4720, 540 },
      7,
   } },

   /* replace1720_0 -> 502 in the cache */
   /* replace1720_1 -> 360 in the cache */
   /* replace1720_2 -> 540 in the cache */
   /* replace1720 -> 4669 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1721_0 -> 502 in the cache */
   /* search1721_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4722 },
      -1,
   } },
   /* search1721_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4723, 540 },
      7,
   } },

   /* replace1721_0 -> 502 in the cache */
   /* replace1721_1 -> 360 in the cache */
   /* replace1721_2 -> 540 in the cache */
   /* replace1721 -> 4669 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1722_0 -> 502 in the cache */
   /* search1722_1_0 -> 360 in the cache */
   /* search1722_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1722_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4725, 540 },
      7,
   } },

   /* replace1722_0 -> 502 in the cache */
   /* replace1722_1 -> 360 in the cache */
   /* replace1722_2 -> 540 in the cache */
   /* replace1722 -> 4669 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1723_0_0_0 -> 16 in the cache */
   /* search1723_0_0 -> 2988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2988 },
      -1,
   } },
   /* search1723_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4727, 36 },
      7,
   } },

   /* replace1723_0 -> 16 in the cache */
   /* replace1723_1 -> 36 in the cache */
   /* replace1723 -> 3697 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1724_0_0_0 -> 16 in the cache */
   /* search1724_0_0 -> 3887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3887 },
      -1,
   } },
   /* search1724_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4729, 36 },
      7,
   } },

   /* replace1724_0 -> 16 in the cache */
   /* replace1724_1 -> 36 in the cache */
   /* replace1724 -> 3697 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1725_0_0 -> 16 in the cache */
   /* search1725_0_1 -> 120 in the cache */
   /* search1725_0 -> 425 in the cache */
   /* search1725_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1725_0 -> 16 in the cache */
   /* replace1725_1 -> 36 in the cache */
   /* replace1725 -> 3697 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1726_0_0_0 -> 16 in the cache */
   /* search1726_0_0 -> 2988 in the cache */
   /* search1726_0 -> 4727 in the cache */
   /* search1726_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4727, 36 },
      7,
   } },

   /* replace1726_0 -> 16 in the cache */
   /* replace1726_1 -> 36 in the cache */
   /* replace1726 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1727_0_0_0 -> 16 in the cache */
   /* search1727_0_0 -> 3887 in the cache */
   /* search1727_0 -> 4729 in the cache */
   /* search1727_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4729, 36 },
      7,
   } },

   /* replace1727_0 -> 16 in the cache */
   /* replace1727_1 -> 36 in the cache */
   /* replace1727 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1728_0_0 -> 16 in the cache */
   /* search1728_0_1 -> 120 in the cache */
   /* search1728_0 -> 425 in the cache */
   /* search1728_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1728_0 -> 16 in the cache */
   /* replace1728_1 -> 36 in the cache */
   /* replace1728 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1729_0_0_0 -> 16 in the cache */
   /* search1729_0_0 -> 2988 in the cache */
   /* search1729_0 -> 4727 in the cache */
   /* search1729_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4727, 36 },
      7,
   } },

   /* replace1729_0 -> 16 in the cache */
   /* replace1729_1 -> 36 in the cache */
   /* replace1729 -> 1973 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1730_0_0_0 -> 16 in the cache */
   /* search1730_0_0 -> 3887 in the cache */
   /* search1730_0 -> 4729 in the cache */
   /* search1730_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4729, 36 },
      7,
   } },

   /* replace1730_0 -> 16 in the cache */
   /* replace1730_1 -> 36 in the cache */
   /* replace1730 -> 1973 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1731_0_0 -> 16 in the cache */
   /* search1731_0_1 -> 120 in the cache */
   /* search1731_0 -> 425 in the cache */
   /* search1731_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1731_0 -> 16 in the cache */
   /* replace1731_1 -> 36 in the cache */
   /* replace1731 -> 1973 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1732_0_0_0 -> 16 in the cache */
   /* search1732_0_0 -> 2988 in the cache */
   /* search1732_0 -> 4727 in the cache */
   /* search1732_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4727, 36 },
      7,
   } },

   /* replace1732_0 -> 16 in the cache */
   /* replace1732_1 -> 36 in the cache */
   /* replace1732 -> 2011 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1733_0_0_0 -> 16 in the cache */
   /* search1733_0_0 -> 3887 in the cache */
   /* search1733_0 -> 4729 in the cache */
   /* search1733_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4729, 36 },
      7,
   } },

   /* replace1733_0 -> 16 in the cache */
   /* replace1733_1 -> 36 in the cache */
   /* replace1733 -> 2011 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1734_0_0 -> 16 in the cache */
   /* search1734_0_1 -> 120 in the cache */
   /* search1734_0 -> 425 in the cache */
   /* search1734_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1734_0 -> 16 in the cache */
   /* replace1734_1 -> 36 in the cache */
   /* replace1734 -> 2011 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1735_0_0_0 -> 16 in the cache */
   /* search1735_0_0 -> 2988 in the cache */
   /* search1735_0 -> 4727 in the cache */
   /* search1735_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4727, 36 },
      7,
   } },

   /* replace1735_0 -> 16 in the cache */
   /* replace1735_1 -> 36 in the cache */
   /* replace1735 -> 2035 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1736_0_0_0 -> 16 in the cache */
   /* search1736_0_0 -> 3887 in the cache */
   /* search1736_0 -> 4729 in the cache */
   /* search1736_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4729, 36 },
      7,
   } },

   /* replace1736_0 -> 16 in the cache */
   /* replace1736_1 -> 36 in the cache */
   /* replace1736 -> 2035 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1737_0_0 -> 16 in the cache */
   /* search1737_0_1 -> 120 in the cache */
   /* search1737_0 -> 425 in the cache */
   /* search1737_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1737_0 -> 16 in the cache */
   /* replace1737_1 -> 36 in the cache */
   /* replace1737 -> 2035 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1738_0_0 -> 16 in the cache */
   /* search1738_0 -> 2988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2988 },
      7,
   } },

   /* replace1738 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1739_0 -> 16 in the cache */
   /* search1739_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1739 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1740_0 -> 502 in the cache */
   /* search1740_1_0_0 -> 360 in the cache */
   /* search1740_1_0 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4719 },
      -1,
   } },
   /* search1740_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4746, 540 },
      7,
   } },

   /* replace1740_0 -> 502 in the cache */
   /* replace1740_1 -> 360 in the cache */
   /* replace1740_2 -> 540 in the cache */
   /* replace1740 -> 4669 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1741_0 -> 502 in the cache */
   /* search1741_1_0_0 -> 360 in the cache */
   /* search1741_1_0 -> 4722 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4722 },
      -1,
   } },
   /* search1741_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4748, 540 },
      7,
   } },

   /* replace1741_0 -> 502 in the cache */
   /* replace1741_1 -> 360 in the cache */
   /* replace1741_2 -> 540 in the cache */
   /* replace1741 -> 4669 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1742_0 -> 502 in the cache */
   /* search1742_1_0 -> 360 in the cache */
   /* search1742_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1742_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4750, 540 },
      7,
   } },

   /* replace1742_0 -> 502 in the cache */
   /* replace1742_1 -> 360 in the cache */
   /* replace1742_2 -> 540 in the cache */
   /* replace1742 -> 4669 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1743_0_0_0 -> 16 in the cache */
   /* search1743_0_0 -> 2988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2988 },
      -1,
   } },
   /* search1743_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4752, 36 },
      7,
   } },

   /* replace1743_0 -> 16 in the cache */
   /* replace1743_1 -> 36 in the cache */
   /* replace1743 -> 3697 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1744_0_0_0 -> 16 in the cache */
   /* search1744_0_0 -> 3887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3887 },
      -1,
   } },
   /* search1744_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4754, 36 },
      7,
   } },

   /* replace1744_0 -> 16 in the cache */
   /* replace1744_1 -> 36 in the cache */
   /* replace1744 -> 3697 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1745_0_0 -> 16 in the cache */
   /* search1745_0_1 -> 120 in the cache */
   /* search1745_0 -> 417 in the cache */
   /* search1745_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1745_0 -> 16 in the cache */
   /* replace1745_1 -> 36 in the cache */
   /* replace1745 -> 3697 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1746_0_0_0 -> 16 in the cache */
   /* search1746_0_0 -> 2988 in the cache */
   /* search1746_0 -> 4752 in the cache */
   /* search1746_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4752, 36 },
      7,
   } },

   /* replace1746_0 -> 16 in the cache */
   /* replace1746_1 -> 36 in the cache */
   /* replace1746 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1747_0_0_0 -> 16 in the cache */
   /* search1747_0_0 -> 3887 in the cache */
   /* search1747_0 -> 4754 in the cache */
   /* search1747_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4754, 36 },
      7,
   } },

   /* replace1747_0 -> 16 in the cache */
   /* replace1747_1 -> 36 in the cache */
   /* replace1747 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1748_0_0 -> 16 in the cache */
   /* search1748_0_1 -> 120 in the cache */
   /* search1748_0 -> 417 in the cache */
   /* search1748_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1748_0 -> 16 in the cache */
   /* replace1748_1 -> 36 in the cache */
   /* replace1748 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1749_0_0_0 -> 16 in the cache */
   /* search1749_0_0 -> 2988 in the cache */
   /* search1749_0 -> 4752 in the cache */
   /* search1749_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4752, 36 },
      7,
   } },

   /* replace1749_0 -> 16 in the cache */
   /* replace1749_1 -> 36 in the cache */
   /* replace1749 -> 1973 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1750_0_0_0 -> 16 in the cache */
   /* search1750_0_0 -> 3887 in the cache */
   /* search1750_0 -> 4754 in the cache */
   /* search1750_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4754, 36 },
      7,
   } },

   /* replace1750_0 -> 16 in the cache */
   /* replace1750_1 -> 36 in the cache */
   /* replace1750 -> 1973 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1751_0_0 -> 16 in the cache */
   /* search1751_0_1 -> 120 in the cache */
   /* search1751_0 -> 417 in the cache */
   /* search1751_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1751_0 -> 16 in the cache */
   /* replace1751_1 -> 36 in the cache */
   /* replace1751 -> 1973 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1752_0_0_0 -> 16 in the cache */
   /* search1752_0_0 -> 2988 in the cache */
   /* search1752_0 -> 4752 in the cache */
   /* search1752_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4752, 36 },
      7,
   } },

   /* replace1752_0 -> 16 in the cache */
   /* replace1752_1 -> 36 in the cache */
   /* replace1752 -> 2011 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1753_0_0_0 -> 16 in the cache */
   /* search1753_0_0 -> 3887 in the cache */
   /* search1753_0 -> 4754 in the cache */
   /* search1753_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4754, 36 },
      7,
   } },

   /* replace1753_0 -> 16 in the cache */
   /* replace1753_1 -> 36 in the cache */
   /* replace1753 -> 2011 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1754_0_0 -> 16 in the cache */
   /* search1754_0_1 -> 120 in the cache */
   /* search1754_0 -> 417 in the cache */
   /* search1754_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1754_0 -> 16 in the cache */
   /* replace1754_1 -> 36 in the cache */
   /* replace1754 -> 2011 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1755_0_0_0 -> 16 in the cache */
   /* search1755_0_0 -> 2988 in the cache */
   /* search1755_0 -> 4752 in the cache */
   /* search1755_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4752, 36 },
      7,
   } },

   /* replace1755_0 -> 16 in the cache */
   /* replace1755_1 -> 36 in the cache */
   /* replace1755 -> 2035 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1756_0_0_0 -> 16 in the cache */
   /* search1756_0_0 -> 3887 in the cache */
   /* search1756_0 -> 4754 in the cache */
   /* search1756_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4754, 36 },
      7,
   } },

   /* replace1756_0 -> 16 in the cache */
   /* replace1756_1 -> 36 in the cache */
   /* replace1756 -> 2035 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1757_0_0 -> 16 in the cache */
   /* search1757_0_1 -> 120 in the cache */
   /* search1757_0 -> 417 in the cache */
   /* search1757_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1757_0 -> 16 in the cache */
   /* replace1757_1 -> 36 in the cache */
   /* replace1757 -> 2035 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4769, 4770 },
      -1,
   } },

   /* replace1758_0_0 -> 4769 in the cache */
   /* replace1758_0_1_0_0_0_0_0_0 -> 4770 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4770, 4772 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4773, 4774 },
      -1,
   } },
   /* replace1758_0_1_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4775, 377 },
      -1,
   } },
   /* replace1758_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4776, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4777, 4778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 4779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4769, 4780 },
      -1,
   } },
   /* replace1758_1_0_0_0_0_0_0 -> 4770 in the cache */
   /* replace1758_1_0_0_0_0_0_1 -> 4772 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4770, 4772 },
      -1,
   } },
   /* replace1758_1_0_0_0_0_1 -> 4774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4782, 4774 },
      -1,
   } },
   /* replace1758_1_0_0_0_1_0_0_0 -> 4770 in the cache */
   /* replace1758_1_0_0_0_1_0_0_1 -> 4772 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4770, 4772 },
      -1,
   } },
   /* replace1758_1_0_0_0_1_0_1 -> 4774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4784, 4774 },
      -1,
   } },
   /* replace1758_1_0_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4785, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4783, 4786 },
      -1,
   } },
   /* replace1758_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4787, 14 },
      -1,
   } },
   /* replace1758_1_0_1 -> 4778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4788, 4778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 4789 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4781, 4790 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1759_1 -> 4770 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4792, 4770 },
      -1,
   } },

   /* replace1759_0_0 -> 4792 in the cache */
   /* replace1759_0_1_0_0_0_0_0 -> 4770 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4770, 4794 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4795, 4796 },
      -1,
   } },
   /* replace1759_0_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4797, 377 },
      -1,
   } },
   /* replace1759_0_1_0_1 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4798, 3971 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4799, 4800 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4792, 4801 },
      -1,
   } },
   /* replace1759_1_0_0_0_0_0 -> 4770 in the cache */
   /* replace1759_1_0_0_0_0_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4770, 4794 },
      -1,
   } },
   /* replace1759_1_0_0_0_1 -> 4796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4803, 4796 },
      -1,
   } },
   /* replace1759_1_0_0_1_0_0_0 -> 4770 in the cache */
   /* replace1759_1_0_0_1_0_0_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4770, 4794 },
      -1,
   } },
   /* replace1759_1_0_0_1_0_1 -> 4796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4805, 4796 },
      -1,
   } },
   /* replace1759_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4806, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4804, 4807 },
      -1,
   } },
   /* replace1759_1_0_1 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4808, 3971 },
      -1,
   } },
   /* replace1759_1_1 -> 4800 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4809, 4800 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4802, 4810 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1760_1 -> 4770 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4812, 4770 },
      -1,
   } },

   /* replace1760_0_0 -> 4812 in the cache */
   /* replace1760_0_1_0 -> 120 in the cache */
   /* replace1760_0_1_1_0_0_0_0_0 -> 4770 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4770, 4814 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4815, 4816 },
      -1,
   } },
   /* replace1760_0_1_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4817, 377 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4818, 4819 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4820, 4821 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 120, 4822 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4812, 4823 },
      -1,
   } },
   /* replace1760_1_0 -> 120 in the cache */
   /* replace1760_1_1_0_0_0_0_0 -> 4770 in the cache */
   /* replace1760_1_1_0_0_0_0_1 -> 4814 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4770, 4814 },
      -1,
   } },
   /* replace1760_1_1_0_0_0_1 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4825, 4816 },
      -1,
   } },
   /* replace1760_1_1_0_0_1_0_0_0 -> 4770 in the cache */
   /* replace1760_1_1_0_0_1_0_0_1 -> 4814 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4770, 4814 },
      -1,
   } },
   /* replace1760_1_1_0_0_1_0_1 -> 4816 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4827, 4816 },
      -1,
   } },
   /* replace1760_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4828, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4826, 4829 },
      -1,
   } },
   /* replace1760_1_1_0_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4830, 4819 },
      -1,
   } },
   /* replace1760_1_1_1 -> 4821 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4831, 4821 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 120, 4832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4824, 4833 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4792, 810 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 4792, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 4835, 4836 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 4837, 4838 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4839, 787 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 4835, 4836 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 4841, 4842 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_0_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4843, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 4840, 4844 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 4845, 4846 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4847, 4848 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 4850, 4838 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4851, 787 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 4853, 4842 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4854, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 4852, 4855 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 4856, 4857 },
      -1,
   } },
   /* search1761_0_0_0_0_0_0_1_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4858, 4848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 4849, 4859 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 4860, 4861 },
      -1,
   } },
   /* search1761_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 4862, 382 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 4864, 4838 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4865, 787 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 4867, 4842 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4868, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 4866, 4869 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_0_1 -> 4846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 4870, 4846 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4871, 4848 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 4873, 4838 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4874, 787 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 4876, 4842 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4877, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 4875, 4878 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 4879, 4857 },
      -1,
   } },
   /* search1761_0_0_0_1_0_0_1_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4880, 4848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 4872, 4881 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 4882, 4883 },
      -1,
   } },
   /* search1761_0_0_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 4884, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 4863, 4885 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 4886, 4887 },
      -1,
   } },
   /* search1761_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 4888, 377 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 4890, 4838 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4891, 787 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 4893, 4842 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4894, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 4892, 4895 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_0_1 -> 4846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 4896, 4846 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4897, 4848 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 4899, 4838 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4900, 787 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 4902, 4842 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4903, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 4901, 4904 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 4905, 4857 },
      -1,
   } },
   /* search1761_1_0_0_0_0_0_1_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4906, 4848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 4898, 4907 },
      -1,
   } },
   /* search1761_1_0_0_0_0_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 4908, 4861 },
      -1,
   } },
   /* search1761_1_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 4909, 382 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 4911, 4838 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4912, 787 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 4914, 4842 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4915, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 4913, 4916 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_0_1 -> 4846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 4917, 4846 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4918, 4848 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_0_0_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 4920, 4838 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4921, 787 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 4835, 4836 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_1_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 4923, 4842 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_0_1_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4924, 787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 4922, 4925 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 4926, 4857 },
      -1,
   } },
   /* search1761_1_0_0_1_0_0_1_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4927, 4848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 4919, 4928 },
      -1,
   } },
   /* search1761_1_0_0_1_0_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 4929, 4883 },
      -1,
   } },
   /* search1761_1_0_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 4930, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 4910, 4931 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 4932, 4933 },
      -1,
   } },
   /* search1761_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 4934, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 4889, 4935 },
      -1,
   } },

   /* replace1761_0 -> 4792 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 4792 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_0 -> 4837 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4837, 377 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_0_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 4938, 4933 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_0 -> 4841 in the cache */
   /* search1762_0_0_0_0_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4841, 377 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_0_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 4940, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 4939, 4941 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4942, 382 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_0_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 4943, 4883 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_0 -> 4850 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4850, 377 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_1_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 4945, 4933 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_0 -> 4853 in the cache */
   /* search1762_0_0_0_0_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4853, 377 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_1_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 4947, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 4946, 4948 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4949, 382 },
      -1,
   } },
   /* search1762_0_0_0_0_0_0_1_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 4950, 4861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 4944, 4951 },
      -1,
   } },
   /* search1762_0_0_0_0_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 4952, 4848 },
      -1,
   } },
   /* search1762_0_0_0_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 4953, 4857 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_0 -> 4864 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4864, 377 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_0_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 4955, 4933 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_0 -> 4867 in the cache */
   /* search1762_0_0_0_1_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4867, 377 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_0_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 4957, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 4956, 4958 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4959, 382 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_0_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 4960, 4883 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_0 -> 4873 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4873, 377 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_1_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 4962, 4933 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_0 -> 4876 in the cache */
   /* search1762_0_0_0_1_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4876, 377 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_1_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 4964, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 4963, 4965 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4966, 382 },
      -1,
   } },
   /* search1762_0_0_0_1_0_0_1_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 4967, 4861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 4961, 4968 },
      -1,
   } },
   /* search1762_0_0_0_1_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 4969, 4848 },
      -1,
   } },
   /* search1762_0_0_0_1_1 -> 4846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 4970, 4846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 4954, 4971 },
      -1,
   } },
   /* search1762_0_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 4972, 787 },
      -1,
   } },
   /* search1762_0_1 -> 4842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 4973, 4842 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_0 -> 4890 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4890, 377 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_0_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 4975, 4933 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_0 -> 4893 in the cache */
   /* search1762_1_0_0_0_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4893, 377 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_0_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 4977, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 4976, 4978 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4979, 382 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_0_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 4980, 4883 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_0 -> 4899 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4899, 377 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_1_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 4982, 4933 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_0 -> 4902 in the cache */
   /* search1762_1_0_0_0_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4902, 377 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_1_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 4984, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 4983, 4985 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4986, 382 },
      -1,
   } },
   /* search1762_1_0_0_0_0_0_1_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 4987, 4861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 4981, 4988 },
      -1,
   } },
   /* search1762_1_0_0_0_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 4989, 4848 },
      -1,
   } },
   /* search1762_1_0_0_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 4990, 4857 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_0 -> 4911 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4911, 377 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_0_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 4992, 4933 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_0 -> 4914 in the cache */
   /* search1762_1_0_0_1_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4914, 377 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_0_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 4994, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 4993, 4995 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4996, 382 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_0_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 4997, 4883 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_0 -> 4920 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4920, 377 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_1_0_0_0_1 -> 4933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 4999, 4933 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4835 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4792 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4836 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_0 -> 4923 in the cache */
   /* search1762_1_0_0_1_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4923, 377 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_1_0_0_1_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5001, 4887 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5000, 5002 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5003, 382 },
      -1,
   } },
   /* search1762_1_0_0_1_0_0_1_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5004, 4861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 4998, 5005 },
      -1,
   } },
   /* search1762_1_0_0_1_0_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5006, 4848 },
      -1,
   } },
   /* search1762_1_0_0_1_1 -> 4846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5007, 4846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 4991, 5008 },
      -1,
   } },
   /* search1762_1_0_1 -> 787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 5009, 787 },
      -1,
   } },
   /* search1762_1_1 -> 4838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5010, 4838 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 4974, 5011 },
      -1,
   } },

   /* replace1762_0 -> 4792 in the cache */
   /* replace1762 -> 4937 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1763_0_0 -> 0 in the cache */
   /* search1763_0_1 -> 3 in the cache */
   /* search1763_0 -> 1036 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1036, 5013 },
      -1,
   } },

   /* replace1763_0 -> 0 in the cache */
   /* replace1763_1 -> 3 in the cache */
   /* replace1763 -> 2351 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1764_0_0 -> 0 in the cache */
   /* search1764_0_1 -> 3 in the cache */
   /* search1764_0 -> 1030 in the cache */
   /* search1764_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1030, 5013 },
      -1,
   } },

   /* replace1764_0 -> 0 in the cache */
   /* replace1764_1 -> 3 in the cache */
   /* replace1764 -> 2386 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1765_0_0 -> 0 in the cache */
   /* search1765_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 5016, 5017 },
      -1,
   } },

   /* replace1765_0 -> 0 in the cache */
   /* replace1765_1 -> 3 in the cache */
   /* replace1765 -> 2371 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1766_0_0 -> 0 in the cache */
   /* search1766_0_1 -> 3 in the cache */
   /* search1766_0 -> 3729 in the cache */
   /* search1766_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 3729, 5017 },
      -1,
   } },

   /* replace1766_0 -> 0 in the cache */
   /* replace1766_1 -> 3 in the cache */
   /* replace1766 -> 2401 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1767_0_0 -> 0 in the cache */
   /* search1767_0_1 -> 3 in the cache */
   /* search1767_0 -> 1036 in the cache */
   /* search1767_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1036, 5013 },
      -1,
   } },

   /* replace1767_0 -> 0 in the cache */
   /* replace1767_1 -> 3 in the cache */
   /* replace1767 -> 2357 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1768_0_0 -> 0 in the cache */
   /* search1768_0_1 -> 3 in the cache */
   /* search1768_0 -> 1030 in the cache */
   /* search1768_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1030, 5013 },
      -1,
   } },

   /* replace1768_0 -> 0 in the cache */
   /* replace1768_1 -> 3 in the cache */
   /* replace1768 -> 2390 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1769_0_0 -> 0 in the cache */
   /* search1769_0_1 -> 3 in the cache */
   /* search1769_0 -> 5016 in the cache */
   /* search1769_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 5016, 5017 },
      -1,
   } },

   /* replace1769_0 -> 0 in the cache */
   /* replace1769_1 -> 3 in the cache */
   /* replace1769 -> 2375 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1770_0_0 -> 0 in the cache */
   /* search1770_0_1 -> 3 in the cache */
   /* search1770_0 -> 3729 in the cache */
   /* search1770_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 3729, 5017 },
      -1,
   } },

   /* replace1770_0 -> 0 in the cache */
   /* replace1770_1 -> 3 in the cache */
   /* replace1770 -> 2405 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1771_0_0 -> 0 in the cache */
   /* search1771_0_1 -> 3 in the cache */
   /* search1771_0 -> 1036 in the cache */
   /* search1771_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1036, 5013 },
      -1,
   } },

   /* replace1771_0 -> 0 in the cache */
   /* replace1771_1 -> 3 in the cache */
   /* replace1771 -> 2364 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1772_0_0 -> 0 in the cache */
   /* search1772_0_1 -> 3 in the cache */
   /* search1772_0 -> 1030 in the cache */
   /* search1772_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1030, 5013 },
      -1,
   } },

   /* replace1772_0 -> 0 in the cache */
   /* replace1772_1 -> 3 in the cache */
   /* replace1772 -> 2396 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1773_0_0 -> 0 in the cache */
   /* search1773_0_1 -> 3 in the cache */
   /* search1773_0 -> 5016 in the cache */
   /* search1773_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 5016, 5017 },
      -1,
   } },

   /* replace1773_0 -> 0 in the cache */
   /* replace1773_1 -> 3 in the cache */
   /* replace1773 -> 2381 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1774_0_0 -> 0 in the cache */
   /* search1774_0_1 -> 3 in the cache */
   /* search1774_0 -> 3729 in the cache */
   /* search1774_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 3729, 5017 },
      -1,
   } },

   /* replace1774_0 -> 0 in the cache */
   /* replace1774_1 -> 3 in the cache */
   /* replace1774 -> 2411 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1775_0_0 -> 0 in the cache */
   /* search1775_0_1 -> 3 in the cache */
   /* search1775_0 -> 1036 in the cache */
   /* search1775_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1036, 5013 },
      -1,
   } },

   /* replace1775_0 -> 0 in the cache */
   /* replace1775_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1776_0_0 -> 0 in the cache */
   /* search1776_0_1 -> 3 in the cache */
   /* search1776_0 -> 1030 in the cache */
   /* search1776_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1030, 5013 },
      -1,
   } },

   /* replace1776_0 -> 0 in the cache */
   /* replace1776_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1777_0_0 -> 0 in the cache */
   /* search1777_0_1 -> 3 in the cache */
   /* search1777_0 -> 5016 in the cache */
   /* search1777_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 5016, 5017 },
      -1,
   } },

   /* replace1777_0 -> 0 in the cache */
   /* replace1777_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1778_0_0 -> 0 in the cache */
   /* search1778_0_1 -> 3 in the cache */
   /* search1778_0 -> 3729 in the cache */
   /* search1778_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 3729, 5017 },
      -1,
   } },

   /* replace1778_0 -> 0 in the cache */
   /* replace1778_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1779_0_0 -> 0 in the cache */
   /* search1779_0_1 -> 3 in the cache */
   /* search1779_0 -> 1036 in the cache */
   /* search1779_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1036, 5013 },
      -1,
   } },

   /* replace1779_0 -> 0 in the cache */
   /* replace1779_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1780_0_0 -> 0 in the cache */
   /* search1780_0_1 -> 3 in the cache */
   /* search1780_0 -> 1030 in the cache */
   /* search1780_1 -> 5013 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1030, 5013 },
      -1,
   } },

   /* replace1780_0 -> 0 in the cache */
   /* replace1780_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1781_0_0 -> 0 in the cache */
   /* search1781_0_1 -> 3 in the cache */
   /* search1781_0 -> 5016 in the cache */
   /* search1781_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 5016, 5017 },
      -1,
   } },

   /* replace1781_0 -> 0 in the cache */
   /* replace1781_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1782_0_0 -> 0 in the cache */
   /* search1782_0_1 -> 3 in the cache */
   /* search1782_0 -> 3729 in the cache */
   /* search1782_1 -> 5017 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 3729, 5017 },
      -1,
   } },

   /* replace1782_0 -> 0 in the cache */
   /* replace1782_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1783_0_0 -> 0 in the cache */
   /* search1783_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1783_1_0 -> 0 in the cache */
   /* search1783_1_1 -> 3 in the cache */
   /* search1783_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5044, 1005 },
      -1,
   } },

   /* replace1783_0 -> 0 in the cache */
   /* replace1783_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1784_0_0 -> 32 in the cache */
   /* search1784_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1784_1_0 -> 2196 in the cache */
   /* search1784_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5047, 5048 },
      -1,
   } },

   /* replace1784_0 -> 2196 in the cache */
   /* replace1784_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 2196, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1785_0_0 -> 0 in the cache */
   /* search1785_0_1 -> 0 in the cache */
   /* search1785_0 -> 5044 in the cache */
   /* search1785_1_0 -> 0 in the cache */
   /* search1785_1_1 -> 3 in the cache */
   /* search1785_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5044, 1002 },
      -1,
   } },

   /* replace1785_0 -> 0 in the cache */
   /* replace1785_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1786_0_0 -> 32 in the cache */
   /* search1786_0_1 -> 32 in the cache */
   /* search1786_0 -> 5047 in the cache */
   /* search1786_1_0 -> 2196 in the cache */
   /* search1786_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5047, 5053 },
      -1,
   } },

   /* replace1786_0 -> 2196 in the cache */
   /* replace1786_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 2196, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1787_0_0 -> 0 in the cache */
   /* search1787_0_1 -> 0 in the cache */
   /* search1787_0 -> 5044 in the cache */
   /* search1787_1_0 -> 0 in the cache */
   /* search1787_1_1 -> 3 in the cache */
   /* search1787_1 -> 1030 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5044, 1030 },
      -1,
   } },

   /* replace1787_0 -> 0 in the cache */
   /* replace1787_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1788_0_0 -> 32 in the cache */
   /* search1788_0_1 -> 32 in the cache */
   /* search1788_0 -> 5047 in the cache */
   /* search1788_1_0 -> 2196 in the cache */
   /* search1788_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2196, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5047, 5058 },
      -1,
   } },

   /* replace1788_0 -> 2196 in the cache */
   /* replace1788_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 2196, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1789_0_0 -> 715 in the cache */
   /* search1789_0_1 -> 984 in the cache */
   /* search1789_0_2 -> 3176 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 984, 3176 },
      -1,
   } },
   /* search1789_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 5061, 987 },
      -1,
   } },

   /* replace1789_0 -> 715 in the cache */
   /* replace1789_1_0 -> 148 in the cache */
   /* replace1789_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1789_2_0 -> 150 in the cache */
   /* replace1789_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5063, 5064 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1790_0_0 -> 715 in the cache */
   /* search1790_0_1 -> 984 in the cache */
   /* search1790_0_2 -> 3176 in the cache */
   /* search1790_0 -> 5061 in the cache */
   /* search1790_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 5061, 987 },
      -1,
   } },

   /* replace1790_0 -> 715 in the cache */
   /* replace1790_1_0 -> 148 in the cache */
   /* replace1790_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1790_2_0 -> 150 in the cache */
   /* replace1790_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5067, 5068 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1791_0_0 -> 715 in the cache */
   /* search1791_0_1 -> 984 in the cache */
   /* search1791_0_2 -> 3176 in the cache */
   /* search1791_0 -> 5061 in the cache */
   /* search1791_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 5061, 987 },
      -1,
   } },

   /* replace1791_0 -> 715 in the cache */
   /* replace1791_1_0 -> 148 in the cache */
   /* replace1791_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1791_2_0 -> 150 in the cache */
   /* replace1791_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5071, 5072 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1792_0_0 -> 715 in the cache */
   /* search1792_0_1 -> 984 in the cache */
   /* search1792_0_2 -> 3176 in the cache */
   /* search1792_0 -> 5061 in the cache */
   /* search1792_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 5061, 987 },
      -1,
   } },

   /* replace1792_0 -> 715 in the cache */
   /* replace1792_1_0 -> 148 in the cache */
   /* replace1792_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1792_2_0 -> 150 in the cache */
   /* replace1792_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5075, 5076 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1793_0_0 -> 715 in the cache */
   /* search1793_0_1 -> 984 in the cache */
   /* search1793_0_2 -> 3176 in the cache */
   /* search1793_0 -> 5061 in the cache */
   /* search1793_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5061, 987 },
      -1,
   } },

   /* replace1793_0 -> 715 in the cache */
   /* replace1793_1_0 -> 148 in the cache */
   /* replace1793_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1793_2_0 -> 150 in the cache */
   /* replace1793_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5079, 5080 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1794_1_0 -> 1125 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5083, 5084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5082, 5085 },
      -1,
   } },

   /* replace1794_0 -> 1125 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5087, 5088 },
      -1,
   } },
   /* replace1794_2_0 -> 5087 in the cache */
   /* replace1794_2_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5087, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5089, 5090 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1795_0_0 -> 715 in the cache */
   /* search1795_0_1 -> 984 in the cache */
   /* search1795_0_2 -> 3176 in the cache */
   /* search1795_0 -> 5061 in the cache */
   /* search1795_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5061, 987 },
      -1,
   } },

   /* replace1795_0 -> 715 in the cache */
   /* replace1795_1_0 -> 148 in the cache */
   /* replace1795_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1795_2_0 -> 150 in the cache */
   /* replace1795_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5093, 5094 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1796_0 -> 5082 in the cache */
   /* search1796_1_0 -> 1125 in the cache */
   /* search1796_1_1 -> 5083 in the cache */
   /* search1796_1_2 -> 5084 in the cache */
   /* search1796_1 -> 5085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5082, 5085 },
      -1,
   } },

   /* replace1796_0 -> 1125 in the cache */
   /* replace1796_1_0 -> 5087 in the cache */
   /* replace1796_1_1 -> 5088 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5087, 5088 },
      -1,
   } },
   /* replace1796_2_0 -> 5087 in the cache */
   /* replace1796_2_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5087, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5097, 5098 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1797_0_0 -> 715 in the cache */
   /* search1797_0_1 -> 984 in the cache */
   /* search1797_0_2 -> 3176 in the cache */
   /* search1797_0 -> 5061 in the cache */
   /* search1797_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5061, 987 },
      -1,
   } },

   /* replace1797_0 -> 715 in the cache */
   /* replace1797_1_0 -> 148 in the cache */
   /* replace1797_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1797_2_0 -> 150 in the cache */
   /* replace1797_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5101, 5102 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1798_0 -> 5082 in the cache */
   /* search1798_1_0 -> 1125 in the cache */
   /* search1798_1_1 -> 5083 in the cache */
   /* search1798_1_2 -> 5084 in the cache */
   /* search1798_1 -> 5085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5082, 5085 },
      -1,
   } },

   /* replace1798_0 -> 1125 in the cache */
   /* replace1798_1_0 -> 5087 in the cache */
   /* replace1798_1_1 -> 5088 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5087, 5088 },
      -1,
   } },
   /* replace1798_2_0 -> 5087 in the cache */
   /* replace1798_2_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5087, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5105, 5106 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1799_0_0 -> 715 in the cache */
   /* search1799_0_1 -> 984 in the cache */
   /* search1799_0_2 -> 3176 in the cache */
   /* search1799_0 -> 5061 in the cache */
   /* search1799_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5061, 987 },
      -1,
   } },

   /* replace1799_0 -> 715 in the cache */
   /* replace1799_1_0 -> 148 in the cache */
   /* replace1799_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1799_2_0 -> 150 in the cache */
   /* replace1799_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5109, 5110 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1800_0 -> 5082 in the cache */
   /* search1800_1_0 -> 1125 in the cache */
   /* search1800_1_1 -> 5083 in the cache */
   /* search1800_1_2 -> 5084 in the cache */
   /* search1800_1 -> 5085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5082, 5085 },
      -1,
   } },

   /* replace1800_0 -> 1125 in the cache */
   /* replace1800_1_0 -> 5087 in the cache */
   /* replace1800_1_1 -> 5088 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5087, 5088 },
      -1,
   } },
   /* replace1800_2_0 -> 5087 in the cache */
   /* replace1800_2_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5087, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5113, 5114 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1801_0_0 -> 715 in the cache */
   /* search1801_0_1 -> 984 in the cache */
   /* search1801_0_2 -> 3176 in the cache */
   /* search1801_0 -> 5061 in the cache */
   /* search1801_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5061, 987 },
      -1,
   } },

   /* replace1801_0 -> 715 in the cache */
   /* replace1801_1_0 -> 148 in the cache */
   /* replace1801_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1801_2_0 -> 150 in the cache */
   /* replace1801_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5117, 5118 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1802_0 -> 5082 in the cache */
   /* search1802_1_0 -> 1125 in the cache */
   /* search1802_1_1 -> 5083 in the cache */
   /* search1802_1_2 -> 5084 in the cache */
   /* search1802_1 -> 5085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5082, 5085 },
      -1,
   } },

   /* replace1802_0 -> 1125 in the cache */
   /* replace1802_1_0 -> 5087 in the cache */
   /* replace1802_1_1 -> 5088 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5087, 5088 },
      -1,
   } },
   /* replace1802_2_0 -> 5087 in the cache */
   /* replace1802_2_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5087, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5121, 5122 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1803_0_0 -> 715 in the cache */
   /* search1803_0_1 -> 984 in the cache */
   /* search1803_0_2 -> 3176 in the cache */
   /* search1803_0 -> 5061 in the cache */
   /* search1803_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5061, 987 },
      -1,
   } },

   /* replace1803_0 -> 715 in the cache */
   /* replace1803_1_0 -> 148 in the cache */
   /* replace1803_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1803_2_0 -> 150 in the cache */
   /* replace1803_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5125, 5126 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1804_0 -> 5082 in the cache */
   /* search1804_1_0 -> 1125 in the cache */
   /* search1804_1_1 -> 5083 in the cache */
   /* search1804_1_2 -> 5084 in the cache */
   /* search1804_1 -> 5085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5082, 5085 },
      -1,
   } },

   /* replace1804_0 -> 1125 in the cache */
   /* replace1804_1_0 -> 5087 in the cache */
   /* replace1804_1_1 -> 5088 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5087, 5088 },
      -1,
   } },
   /* replace1804_2_0 -> 5087 in the cache */
   /* replace1804_2_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5087, 1664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1125, 5129, 5130 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1805_0_0 -> 715 in the cache */
   /* search1805_0_1 -> 984 in the cache */
   /* search1805_0_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 984, 150 },
      0,
   } },
   /* search1805_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 5132, 987 },
      -1,
   } },

   /* replace1805_0 -> 715 in the cache */
   /* replace1805_1_0 -> 148 in the cache */
   /* replace1805_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1805_2_0 -> 150 in the cache */
   /* replace1805_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5134, 5135 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1806_0_0 -> 715 in the cache */
   /* search1806_0_1 -> 984 in the cache */
   /* search1806_0_2 -> 150 in the cache */
   /* search1806_0 -> 5132 in the cache */
   /* search1806_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 5132, 987 },
      -1,
   } },

   /* replace1806_0 -> 715 in the cache */
   /* replace1806_1_0 -> 148 in the cache */
   /* replace1806_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1806_2_0 -> 150 in the cache */
   /* replace1806_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5138, 5139 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search1807_0_0 -> 715 in the cache */
   /* search1807_0_1 -> 33 in the cache */
   /* search1807_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 33, 133 },
      0,
   } },
   /* search1807_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 5141, 296 },
      -1,
   } },

   /* replace1807_0 -> 715 in the cache */
   /* replace1807_1_0 -> 36 in the cache */
   /* replace1807_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 161 },
      -1,
   } },
   /* replace1807_2_0 -> 133 in the cache */
   /* replace1807_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5143, 5144 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1808_0_0 -> 715 in the cache */
   /* search1808_0_1 -> 984 in the cache */
   /* search1808_0_2 -> 150 in the cache */
   /* search1808_0 -> 5132 in the cache */
   /* search1808_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5132, 987 },
      -1,
   } },

   /* replace1808_0 -> 715 in the cache */
   /* replace1808_1_0 -> 148 in the cache */
   /* replace1808_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1808_2_0 -> 150 in the cache */
   /* replace1808_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5147, 5148 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1809_0_0 -> 715 in the cache */
   /* search1809_0_1 -> 984 in the cache */
   /* search1809_0_2 -> 150 in the cache */
   /* search1809_0 -> 5132 in the cache */
   /* search1809_1 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5132, 987 },
      -1,
   } },

   /* replace1809_0 -> 715 in the cache */
   /* replace1809_1_0 -> 148 in the cache */
   /* replace1809_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1809_2_0 -> 150 in the cache */
   /* replace1809_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5151, 5152 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1810_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1810 -> 113 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1811_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1811 -> 113 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1812_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1812 -> 113 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1813_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1813 -> 113 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1814_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1814 -> 113 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1815_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1815 -> 113 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1816_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 5160, 36 },
      -1,
   } },

   /* replace1816 -> 120 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1817_0 -> 5160 in the cache */
   /* search1817_1 -> 36 in the cache */
   /* search1817_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5160, 36, 133 },
      -1,
   } },

   /* replace1817 -> 133 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1818_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1818_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5163, 133 },
      -1,
   } },

   /* replace1818 -> 133 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1819_0 -> 715 in the cache */
   /* search1819_1_0 -> 707 in the cache */
   /* search1819_1_1 -> 708 in the cache */
   /* search1819_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 717 },
      0,
   } },
   /* search1819_2_0 -> 707 in the cache */
   /* search1819_2_1 -> 708 in the cache */
   /* search1819_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5165, 5166 },
      -1,
   } },

   /* replace1819_0 -> 707 in the cache */
   /* replace1819_1 -> 708 in the cache */
   /* replace1819_2_0 -> 715 in the cache */
   /* replace1819_2_1 -> 717 in the cache */
   /* replace1819_2_2 -> 719 in the cache */
   /* replace1819_2 -> 1251 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 1251 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1820_0 -> 715 in the cache */
   /* search1820_1_0 -> 707 in the cache */
   /* search1820_1_1 -> 708 in the cache */
   /* search1820_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 717 },
      -1,
   } },
   /* search1820_2_0 -> 707 in the cache */
   /* search1820_2_1 -> 708 in the cache */
   /* search1820_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 719 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5169, 5170 },
      -1,
   } },

   /* replace1820_0 -> 707 in the cache */
   /* replace1820_1 -> 708 in the cache */
   /* replace1820_2_0 -> 715 in the cache */
   /* replace1820_2_1 -> 717 in the cache */
   /* replace1820_2_2 -> 719 in the cache */
   /* replace1820_2 -> 1251 in the cache */
   /* replace1820 -> 5168 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1821_0 -> 715 in the cache */
   /* search1821_1_0 -> 707 in the cache */
   /* search1821_1_1 -> 708 in the cache */
   /* search1821_1_2 -> 717 in the cache */
   /* search1821_1 -> 5165 in the cache */
   /* search1821_2_0 -> 707 in the cache */
   /* search1821_2_1 -> 719 in the cache */
   /* search1821_2_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 719, 717 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5165, 5172 },
      -1,
   } },

   /* replace1821_0 -> 707 in the cache */
   /* replace1821_1_0 -> 715 in the cache */
   /* replace1821_1_1 -> 708 in the cache */
   /* replace1821_1_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 708, 719 },
      -1,
   } },
   /* replace1821_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 5174, 717 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1822_0 -> 715 in the cache */
   /* search1822_1_0 -> 707 in the cache */
   /* search1822_1_1 -> 708 in the cache */
   /* search1822_1_2 -> 717 in the cache */
   /* search1822_1 -> 5169 in the cache */
   /* search1822_2_0 -> 707 in the cache */
   /* search1822_2_1 -> 719 in the cache */
   /* search1822_2_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 719, 717 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5169, 5176 },
      -1,
   } },

   /* replace1822_0 -> 707 in the cache */
   /* replace1822_1_0 -> 715 in the cache */
   /* replace1822_1_1 -> 708 in the cache */
   /* replace1822_1_2 -> 719 in the cache */
   /* replace1822_1 -> 5174 in the cache */
   /* replace1822_2 -> 717 in the cache */
   /* replace1822 -> 5175 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1823_0 -> 715 in the cache */
   /* search1823_1_0 -> 148 in the cache */
   /* search1823_1_1 -> 150 in the cache */
   /* search1823_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 148, 150, 151 },
      0,
   } },
   /* search1823_2_0 -> 1257 in the cache */
   /* search1823_2_1 -> 150 in the cache */
   /* search1823_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1257, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5178, 5179 },
      -1,
   } },

   /* replace1823_0_0 -> 715 in the cache */
   /* replace1823_0_1 -> 148 in the cache */
   /* replace1823_0_2 -> 1257 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 1257 },
      -1,
   } },
   /* replace1823_1 -> 150 in the cache */
   /* replace1823_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 5181, 150, 151 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1824_0 -> 715 in the cache */
   /* search1824_1_0 -> 148 in the cache */
   /* search1824_1_1 -> 150 in the cache */
   /* search1824_1_2 -> 151 in the cache */
   /* search1824_1 -> 663 in the cache */
   /* search1824_2_0 -> 1257 in the cache */
   /* search1824_2_1 -> 150 in the cache */
   /* search1824_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1257, 150, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 663, 5183 },
      -1,
   } },

   /* replace1824_0_0 -> 715 in the cache */
   /* replace1824_0_1 -> 148 in the cache */
   /* replace1824_0_2 -> 1257 in the cache */
   /* replace1824_0 -> 5181 in the cache */
   /* replace1824_1 -> 150 in the cache */
   /* replace1824_2 -> 151 in the cache */
   /* replace1824 -> 5182 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1825_0 -> 715 in the cache */
   /* search1825_1_0 -> 36 in the cache */
   /* search1825_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 133 },
      0,
   } },
   /* search1825_2_0 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5186 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5185, 5187 },
      -1,
   } },

   /* replace1825_0 -> 36 in the cache */
   /* replace1825_1_0 -> 715 in the cache */
   /* replace1825_1_1 -> 133 in the cache */
   /* replace1825_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 5189 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1826_0 -> 715 in the cache */
   /* search1826_1_0 -> 36 in the cache */
   /* search1826_1_1 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 332 },
      0,
   } },
   /* search1826_2_0 -> 36 in the cache */
   /* search1826_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5191, 5192 },
      -1,
   } },

   /* replace1826_0 -> 36 in the cache */
   /* replace1826_1_0 -> 715 in the cache */
   /* replace1826_1_1 -> 133 in the cache */
   /* replace1826_1_2 -> 161 in the cache */
   /* replace1826_1 -> 5189 in the cache */
   /* replace1826 -> 5190 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1827_0 -> 715 in the cache */
   /* search1827_1_0 -> 36 in the cache */
   /* search1827_1_1 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 332 },
      -1,
   } },
   /* search1827_2_0 -> 36 in the cache */
   /* search1827_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5194, 5195 },
      -1,
   } },

   /* replace1827_0 -> 36 in the cache */
   /* replace1827_1_0 -> 715 in the cache */
   /* replace1827_1_1 -> 133 in the cache */
   /* replace1827_1_2 -> 161 in the cache */
   /* replace1827_1 -> 5189 in the cache */
   /* replace1827 -> 5190 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1828_0 -> 715 in the cache */
   /* search1828_1_0 -> 36 in the cache */
   /* search1828_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 133 },
      -1,
   } },
   /* search1828_2_0 -> 36 in the cache */
   /* search1828_2_1 -> 5186 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5186 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5197, 5198 },
      -1,
   } },

   /* replace1828_0 -> 36 in the cache */
   /* replace1828_1_0 -> 715 in the cache */
   /* replace1828_1_1 -> 133 in the cache */
   /* replace1828_1_2 -> 161 in the cache */
   /* replace1828_1 -> 5189 in the cache */
   /* replace1828 -> 5190 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1829_0 -> 715 in the cache */
   /* search1829_1_0 -> 148 in the cache */
   /* search1829_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1829_2_0 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5200, 5202 },
      -1,
   } },

   /* replace1829_0 -> 148 in the cache */
   /* replace1829_1_0 -> 715 in the cache */
   /* replace1829_1_1 -> 150 in the cache */
   /* replace1829_1_2 -> 151 in the cache */
   /* replace1829_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1830_0 -> 715 in the cache */
   /* search1830_1_0 -> 148 in the cache */
   /* search1830_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1830_2_0 -> 148 in the cache */
   /* search1830_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5205, 5206 },
      -1,
   } },

   /* replace1830_0 -> 148 in the cache */
   /* replace1830_1_0 -> 715 in the cache */
   /* replace1830_1_1 -> 150 in the cache */
   /* replace1830_1_2 -> 151 in the cache */
   /* replace1830_1 -> 1246 in the cache */
   /* replace1830 -> 5204 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1831_0 -> 715 in the cache */
   /* search1831_1_0 -> 148 in the cache */
   /* search1831_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1831_2_0 -> 148 in the cache */
   /* search1831_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5208, 5209 },
      -1,
   } },

   /* replace1831_0 -> 148 in the cache */
   /* replace1831_1_0 -> 715 in the cache */
   /* replace1831_1_1 -> 150 in the cache */
   /* replace1831_1_2 -> 151 in the cache */
   /* replace1831_1 -> 1246 in the cache */
   /* replace1831 -> 5204 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1832_0 -> 715 in the cache */
   /* search1832_1_0 -> 148 in the cache */
   /* search1832_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1832_2_0 -> 148 in the cache */
   /* search1832_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5211, 5212 },
      -1,
   } },

   /* replace1832_0 -> 148 in the cache */
   /* replace1832_1_0 -> 715 in the cache */
   /* replace1832_1_1 -> 150 in the cache */
   /* replace1832_1_2 -> 151 in the cache */
   /* replace1832_1 -> 1246 in the cache */
   /* replace1832 -> 5204 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1833_0 -> 715 in the cache */
   /* search1833_1_0 -> 148 in the cache */
   /* search1833_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1833_2_0 -> 148 in the cache */
   /* search1833_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5214, 5215 },
      -1,
   } },

   /* replace1833_0 -> 148 in the cache */
   /* replace1833_1_0 -> 715 in the cache */
   /* replace1833_1_1 -> 150 in the cache */
   /* replace1833_1_2 -> 151 in the cache */
   /* replace1833_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1834_0 -> 715 in the cache */
   /* search1834_1_0 -> 148 in the cache */
   /* search1834_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1834_2_0 -> 148 in the cache */
   /* search1834_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5218, 5219 },
      -1,
   } },

   /* replace1834_0 -> 148 in the cache */
   /* replace1834_1_0 -> 715 in the cache */
   /* replace1834_1_1 -> 150 in the cache */
   /* replace1834_1_2 -> 151 in the cache */
   /* replace1834_1 -> 1246 in the cache */
   /* replace1834 -> 5217 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1835_0 -> 715 in the cache */
   /* search1835_1_0 -> 148 in the cache */
   /* search1835_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1835_2_0 -> 148 in the cache */
   /* search1835_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5221, 5222 },
      -1,
   } },

   /* replace1835_0 -> 148 in the cache */
   /* replace1835_1_0 -> 715 in the cache */
   /* replace1835_1_1 -> 150 in the cache */
   /* replace1835_1_2 -> 151 in the cache */
   /* replace1835_1 -> 1246 in the cache */
   /* replace1835 -> 5217 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1836_0 -> 715 in the cache */
   /* search1836_1_0 -> 148 in the cache */
   /* search1836_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1836_2_0 -> 148 in the cache */
   /* search1836_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5224, 5225 },
      -1,
   } },

   /* replace1836_0 -> 148 in the cache */
   /* replace1836_1_0 -> 715 in the cache */
   /* replace1836_1_1 -> 150 in the cache */
   /* replace1836_1_2 -> 151 in the cache */
   /* replace1836_1 -> 1246 in the cache */
   /* replace1836 -> 5217 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1837_0 -> 715 in the cache */
   /* search1837_1_0 -> 148 in the cache */
   /* search1837_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1837_2_0 -> 148 in the cache */
   /* search1837_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5227, 5228 },
      -1,
   } },

   /* replace1837_0 -> 148 in the cache */
   /* replace1837_1_0 -> 715 in the cache */
   /* replace1837_1_1 -> 150 in the cache */
   /* replace1837_1_2 -> 151 in the cache */
   /* replace1837_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1838_0 -> 715 in the cache */
   /* search1838_1_0 -> 148 in the cache */
   /* search1838_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1838_2_0 -> 148 in the cache */
   /* search1838_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5231, 5232 },
      -1,
   } },

   /* replace1838_0 -> 148 in the cache */
   /* replace1838_1_0 -> 715 in the cache */
   /* replace1838_1_1 -> 150 in the cache */
   /* replace1838_1_2 -> 151 in the cache */
   /* replace1838_1 -> 1246 in the cache */
   /* replace1838 -> 5230 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1839_0 -> 715 in the cache */
   /* search1839_1_0 -> 148 in the cache */
   /* search1839_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1839_2_0 -> 148 in the cache */
   /* search1839_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5234, 5235 },
      -1,
   } },

   /* replace1839_0 -> 148 in the cache */
   /* replace1839_1_0 -> 715 in the cache */
   /* replace1839_1_1 -> 150 in the cache */
   /* replace1839_1_2 -> 151 in the cache */
   /* replace1839_1 -> 1246 in the cache */
   /* replace1839 -> 5230 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1840_0 -> 715 in the cache */
   /* search1840_1_0 -> 148 in the cache */
   /* search1840_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1840_2_0 -> 148 in the cache */
   /* search1840_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5237, 5238 },
      -1,
   } },

   /* replace1840_0 -> 148 in the cache */
   /* replace1840_1_0 -> 715 in the cache */
   /* replace1840_1_1 -> 150 in the cache */
   /* replace1840_1_2 -> 151 in the cache */
   /* replace1840_1 -> 1246 in the cache */
   /* replace1840 -> 5230 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1841_0 -> 715 in the cache */
   /* search1841_1_0 -> 148 in the cache */
   /* search1841_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1841_2_0 -> 148 in the cache */
   /* search1841_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5240, 5241 },
      -1,
   } },

   /* replace1841_0 -> 148 in the cache */
   /* replace1841_1_0 -> 715 in the cache */
   /* replace1841_1_1 -> 150 in the cache */
   /* replace1841_1_2 -> 151 in the cache */
   /* replace1841_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1842_0 -> 715 in the cache */
   /* search1842_1_0 -> 148 in the cache */
   /* search1842_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1842_2_0 -> 148 in the cache */
   /* search1842_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5244, 5245 },
      -1,
   } },

   /* replace1842_0 -> 148 in the cache */
   /* replace1842_1_0 -> 715 in the cache */
   /* replace1842_1_1 -> 150 in the cache */
   /* replace1842_1_2 -> 151 in the cache */
   /* replace1842_1 -> 1246 in the cache */
   /* replace1842 -> 5243 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1843_0 -> 715 in the cache */
   /* search1843_1_0 -> 148 in the cache */
   /* search1843_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1843_2_0 -> 148 in the cache */
   /* search1843_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5247, 5248 },
      -1,
   } },

   /* replace1843_0 -> 148 in the cache */
   /* replace1843_1_0 -> 715 in the cache */
   /* replace1843_1_1 -> 150 in the cache */
   /* replace1843_1_2 -> 151 in the cache */
   /* replace1843_1 -> 1246 in the cache */
   /* replace1843 -> 5243 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1844_0 -> 715 in the cache */
   /* search1844_1_0 -> 148 in the cache */
   /* search1844_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1844_2_0 -> 148 in the cache */
   /* search1844_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5250, 5251 },
      -1,
   } },

   /* replace1844_0 -> 148 in the cache */
   /* replace1844_1_0 -> 715 in the cache */
   /* replace1844_1_1 -> 150 in the cache */
   /* replace1844_1_2 -> 151 in the cache */
   /* replace1844_1 -> 1246 in the cache */
   /* replace1844 -> 5243 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1845_0 -> 715 in the cache */
   /* search1845_1_0 -> 148 in the cache */
   /* search1845_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1845_2_0 -> 148 in the cache */
   /* search1845_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5253, 5254 },
      -1,
   } },

   /* replace1845_0 -> 148 in the cache */
   /* replace1845_1_0 -> 715 in the cache */
   /* replace1845_1_1 -> 150 in the cache */
   /* replace1845_1_2 -> 151 in the cache */
   /* replace1845_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1846_0 -> 715 in the cache */
   /* search1846_1_0 -> 148 in the cache */
   /* search1846_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1846_2_0 -> 148 in the cache */
   /* search1846_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5257, 5258 },
      -1,
   } },

   /* replace1846_0 -> 148 in the cache */
   /* replace1846_1_0 -> 715 in the cache */
   /* replace1846_1_1 -> 150 in the cache */
   /* replace1846_1_2 -> 151 in the cache */
   /* replace1846_1 -> 1246 in the cache */
   /* replace1846 -> 5256 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1847_0 -> 715 in the cache */
   /* search1847_1_0 -> 148 in the cache */
   /* search1847_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1847_2_0 -> 148 in the cache */
   /* search1847_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5260, 5261 },
      -1,
   } },

   /* replace1847_0 -> 148 in the cache */
   /* replace1847_1_0 -> 715 in the cache */
   /* replace1847_1_1 -> 150 in the cache */
   /* replace1847_1_2 -> 151 in the cache */
   /* replace1847_1 -> 1246 in the cache */
   /* replace1847 -> 5256 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1848_0 -> 715 in the cache */
   /* search1848_1_0 -> 148 in the cache */
   /* search1848_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1848_2_0 -> 148 in the cache */
   /* search1848_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5263, 5264 },
      -1,
   } },

   /* replace1848_0 -> 148 in the cache */
   /* replace1848_1_0 -> 715 in the cache */
   /* replace1848_1_1 -> 150 in the cache */
   /* replace1848_1_2 -> 151 in the cache */
   /* replace1848_1 -> 1246 in the cache */
   /* replace1848 -> 5256 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1849_0 -> 715 in the cache */
   /* search1849_1_0 -> 148 in the cache */
   /* search1849_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1849_2_0 -> 148 in the cache */
   /* search1849_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5266, 5267 },
      -1,
   } },

   /* replace1849_0 -> 148 in the cache */
   /* replace1849_1_0 -> 715 in the cache */
   /* replace1849_1_1 -> 150 in the cache */
   /* replace1849_1_2 -> 151 in the cache */
   /* replace1849_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1850_0 -> 715 in the cache */
   /* search1850_1_0 -> 148 in the cache */
   /* search1850_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1850_2_0 -> 148 in the cache */
   /* search1850_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5270, 5271 },
      -1,
   } },

   /* replace1850_0 -> 148 in the cache */
   /* replace1850_1_0 -> 715 in the cache */
   /* replace1850_1_1 -> 150 in the cache */
   /* replace1850_1_2 -> 151 in the cache */
   /* replace1850_1 -> 1246 in the cache */
   /* replace1850 -> 5269 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1851_0 -> 715 in the cache */
   /* search1851_1_0 -> 148 in the cache */
   /* search1851_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1851_2_0 -> 148 in the cache */
   /* search1851_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5273, 5274 },
      -1,
   } },

   /* replace1851_0 -> 148 in the cache */
   /* replace1851_1_0 -> 715 in the cache */
   /* replace1851_1_1 -> 150 in the cache */
   /* replace1851_1_2 -> 151 in the cache */
   /* replace1851_1 -> 1246 in the cache */
   /* replace1851 -> 5269 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1852_0 -> 715 in the cache */
   /* search1852_1_0 -> 148 in the cache */
   /* search1852_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1852_2_0 -> 148 in the cache */
   /* search1852_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5276, 5277 },
      -1,
   } },

   /* replace1852_0 -> 148 in the cache */
   /* replace1852_1_0 -> 715 in the cache */
   /* replace1852_1_1 -> 150 in the cache */
   /* replace1852_1_2 -> 151 in the cache */
   /* replace1852_1 -> 1246 in the cache */
   /* replace1852 -> 5269 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1853_0 -> 715 in the cache */
   /* search1853_1_0 -> 148 in the cache */
   /* search1853_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1853_2_0 -> 148 in the cache */
   /* search1853_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5279, 5280 },
      -1,
   } },

   /* replace1853_0 -> 148 in the cache */
   /* replace1853_1_0 -> 715 in the cache */
   /* replace1853_1_1 -> 150 in the cache */
   /* replace1853_1_2 -> 151 in the cache */
   /* replace1853_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1854_0 -> 715 in the cache */
   /* search1854_1_0 -> 148 in the cache */
   /* search1854_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1854_2_0 -> 148 in the cache */
   /* search1854_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5283, 5284 },
      -1,
   } },

   /* replace1854_0 -> 148 in the cache */
   /* replace1854_1_0 -> 715 in the cache */
   /* replace1854_1_1 -> 150 in the cache */
   /* replace1854_1_2 -> 151 in the cache */
   /* replace1854_1 -> 1246 in the cache */
   /* replace1854 -> 5282 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1855_0 -> 715 in the cache */
   /* search1855_1_0 -> 148 in the cache */
   /* search1855_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1855_2_0 -> 148 in the cache */
   /* search1855_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5286, 5287 },
      -1,
   } },

   /* replace1855_0 -> 148 in the cache */
   /* replace1855_1_0 -> 715 in the cache */
   /* replace1855_1_1 -> 150 in the cache */
   /* replace1855_1_2 -> 151 in the cache */
   /* replace1855_1 -> 1246 in the cache */
   /* replace1855 -> 5282 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1856_0 -> 715 in the cache */
   /* search1856_1_0 -> 148 in the cache */
   /* search1856_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1856_2_0 -> 148 in the cache */
   /* search1856_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5289, 5290 },
      -1,
   } },

   /* replace1856_0 -> 148 in the cache */
   /* replace1856_1_0 -> 715 in the cache */
   /* replace1856_1_1 -> 150 in the cache */
   /* replace1856_1_2 -> 151 in the cache */
   /* replace1856_1 -> 1246 in the cache */
   /* replace1856 -> 5282 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1857_0 -> 715 in the cache */
   /* search1857_1_0 -> 148 in the cache */
   /* search1857_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1857_2_0 -> 148 in the cache */
   /* search1857_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5292, 5293 },
      -1,
   } },

   /* replace1857_0 -> 148 in the cache */
   /* replace1857_1_0 -> 715 in the cache */
   /* replace1857_1_1 -> 150 in the cache */
   /* replace1857_1_2 -> 151 in the cache */
   /* replace1857_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1858_0 -> 715 in the cache */
   /* search1858_1_0 -> 148 in the cache */
   /* search1858_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1858_2_0 -> 148 in the cache */
   /* search1858_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5296, 5297 },
      -1,
   } },

   /* replace1858_0 -> 148 in the cache */
   /* replace1858_1_0 -> 715 in the cache */
   /* replace1858_1_1 -> 150 in the cache */
   /* replace1858_1_2 -> 151 in the cache */
   /* replace1858_1 -> 1246 in the cache */
   /* replace1858 -> 5295 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1859_0 -> 715 in the cache */
   /* search1859_1_0 -> 148 in the cache */
   /* search1859_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1859_2_0 -> 148 in the cache */
   /* search1859_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5299, 5300 },
      -1,
   } },

   /* replace1859_0 -> 148 in the cache */
   /* replace1859_1_0 -> 715 in the cache */
   /* replace1859_1_1 -> 150 in the cache */
   /* replace1859_1_2 -> 151 in the cache */
   /* replace1859_1 -> 1246 in the cache */
   /* replace1859 -> 5295 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1860_0 -> 715 in the cache */
   /* search1860_1_0 -> 148 in the cache */
   /* search1860_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1860_2_0 -> 148 in the cache */
   /* search1860_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5302, 5303 },
      -1,
   } },

   /* replace1860_0 -> 148 in the cache */
   /* replace1860_1_0 -> 715 in the cache */
   /* replace1860_1_1 -> 150 in the cache */
   /* replace1860_1_2 -> 151 in the cache */
   /* replace1860_1 -> 1246 in the cache */
   /* replace1860 -> 5295 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1861_0 -> 715 in the cache */
   /* search1861_1_0 -> 148 in the cache */
   /* search1861_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1861_2_0 -> 148 in the cache */
   /* search1861_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5305, 5306 },
      -1,
   } },

   /* replace1861_0 -> 148 in the cache */
   /* replace1861_1_0 -> 715 in the cache */
   /* replace1861_1_1 -> 150 in the cache */
   /* replace1861_1_2 -> 151 in the cache */
   /* replace1861_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1862_0 -> 715 in the cache */
   /* search1862_1_0 -> 148 in the cache */
   /* search1862_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1862_2_0 -> 148 in the cache */
   /* search1862_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5309, 5310 },
      -1,
   } },

   /* replace1862_0 -> 148 in the cache */
   /* replace1862_1_0 -> 715 in the cache */
   /* replace1862_1_1 -> 150 in the cache */
   /* replace1862_1_2 -> 151 in the cache */
   /* replace1862_1 -> 1246 in the cache */
   /* replace1862 -> 5308 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1863_0 -> 715 in the cache */
   /* search1863_1_0 -> 148 in the cache */
   /* search1863_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1863_2_0 -> 148 in the cache */
   /* search1863_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5312, 5313 },
      -1,
   } },

   /* replace1863_0 -> 148 in the cache */
   /* replace1863_1_0 -> 715 in the cache */
   /* replace1863_1_1 -> 150 in the cache */
   /* replace1863_1_2 -> 151 in the cache */
   /* replace1863_1 -> 1246 in the cache */
   /* replace1863 -> 5308 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1864_0 -> 715 in the cache */
   /* search1864_1_0 -> 148 in the cache */
   /* search1864_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1864_2_0 -> 148 in the cache */
   /* search1864_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5315, 5316 },
      -1,
   } },

   /* replace1864_0 -> 148 in the cache */
   /* replace1864_1_0 -> 715 in the cache */
   /* replace1864_1_1 -> 150 in the cache */
   /* replace1864_1_2 -> 151 in the cache */
   /* replace1864_1 -> 1246 in the cache */
   /* replace1864 -> 5308 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1865_0 -> 715 in the cache */
   /* search1865_1_0 -> 148 in the cache */
   /* search1865_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1865_2_0 -> 148 in the cache */
   /* search1865_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5318, 5319 },
      -1,
   } },

   /* replace1865_0 -> 148 in the cache */
   /* replace1865_1_0 -> 715 in the cache */
   /* replace1865_1_1 -> 150 in the cache */
   /* replace1865_1_2 -> 151 in the cache */
   /* replace1865_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1866_0 -> 715 in the cache */
   /* search1866_1_0 -> 148 in the cache */
   /* search1866_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1866_2_0 -> 148 in the cache */
   /* search1866_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5322, 5323 },
      -1,
   } },

   /* replace1866_0 -> 148 in the cache */
   /* replace1866_1_0 -> 715 in the cache */
   /* replace1866_1_1 -> 150 in the cache */
   /* replace1866_1_2 -> 151 in the cache */
   /* replace1866_1 -> 1246 in the cache */
   /* replace1866 -> 5321 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1867_0 -> 715 in the cache */
   /* search1867_1_0 -> 148 in the cache */
   /* search1867_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1867_2_0 -> 148 in the cache */
   /* search1867_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5325, 5326 },
      -1,
   } },

   /* replace1867_0 -> 148 in the cache */
   /* replace1867_1_0 -> 715 in the cache */
   /* replace1867_1_1 -> 150 in the cache */
   /* replace1867_1_2 -> 151 in the cache */
   /* replace1867_1 -> 1246 in the cache */
   /* replace1867 -> 5321 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1868_0 -> 715 in the cache */
   /* search1868_1_0 -> 148 in the cache */
   /* search1868_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1868_2_0 -> 148 in the cache */
   /* search1868_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5328, 5329 },
      -1,
   } },

   /* replace1868_0 -> 148 in the cache */
   /* replace1868_1_0 -> 715 in the cache */
   /* replace1868_1_1 -> 150 in the cache */
   /* replace1868_1_2 -> 151 in the cache */
   /* replace1868_1 -> 1246 in the cache */
   /* replace1868 -> 5321 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1869_0 -> 715 in the cache */
   /* search1869_1_0 -> 148 in the cache */
   /* search1869_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1869_2_0 -> 148 in the cache */
   /* search1869_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5331, 5332 },
      -1,
   } },

   /* replace1869_0 -> 148 in the cache */
   /* replace1869_1_0 -> 715 in the cache */
   /* replace1869_1_1 -> 150 in the cache */
   /* replace1869_1_2 -> 151 in the cache */
   /* replace1869_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1870_0 -> 715 in the cache */
   /* search1870_1_0 -> 148 in the cache */
   /* search1870_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1870_2_0 -> 148 in the cache */
   /* search1870_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5335, 5336 },
      -1,
   } },

   /* replace1870_0 -> 148 in the cache */
   /* replace1870_1_0 -> 715 in the cache */
   /* replace1870_1_1 -> 150 in the cache */
   /* replace1870_1_2 -> 151 in the cache */
   /* replace1870_1 -> 1246 in the cache */
   /* replace1870 -> 5334 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1871_0 -> 715 in the cache */
   /* search1871_1_0 -> 148 in the cache */
   /* search1871_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1871_2_0 -> 148 in the cache */
   /* search1871_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5338, 5339 },
      -1,
   } },

   /* replace1871_0 -> 148 in the cache */
   /* replace1871_1_0 -> 715 in the cache */
   /* replace1871_1_1 -> 150 in the cache */
   /* replace1871_1_2 -> 151 in the cache */
   /* replace1871_1 -> 1246 in the cache */
   /* replace1871 -> 5334 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1872_0 -> 715 in the cache */
   /* search1872_1_0 -> 148 in the cache */
   /* search1872_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1872_2_0 -> 148 in the cache */
   /* search1872_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5341, 5342 },
      -1,
   } },

   /* replace1872_0 -> 148 in the cache */
   /* replace1872_1_0 -> 715 in the cache */
   /* replace1872_1_1 -> 150 in the cache */
   /* replace1872_1_2 -> 151 in the cache */
   /* replace1872_1 -> 1246 in the cache */
   /* replace1872 -> 5334 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1873_0 -> 715 in the cache */
   /* search1873_1_0 -> 148 in the cache */
   /* search1873_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1873_2_0 -> 148 in the cache */
   /* search1873_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5344, 5345 },
      -1,
   } },

   /* replace1873_0 -> 148 in the cache */
   /* replace1873_1_0 -> 715 in the cache */
   /* replace1873_1_1 -> 150 in the cache */
   /* replace1873_1_2 -> 151 in the cache */
   /* replace1873_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1874_0 -> 715 in the cache */
   /* search1874_1_0 -> 148 in the cache */
   /* search1874_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 3191 },
      0,
   } },
   /* search1874_2_0 -> 148 in the cache */
   /* search1874_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5348, 5349 },
      -1,
   } },

   /* replace1874_0 -> 148 in the cache */
   /* replace1874_1_0 -> 715 in the cache */
   /* replace1874_1_1 -> 150 in the cache */
   /* replace1874_1_2 -> 151 in the cache */
   /* replace1874_1 -> 1246 in the cache */
   /* replace1874 -> 5347 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1875_0 -> 715 in the cache */
   /* search1875_1_0 -> 148 in the cache */
   /* search1875_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 3191 },
      -1,
   } },
   /* search1875_2_0 -> 148 in the cache */
   /* search1875_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5351, 5352 },
      -1,
   } },

   /* replace1875_0 -> 148 in the cache */
   /* replace1875_1_0 -> 715 in the cache */
   /* replace1875_1_1 -> 150 in the cache */
   /* replace1875_1_2 -> 151 in the cache */
   /* replace1875_1 -> 1246 in the cache */
   /* replace1875 -> 5347 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1876_0 -> 715 in the cache */
   /* search1876_1_0 -> 148 in the cache */
   /* search1876_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1876_2_0 -> 148 in the cache */
   /* search1876_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5354, 5355 },
      -1,
   } },

   /* replace1876_0 -> 148 in the cache */
   /* replace1876_1_0 -> 715 in the cache */
   /* replace1876_1_1 -> 150 in the cache */
   /* replace1876_1_2 -> 151 in the cache */
   /* replace1876_1 -> 1246 in the cache */
   /* replace1876 -> 5347 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1877_0 -> 715 in the cache */
   /* search1877_1_0 -> 148 in the cache */
   /* search1877_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 150 },
      0,
   } },
   /* search1877_2_0 -> 148 in the cache */
   /* search1877_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5357, 5358 },
      -1,
   } },

   /* replace1877_0 -> 148 in the cache */
   /* replace1877_1_0 -> 715 in the cache */
   /* replace1877_1_1 -> 150 in the cache */
   /* replace1877_1_2 -> 151 in the cache */
   /* replace1877_1 -> 1246 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 1246 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1878_0 -> 715 in the cache */
   /* search1878_1_0 -> 148 in the cache */
   /* search1878_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 150 },
      -1,
   } },
   /* search1878_2_0 -> 148 in the cache */
   /* search1878_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5361, 5362 },
      -1,
   } },

   /* replace1878_0 -> 148 in the cache */
   /* replace1878_1_0 -> 715 in the cache */
   /* replace1878_1_1 -> 150 in the cache */
   /* replace1878_1_2 -> 151 in the cache */
   /* replace1878_1 -> 1246 in the cache */
   /* replace1878 -> 5360 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1879_0 -> 715 in the cache */
   /* search1879_1_0 -> 125 in the cache */
   /* search1879_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1879_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5365, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5364, 5366 },
      -1,
   } },

   /* replace1879_0_0 -> 715 in the cache */
   /* replace1879_0_1 -> 125 in the cache */
   /* replace1879_0_2 -> 5365 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 125, 5365 },
      -1,
   } },
   /* replace1879_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5368, 127 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1880_0 -> 715 in the cache */
   /* search1880_1_0 -> 125 in the cache */
   /* search1880_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   /* search1880_2_0 -> 5365 in the cache */
   /* search1880_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5365, 127 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5370, 5371 },
      -1,
   } },

   /* replace1880_0_0 -> 715 in the cache */
   /* replace1880_0_1 -> 125 in the cache */
   /* replace1880_0_2 -> 5365 in the cache */
   /* replace1880_0 -> 5368 in the cache */
   /* replace1880_1 -> 127 in the cache */
   /* replace1880 -> 5369 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search1881_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5373 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5374, 5376 },
      -1,
   } },

   /* replace1881_0_0 -> 502 in the cache */
   /* replace1881_0_1 -> 5373 in the cache */
   /* replace1881_0_2 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5373, 5375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search1882_0 -> 502 in the cache */
   /* search1882_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1882_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5380, 5381 },
      -1,
   } },

   /* replace1882_0_0 -> 502 in the cache */
   /* replace1882_0_1 -> 5373 in the cache */
   /* replace1882_0_2 -> 5375 in the cache */
   /* replace1882_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search1883_0 -> 502 in the cache */
   /* search1883_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1883_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5384, 5385 },
      -1,
   } },

   /* replace1883_0_0 -> 502 in the cache */
   /* replace1883_0_1 -> 5373 in the cache */
   /* replace1883_0_2 -> 5375 in the cache */
   /* replace1883_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search1884_0 -> 502 in the cache */
   /* search1884_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1884_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5388, 5389 },
      -1,
   } },

   /* replace1884_0_0 -> 502 in the cache */
   /* replace1884_0_1 -> 5373 in the cache */
   /* replace1884_0_2 -> 5375 in the cache */
   /* replace1884_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search1885_0 -> 502 in the cache */
   /* search1885_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1885_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5392, 5393 },
      -1,
   } },

   /* replace1885_0_0 -> 502 in the cache */
   /* replace1885_0_1 -> 5373 in the cache */
   /* replace1885_0_2 -> 5375 in the cache */
   /* replace1885_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1886_0 -> 502 in the cache */
   /* search1886_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1886_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5396, 5397 },
      -1,
   } },

   /* replace1886_0_0 -> 502 in the cache */
   /* replace1886_0_1 -> 5373 in the cache */
   /* replace1886_0_2 -> 5375 in the cache */
   /* replace1886_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search1887_0 -> 502 in the cache */
   /* search1887_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1887_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5400, 5401 },
      -1,
   } },

   /* replace1887_0_0 -> 502 in the cache */
   /* replace1887_0_1 -> 5373 in the cache */
   /* replace1887_0_2 -> 5375 in the cache */
   /* replace1887_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search1888_0 -> 502 in the cache */
   /* search1888_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1888_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5404, 5405 },
      -1,
   } },

   /* replace1888_0_0 -> 502 in the cache */
   /* replace1888_0_1 -> 5373 in the cache */
   /* replace1888_0_2 -> 5375 in the cache */
   /* replace1888_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search1889_0 -> 502 in the cache */
   /* search1889_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1889_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5408, 5409 },
      -1,
   } },

   /* replace1889_0_0 -> 502 in the cache */
   /* replace1889_0_1 -> 5373 in the cache */
   /* replace1889_0_2 -> 5375 in the cache */
   /* replace1889_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search1890_0 -> 502 in the cache */
   /* search1890_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5373 },
      0,
   } },
   /* search1890_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5375 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5412, 5413 },
      -1,
   } },

   /* replace1890_0_0 -> 502 in the cache */
   /* replace1890_0_1 -> 5373 in the cache */
   /* replace1890_0_2 -> 5375 in the cache */
   /* replace1890_0 -> 5378 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5378 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1891_0 -> 502 in the cache */
   /* search1891_1_0 -> 5373 in the cache */
   /* search1891_1 -> 5396 in the cache */
   /* search1891_2_0 -> 5375 in the cache */
   /* search1891_2 -> 5397 in the cache */
   /* search1891 -> 5398 in the cache */

   /* replace1891_0_0 -> 502 in the cache */
   /* replace1891_0_1 -> 5373 in the cache */
   /* replace1891_0_2 -> 5375 in the cache */
   /* replace1891_0 -> 5378 in the cache */
   /* replace1891 -> 5399 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search1892_0_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5416, 5417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5418 },
      -1,
   } },

   /* replace1892_0 -> 502 in the cache */
   /* replace1892_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5373 },
      -1,
   } },
   /* replace1892_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5420, 5421 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search1893_0_0 -> 502 in the cache */
   /* search1893_0_1 -> 5416 in the cache */
   /* search1893_0_2 -> 5417 in the cache */
   /* search1893_0 -> 5418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5418 },
      -1,
   } },

   /* replace1893_0 -> 502 in the cache */
   /* replace1893_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5373 },
      -1,
   } },
   /* replace1893_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5424, 5425 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search1894_0_0 -> 502 in the cache */
   /* search1894_0_1 -> 5416 in the cache */
   /* search1894_0_2 -> 5417 in the cache */
   /* search1894_0 -> 5418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5418 },
      -1,
   } },

   /* replace1894_0 -> 502 in the cache */
   /* replace1894_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5373 },
      -1,
   } },
   /* replace1894_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5428, 5429 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search1895_0_0 -> 502 in the cache */
   /* search1895_0_1 -> 5416 in the cache */
   /* search1895_0_2 -> 5417 in the cache */
   /* search1895_0 -> 5418 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5418 },
      -1,
   } },

   /* replace1895_0 -> 502 in the cache */
   /* replace1895_1_0 -> 5373 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5373 },
      -1,
   } },
   /* replace1895_2_0 -> 5375 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5432, 5433 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search1896_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace1896_1_0_0 -> 16 in the cache */
   /* replace1896_1_0_1 -> 377 in the cache */
   /* replace1896_1_0 -> 949 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 949, 5437 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5436, 5438 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search1897_0_0 -> 16 in the cache */
   /* search1897_0_1 -> 36 in the cache */
   /* search1897_0 -> 2890 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* replace1897_0_0 -> 16 in the cache */
   /* replace1897_0 -> 3578 in the cache */
   /* replace1897_1_0 -> 36 in the cache */
   /* replace1897_1 -> 3575 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3578, 3575 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search1898_0_0 -> 16 in the cache */
   /* search1898_0_1 -> 36 in the cache */
   /* search1898_0 -> 2890 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* replace1898_0_0 -> 16 in the cache */
   /* replace1898_0 -> 1935 in the cache */
   /* replace1898_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1935, 5443 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search1899_0_0 -> 16 in the cache */
   /* search1899_0_1 -> 36 in the cache */
   /* search1899_0 -> 2890 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* replace1899_0_0 -> 16 in the cache */
   /* replace1899_0 -> 2988 in the cache */
   /* replace1899_1_0 -> 36 in the cache */
   /* replace1899_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2988, 4401 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search1900_0_0 -> 16 in the cache */
   /* search1900_0_1 -> 36 in the cache */
   /* search1900_0 -> 2890 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* replace1900_0_0 -> 16 in the cache */
   /* replace1900_0 -> 3887 in the cache */
   /* replace1900_1_0 -> 36 in the cache */
   /* replace1900_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3887, 4072 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search1901_0_0 -> 16 in the cache */
   /* search1901_0_1 -> 36 in the cache */
   /* search1901_0 -> 2890 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2890 },
      -1,
   } },

   /* replace1901_0_0 -> 16 in the cache */
   /* replace1901_0 -> 1946 in the cache */
   /* replace1901_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1946, 5450 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search1902_0_0 -> 16 in the cache */
   /* search1902_0_1 -> 36 in the cache */
   /* search1902_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5452 },
      -1,
   } },

   /* replace1902_0_0 -> 16 in the cache */
   /* replace1902_0 -> 3578 in the cache */
   /* replace1902_1_0 -> 36 in the cache */
   /* replace1902_1 -> 3575 in the cache */
   /* replace1902_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3578, 3575, 5454 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search1903_0_0 -> 16 in the cache */
   /* search1903_0_1 -> 36 in the cache */
   /* search1903_0_2 -> 133 in the cache */
   /* search1903_0 -> 5452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5452 },
      -1,
   } },

   /* replace1903_0_0 -> 16 in the cache */
   /* replace1903_0 -> 1935 in the cache */
   /* replace1903_1_0 -> 36 in the cache */
   /* replace1903_1 -> 5443 in the cache */
   /* replace1903_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1935, 5443, 5457 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search1904_0_0 -> 16 in the cache */
   /* search1904_0_1 -> 36 in the cache */
   /* search1904_0_2 -> 133 in the cache */
   /* search1904_0 -> 5452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5452 },
      -1,
   } },

   /* replace1904_0_0 -> 16 in the cache */
   /* replace1904_0 -> 2988 in the cache */
   /* replace1904_1_0 -> 36 in the cache */
   /* replace1904_1 -> 4401 in the cache */
   /* replace1904_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 2988, 4401, 5460 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search1905_0_0 -> 16 in the cache */
   /* search1905_0_1 -> 36 in the cache */
   /* search1905_0_2 -> 133 in the cache */
   /* search1905_0 -> 5452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5452 },
      -1,
   } },

   /* replace1905_0_0 -> 16 in the cache */
   /* replace1905_0 -> 3887 in the cache */
   /* replace1905_1_0 -> 36 in the cache */
   /* replace1905_1 -> 4072 in the cache */
   /* replace1905_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3887, 4072, 5463 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search1906_0_0 -> 16 in the cache */
   /* search1906_0_1 -> 36 in the cache */
   /* search1906_0_2 -> 133 in the cache */
   /* search1906_0 -> 5452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5452 },
      -1,
   } },

   /* replace1906_0_0 -> 16 in the cache */
   /* replace1906_0 -> 1946 in the cache */
   /* replace1906_1_0 -> 36 in the cache */
   /* replace1906_1 -> 5450 in the cache */
   /* replace1906_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1946, 5450, 5466 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search1907_0_0 -> 16 in the cache */
   /* search1907_0_1 -> 36 in the cache */
   /* search1907_0_2 -> 133 in the cache */
   /* search1907_0_3 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5468 },
      -1,
   } },

   /* replace1907_0_0 -> 16 in the cache */
   /* replace1907_0 -> 3578 in the cache */
   /* replace1907_1_0 -> 36 in the cache */
   /* replace1907_1 -> 3575 in the cache */
   /* replace1907_2_0 -> 133 in the cache */
   /* replace1907_2 -> 5454 in the cache */
   /* replace1907_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3578, 3575, 5454, 5470 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search1908_0_0 -> 16 in the cache */
   /* search1908_0_1 -> 36 in the cache */
   /* search1908_0_2 -> 133 in the cache */
   /* search1908_0_3 -> 161 in the cache */
   /* search1908_0 -> 5468 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5468 },
      -1,
   } },

   /* replace1908_0_0 -> 16 in the cache */
   /* replace1908_0 -> 1935 in the cache */
   /* replace1908_1_0 -> 36 in the cache */
   /* replace1908_1 -> 5443 in the cache */
   /* replace1908_2_0 -> 133 in the cache */
   /* replace1908_2 -> 5457 in the cache */
   /* replace1908_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1935, 5443, 5457, 5473 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search1909_0_0 -> 16 in the cache */
   /* search1909_0_1 -> 36 in the cache */
   /* search1909_0_2 -> 133 in the cache */
   /* search1909_0_3 -> 161 in the cache */
   /* search1909_0 -> 5468 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5468 },
      -1,
   } },

   /* replace1909_0_0 -> 16 in the cache */
   /* replace1909_0 -> 2988 in the cache */
   /* replace1909_1_0 -> 36 in the cache */
   /* replace1909_1 -> 4401 in the cache */
   /* replace1909_2_0 -> 133 in the cache */
   /* replace1909_2 -> 5460 in the cache */
   /* replace1909_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2988, 4401, 5460, 5476 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search1910_0_0 -> 16 in the cache */
   /* search1910_0_1 -> 36 in the cache */
   /* search1910_0_2 -> 133 in the cache */
   /* search1910_0_3 -> 161 in the cache */
   /* search1910_0 -> 5468 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5468 },
      -1,
   } },

   /* replace1910_0_0 -> 16 in the cache */
   /* replace1910_0 -> 3887 in the cache */
   /* replace1910_1_0 -> 36 in the cache */
   /* replace1910_1 -> 4072 in the cache */
   /* replace1910_2_0 -> 133 in the cache */
   /* replace1910_2 -> 5463 in the cache */
   /* replace1910_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3887, 4072, 5463, 5479 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search1911_0_0 -> 16 in the cache */
   /* search1911_0_1 -> 36 in the cache */
   /* search1911_0_2 -> 133 in the cache */
   /* search1911_0_3 -> 161 in the cache */
   /* search1911_0 -> 5468 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5468 },
      -1,
   } },

   /* replace1911_0_0 -> 16 in the cache */
   /* replace1911_0 -> 1946 in the cache */
   /* replace1911_1_0 -> 36 in the cache */
   /* replace1911_1 -> 5450 in the cache */
   /* replace1911_2_0 -> 133 in the cache */
   /* replace1911_2 -> 5466 in the cache */
   /* replace1911_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1946, 5450, 5466, 5482 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_used_by_if),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_lower_half_zero),
   (is_upper_half_zero),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2464, 1178, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2895, 2985, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2838, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2724, 2725, 0 },
   { 2726, 2727, 0 },
   { 2728, 1182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 16, 0 },
   { 123, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 253, 254, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 120, 0 },
   { 225, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 3591, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 333, 335, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 333, 335, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 336, 338, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 336, 338, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 36, 0 },
   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 36, 0 },
   { 348, 349, 7 },
   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 350, 351, 8 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 350, 351, 8 },
   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 342, 344, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 342, 344, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 345, 347, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 345, 347, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 36, 0 },
   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 36, 0 },
   { 354, 355, 7 },
   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 36, 0 },
   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 36, 0 },
   { 356, 357, 8 },
   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 291, 36, 0 },
   { 339, 341, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 291, 36, 0 },
   { 339, 341, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 36, 0 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 36, 0 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 36, 0 },
   { 293, 36, 0 },
   { 352, 353, 7 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 669, 673, 20 },
   { 2834, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 674, 683, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 684, 685, 22 },
   { 2832, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 688, 24 },
   { 2835, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 689, 691, 25 },
   { 2833, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 723, 728, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 757, 758, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 751, 754, 0 },
   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 761, 754, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2468, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2468, 1178, 0 },
   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2467, 32, 0 },
   { 2918, 2919, 55 },
   { 2920, 387, 55 },
   { 2921, 2922, 55 },
   { 2952, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2466, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2466, 1178, 0 },
   { 2467, 32, 0 },
   { 2918, 2919, 55 },
   { 2920, 387, 55 },
   { 2921, 2922, 55 },
   { 2952, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 2885, 1033, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1274, 61, 0 },
   { 1275, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1277, 32, 0 },
   { 1278, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3502, 3505, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3497, 3501, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3497, 3501, 81 },
   { 4640, 11, 0 },
   { 4693, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3506, 3510, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3506, 3510, 82 },
   { 4745, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3511, 3514, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3511, 3514, 82 },
   { 4718, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2304, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2304, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2304, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2304, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2299, 2305, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2301, 2306, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2325, 2332, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2333, 2335, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 2338, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2339, 2342, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2343, 2347, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2350, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2351, 2356, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2363, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 2370, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2371, 2374, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 2380, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 2385, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2386, 2389, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2390, 2395, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2396, 2400, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 2404, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2405, 2410, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2411, 2415, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3139, 3140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3139, 3140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2474, 2477, 47 },
   { 2481, 2484, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2487, 2489, 47 },
   { 2492, 2494, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2502, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2502, 48 },
   { 2523, 32, 0 },
   { 2524, 236, 0 },
   { 2525, 2522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2502, 48 },
   { 2526, 2497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2502, 48 },
   { 2523, 32, 0 },
   { 2524, 236, 0 },
   { 2525, 2522, 0 },
   { 2526, 2497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2515, 2569, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2564, 2566, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2563, 2544, 0 },
   { 2564, 2566, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2571, 2653, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 2723, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2886, 2980, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2896, 2987, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2904, 2988, 61 },
   { 2904, 2988, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2906, 2989, 61 },
   { 2906, 2989, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3443, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2940, 393, 55 },
   { 2941, 396, 55 },
   { 2942, 400, 55 },
   { 2943, 403, 55 },
   { 2956, 425, 56 },
   { 2957, 428, 56 },
   { 3443, 120, 0 },
   { 3445, 3447, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3444, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2944, 374, 55 },
   { 2945, 378, 55 },
   { 2946, 383, 55 },
   { 2947, 387, 55 },
   { 2958, 417, 56 },
   { 2959, 420, 56 },
   { 3444, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2981, 2984, 59 },
   { 2981, 3583, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2991, 3581, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2998, 3582, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3026, 3580, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3026, 3580, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3026, 3580, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3026, 3580, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3135, 16, 0 },
   { 3136, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3137, 3138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3141, 3143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3144, 3145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3493, 3496, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3478, 3482, 78 },
   { 3478, 3486, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3488, 3492, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3296, 3299, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3300, 3303, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3304, 3307, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3308, 3309, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3314, 3318, 65 },
   { 3314, 3415, 74 },
   { 3314, 3417, 75 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3319, 3322, 66 },
   { 3333, 3337, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3323, 3325, 66 },
   { 3338, 3340, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3326, 3329, 66 },
   { 3341, 3345, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3330, 3332, 66 },
   { 3346, 3348, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3349, 3353, 68 },
   { 3354, 3356, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3357, 3358, 69 },
   { 3359, 3362, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3363, 3376, 71 },
   { 3655, 3666, 102 },
   { 3675, 3686, 102 },
   { 3695, 3705, 102 },
   { 3363, 3720, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3377, 3385, 71 },
   { 3667, 3674, 102 },
   { 3687, 3694, 102 },
   { 3706, 3713, 102 },
   { 3377, 3725, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3421, 3424, 76 },
   { 3421, 3471, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3425, 3427, 76 },
   { 3425, 3477, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3428, 2457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3516, 3522, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3523, 3528, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3529, 3536, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3537, 3542, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3543, 3548, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3549, 3556, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3557, 3564, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3565, 3574, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3584, 3586, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3592, 909, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3593, 3597, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3598, 3602, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3603, 3604, 98 },
   { 3603, 49, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3605, 3598, 99 },
   { 3605, 3607, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3608, 3593, 100 },
   { 3608, 49, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3609, 3604, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3610, 536, 0 },
   { 3611, 3612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3609, 3604, 0 },
   { 3610, 536, 0 },
   { 3611, 3612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3610, 536, 0 },
   { 3611, 3612, 0 },
   { 3613, 3615, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3609, 3604, 0 },
   { 3610, 536, 0 },
   { 3611, 3612, 0 },
   { 3613, 3615, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3617, 3619, 1 },
   { 3621, 3625, 1 },
   { 3626, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3777, 715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3778, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3780, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4771, 4791, 105 },
   { 4793, 4811, 105 },
   { 4813, 4834, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5154, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5155, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5156, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5157, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5158, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5159, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5161, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5164, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5162, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5162, 133, 0 },
   { 5164, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5435, 5439, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4629, 4627, 0 },
   { 4682, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4654, 4627, 0 },
   { 4707, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3171, 3172, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3171, 3172, 0 },
   { 3215, 3172, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3154, 3155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 980, 983, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 5150, 5153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4629, 4627, 0 },
   { 4682, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4654, 4627, 0 },
   { 4707, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4629, 4627, 0 },
   { 4682, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4654, 4627, 0 },
   { 4707, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4629, 4627, 0 },
   { 4654, 4627, 0 },
   { 4682, 49, 0 },
   { 4707, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4629, 4627, 0 },
   { 4682, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4629, 4627, 0 },
   { 4682, 49, 0 },
   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4654, 4627, 0 },
   { 4707, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4654, 4627, 0 },
   { 4707, 49, 0 },
   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4734, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3261, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3261, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 191, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3201, 3202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3201, 3202, 0 },
   { 3243, 3202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 297, 299, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 301, 302, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 308, 309, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 311, 312, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 304, 306, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5146, 5149, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 177, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4651, 3677, 0 },
   { 4679, 3697, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4731, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3025, 3026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2556, 2558, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3650, 3632, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2556, 2558, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3289, 103, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2733, 715, 0 },
   { 2734, 1081, 0 },
   { 2737, 2738, 0 },
   { 2739, 2740, 0 },
   { 2743, 2744, 0 },
   { 2745, 2746, 0 },
   { 2747, 2748, 0 },
   { 2749, 2750, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2756, 2757, 54 },
   { 2758, 2759, 54 },
   { 2762, 2763, 54 },
   { 2764, 2765, 54 },
   { 2766, 3, 0 },
   { 2769, 2173, 0 },
   { 2770, 2772, 0 },
   { 2774, 1177, 0 },
   { 2775, 2771, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5229, 5230, 0 },
   { 5233, 5230, 0 },
   { 5236, 5230, 0 },
   { 5239, 5230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5410, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5414, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5216, 5217, 0 },
   { 5220, 5217, 0 },
   { 5223, 5217, 0 },
   { 5226, 5217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5203, 5204, 0 },
   { 5207, 5204, 0 },
   { 5210, 5204, 0 },
   { 5213, 5204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5188, 5190, 0 },
   { 5193, 5190, 0 },
   { 5196, 5190, 0 },
   { 5199, 5190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5242, 5243, 0 },
   { 5246, 5243, 0 },
   { 5249, 5243, 0 },
   { 5252, 5243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5255, 5256, 0 },
   { 5259, 5256, 0 },
   { 5262, 5256, 0 },
   { 5265, 5256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5398, 5399, 0 },
   { 5398, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5167, 5168, 0 },
   { 5171, 5168, 0 },
   { 5173, 5175, 0 },
   { 5177, 5175, 0 },
   { 5180, 5182, 0 },
   { 5184, 5182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 1247, 1245, 0 },
   { 1250, 1252, 0 },
   { 1255, 1252, 0 },
   { 1259, 1261, 0 },
   { 1264, 1261, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3290, 3291, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1715, 1717, 0 },
   { 1822, 1824, 0 },
   { 1905, 1907, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5281, 5282, 0 },
   { 5285, 5282, 0 },
   { 5288, 5282, 0 },
   { 5291, 5282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5294, 5295, 0 },
   { 5298, 5295, 0 },
   { 5301, 5295, 0 },
   { 5304, 5295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5307, 5308, 0 },
   { 5311, 5308, 0 },
   { 5314, 5308, 0 },
   { 5317, 5308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5320, 5321, 0 },
   { 5324, 5321, 0 },
   { 5327, 5321, 0 },
   { 5330, 5321, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5333, 5334, 0 },
   { 5337, 5334, 0 },
   { 5340, 5334, 0 },
   { 5343, 5334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5346, 5347, 0 },
   { 5350, 5347, 0 },
   { 5353, 5347, 0 },
   { 5356, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4621, 4616, 0 },
   { 4674, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4646, 4616, 0 },
   { 4699, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4751, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4726, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5268, 5269, 0 },
   { 5272, 5269, 0 },
   { 5275, 5269, 0 },
   { 5278, 5269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5390, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5394, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5359, 5360, 0 },
   { 5363, 5360, 0 },
   { 5367, 5369, 0 },
   { 5372, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5386, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5377, 5379, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5382, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5402, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 5406, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3271, 3262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3273, 3265, 0 },
   { 3276, 3265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3274, 3268, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2074, 2075, 0 },
   { 2100, 2101, 0 },
   { 2126, 904, 0 },
   { 2151, 2152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2074, 2075, 0 },
   { 2100, 2101, 0 },
   { 2126, 904, 0 },
   { 2151, 2152, 0 },
   { 2464, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 778, 780, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 782, 792, 0 },
   { 805, 814, 0 },
   { 827, 835, 0 },
   { 848, 857, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 976, 978, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 948, 949, 0 },
   { 955, 956, 0 },
   { 961, 962, 0 },
   { 969, 970, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 872, 0 },
   { 877, 880, 0 },
   { 885, 887, 0 },
   { 892, 895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 869, 872, 0 },
   { 877, 880, 0 },
   { 885, 887, 0 },
   { 892, 895, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 872, 0 },
   { 877, 880, 0 },
   { 885, 887, 0 },
   { 892, 895, 0 },
   { 2074, 2075, 0 },
   { 2100, 2101, 0 },
   { 2126, 904, 0 },
   { 2151, 2152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 872, 0 },
   { 877, 880, 0 },
   { 885, 887, 0 },
   { 892, 895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 873, 872, 0 },
   { 881, 880, 0 },
   { 888, 887, 0 },
   { 896, 895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 873, 872, 0 },
   { 881, 880, 0 },
   { 888, 887, 0 },
   { 896, 895, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 873, 872, 0 },
   { 881, 880, 0 },
   { 888, 887, 0 },
   { 896, 895, 0 },
   { 2074, 2075, 0 },
   { 2100, 2101, 0 },
   { 2126, 904, 0 },
   { 2151, 2152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 873, 872, 0 },
   { 881, 880, 0 },
   { 888, 887, 0 },
   { 896, 895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { 3020, 3021, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 909, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 904, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 964, 962, 0 },
   { 972, 970, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 913, 915, 0 },
   { 919, 921, 0 },
   { 925, 927, 0 },
   { 931, 933, 0 },
   { 937, 939, 0 },
   { 943, 945, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2456, 2457, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2456, 2457, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 3245, 3247, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2455, 3, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 952, 951, 0 },
   { 959, 958, 0 },
   { 966, 965, 0 },
   { 974, 973, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2003, 2004, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 2456, 2457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 184, 0 },
   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 5056, 5057, 0 },
   { 5059, 5060, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 5045, 5046, 0 },
   { 5049, 5050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 5051, 5052, 0 },
   { 5054, 5055, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1032, 1033, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2420, 2419, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1994, 1996, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1999, 2000, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2460, 2461, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 1582, 1568, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 1692, 1693, 0 },
   { 1694, 1693, 0 },
   { 1799, 1800, 0 },
   { 1801, 1800, 0 },
   { 1882, 1883, 0 },
   { 1884, 1883, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 1582, 1568, 0 },
   { 1692, 1693, 0 },
   { 1694, 1693, 0 },
   { 1799, 1800, 0 },
   { 1801, 1800, 0 },
   { 1882, 1883, 0 },
   { 1884, 1883, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 1587, 1571, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 1587, 1571, 0 },
   { 1692, 1693, 0 },
   { 1694, 1693, 0 },
   { 1799, 1800, 0 },
   { 1801, 1800, 0 },
   { 1882, 1883, 0 },
   { 1884, 1883, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1035, 1033, 0 },
   { 1566, 1568, 0 },
   { 1569, 1571, 0 },
   { 1582, 1568, 0 },
   { 1587, 1571, 0 },
   { 1692, 1693, 0 },
   { 1694, 1693, 0 },
   { 1799, 1800, 0 },
   { 1801, 1800, 0 },
   { 1882, 1883, 0 },
   { 1884, 1883, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 1590, 1574, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1210, 1211, 35 },
   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 1695, 1696, 0 },
   { 1697, 1696, 0 },
   { 1802, 1803, 0 },
   { 1804, 1803, 0 },
   { 1885, 1886, 0 },
   { 1887, 1886, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1210, 1211, 35 },
   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 1590, 1574, 0 },
   { 1695, 1696, 0 },
   { 1697, 1696, 0 },
   { 1802, 1803, 0 },
   { 1804, 1803, 0 },
   { 1885, 1886, 0 },
   { 1887, 1886, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 1593, 1577, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1210, 1211, 35 },
   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 1593, 1577, 0 },
   { 1695, 1696, 0 },
   { 1697, 1696, 0 },
   { 1802, 1803, 0 },
   { 1804, 1803, 0 },
   { 1885, 1886, 0 },
   { 1887, 1886, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1210, 1211, 35 },
   { 1572, 1574, 0 },
   { 1575, 1577, 0 },
   { 1590, 1574, 0 },
   { 1593, 1577, 0 },
   { 1695, 1696, 0 },
   { 1697, 1696, 0 },
   { 1802, 1803, 0 },
   { 1804, 1803, 0 },
   { 1885, 1886, 0 },
   { 1887, 1886, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1040, 1033, 0 },
   { 1634, 1635, 0 },
   { 1636, 1637, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1033, 0 },
   { 1642, 1643, 0 },
   { 1644, 1645, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1638, 1639, 0 },
   { 1640, 1641, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1646, 1647, 0 },
   { 1648, 1649, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1038, 1033, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2056, 2058, 40 },
   { 2056, 2064, 42 },
   { 2082, 2084, 40 },
   { 2082, 2090, 42 },
   { 2108, 2110, 40 },
   { 2108, 2116, 42 },
   { 2133, 2135, 40 },
   { 2133, 2141, 42 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2068, 2069, 43 },
   { 2094, 2095, 43 },
   { 2120, 2121, 43 },
   { 2145, 2146, 43 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1982, 1983, 0 },
   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4657, 1965, 0 },
   { 4685, 1973, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1977, 1979, 0 },
   { 2443, 32, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1986, 1987, 0 },
   { 2443, 32, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4737, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1990, 1991, 0 },
   { 2443, 32, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 2454, 2237, 0 },
   { 3249, 3251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2027, 2028, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2421, 2422, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2022, 2024, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2025, 2026, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 2462, 2463, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1675, 1008, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1554, 1535, 0 },
   { 1675, 1008, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1675, 1008, 0 },
   { 1678, 1680, 0 },
   { 1683, 1680, 0 },
   { 1785, 1787, 0 },
   { 1790, 1787, 0 },
   { 1868, 1870, 0 },
   { 1873, 1870, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1554, 1535, 0 },
   { 1675, 1008, 0 },
   { 1678, 1680, 0 },
   { 1683, 1680, 0 },
   { 1785, 1787, 0 },
   { 1790, 1787, 0 },
   { 1868, 1870, 0 },
   { 1873, 1870, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1559, 1541, 0 },
   { 1675, 1008, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1559, 1541, 0 },
   { 1675, 1008, 0 },
   { 1678, 1680, 0 },
   { 1683, 1680, 0 },
   { 1785, 1787, 0 },
   { 1790, 1787, 0 },
   { 1868, 1870, 0 },
   { 1873, 1870, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1533, 1535, 0 },
   { 1539, 1541, 0 },
   { 1554, 1535, 0 },
   { 1559, 1541, 0 },
   { 1675, 1008, 0 },
   { 1678, 1680, 0 },
   { 1683, 1680, 0 },
   { 1785, 1787, 0 },
   { 1790, 1787, 0 },
   { 1868, 1870, 0 },
   { 1873, 1870, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 1562, 1546, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 1686, 1688, 0 },
   { 1691, 1688, 0 },
   { 1793, 1795, 0 },
   { 1798, 1795, 0 },
   { 1876, 1878, 0 },
   { 1881, 1878, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 1562, 1546, 0 },
   { 1686, 1688, 0 },
   { 1691, 1688, 0 },
   { 1793, 1795, 0 },
   { 1798, 1795, 0 },
   { 1876, 1878, 0 },
   { 1881, 1878, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 1565, 1551, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 1565, 1551, 0 },
   { 1686, 1688, 0 },
   { 1691, 1688, 0 },
   { 1793, 1795, 0 },
   { 1798, 1795, 0 },
   { 1876, 1878, 0 },
   { 1881, 1878, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1544, 1546, 0 },
   { 1549, 1551, 0 },
   { 1562, 1546, 0 },
   { 1565, 1551, 0 },
   { 1686, 1688, 0 },
   { 1691, 1688, 0 },
   { 1793, 1795, 0 },
   { 1798, 1795, 0 },
   { 1876, 1878, 0 },
   { 1881, 1878, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1596, 1598, 0 },
   { 1601, 1603, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1616, 1618, 0 },
   { 1621, 1623, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1626, 1628, 0 },
   { 1631, 1633, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2163, 2164, 0 },
   { 2167, 2168, 0 },
   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2065, 2067, 43 },
   { 2091, 2093, 43 },
   { 2117, 2119, 43 },
   { 2142, 2144, 43 },
   { 2159, 2160, 0 },
   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2061, 2062, 41 },
   { 2061, 2070, 42 },
   { 2087, 2088, 41 },
   { 2087, 2096, 42 },
   { 2113, 2114, 41 },
   { 2113, 2122, 42 },
   { 2138, 2139, 41 },
   { 2138, 2147, 42 },
   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2016, 2017, 0 },
   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4660, 2007, 0 },
   { 4688, 2011, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4688, 2011, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2013, 2015, 0 },
   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4660, 2007, 0 },
   { 4713, 2011, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2018, 2019, 0 },
   { 2446, 32, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4740, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2020, 2021, 0 },
   { 2446, 32, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 3027, 3026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4691, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4663, 2031, 0 },
   { 4716, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4638, 2031, 0 },
   { 4691, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4663, 2031, 0 },
   { 4716, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 3253, 3255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2051, 2052, 0 },
   { 2449, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2046, 2048, 0 },
   { 2449, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2049, 2050, 0 },
   { 2449, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2040, 2041, 0 },
   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4691, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4663, 2031, 0 },
   { 4691, 2035, 0 },
   { 4716, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4691, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4691, 2035, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2037, 2039, 0 },
   { 2449, 61, 0 },
   { 4663, 2031, 0 },
   { 4716, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4663, 2031, 0 },
   { 4716, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4663, 2031, 0 },
   { 4716, 2035, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2042, 2043, 0 },
   { 2449, 61, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4743, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2044, 2045, 0 },
   { 2449, 61, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2078, 2079, 0 },
   { 2104, 2105, 0 },
   { 2129, 2130, 0 },
   { 2155, 2156, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2078, 2079, 0 },
   { 2104, 2105, 0 },
   { 2129, 2130, 0 },
   { 2155, 2156, 0 },
   { 2468, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2468, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 874, 876, 0 },
   { 882, 884, 0 },
   { 889, 891, 0 },
   { 897, 899, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 874, 876, 0 },
   { 882, 884, 0 },
   { 889, 891, 0 },
   { 897, 899, 0 },
   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 2950, 425, 56 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 874, 876, 0 },
   { 882, 884, 0 },
   { 889, 891, 0 },
   { 897, 899, 0 },
   { 2078, 2079, 0 },
   { 2104, 2105, 0 },
   { 2129, 2130, 0 },
   { 2155, 2156, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 874, 876, 0 },
   { 882, 884, 0 },
   { 889, 891, 0 },
   { 897, 899, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 794, 796, 0 },
   { 816, 818, 0 },
   { 837, 839, 0 },
   { 859, 861, 0 },
   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { 3022, 3019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2076, 2077, 0 },
   { 2102, 2103, 0 },
   { 2127, 2128, 0 },
   { 2153, 2154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2076, 2077, 0 },
   { 2102, 2103, 0 },
   { 2127, 2128, 0 },
   { 2153, 2154, 0 },
   { 2466, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2467, 32, 0 },
   { 2918, 2919, 55 },
   { 2920, 387, 55 },
   { 2921, 2922, 55 },
   { 2951, 417, 56 },
   { 2952, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2467, 32, 0 },
   { 2918, 2919, 55 },
   { 2920, 387, 55 },
   { 2921, 2922, 55 },
   { 2952, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2076, 2077, 0 },
   { 2102, 2103, 0 },
   { 2127, 2128, 0 },
   { 2153, 2154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 798, 803, 0 },
   { 820, 825, 0 },
   { 841, 846, 0 },
   { 863, 868, 0 },
   { 2467, 32, 0 },
   { 2918, 2919, 55 },
   { 2920, 387, 55 },
   { 2921, 2922, 55 },
   { 2952, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3095, 3096, 0 },
   { 3098, 400, 0 },
   { 3099, 396, 0 },
   { 3100, 393, 0 },
   { 3102, 3073, 0 },
   { 3104, 3068, 0 },
   { 3106, 3063, 0 },
   { 3108, 3060, 0 },
   { 3110, 3056, 0 },
   { 3112, 3052, 0 },
   { 3114, 3115, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3045, 2913, 0 },
   { 3047, 396, 0 },
   { 3048, 400, 0 },
   { 3049, 403, 0 },
   { 3051, 3052, 0 },
   { 3054, 3056, 0 },
   { 3058, 3060, 0 },
   { 3061, 3063, 0 },
   { 3066, 3068, 0 },
   { 3071, 3073, 0 },
   { 3074, 2917, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3075, 2913, 0 },
   { 3077, 396, 0 },
   { 3078, 400, 0 },
   { 3079, 403, 0 },
   { 3081, 3052, 0 },
   { 3083, 3056, 0 },
   { 3085, 3060, 0 },
   { 3087, 3063, 0 },
   { 3089, 3068, 0 },
   { 3091, 3073, 0 },
   { 3092, 2917, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2949, 2933, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2948, 2933, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3093, 2927, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3037, 3038, 0 },
   { 3039, 3040, 0 },
   { 3041, 3042, 0 },
   { 3043, 3044, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3116, 3117, 0 },
   { 3118, 383, 0 },
   { 3119, 378, 0 },
   { 3120, 374, 0 },
   { 3121, 3122, 0 },
   { 3123, 3124, 0 },
   { 3125, 3126, 0 },
   { 3127, 3128, 0 },
   { 3129, 3130, 0 },
   { 3131, 3132, 0 },
   { 3133, 3134, 0 },
   { 3497, 3501, 81 },
   { 4640, 11, 0 },
   { 4693, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3029, 3030, 0 },
   { 3031, 3032, 0 },
   { 3033, 3034, 0 },
   { 3035, 3036, 0 },
   { 3497, 3501, 81 },
   { 4640, 11, 0 },
   { 4693, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2897, 21, 0 },
   { 2886, 2980, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 2895, 2985, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 2895, 2985, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2895, 2985, 60 },
   { 2995, 2895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2887, 16, 0 },
   { 2895, 2985, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2295, 0 },
   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2297, 0 },
   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2299, 0 },
   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2302, 2301, 0 },
   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2837, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3747, 715, 0 },
   { 3750, 6, 0 },
   { 3754, 11, 0 },
   { 3756, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3186, 3188, 0 },
   { 3190, 3188, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3186, 3188, 0 },
   { 3190, 3188, 0 },
   { 3217, 3188, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3193, 3195, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3193, 3195, 0 },
   { 3224, 3226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3197, 3199, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3197, 3199, 0 },
   { 3234, 3236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 5133, 5136, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3159, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3159, 3161, 0 },
   { 3204, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3167, 3169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3167, 3169, 0 },
   { 3208, 3169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 5137, 5140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { 5137, 5140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2423, 1217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2554, 2555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2559, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3148, 3149, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3284, 3285, 0 },
   { 3287, 3288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3148, 3149, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3163, 3165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3163, 3165, 0 },
   { 3206, 3165, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 5142, 5145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3284, 3285, 0 },
   { 3287, 3288, 0 },
   { 5142, 5145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3148, 3149, 6 },
   { 3284, 3285, 0 },
   { 3287, 3288, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 2561, 2562, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { 3211, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { 3211, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { 3211, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3177, 3179, 0 },
   { 3211, 3179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3182, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3182, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3182, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3182, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3151, 3152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3151, 3152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3151, 3152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3151, 3152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { 3212, 3181, 0 },
   { 3213, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { 3212, 3181, 0 },
   { 3213, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { 3212, 3181, 0 },
   { 3213, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3180, 3181, 0 },
   { 3212, 3181, 0 },
   { 3213, 3183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3153, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 253, 254, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3153, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3153, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3153, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 1468, 202, 0 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1463, 1465, 0 },
   { 202, 1455, 37 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1467, 1466, 0 },
   { 202, 1455, 37 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1140, 1141, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1061, 1062, 0 },
   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1183, 1184, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1140, 1141, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1140, 1141, 0 },
   { 1159, 1161, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1011, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { 5062, 5065, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1175, 1081, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1194, 1184, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1047, 1048, 0 },
   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1140, 1141, 0 },
   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1113, 1112, 0 },
   { 1344, 1112, 0 },
   { 1348, 1112, 0 },
   { 1352, 1112, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 1186, 0 },
   { 4548, 4550, 104 },
   { 4565, 4550, 104 },
   { 4573, 4574, 0 },
   { 4587, 4589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 670, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2204, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2198, 2199, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1053, 1054, 0 },
   { 1121, 670, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1203, 1204, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1190, 1191, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1066, 1068, 0 },
   { 1076, 1077, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { 5086, 5091, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2204, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1201, 1202, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2198, 2199, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1044, 1034, 0 },
   { 1121, 670, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 670, 0 },
   { 1136, 1137, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 2204, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 2198, 2199, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 1145, 1148, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { 5078, 5081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2200, 1034, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2200, 1034, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 670, 0 },
   { 2200, 1034, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2200, 1034, 0 },
   { 2204, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2198, 2199, 0 },
   { 2200, 1034, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1199, 1200, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 670, 0 },
   { 2205, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2204, 1033, 0 },
   { 2205, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2198, 2199, 0 },
   { 2205, 1033, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { 4555, 4556, 104 },
   { 4562, 4563, 104 },
   { 4568, 4556, 104 },
   { 4572, 4563, 104 },
   { 4579, 4580, 0 },
   { 4584, 4585, 0 },
   { 4594, 4595, 0 },
   { 4600, 4601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1122, 1123, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 2207, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1058, 0 },
   { 1122, 1123, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1207, 1208, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { 5096, 5099, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1080, 1081, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1197, 1198, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 2207, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1045, 1046, 0 },
   { 1122, 1123, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1185, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1138, 1139, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1138, 1139, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1122, 1123, 0 },
   { 1138, 1139, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1138, 1139, 0 },
   { 2202, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1138, 1139, 0 },
   { 2206, 2207, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1138, 1139, 0 },
   { 1154, 1155, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1002, 0 },
   { 1075, 1058, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { 5092, 5095, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 1046, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2208, 1046, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1122, 1123, 0 },
   { 2208, 1046, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1186, 0 },
   { 2208, 1046, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2206, 2207, 0 },
   { 2208, 1046, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1195, 1196, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1122, 1123, 0 },
   { 2203, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1186, 0 },
   { 2203, 1186, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1186, 0 },
   { 2206, 2207, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { 4553, 4554, 104 },
   { 4559, 4561, 104 },
   { 4567, 4554, 104 },
   { 4571, 4561, 104 },
   { 4577, 4578, 0 },
   { 4582, 4583, 0 },
   { 4592, 4593, 0 },
   { 4597, 4599, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1142, 1143, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1059, 1060, 0 },
   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1181, 1182, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1142, 1143, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1142, 1143, 0 },
   { 1167, 1168, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1073, 1008, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { 5066, 5069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 715, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1193, 1182, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1049, 1050, 0 },
   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1142, 1143, 0 },
   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1102, 1101, 0 },
   { 1345, 1329, 0 },
   { 1349, 1329, 0 },
   { 1353, 1329, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2442, 1033, 0 },
   { 4551, 4552, 104 },
   { 4566, 4552, 104 },
   { 4575, 4576, 0 },
   { 4590, 4591, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1445, 32, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1509, 1510, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1223, 1226, 0 },
   { 1269, 32, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1455, 202, 35 },
   { 1459, 1460, 35 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1219, 1217, 0 },
   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1449, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1449, 103, 0 },
   { 1453, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1507, 1508, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1457, 202, 35 },
   { 1462, 1460, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1449, 103, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1449, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5419, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2072, 6, 0 },
   { 2098, 11, 0 },
   { 2124, 16, 0 },
   { 2149, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 2838, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 2838, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2838, 32, 0 },
   { 5423, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 2724, 2725, 0 },
   { 2726, 2727, 0 },
   { 2728, 1182, 0 },
   { 111, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2724, 2725, 0 },
   { 2726, 2727, 0 },
   { 2728, 1182, 0 },
   { 2803, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2724, 2725, 0 },
   { 2726, 2727, 0 },
   { 2728, 1182, 0 },
   { 2796, 11, 0 },
   { 2798, 16, 0 },
   { 3748, 715, 0 },
   { 3752, 6, 0 },
   { 2796, 11, 0 },
   { 2798, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2724, 2725, 0 },
   { 2726, 2727, 0 },
   { 2728, 1182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2724, 2725, 0 },
   { 2726, 2727, 0 },
   { 2728, 1182, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 3586, 3584, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1441, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1450, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1450, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 3588, 3584, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1450, 106, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1450, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1724, 11, 0 },
   { 1831, 16, 0 },
   { 1914, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3759, 2787, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2799, 2800, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1722, 11, 0 },
   { 1829, 16, 0 },
   { 1912, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1750, 1751, 0 },
   { 1773, 1774, 0 },
   { 1857, 1858, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1938, 1939, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1726, 11, 0 },
   { 1833, 16, 0 },
   { 1916, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3758, 2787, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2801, 2802, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1725, 11, 0 },
   { 1832, 16, 0 },
   { 1915, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1748, 1749, 0 },
   { 1771, 1772, 0 },
   { 1855, 1856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1936, 1937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1753, 1754, 0 },
   { 1776, 1754, 0 },
   { 1859, 1752, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1745, 1342, 0 },
   { 1768, 1342, 0 },
   { 1852, 1346, 0 },
   { 3757, 1466, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { 5469, 5471, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { 5453, 5455, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { 5440, 5441, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1756, 1757, 0 },
   { 1778, 1757, 0 },
   { 1860, 1755, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1740, 11, 0 },
   { 1763, 11, 0 },
   { 1847, 16, 0 },
   { 2830, 16, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2823, 16, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2828, 1932, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2829, 1929, 0 },
   { 3774, 11, 0 },
   { 3775, 16, 0 },
   { 3776, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1930, 1931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2817, 1342, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5472, 5474, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5456, 5458, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5442, 5444, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1933, 1934, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2806, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2805, 1208, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5427, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1007, 1008, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1001, 1002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1004, 1005, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1010, 1011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1013, 1014, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1016, 1017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1019, 1020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1022, 1023, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1025, 1026, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1028, 1029, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 1172, 0 },
   { 2434, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 1172, 0 },
   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1359, 1360, 0 },
   { 1364, 1363, 0 },
   { 1381, 1382, 0 },
   { 1386, 1385, 0 },
   { 1403, 1404, 0 },
   { 1408, 1407, 0 },
   { 1423, 1424, 0 },
   { 1428, 1427, 0 },
   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { 5070, 5073, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 1081, 0 },
   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1367, 1360, 0 },
   { 1369, 1363, 0 },
   { 1389, 1382, 0 },
   { 1391, 1385, 0 },
   { 1411, 1404, 0 },
   { 1412, 1407, 0 },
   { 1431, 1424, 0 },
   { 1433, 1427, 0 },
   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1372, 1360, 0 },
   { 1374, 1363, 0 },
   { 1394, 1382, 0 },
   { 1396, 1385, 0 },
   { 1415, 1404, 0 },
   { 1416, 1407, 0 },
   { 1436, 1424, 0 },
   { 1438, 1427, 0 },
   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { 3911, 3916, 103 },
   { 3958, 3963, 103 },
   { 4004, 4009, 103 },
   { 4071, 4076, 104 },
   { 4122, 4127, 104 },
   { 4200, 4205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { 4254, 4257, 103 },
   { 4294, 4298, 103 },
   { 4336, 4341, 103 },
   { 4400, 4405, 104 },
   { 4445, 4450, 104 },
   { 4517, 4522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { 3465, 3462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { 3461, 3462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 1112, 0 },
   { 1332, 1112, 0 },
   { 1336, 1112, 0 },
   { 1340, 1112, 0 },
   { 2434, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 3893, 3895, 103 },
   { 3950, 3895, 103 },
   { 3995, 3895, 103 },
   { 4042, 4043, 104 },
   { 4056, 4058, 104 },
   { 4107, 4043, 104 },
   { 4115, 4058, 104 },
   { 4159, 4160, 0 },
   { 4172, 4173, 0 },
   { 4185, 4187, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 4238, 4240, 103 },
   { 4286, 4240, 103 },
   { 4328, 4240, 103 },
   { 4372, 4373, 104 },
   { 4385, 4387, 104 },
   { 4430, 4373, 104 },
   { 4438, 4387, 104 },
   { 4477, 4478, 0 },
   { 4490, 4491, 0 },
   { 4502, 4504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1173, 1174, 0 },
   { 2435, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1173, 1174, 0 },
   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1361, 1360, 0 },
   { 1362, 1363, 0 },
   { 1383, 1382, 0 },
   { 1384, 1385, 0 },
   { 1405, 1404, 0 },
   { 1406, 1407, 0 },
   { 1425, 1424, 0 },
   { 1426, 1427, 0 },
   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { 5074, 5077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 715, 0 },
   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1366, 1363, 0 },
   { 1370, 1360, 0 },
   { 1388, 1385, 0 },
   { 1392, 1382, 0 },
   { 1410, 1407, 0 },
   { 1413, 1404, 0 },
   { 1430, 1427, 0 },
   { 1434, 1424, 0 },
   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1371, 1363, 0 },
   { 1375, 1360, 0 },
   { 1393, 1385, 0 },
   { 1397, 1382, 0 },
   { 1414, 1407, 0 },
   { 1417, 1404, 0 },
   { 1435, 1427, 0 },
   { 1439, 1424, 0 },
   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { 3917, 3920, 103 },
   { 3964, 3967, 103 },
   { 4010, 4013, 103 },
   { 4077, 4080, 104 },
   { 4128, 4131, 104 },
   { 4206, 4209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { 4258, 4261, 103 },
   { 4299, 4302, 103 },
   { 4342, 4345, 103 },
   { 4406, 4409, 104 },
   { 4451, 4454, 104 },
   { 4523, 4526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { 3464, 3460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { 3455, 3460, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 1329, 0 },
   { 1333, 1329, 0 },
   { 1337, 1329, 0 },
   { 1341, 1329, 0 },
   { 2435, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 3896, 3897, 103 },
   { 3951, 3897, 103 },
   { 3996, 3897, 103 },
   { 4044, 4045, 104 },
   { 4059, 4060, 104 },
   { 4108, 4045, 104 },
   { 4116, 4060, 104 },
   { 4161, 4162, 0 },
   { 4174, 4175, 0 },
   { 4188, 4189, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 4241, 4242, 103 },
   { 4287, 4242, 103 },
   { 4329, 4242, 103 },
   { 4374, 4375, 104 },
   { 4388, 4389, 104 },
   { 4431, 4375, 104 },
   { 4439, 4389, 104 },
   { 4479, 4480, 0 },
   { 4492, 4493, 0 },
   { 4505, 4506, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2217, 2218, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1033, 0 },
   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { 5120, 5123, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1033, 0 },
   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1033, 0 },
   { 2281, 2282, 0 },
   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2217, 2218, 0 },
   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2217, 2218, 0 },
   { 2258, 2260, 0 },
   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { 4268, 4273, 103 },
   { 4309, 4314, 103 },
   { 4353, 4359, 103 },
   { 4415, 4419, 104 },
   { 4461, 4466, 104 },
   { 4532, 4536, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2238, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2238, 1033, 0 },
   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1033, 0 },
   { 2238, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1033, 0 },
   { 2238, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2217, 2218, 0 },
   { 2238, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { 5116, 5119, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2219, 1041, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2219, 1041, 0 },
   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2219, 1041, 0 },
   { 2236, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2219, 1041, 0 },
   { 2229, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2217, 2218, 0 },
   { 2219, 1041, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2219, 1041, 0 },
   { 2262, 2264, 0 },
   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1033, 0 },
   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1033, 0 },
   { 2236, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1033, 0 },
   { 2230, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2217, 2218, 0 },
   { 2230, 1033, 0 },
   { 2436, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 1033, 0 },
   { 2283, 2284, 0 },
   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2885, 1033, 0 },
   { 4262, 4267, 103 },
   { 4303, 4308, 103 },
   { 4346, 4352, 103 },
   { 4410, 4414, 104 },
   { 4455, 4460, 104 },
   { 4527, 4531, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 4245, 4246, 103 },
   { 4252, 4253, 103 },
   { 4289, 4246, 103 },
   { 4293, 4253, 103 },
   { 4331, 4246, 103 },
   { 4335, 4253, 103 },
   { 4378, 4379, 104 },
   { 4383, 4384, 104 },
   { 4392, 4393, 104 },
   { 4398, 4399, 104 },
   { 4433, 4379, 104 },
   { 4436, 4384, 104 },
   { 4441, 4393, 104 },
   { 4444, 4399, 104 },
   { 4483, 4484, 0 },
   { 4488, 4489, 0 },
   { 4496, 4497, 0 },
   { 4500, 4501, 0 },
   { 4509, 4510, 0 },
   { 4515, 4516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2239, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2232, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2239, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { 5128, 5131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1186, 0 },
   { 2266, 2268, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2232, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2232, 0 },
   { 2285, 2286, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { 4280, 4285, 103 },
   { 4321, 4326, 103 },
   { 4366, 4371, 103 },
   { 4425, 4429, 104 },
   { 4472, 4476, 104 },
   { 4542, 4546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2240, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2239, 1186, 0 },
   { 2240, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1186, 0 },
   { 2240, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2232, 0 },
   { 2240, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { 5124, 5127, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2233, 2234, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2233, 2234, 0 },
   { 2239, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1186, 0 },
   { 2233, 2234, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2231, 2232, 0 },
   { 2233, 2234, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2233, 2234, 0 },
   { 2287, 2288, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1186, 0 },
   { 2239, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1186, 0 },
   { 2222, 1186, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1186, 0 },
   { 2231, 2232, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1186, 0 },
   { 2270, 2272, 0 },
   { 2437, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { 4274, 4279, 103 },
   { 4315, 4320, 103 },
   { 4360, 4365, 103 },
   { 4420, 4424, 104 },
   { 4467, 4471, 104 },
   { 4537, 4541, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2437, 1186, 0 },
   { 4243, 4244, 103 },
   { 4249, 4251, 103 },
   { 4288, 4244, 103 },
   { 4292, 4251, 103 },
   { 4330, 4244, 103 },
   { 4334, 4251, 103 },
   { 4376, 4377, 104 },
   { 4381, 4382, 104 },
   { 4390, 4391, 104 },
   { 4395, 4397, 104 },
   { 4432, 4377, 104 },
   { 4435, 4382, 104 },
   { 4440, 4391, 104 },
   { 4443, 4397, 104 },
   { 4481, 4482, 0 },
   { 4486, 4487, 0 },
   { 4494, 4495, 0 },
   { 4498, 4499, 0 },
   { 4507, 4508, 0 },
   { 4512, 4514, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3430, 3431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3428, 2457, 0 },
   { 3430, 3431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 4602, 2985, 0 },
   { 4603, 2988, 0 },
   { 4605, 4463, 0 },
   { 4607, 1951, 0 },
   { 4608, 1967, 0 },
   { 4610, 4356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1746, 1330, 0 },
   { 1769, 1330, 0 },
   { 1853, 1334, 0 },
   { 3763, 2787, 0 },
   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 5478, 5480, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 5462, 5464, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 5447, 5448, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1742, 11, 0 },
   { 1765, 11, 0 },
   { 1849, 16, 0 },
   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 3782, 3783, 0 },
   { 3790, 3783, 0 },
   { 3796, 3783, 0 },
   { 3802, 3783, 0 },
   { 3807, 3808, 0 },
   { 3811, 3781, 0 },
   { 3815, 3781, 0 },
   { 3819, 3781, 0 },
   { 3823, 3824, 0 },
   { 3827, 3824, 0 },
   { 3829, 3830, 0 },
   { 3833, 3789, 0 },
   { 3837, 3789, 0 },
   { 3841, 3842, 0 },
   { 3845, 3842, 0 },
   { 3847, 3848, 0 },
   { 3850, 3842, 0 },
   { 3852, 3848, 0 },
   { 3854, 1741, 0 },
   { 3856, 3795, 0 },
   { 3860, 3861, 0 },
   { 3864, 3861, 0 },
   { 3866, 3867, 0 },
   { 3870, 3861, 0 },
   { 3872, 3867, 0 },
   { 3874, 1764, 0 },
   { 3876, 3861, 0 },
   { 3878, 3867, 0 },
   { 3880, 1764, 0 },
   { 3882, 1848, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 3785, 3786, 0 },
   { 3792, 3786, 0 },
   { 3798, 3786, 0 },
   { 3804, 3786, 0 },
   { 3812, 3784, 0 },
   { 3816, 3784, 0 },
   { 3820, 3784, 0 },
   { 3834, 3791, 0 },
   { 3838, 3791, 0 },
   { 3857, 3797, 0 },
   { 4639, 11, 0 },
   { 4692, 16, 0 },
   { 4744, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2824, 16, 0 },
   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 1943, 0 },
   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 3884, 3885, 0 },
   { 3884, 3885, 0 },
   { 3886, 3887, 0 },
   { 3886, 3887, 0 },
   { 3888, 3767, 0 },
   { 3888, 3767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1747, 1330, 0 },
   { 1770, 1330, 0 },
   { 1854, 1334, 0 },
   { 3761, 2787, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 5475, 5477, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 5459, 5461, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 5445, 5446, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2930, 2932, 55 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 3787, 3783, 0 },
   { 3793, 3783, 0 },
   { 3799, 3783, 0 },
   { 3805, 3783, 0 },
   { 3813, 3781, 0 },
   { 3817, 3781, 0 },
   { 3821, 3781, 0 },
   { 3835, 3789, 0 },
   { 3839, 3789, 0 },
   { 3858, 3795, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1744, 11, 0 },
   { 1767, 11, 0 },
   { 1851, 16, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 3788, 3786, 0 },
   { 3794, 3786, 0 },
   { 3800, 3786, 0 },
   { 3806, 3786, 0 },
   { 3809, 3810, 0 },
   { 3814, 3784, 0 },
   { 3818, 3784, 0 },
   { 3822, 3784, 0 },
   { 3825, 3826, 0 },
   { 3828, 3826, 0 },
   { 3831, 3832, 0 },
   { 3836, 3791, 0 },
   { 3840, 3791, 0 },
   { 3843, 3844, 0 },
   { 3846, 3844, 0 },
   { 3849, 2960, 0 },
   { 3851, 3844, 0 },
   { 3853, 2960, 0 },
   { 3855, 1743, 0 },
   { 3859, 3797, 0 },
   { 3862, 3863, 0 },
   { 3865, 3863, 0 },
   { 3868, 3869, 0 },
   { 3871, 3863, 0 },
   { 3873, 3869, 0 },
   { 3875, 1766, 0 },
   { 3877, 3863, 0 },
   { 3879, 3869, 0 },
   { 3881, 1766, 0 },
   { 3883, 1850, 0 },
   { 4611, 11, 0 },
   { 4664, 16, 0 },
   { 4717, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2825, 16, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2926, 2928, 55 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2827, 1940, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 3889, 1967, 0 },
   { 3889, 1967, 0 },
   { 3890, 2988, 0 },
   { 3890, 2988, 0 },
   { 3891, 3772, 0 },
   { 3891, 3772, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2896, 2987, 60 },
   { 3002, 2896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2888, 36, 0 },
   { 2896, 2987, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2904, 2988, 61 },
   { 2992, 2904, 0 },
   { 2904, 2988, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2904, 2988, 61 },
   { 3006, 2904, 0 },
   { 3007, 2906, 0 },
   { 2904, 2988, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2906, 2989, 61 },
   { 2999, 2906, 0 },
   { 2906, 2989, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3433, 3426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3435, 3426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3435, 3426, 0 },
   { 3443, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3433, 3426, 0 },
   { 3435, 3426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3436, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3437, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3437, 3423, 0 },
   { 3444, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3436, 3423, 0 },
   { 3437, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2990, 2991, 0 },
   { 2991, 3581, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3005, 2998, 0 },
   { 2991, 3581, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3003, 2991, 0 },
   { 3004, 2998, 0 },
   { 2991, 3581, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2997, 2998, 0 },
   { 2998, 3582, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3439, 3440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3442, 3440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3439, 3440, 0 },
   { 3442, 3440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 2211, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 5104, 5107, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1033, 0 },
   { 2273, 2274, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 2211, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 2211, 0 },
   { 2242, 2244, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 3930, 3936, 103 },
   { 3976, 3981, 103 },
   { 4023, 4029, 103 },
   { 4089, 4094, 104 },
   { 4140, 4146, 104 },
   { 4218, 4224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 1427, 3399, 73 },
   { 5100, 5103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1039, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1039, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 3392, 3394, 72 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1039, 0 },
   { 2223, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 2211, 0 },
   { 2212, 1039, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2212, 1039, 0 },
   { 2246, 2248, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 3392, 3394, 72 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 3387, 3390, 72 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1033, 0 },
   { 2224, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2210, 2211, 0 },
   { 2224, 1033, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 1033, 0 },
   { 2275, 2276, 0 },
   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 3387, 3390, 72 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 1427, 3399, 73 },
   { 3921, 3928, 103 },
   { 3968, 3975, 103 },
   { 4014, 4021, 103 },
   { 4081, 4088, 104 },
   { 4132, 4139, 104 },
   { 4210, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 3900, 3901, 103 },
   { 3909, 3910, 103 },
   { 3953, 3901, 103 },
   { 3957, 3910, 103 },
   { 3998, 3901, 103 },
   { 4002, 3910, 103 },
   { 4048, 4049, 104 },
   { 4053, 4054, 104 },
   { 4063, 4064, 104 },
   { 4069, 4070, 104 },
   { 4110, 4049, 104 },
   { 4113, 4054, 104 },
   { 4118, 4064, 104 },
   { 4121, 4070, 104 },
   { 4165, 4166, 0 },
   { 4170, 4171, 0 },
   { 4178, 4179, 0 },
   { 4182, 4183, 0 },
   { 4192, 4193, 0 },
   { 4198, 4199, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1186, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2226, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 5112, 5115, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1186, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1186, 0 },
   { 2250, 2252, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2226, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2226, 0 },
   { 2277, 2278, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 3943, 3948, 103 },
   { 3988, 3993, 103 },
   { 4036, 4041, 103 },
   { 4101, 4106, 104 },
   { 4153, 4158, 104 },
   { 4231, 4236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { 5108, 5111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2228, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2228, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 3397, 3398, 72 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1186, 0 },
   { 2227, 2228, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2225, 2226, 0 },
   { 2227, 2228, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2227, 2228, 0 },
   { 2279, 2280, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 3397, 3398, 72 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1186, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1186, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 3395, 3396, 72 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1186, 0 },
   { 2215, 1186, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1186, 0 },
   { 2225, 2226, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2215, 1186, 0 },
   { 2254, 2256, 0 },
   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 3395, 3396, 72 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { 3937, 3942, 103 },
   { 3982, 3987, 103 },
   { 4030, 4035, 103 },
   { 4095, 4100, 104 },
   { 4147, 4152, 104 },
   { 4225, 4230, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 3898, 3899, 103 },
   { 3906, 3908, 103 },
   { 3952, 3899, 103 },
   { 3956, 3908, 103 },
   { 3997, 3899, 103 },
   { 4001, 3908, 103 },
   { 4046, 4047, 104 },
   { 4051, 4052, 104 },
   { 4061, 4062, 104 },
   { 4066, 4068, 104 },
   { 4109, 4047, 104 },
   { 4112, 4052, 104 },
   { 4117, 4062, 104 },
   { 4120, 4068, 104 },
   { 4163, 4164, 0 },
   { 4168, 4169, 0 },
   { 4176, 4177, 0 },
   { 4180, 4181, 0 },
   { 4190, 4191, 0 },
   { 4195, 4197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3584, 3586, 92 },
   { 5431, 5434, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2351, 2356, 45 },
   { 5015, 2386, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2351, 2356, 45 },
   { 5014, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2363, 45 },
   { 5021, 2390, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2363, 45 },
   { 5020, 2357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 2370, 45 },
   { 5025, 2396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 2370, 45 },
   { 5024, 2364, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5030, 5031, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5028, 5029, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5038, 5039, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5036, 5037, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2819, 1330, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2809, 2810, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 1330, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2811, 2812, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3760, 1466, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1758, 1759, 0 },
   { 1779, 1780, 0 },
   { 1861, 1862, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1947, 1948, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 1466, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1719, 1720, 0 },
   { 1826, 1827, 0 },
   { 1909, 1910, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1760, 1761, 0 },
   { 1781, 1782, 0 },
   { 1863, 1864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1949, 1950, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2818, 1330, 0 },
   { 2818, 1330, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5481, 5483, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5465, 5467, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5449, 5451, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1944, 1945, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1941, 1942, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2807, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2808, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2821, 1342, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2813, 2814, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2822, 1342, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2815, 2816, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 731, 733, 33 },
   { 743, 744, 0 },
   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 731, 733, 33 },
   { 738, 740, 0 },
   { 743, 744, 0 },
   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 731, 733, 33 },
   { 735, 249, 0 },
   { 738, 740, 0 },
   { 743, 744, 0 },
   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 740, 0 },
   { 757, 758, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 746, 249, 0 },
   { 748, 740, 0 },
   { 757, 758, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 750, 249, 0 },
   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 750, 249, 0 },
   { 751, 754, 0 },
   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2177, 2178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2371, 2374, 45 },
   { 5019, 2401, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2371, 2374, 45 },
   { 5018, 2371, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 2380, 45 },
   { 5023, 2405, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2375, 2380, 45 },
   { 5022, 2375, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 2385, 45 },
   { 5027, 2411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 2385, 45 },
   { 5026, 2381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5034, 5035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5032, 5033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5042, 5043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5040, 5041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1290, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1274, 61, 0 },
   { 1275, 32, 0 },
   { 1290, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1274, 61, 0 },
   { 1275, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1290, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1282, 1283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1277, 32, 0 },
   { 1278, 63, 0 },
   { 1282, 1283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2975, 2976, 0 },
   { 3511, 3514, 82 },
   { 4718, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2977, 2976, 0 },
   { 3511, 3514, 82 },
   { 4718, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3023, 3019, 0 },
   { 3511, 3514, 82 },
   { 4718, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2299, 2305, 44 },
   { 2311, 2295, 0 },
   { 2319, 2297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2299, 2305, 44 },
   { 2312, 2297, 0 },
   { 2320, 2295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2299, 2305, 44 },
   { 2308, 2299, 0 },
   { 2317, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2299, 2305, 44 },
   { 2310, 2301, 0 },
   { 2318, 2299, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2301, 2306, 44 },
   { 2315, 2295, 0 },
   { 2323, 2297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2301, 2306, 44 },
   { 2316, 2297, 0 },
   { 2324, 2295, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2301, 2306, 44 },
   { 2313, 2299, 0 },
   { 2321, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2301, 2306, 44 },
   { 2314, 2301, 0 },
   { 2322, 2299, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { 3631, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { 3628, 3629, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { 3628, 3629, 101 },
   { 3631, 3632, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { 3634, 3635, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { 3637, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 36, 0 },
   { 3634, 3635, 101 },
   { 3637, 3638, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2498, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2550, 2551, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2542, 2543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2545, 2546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2548, 2549, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2533, 2535, 0 },
   { 2515, 2569, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2536, 2537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2568, 2547, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2567, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2570, 2515, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2538, 2541, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2496, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2502, 48 },
   { 2523, 32, 0 },
   { 2524, 236, 0 },
   { 2525, 2522, 0 },
   { 2530, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2889, 2890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2892, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2901, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2903, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2894, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 196, 3, 0 },
   { 3201, 3202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 196, 3, 0 },
   { 3201, 3202, 0 },
   { 3243, 3202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4625, 3677, 0 },
   { 4679, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4650, 3677, 0 },
   { 4679, 3697, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4625, 3677, 0 },
   { 4648, 3677, 0 },
   { 4679, 3697, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4625, 3677, 0 },
   { 4678, 3697, 0 },
   { 4679, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4625, 3677, 0 },
   { 4676, 3697, 0 },
   { 4679, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4651, 3677, 0 },
   { 4704, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4650, 3677, 0 },
   { 4651, 3677, 0 },
   { 4703, 3697, 0 },
   { 4704, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3677, 0 },
   { 4651, 3677, 0 },
   { 4701, 3697, 0 },
   { 4704, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4651, 3677, 0 },
   { 4678, 3697, 0 },
   { 4704, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4651, 3677, 0 },
   { 4676, 3697, 0 },
   { 4704, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { 4756, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4731, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4731, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { 4731, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4650, 3677, 0 },
   { 4703, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4648, 3677, 0 },
   { 4701, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4624, 3677, 0 },
   { 4678, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4622, 3677, 0 },
   { 4676, 3697, 0 },
   { 4728, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4648, 3677, 0 },
   { 4650, 3677, 0 },
   { 4701, 3697, 0 },
   { 4703, 3697, 0 },
   { 4753, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4650, 3677, 0 },
   { 4678, 3697, 0 },
   { 4703, 3697, 0 },
   { 4730, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4650, 3677, 0 },
   { 4676, 3697, 0 },
   { 4703, 3697, 0 },
   { 4728, 3697, 0 },
   { 4755, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4624, 3677, 0 },
   { 4648, 3677, 0 },
   { 4678, 3697, 0 },
   { 4701, 3697, 0 },
   { 4730, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4648, 3677, 0 },
   { 4676, 3697, 0 },
   { 4701, 3697, 0 },
   { 4728, 3697, 0 },
   { 4753, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4622, 3677, 0 },
   { 4624, 3677, 0 },
   { 4676, 3697, 0 },
   { 4678, 3697, 0 },
   { 4728, 3697, 0 },
   { 4730, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3016, 3017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4653, 4627, 0 },
   { 4706, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4652, 4627, 0 },
   { 4705, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4681, 49, 0 },
   { 4733, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4680, 49, 0 },
   { 4732, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 988, 992, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 980, 983, 0 },
   { 988, 992, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4653, 4627, 0 },
   { 4706, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4652, 4627, 0 },
   { 4705, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4628, 4627, 0 },
   { 4681, 49, 0 },
   { 4733, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4626, 4627, 0 },
   { 4680, 49, 0 },
   { 4732, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4653, 4627, 0 },
   { 4706, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4652, 4627, 0 },
   { 4705, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4628, 4627, 0 },
   { 4681, 49, 0 },
   { 4733, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { 4626, 4627, 0 },
   { 4680, 49, 0 },
   { 4732, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4629, 4627, 0 },
   { 4653, 4627, 0 },
   { 4682, 49, 0 },
   { 4706, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4629, 4627, 0 },
   { 4652, 4627, 0 },
   { 4682, 49, 0 },
   { 4705, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4629, 4627, 0 },
   { 4681, 49, 0 },
   { 4682, 49, 0 },
   { 4733, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4629, 4627, 0 },
   { 4680, 49, 0 },
   { 4682, 49, 0 },
   { 4732, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4653, 4627, 0 },
   { 4654, 4627, 0 },
   { 4706, 49, 0 },
   { 4707, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4652, 4627, 0 },
   { 4654, 4627, 0 },
   { 4705, 49, 0 },
   { 4707, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4654, 4627, 0 },
   { 4681, 49, 0 },
   { 4707, 49, 0 },
   { 4733, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4654, 4627, 0 },
   { 4680, 49, 0 },
   { 4707, 49, 0 },
   { 4732, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4653, 4627, 0 },
   { 4706, 49, 0 },
   { 4758, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4652, 4627, 0 },
   { 4705, 49, 0 },
   { 4757, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4681, 49, 0 },
   { 4733, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4680, 49, 0 },
   { 4732, 49, 0 },
   { 4759, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4653, 4627, 0 },
   { 4706, 49, 0 },
   { 4734, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4652, 4627, 0 },
   { 4705, 49, 0 },
   { 4734, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4681, 49, 0 },
   { 4733, 49, 0 },
   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4680, 49, 0 },
   { 4732, 49, 0 },
   { 4734, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4652, 4627, 0 },
   { 4653, 4627, 0 },
   { 4705, 49, 0 },
   { 4706, 49, 0 },
   { 4757, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4653, 4627, 0 },
   { 4681, 49, 0 },
   { 4706, 49, 0 },
   { 4733, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4653, 4627, 0 },
   { 4680, 49, 0 },
   { 4706, 49, 0 },
   { 4732, 49, 0 },
   { 4758, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4628, 4627, 0 },
   { 4652, 4627, 0 },
   { 4681, 49, 0 },
   { 4705, 49, 0 },
   { 4733, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4652, 4627, 0 },
   { 4680, 49, 0 },
   { 4705, 49, 0 },
   { 4732, 49, 0 },
   { 4757, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4626, 4627, 0 },
   { 4628, 4627, 0 },
   { 4680, 49, 0 },
   { 4681, 49, 0 },
   { 4732, 49, 0 },
   { 4733, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 872, 0 },
   { 877, 880, 0 },
   { 885, 887, 0 },
   { 892, 895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 873, 872, 0 },
   { 881, 880, 0 },
   { 888, 887, 0 },
   { 896, 895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 994, 997, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 771, 775, 0 },
   { 976, 978, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 976, 978, 0 },
   { 994, 997, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { 3010, 3012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2468, 1178, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 874, 876, 0 },
   { 882, 884, 0 },
   { 889, 891, 0 },
   { 897, 899, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { 3013, 3009, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1106, 1105, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1110, 1109, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1061, 1062, 0 },
   { 1163, 1166, 0 },
   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1104, 1105, 0 },
   { 1140, 1141, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1108, 1109, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1107, 1105, 0 },
   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1047, 1048, 0 },
   { 1114, 1112, 0 },
   { 2417, 1208, 0 },
   { 2441, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1091, 1088, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1098, 1096, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1059, 1060, 0 },
   { 1169, 1170, 0 },
   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1087, 1088, 0 },
   { 1142, 1143, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1093, 1088, 0 },
   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1049, 1050, 0 },
   { 1103, 1101, 0 },
   { 2416, 1204, 0 },
   { 2442, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { 5137, 5140, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 240, 238, 0 },
   { 3159, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 240, 238, 0 },
   { 3159, 3161, 0 },
   { 3204, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3146, 3147, 0 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 364, 365, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 364, 365, 9 },
   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 505, 506, 0 },
   { 568, 569, 0 },
   { 572, 573, 0 },
   { 640, 641, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 511, 513, 0 },
   { 577, 579, 0 },
   { 650, 652, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2447, 32, 0 },
   { 2448, 1186, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2477, 2474, 46 },
   { 2484, 2481, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2489, 2487, 46 },
   { 2494, 2492, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2172, 63, 0 },
   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1654, 1657, 0 },
   { 1661, 1657, 0 },
   { 1666, 1669, 0 },
   { 1673, 1669, 0 },
   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2170, 1186, 0 },
   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4659, 2007, 0 },
   { 4688, 2011, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4635, 2007, 0 },
   { 4658, 2007, 0 },
   { 4688, 2011, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4635, 2007, 0 },
   { 4687, 2011, 0 },
   { 4688, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4635, 2007, 0 },
   { 4686, 2011, 0 },
   { 4688, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4660, 2007, 0 },
   { 4712, 2011, 0 },
   { 4713, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4660, 2007, 0 },
   { 4711, 2011, 0 },
   { 4713, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4660, 2007, 0 },
   { 4687, 2011, 0 },
   { 4713, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4660, 2007, 0 },
   { 4686, 2011, 0 },
   { 4713, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4764, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4763, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { 4765, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4659, 2007, 0 },
   { 4712, 2011, 0 },
   { 4740, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4711, 2011, 0 },
   { 4740, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { 4740, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2477, 2474, 46 },
   { 2484, 2481, 46 },
   { 2489, 2487, 46 },
   { 2494, 2492, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4687, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2778, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4658, 2007, 0 },
   { 4659, 2007, 0 },
   { 4711, 2011, 0 },
   { 4712, 2011, 0 },
   { 4763, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4659, 2007, 0 },
   { 4687, 2011, 0 },
   { 4712, 2011, 0 },
   { 4739, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4659, 2007, 0 },
   { 4686, 2011, 0 },
   { 4712, 2011, 0 },
   { 4738, 2011, 0 },
   { 4764, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4634, 2007, 0 },
   { 4658, 2007, 0 },
   { 4687, 2011, 0 },
   { 4711, 2011, 0 },
   { 4739, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4658, 2007, 0 },
   { 4686, 2011, 0 },
   { 4711, 2011, 0 },
   { 4738, 2011, 0 },
   { 4763, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4634, 2007, 0 },
   { 4686, 2011, 0 },
   { 4687, 2011, 0 },
   { 4738, 2011, 0 },
   { 4739, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4633, 2007, 0 },
   { 4686, 2011, 0 },
   { 4738, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 3018, 3017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3733, 3734, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3739, 3740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3745, 3746, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3728, 3731, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3736, 3737, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3742, 3743, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2455, 3, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2455, 3, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2789, 1466, 0 },
   { 2790, 2787, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1954, 1957, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 2456, 2457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2456, 2457, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 184, 0 },
   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 2460, 2461, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2056, 2058, 40 },
   { 2056, 2064, 42 },
   { 2082, 2084, 40 },
   { 2082, 2090, 42 },
   { 2108, 2110, 40 },
   { 2108, 2116, 42 },
   { 2133, 2135, 40 },
   { 2133, 2141, 42 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1038, 1033, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4685, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4656, 1965, 0 },
   { 4685, 1973, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4632, 1965, 0 },
   { 4655, 1965, 0 },
   { 4685, 1973, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4632, 1965, 0 },
   { 4684, 1973, 0 },
   { 4685, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4632, 1965, 0 },
   { 4683, 1973, 0 },
   { 4685, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4657, 1965, 0 },
   { 4710, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4656, 1965, 0 },
   { 4657, 1965, 0 },
   { 4709, 1973, 0 },
   { 4710, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4657, 1965, 0 },
   { 4708, 1973, 0 },
   { 4710, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4657, 1965, 0 },
   { 4684, 1973, 0 },
   { 4710, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4657, 1965, 0 },
   { 4683, 1973, 0 },
   { 4710, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { 4762, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4737, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4737, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { 4737, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2455, 3, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 2776, 2777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1356, 1357, 0 },
   { 1378, 1379, 0 },
   { 1400, 1401, 0 },
   { 1420, 1421, 0 },
   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4656, 1965, 0 },
   { 4709, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4708, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4684, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2056, 2058, 40 },
   { 2056, 2064, 42 },
   { 2082, 2084, 40 },
   { 2082, 2090, 42 },
   { 2108, 2110, 40 },
   { 2108, 2116, 42 },
   { 2133, 2135, 40 },
   { 2133, 2141, 42 },
   { 2443, 32, 0 },
   { 2909, 2911, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4655, 1965, 0 },
   { 4656, 1965, 0 },
   { 4708, 1973, 0 },
   { 4709, 1973, 0 },
   { 4760, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4656, 1965, 0 },
   { 4684, 1973, 0 },
   { 4709, 1973, 0 },
   { 4736, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4656, 1965, 0 },
   { 4683, 1973, 0 },
   { 4709, 1973, 0 },
   { 4735, 1973, 0 },
   { 4761, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4631, 1965, 0 },
   { 4655, 1965, 0 },
   { 4684, 1973, 0 },
   { 4708, 1973, 0 },
   { 4736, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4655, 1965, 0 },
   { 4683, 1973, 0 },
   { 4708, 1973, 0 },
   { 4735, 1973, 0 },
   { 4760, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4631, 1965, 0 },
   { 4683, 1973, 0 },
   { 4684, 1973, 0 },
   { 4735, 1973, 0 },
   { 4736, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2443, 32, 0 },
   { 4630, 1965, 0 },
   { 4683, 1973, 0 },
   { 4735, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 2293, 0 },
   { 2838, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2899, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1118, 1088, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { 1206, 1204, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { 1150, 1153, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { 2431, 715, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 1228, 1005, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 1145, 1148, 0 },
   { 1228, 1005, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 1105, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 1209, 1208, 0 },
   { 1209, 1208, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 1156, 1157, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 1083, 1081, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1519, 1521, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1445, 32, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1440, 1205, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 1440, 1205, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1525, 1526, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1457, 202, 35 },
   { 1462, 1460, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1447, 32, 0 },
   { 1449, 103, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1449, 103, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1449, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { 1449, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1447, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { 1447, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1216, 1218, 0 },
   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { 1451, 103, 0 },
   { 1513, 1516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1280, 1232, 0 },
   { 1297, 1299, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 1471, 1473, 35 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 1476, 1478, 35 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 1481, 1483, 38 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 1485, 1489, 35 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1455, 37 },
   { 2424, 1214, 0 },
   { 2840, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3219, 3222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3228, 3232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3238, 3241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 765, 767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 201, 3, 0 },
   { 3186, 3188, 0 },
   { 3190, 3188, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 201, 3, 0 },
   { 3186, 3188, 0 },
   { 3190, 3188, 0 },
   { 3217, 3188, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 201, 3, 0 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 687, 684, 23 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 201, 3, 0 },
   { 687, 684, 23 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2502, 48 },
   { 2523, 32, 0 },
   { 2524, 236, 0 },
   { 2525, 2522, 0 },
   { 2532, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2503, 2499, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2503, 2499, 49 },
   { 2514, 2515, 0 },
   { 2518, 236, 0 },
   { 2521, 2522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { 1441, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { 1446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 2792, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1448, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1307, 1309, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1448, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 3588, 3584, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1307, 1309, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1307, 1309, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1448, 32, 0 },
   { 1450, 106, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1450, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1307, 1309, 0 },
   { 1450, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1448, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1448, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1307, 1309, 0 },
   { 1448, 32, 0 },
   { 1452, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1452, 106, 36 },
   { 2791, 2777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1285, 1286, 0 },
   { 1307, 1309, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1033, 0 },
   { 2785, 715, 0 },
   { 2880, 1033, 0 },
   { 2881, 1186, 0 },
   { 2882, 1186, 0 },
   { 1427, 3399, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 1033, 0 },
   { 2786, 715, 0 },
   { 2884, 1186, 0 },
   { 3406, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 1186, 0 },
   { 2784, 1081, 0 },
   { 2877, 1186, 0 },
   { 2878, 1033, 0 },
   { 2879, 1033, 0 },
   { 1424, 3400, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2434, 1186, 0 },
   { 2729, 715, 0 },
   { 2732, 1081, 0 },
   { 2780, 1081, 0 },
   { 2781, 715, 0 },
   { 2876, 1033, 0 },
   { 3404, 3405, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 1033, 0 },
   { 2730, 1081, 0 },
   { 2731, 715, 0 },
   { 2782, 715, 0 },
   { 2783, 1081, 0 },
   { 2875, 1186, 0 },
   { 3401, 3403, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2176, 1329, 0 },
   { 2435, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1290, 1291, 0 },
   { 1317, 1319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1274, 61, 0 },
   { 1275, 32, 0 },
   { 1290, 1291, 0 },
   { 1317, 1319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1290, 1291, 0 },
   { 1317, 1319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 2794, 2777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1282, 1283, 0 },
   { 1302, 1304, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1277, 32, 0 },
   { 1278, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1277, 32, 0 },
   { 1278, 63, 0 },
   { 1282, 1283, 0 },
   { 1302, 1304, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1282, 1283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 2793, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 32, 0 },
   { 1282, 1283, 0 },
   { 1302, 1304, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2735, 1067, 0 },
   { 2736, 665, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3650, 3632, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3650, 3632, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1229, 1230, 0 },
   { 1231, 1232, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3649, 3629, 101 },
   { 3650, 3632, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3654, 3638, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3654, 3638, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 1236, 1237, 0 },
   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3652, 3635, 101 },
   { 3654, 3638, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2291, 2292, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3642, 3643, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3642, 3643, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2291, 2292, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3640, 3641, 101 },
   { 3642, 3643, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3647, 3648, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3647, 3648, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4644, 4616, 0 },
   { 4697, 4669, 0 },
   { 4749, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4642, 4616, 0 },
   { 4695, 4669, 0 },
   { 4747, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4619, 4616, 0 },
   { 4672, 4669, 0 },
   { 4724, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1247, 1245, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3293, 3295, 0 },
   { 3644, 3645, 101 },
   { 3647, 3648, 101 },
   { 4615, 4616, 0 },
   { 4668, 4669, 0 },
   { 4721, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3264, 3262, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3267, 3265, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1088, 0 },
   { 1267, 1096, 0 },
   { 1268, 1096, 0 },
   { 2766, 3, 0 },
   { 3270, 3268, 0 },
   { 3644, 3645, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3450, 3448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3453, 3448, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1530, 1529, 0 },
   { 3502, 3505, 81 },
   { 4612, 11, 0 },
   { 4665, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4662, 2031, 0 },
   { 4715, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4661, 2031, 0 },
   { 4714, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4690, 2035, 0 },
   { 4742, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4689, 2035, 0 },
   { 4741, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4662, 2031, 0 },
   { 4715, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4661, 2031, 0 },
   { 4714, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4637, 2031, 0 },
   { 4690, 2035, 0 },
   { 4742, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 2450, 32, 0 },
   { 4636, 2031, 0 },
   { 4689, 2035, 0 },
   { 4741, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4662, 2031, 0 },
   { 4691, 2035, 0 },
   { 4715, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4638, 2031, 0 },
   { 4661, 2031, 0 },
   { 4691, 2035, 0 },
   { 4714, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4638, 2031, 0 },
   { 4690, 2035, 0 },
   { 4691, 2035, 0 },
   { 4742, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4638, 2031, 0 },
   { 4689, 2035, 0 },
   { 4691, 2035, 0 },
   { 4741, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4662, 2031, 0 },
   { 4663, 2031, 0 },
   { 4715, 2035, 0 },
   { 4716, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4661, 2031, 0 },
   { 4663, 2031, 0 },
   { 4714, 2035, 0 },
   { 4716, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4663, 2031, 0 },
   { 4690, 2035, 0 },
   { 4716, 2035, 0 },
   { 4742, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4663, 2031, 0 },
   { 4689, 2035, 0 },
   { 4716, 2035, 0 },
   { 4741, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4662, 2031, 0 },
   { 4715, 2035, 0 },
   { 4767, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4661, 2031, 0 },
   { 4714, 2035, 0 },
   { 4766, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4690, 2035, 0 },
   { 4742, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4689, 2035, 0 },
   { 4741, 2035, 0 },
   { 4768, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4662, 2031, 0 },
   { 4715, 2035, 0 },
   { 4743, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4661, 2031, 0 },
   { 4714, 2035, 0 },
   { 4743, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4690, 2035, 0 },
   { 4742, 2035, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4689, 2035, 0 },
   { 4741, 2035, 0 },
   { 4743, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4661, 2031, 0 },
   { 4662, 2031, 0 },
   { 4714, 2035, 0 },
   { 4715, 2035, 0 },
   { 4766, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4662, 2031, 0 },
   { 4690, 2035, 0 },
   { 4715, 2035, 0 },
   { 4742, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4662, 2031, 0 },
   { 4689, 2035, 0 },
   { 4715, 2035, 0 },
   { 4741, 2035, 0 },
   { 4767, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4637, 2031, 0 },
   { 4661, 2031, 0 },
   { 4690, 2035, 0 },
   { 4714, 2035, 0 },
   { 4742, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4661, 2031, 0 },
   { 4689, 2035, 0 },
   { 4714, 2035, 0 },
   { 4741, 2035, 0 },
   { 4766, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4637, 2031, 0 },
   { 4689, 2035, 0 },
   { 4690, 2035, 0 },
   { 4741, 2035, 0 },
   { 4742, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 61, 0 },
   { 4636, 2031, 0 },
   { 4689, 2035, 0 },
   { 4741, 2035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1744, 11, 0 },
   { 1767, 11, 0 },
   { 1851, 16, 0 },
   { 1960, 1957, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 3788, 3786, 0 },
   { 3794, 3786, 0 },
   { 3800, 3786, 0 },
   { 3806, 3786, 0 },
   { 3809, 3810, 0 },
   { 3814, 3784, 0 },
   { 3818, 3784, 0 },
   { 3822, 3784, 0 },
   { 3825, 3826, 0 },
   { 3828, 3826, 0 },
   { 3831, 3832, 0 },
   { 3836, 3791, 0 },
   { 3840, 3791, 0 },
   { 3843, 3844, 0 },
   { 3846, 3844, 0 },
   { 3849, 2960, 0 },
   { 3851, 3844, 0 },
   { 3853, 2960, 0 },
   { 3855, 1743, 0 },
   { 3859, 3797, 0 },
   { 3862, 3863, 0 },
   { 3865, 3863, 0 },
   { 3868, 3869, 0 },
   { 3871, 3863, 0 },
   { 3873, 3869, 0 },
   { 3875, 1766, 0 },
   { 3877, 3863, 0 },
   { 3879, 3869, 0 },
   { 3881, 1766, 0 },
   { 3883, 1850, 0 },
   { 4611, 11, 0 },
   { 4664, 16, 0 },
   { 4717, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1744, 11, 0 },
   { 1767, 11, 0 },
   { 1851, 16, 0 },
   { 2938, 2939, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { 3788, 3786, 0 },
   { 3794, 3786, 0 },
   { 3800, 3786, 0 },
   { 3806, 3786, 0 },
   { 3809, 3810, 0 },
   { 3814, 3784, 0 },
   { 3818, 3784, 0 },
   { 3822, 3784, 0 },
   { 3825, 3826, 0 },
   { 3828, 3826, 0 },
   { 3831, 3832, 0 },
   { 3836, 3791, 0 },
   { 3840, 3791, 0 },
   { 3843, 3844, 0 },
   { 3846, 3844, 0 },
   { 3849, 2960, 0 },
   { 3851, 3844, 0 },
   { 3853, 2960, 0 },
   { 3855, 1743, 0 },
   { 3859, 3797, 0 },
   { 3862, 3863, 0 },
   { 3865, 3863, 0 },
   { 3868, 3869, 0 },
   { 3871, 3863, 0 },
   { 3873, 3869, 0 },
   { 3875, 1766, 0 },
   { 3877, 3863, 0 },
   { 3879, 3869, 0 },
   { 3881, 1766, 0 },
   { 3883, 1850, 0 },
   { 4611, 11, 0 },
   { 4664, 16, 0 },
   { 4717, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2935, 2937, 0 },
   { 3764, 715, 0 },
   { 3765, 6, 0 },
   { 3766, 11, 0 },
   { 3767, 16, 0 },
   { 3768, 21, 0 },
   { 3785, 3786, 0 },
   { 3792, 3786, 0 },
   { 3798, 3786, 0 },
   { 3804, 3786, 0 },
   { 3812, 3784, 0 },
   { 3816, 3784, 0 },
   { 3820, 3784, 0 },
   { 3834, 3791, 0 },
   { 3838, 3791, 0 },
   { 3857, 3797, 0 },
   { 4639, 11, 0 },
   { 4692, 16, 0 },
   { 4744, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2072, 6, 0 },
   { 2098, 11, 0 },
   { 2124, 16, 0 },
   { 2149, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2473, 2474, 46 },
   { 2480, 2481, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2486, 2487, 46 },
   { 2491, 2492, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2473, 2474, 46 },
   { 2480, 2481, 46 },
   { 2489, 2487, 46 },
   { 2494, 2492, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2477, 2474, 46 },
   { 2484, 2481, 46 },
   { 2486, 2487, 46 },
   { 2491, 2492, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2473, 2474, 46 },
   { 2480, 2481, 46 },
   { 2486, 2487, 46 },
   { 2491, 2492, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 904, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 964, 962, 0 },
   { 972, 970, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 952, 951, 0 },
   { 959, 958, 0 },
   { 966, 965, 0 },
   { 974, 973, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 3259, 3188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 1730, 1731, 39 },
   { 1837, 1838, 39 },
   { 1920, 1921, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2006, 2008, 0 },
   { 2010, 2012, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1964, 1966, 0 },
   { 1972, 1974, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2030, 2032, 0 },
   { 2034, 2036, 0 },
   { 3769, 715, 0 },
   { 3770, 6, 0 },
   { 3771, 11, 0 },
   { 3772, 16, 0 },
   { 3773, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 948, 949, 0 },
   { 955, 956, 0 },
   { 961, 962, 0 },
   { 969, 970, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1493, 1494, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1455, 202, 35 },
   { 1459, 1460, 35 },
   { 1493, 1494, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 2841, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1445, 32, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1443, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1493, 1494, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1519, 1521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1288, 1234, 0 },
   { 1312, 1314, 0 },
   { 1440, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1440, 1205, 0 },
   { 1493, 1494, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3278, 3279, 0 },
   { 3281, 3282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 505, 506, 0 },
   { 564, 559, 0 },
   { 572, 573, 0 },
   { 635, 630, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1111, 1112, 0 },
   { 1140, 1141, 0 },
   { 2441, 1186, 0 },
   { 2857, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1100, 1101, 0 },
   { 1142, 1143, 0 },
   { 2442, 1033, 0 },
   { 2856, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2509, 2512, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { 1117, 1088, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 1119, 1105, 0 },
   { 2440, 1186, 0 },
   { 2860, 1186, 0 },
   { 2863, 1033, 0 },
   { 2866, 1033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1498, 1499, 0 },
   { 3586, 3584, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1446, 32, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1441, 1442, 0 },
   { 1444, 1442, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1293, 1294, 0 },
   { 1322, 1324, 0 },
   { 1498, 1499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1274, 61, 0 },
   { 1275, 32, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1290, 1291, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1273, 32, 0 },
   { 1290, 1291, 0 },
   { 1317, 1319, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 1737, 1738, 39 },
   { 1844, 1845, 39 },
   { 1927, 1928, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 2454, 2237, 0 },
   { 2971, 2973, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 1145, 1148, 0 },
   { 2438, 1033, 0 },
   { 2845, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1137, 0 },
   { 1145, 1148, 0 },
   { 1228, 1005, 0 },
   { 2438, 1033, 0 },
   { 2849, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1132, 1135, 0 },
   { 2200, 1034, 0 },
   { 2438, 1033, 0 },
   { 2868, 1033, 0 },
   { 2871, 1186, 0 },
   { 2874, 1186, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 2852, 2844, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1525, 1526, 35 },
   { 2854, 2848, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 714, 722, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 519, 520, 15 },
   { 585, 586, 17 },
   { 658, 659, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 548, 549, 17 },
   { 618, 619, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 492, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 561, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 548, 549, 17 },
   { 618, 619, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2183, 2186, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2191, 2195, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2183, 2186, 0 },
   { 2191, 2195, 0 },
   { 2443, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2455, 3, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1088, 0 },
   { 1266, 1088, 0 },
   { 1268, 1096, 0 },
   { 1705, 1712, 0 },
   { 1812, 1819, 0 },
   { 1895, 1902, 0 },
   { 2766, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 904, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 964, 962, 0 },
   { 972, 970, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 952, 951, 0 },
   { 959, 958, 0 },
   { 966, 965, 0 },
   { 974, 973, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 948, 949, 0 },
   { 955, 956, 0 },
   { 961, 962, 0 },
   { 969, 970, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2455, 3, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 904, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 964, 962, 0 },
   { 972, 970, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 952, 951, 0 },
   { 959, 958, 0 },
   { 966, 965, 0 },
   { 974, 973, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 948, 949, 0 },
   { 955, 956, 0 },
   { 961, 962, 0 },
   { 969, 970, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2455, 3, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 904, 0 },
   { 950, 949, 0 },
   { 957, 956, 0 },
   { 964, 962, 0 },
   { 972, 970, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 952, 951, 0 },
   { 959, 958, 0 },
   { 966, 965, 0 },
   { 974, 973, 0 },
   { 2426, 2427, 0 },
   { 2429, 2430, 0 },
   { 2443, 32, 0 },
   { 2444, 32, 0 },
   { 2445, 61, 0 },
   { 2923, 2924, 55 },
   { 2954, 2955, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 948, 949, 0 },
   { 955, 956, 0 },
   { 961, 962, 0 },
   { 969, 970, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2469, 32, 0 },
   { 2912, 2913, 55 },
   { 973, 403, 55 },
   { 2915, 2917, 55 },
   { 965, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2446, 32, 0 },
   { 2453, 3, 0 },
   { 5012, 4937, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2446, 32, 0 },
   { 4936, 4937, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         3,
         3,
         346,
         347,
         348,
         349,
         350,
         3,
         351,
         352,
         353,
         354,
         2319,
         2320,
         2321,
         2322,
         2323,
         2324,
         2,
         346,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         2,
         347,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         341,
         348,
         341,
         341,
         341,
         341,
         341,
         341,
         355,
         356,
         357,
         358,
         341,
         341,
         2325,
         2326,
         2327,
         2328,
         2,
         349,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         2,
         350,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         2,
         3,
         2,
         2,
         341,
         2,
         2,
         359,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         342,
         351,
         342,
         342,
         355,
         342,
         342,
         342,
         342,
         360,
         361,
         362,
         342,
         342,
         2329,
         2330,
         2331,
         2332,
         343,
         352,
         343,
         343,
         356,
         343,
         343,
         343,
         360,
         343,
         363,
         364,
         343,
         343,
         2333,
         2334,
         2335,
         2336,
         344,
         353,
         344,
         344,
         357,
         344,
         344,
         344,
         361,
         363,
         344,
         365,
         344,
         344,
         2337,
         2338,
         2339,
         2340,
         345,
         354,
         345,
         345,
         358,
         345,
         345,
         345,
         362,
         364,
         365,
         345,
         345,
         345,
         2341,
         2342,
         2343,
         2344,
         2,
         2319,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         2,
         2320,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2315,
         2316,
         2317,
         2318,
         2315,
         2321,
         2315,
         2315,
         2325,
         2315,
         2315,
         2315,
         2329,
         2333,
         2337,
         2341,
         2315,
         2315,
         2315,
         2345,
         2346,
         2347,
         2316,
         2322,
         2316,
         2316,
         2326,
         2316,
         2316,
         2316,
         2330,
         2334,
         2338,
         2342,
         2316,
         2316,
         2345,
         2316,
         2348,
         2349,
         2317,
         2323,
         2317,
         2317,
         2327,
         2317,
         2317,
         2317,
         2331,
         2335,
         2339,
         2343,
         2317,
         2317,
         2346,
         2348,
         2317,
         2350,
         2318,
         2324,
         2318,
         2318,
         2328,
         2318,
         2318,
         2318,
         2332,
         2336,
         2340,
         2344,
         2318,
         2318,
         2347,
         2349,
         2350,
         2318,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         4,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         4,
         14,
         4,
         4,
         4,
         4,
         0,
         11,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         19,
         0,
         5,
         5,
         3,
         6,
         20,
         15,
         3,
         6,
         21,
         5,
         5,
         3,
         6,
         22,
         15,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         0,
         15,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         6,
         7,
         6,
         6,
         6,
         1342,
         6,
         6,
         6,
         1343,
         6,
         6,
         6,
         2352,
         6,
         6,
         6,
         1342,
         6,
         1342,
         6,
         1342,
         6,
         1342,
         4,
         1344,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1345,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1346,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1347,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         1348,
         1349,
         1348,
         1348,
         1348,
         1350,
         1348,
         1348,
         1348,
         1351,
         1348,
         1348,
         1348,
         2353,
         1348,
         1348,
         1348,
         1350,
         1348,
         1350,
         1348,
         1350,
         1348,
         1350,
         1352,
         1353,
         1352,
         1352,
         1352,
         1354,
         1352,
         1352,
         1352,
         1355,
         1352,
         1352,
         1352,
         2354,
         1352,
         1352,
         1352,
         1354,
         1352,
         1354,
         1352,
         1354,
         1352,
         1354,
         4,
         1356,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         5,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1357,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2355,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2356,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1346,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2357,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2358,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3033,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3124,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3130,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3134,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3139,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3143,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3148,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2351,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         8,
         1567,
         1568,
         1569,
         1570,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         366,
         367,
         366,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         14,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         5,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         16,
         1571,
         1572,
         1573,
         1574,
         1575,
         1576,
         1577,
         1578,
         1579,
         1580,
         1581,
         1582,
         1583,
         2683,
         2684,
         2685,
         3026,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         4,
         6,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         17,
         1840,
         1841,
         1842,
         1843,
         1844,
         2993,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         18,
         1584,
         1585,
         1586,
         1587,
         1588,
         1589,
         1590,
         1591,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         2136,
         2137,
         2138,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1845,
         1846,
         1847,
         2603,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1592,
         1593,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         22,
         1848,
         1849,
         1850,
         1851,
         1852,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         7,
         8,
         7,
         8,
         7,
         8,
         9,
         10,
         9,
         10,
         9,
         10,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         14,
         2,
         2,
         15,
         16,
         17,
         18,
         19,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         3,
         21,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         20,
         3,
         3,
         3,
         3,
         3,
         5,
         22,
         5,
         5,
         23,
         24,
         5,
         5,
         5,
         5,
         5,
         22,
         5,
         5,
         5,
         23,
         24,
         22,
         5,
         5,
         23,
         24,
         5,
         22,
         22,
         22,
         25,
         26,
         5,
         23,
         24,
         23,
         24,
         23,
         27,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         28,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         30,
         31,
         5,
         5,
         30,
         31,
         5,
         5,
         5,
         30,
         31,
         5,
         22,
         32,
         33,
         34,
         22,
         5,
         30,
         31,
         5,
         30,
         31,
         5,
         23,
         35,
         36,
         23,
         24,
         37,
         38,
         24,
         5,
         5,
         30,
         31,
         5,
         30,
         31,
         31,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         11,
         11,
         11,
         20,
         3,
         21,
         21,
         21,
         21,
         21,
         21,
         4,
         4,
         20,
         20,
         3,
         20,
         20,
         3,
         0,
         2,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         21,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         20,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         44,
         43,
         44,
         43,
         44,
         43,
         45,
         43,
         44,
         43,
         44,
         46,
         47,
         48,
         49,
         43,
         44,
         50,
         51,
         52,
         44,
         43,
         44,
         53,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 54,
      .table = (const uint16_t []) {
      
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         24,
         24,
         1596,
         1597,
         1598,
         24,
         24,
         1599,
         1600,
         1601,
         1602,
         24,
         1603,
         24,
         2668,
         2669,
         2670,
         2671,
         2672,
         2673,
         2674,
         2675,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         3004,
         3004,
         3005,
         3004,
         3004,
         3006,
         3006,
         3004,
         3004,
         3007,
         3008,
         2672,
         3111,
         24,
         3004,
         3004,
         24,
         3006,
         24,
         3004,
         3005,
         3004,
         3004,
         3004,
         1594,
         1596,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1595,
         1597,
         1604,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1604,
         1604,
         1604,
         1604,
         1604,
         2677,
         2667,
         2667,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         3011,
         3011,
         1595,
         3011,
         3011,
         3012,
         3012,
         3011,
         3011,
         1595,
         1604,
         1604,
         1604,
         1595,
         3011,
         3011,
         1595,
         3012,
         1595,
         3011,
         1595,
         3011,
         3011,
         3011,
         1595,
         1598,
         1604,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1604,
         1604,
         1604,
         1604,
         1604,
         2677,
         2667,
         2667,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         3011,
         3011,
         1595,
         3011,
         3011,
         3012,
         3012,
         3011,
         3011,
         1595,
         1604,
         1604,
         1604,
         1595,
         3011,
         3011,
         1595,
         3012,
         1595,
         3011,
         1595,
         3011,
         3011,
         3011,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         1605,
         3014,
         3014,
         1605,
         3016,
         1605,
         3014,
         1605,
         3013,
         3014,
         3014,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         1607,
         23,
         23,
         1608,
         1608,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         23,
         1599,
         1594,
         1595,
         1595,
         1606,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1606,
         1606,
         1606,
         1606,
         1606,
         1606,
         23,
         23,
         3017,
         3017,
         1606,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         23,
         1594,
         1594,
         1594,
         1606,
         3017,
         3017,
         1606,
         3018,
         1606,
         3017,
         1606,
         3017,
         3017,
         3017,
         23,
         1600,
         1594,
         1595,
         1595,
         1606,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1606,
         1606,
         1606,
         1606,
         1606,
         1606,
         23,
         23,
         3017,
         3017,
         1606,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         23,
         1594,
         1594,
         1594,
         1606,
         3017,
         3017,
         1606,
         3018,
         1606,
         3017,
         1606,
         3017,
         3017,
         3017,
         23,
         1601,
         1594,
         1595,
         1595,
         23,
         1608,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         23,
         1602,
         1594,
         1595,
         1595,
         23,
         1608,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         2678,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         23,
         1603,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         1594,
         1594,
         1594,
         1594,
         2679,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         2679,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         1594,
         2668,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1594,
         2669,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1594,
         2670,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1594,
         2671,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1594,
         2672,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2679,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2679,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         2666,
         2673,
         2666,
         2677,
         2677,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2680,
         2680,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         2666,
         3019,
         3019,
         2666,
         3019,
         3019,
         3020,
         3020,
         3019,
         3019,
         2666,
         2666,
         2666,
         2666,
         2666,
         3019,
         3019,
         2666,
         3020,
         2666,
         3019,
         2666,
         3019,
         3019,
         3019,
         2667,
         2674,
         2676,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         3021,
         3021,
         2667,
         3021,
         3021,
         3022,
         3022,
         3021,
         3021,
         2667,
         2676,
         2676,
         2676,
         2667,
         3021,
         3021,
         2667,
         3022,
         2667,
         3021,
         2667,
         3021,
         3021,
         3021,
         2667,
         2675,
         2676,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         2667,
         3021,
         3021,
         2667,
         3021,
         3021,
         3022,
         3022,
         3021,
         3021,
         2667,
         2676,
         2676,
         2676,
         2667,
         3021,
         3021,
         2667,
         3022,
         2667,
         3021,
         2667,
         3021,
         3021,
         3021,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         3112,
         3014,
         3014,
         3112,
         3016,
         3112,
         3014,
         3112,
         3113,
         3114,
         3114,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         1605,
         3115,
         3115,
         1605,
         3116,
         1605,
         3115,
         1605,
         3013,
         3014,
         3115,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         2681,
         1605,
         2681,
         2681,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3023,
         3024,
         23,
         1594,
         1594,
         1594,
         1605,
         3014,
         3014,
         1605,
         3016,
         2681,
         3024,
         1605,
         3013,
         3014,
         3014,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         3112,
         3115,
         3115,
         3112,
         3116,
         3112,
         3115,
         3112,
         3113,
         3114,
         3117,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         2681,
         1605,
         2681,
         2681,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3023,
         3024,
         23,
         1594,
         1594,
         1594,
         3112,
         3014,
         3014,
         3112,
         3016,
         3118,
         3024,
         3112,
         3113,
         3114,
         3114,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         2681,
         1605,
         2681,
         2681,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3023,
         3024,
         23,
         1594,
         1594,
         1594,
         1605,
         3115,
         3115,
         1605,
         3116,
         2681,
         3119,
         1605,
         3013,
         3014,
         3115,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         2678,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         2678,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         1594,
         1594,
         1594,
         1594,
         2679,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         3025,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         3002,
         3004,
         3009,
         3011,
         3011,
         3013,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3013,
         3013,
         3013,
         3013,
         3013,
         3013,
         3002,
         3002,
         3013,
         3014,
         3013,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         3002,
         3009,
         3009,
         3009,
         3013,
         3014,
         3014,
         3013,
         3016,
         3013,
         3014,
         3013,
         3013,
         3014,
         3014,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3014,
         3014,
         3014,
         3014,
         3014,
         3002,
         3002,
         3014,
         3014,
         3014,
         3014,
         3014,
         3016,
         3016,
         3014,
         3014,
         3002,
         3009,
         3009,
         3009,
         3014,
         3014,
         3014,
         3014,
         3016,
         3014,
         3014,
         3014,
         3014,
         3014,
         3014,
         23,
         3005,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3013,
         3014,
         1605,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         3112,
         3014,
         3014,
         3112,
         3016,
         3112,
         3014,
         3112,
         3113,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3013,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3013,
         3013,
         3013,
         3013,
         3013,
         3013,
         3002,
         3002,
         3013,
         3014,
         3013,
         3013,
         3014,
         3015,
         3016,
         3013,
         3014,
         3002,
         3009,
         3009,
         3009,
         3113,
         3014,
         3014,
         3113,
         3016,
         3113,
         3014,
         3113,
         3113,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3014,
         3014,
         3014,
         3014,
         3014,
         3002,
         3002,
         3014,
         3014,
         3014,
         3014,
         3014,
         3016,
         3016,
         3014,
         3014,
         3002,
         3009,
         3009,
         3009,
         3114,
         3014,
         3014,
         3114,
         3016,
         3114,
         3014,
         3114,
         3114,
         3114,
         3114,
         3003,
         3006,
         3010,
         3012,
         3012,
         3015,
         3003,
         3018,
         3018,
         3003,
         3003,
         3003,
         3003,
         3003,
         3010,
         3010,
         3010,
         3010,
         3010,
         3020,
         3022,
         3022,
         3015,
         3015,
         3015,
         3015,
         3015,
         3015,
         3003,
         3003,
         3015,
         3016,
         3015,
         3015,
         3016,
         3015,
         3016,
         3015,
         3016,
         3003,
         3010,
         3010,
         3010,
         3015,
         3116,
         3116,
         3015,
         3116,
         3015,
         3116,
         3015,
         3015,
         3016,
         3116,
         3003,
         3006,
         3010,
         3012,
         3012,
         3016,
         3003,
         3018,
         3018,
         3003,
         3003,
         3003,
         3003,
         3003,
         3010,
         3010,
         3010,
         3010,
         3010,
         3020,
         3022,
         3022,
         3016,
         3016,
         3016,
         3016,
         3016,
         3016,
         3003,
         3003,
         3016,
         3016,
         3016,
         3016,
         3016,
         3016,
         3016,
         3016,
         3016,
         3003,
         3010,
         3010,
         3010,
         3016,
         3116,
         3116,
         3016,
         3116,
         3016,
         3116,
         3016,
         3016,
         3016,
         3116,
         3002,
         3004,
         3009,
         3011,
         3011,
         3013,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3013,
         3013,
         3023,
         3013,
         3023,
         3023,
         3002,
         3002,
         3013,
         3014,
         3013,
         3013,
         3014,
         3015,
         3016,
         3023,
         3024,
         3002,
         3009,
         3009,
         3009,
         3013,
         3014,
         3014,
         3013,
         3016,
         3023,
         3024,
         3013,
         3013,
         3014,
         3014,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3014,
         3024,
         3014,
         3024,
         3024,
         3002,
         3002,
         3014,
         3014,
         3014,
         3014,
         3014,
         3016,
         3016,
         3024,
         3024,
         3002,
         3009,
         3009,
         3009,
         3014,
         3014,
         3014,
         3014,
         3016,
         3024,
         3024,
         3014,
         3014,
         3014,
         3014,
         23,
         3007,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3002,
         3002,
         23,
         3002,
         3002,
         3003,
         3003,
         3002,
         3002,
         23,
         1594,
         1594,
         1594,
         23,
         3002,
         3002,
         23,
         3003,
         23,
         3002,
         23,
         3002,
         3002,
         3002,
         1594,
         3008,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1594,
         2672,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2679,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3025,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         1594,
         3111,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2676,
         2676,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3009,
         3009,
         3010,
         3010,
         3009,
         3009,
         1594,
         1594,
         1594,
         1594,
         1594,
         3009,
         3009,
         1594,
         3010,
         1594,
         3009,
         1594,
         3009,
         3009,
         3009,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         3112,
         1605,
         1605,
         3112,
         3112,
         1605,
         23,
         23,
         3013,
         3014,
         3112,
         3113,
         3114,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         3112,
         3014,
         3114,
         3112,
         3016,
         3112,
         3014,
         3112,
         3113,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3115,
         3014,
         3115,
         3014,
         3115,
         3002,
         3002,
         3014,
         3014,
         3014,
         3014,
         3014,
         3116,
         3116,
         3014,
         3014,
         3002,
         3009,
         3009,
         3009,
         3014,
         3014,
         3014,
         3115,
         3116,
         3014,
         3014,
         3014,
         3014,
         3014,
         3014,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3115,
         3014,
         3115,
         3014,
         3115,
         3002,
         3002,
         3014,
         3014,
         3014,
         3014,
         3014,
         3116,
         3116,
         3014,
         3014,
         3002,
         3009,
         3009,
         3009,
         3114,
         3014,
         3014,
         3117,
         3116,
         3114,
         3014,
         3114,
         3114,
         3114,
         3114,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         3112,
         1605,
         1605,
         3112,
         3112,
         1605,
         23,
         23,
         3013,
         3014,
         3112,
         3113,
         3114,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         3112,
         3115,
         3117,
         3112,
         3116,
         3112,
         3115,
         3112,
         3113,
         3114,
         3117,
         3003,
         3006,
         3010,
         3012,
         3012,
         3016,
         3003,
         3018,
         3018,
         3003,
         3003,
         3003,
         3003,
         3003,
         3010,
         3010,
         3010,
         3010,
         3010,
         3020,
         3022,
         3022,
         3016,
         3116,
         3016,
         3116,
         3016,
         3116,
         3003,
         3003,
         3016,
         3016,
         3016,
         3016,
         3016,
         3116,
         3116,
         3016,
         3016,
         3003,
         3010,
         3010,
         3010,
         3016,
         3116,
         3116,
         3116,
         3116,
         3016,
         3116,
         3016,
         3016,
         3016,
         3116,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         3112,
         1605,
         2681,
         3112,
         3118,
         2681,
         23,
         23,
         3013,
         3014,
         3112,
         3113,
         3114,
         3015,
         3016,
         3023,
         3024,
         23,
         1594,
         1594,
         1594,
         3112,
         3014,
         3114,
         3112,
         3016,
         3118,
         3024,
         3112,
         3113,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3014,
         3115,
         3024,
         3115,
         3024,
         3119,
         3002,
         3002,
         3014,
         3014,
         3014,
         3014,
         3014,
         3116,
         3116,
         3024,
         3024,
         3002,
         3009,
         3009,
         3009,
         3014,
         3014,
         3014,
         3115,
         3116,
         3024,
         3024,
         3014,
         3014,
         3014,
         3014,
         23,
         3005,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2666,
         2667,
         2667,
         3112,
         1605,
         1605,
         3112,
         3112,
         1605,
         23,
         23,
         3013,
         3014,
         3112,
         3113,
         3114,
         3015,
         3016,
         3013,
         3014,
         23,
         1594,
         1594,
         1594,
         3112,
         3014,
         3114,
         3112,
         3016,
         3112,
         3014,
         3112,
         3113,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3013,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3113,
         3013,
         3013,
         3113,
         3113,
         3013,
         3002,
         3002,
         3013,
         3014,
         3113,
         3113,
         3114,
         3015,
         3016,
         3013,
         3014,
         3002,
         3009,
         3009,
         3009,
         3113,
         3014,
         3114,
         3113,
         3016,
         3113,
         3014,
         3113,
         3113,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3114,
         3014,
         3014,
         3114,
         3114,
         3014,
         3002,
         3002,
         3014,
         3014,
         3114,
         3114,
         3114,
         3016,
         3016,
         3014,
         3014,
         3002,
         3009,
         3009,
         3009,
         3114,
         3014,
         3114,
         3114,
         3016,
         3114,
         3014,
         3114,
         3114,
         3114,
         3114,
         3002,
         3004,
         3009,
         3011,
         3011,
         3014,
         3002,
         3017,
         3017,
         3002,
         3002,
         3002,
         3002,
         3002,
         3009,
         3009,
         3009,
         3009,
         3009,
         3019,
         3021,
         3021,
         3114,
         3115,
         3014,
         3117,
         3114,
         3115,
         3002,
         3002,
         3014,
         3014,
         3114,
         3114,
         3114,
         3116,
         3116,
         3014,
         3014,
         3002,
         3009,
         3009,
         3009,
         3114,
         3014,
         3114,
         3117,
         3116,
         3114,
         3014,
         3114,
         3114,
         3114,
         3114,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         23,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 31,
      .table = (const uint16_t []) {
      
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         26,
         26,
         26,
         379,
         380,
         381,
         382,
         383,
         384,
         385,
         386,
         387,
         388,
         389,
         390,
         391,
         392,
         26,
         26,
         26,
         2230,
         2231,
         2232,
         2233,
         2234,
         2235,
         26,
         26,
         26,
         26,
         380,
         25,
         26,
         393,
         393,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         25,
         379,
         393,
         393,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         368,
         380,
         368,
         368,
         368,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         368,
         401,
         402,
         403,
         404,
         368,
         368,
         368,
         2236,
         2237,
         2238,
         2239,
         2240,
         2241,
         368,
         368,
         368,
         368,
         368,
         25,
         381,
         25,
         25,
         394,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         394,
         369,
         382,
         369,
         369,
         395,
         369,
         369,
         405,
         406,
         407,
         408,
         409,
         369,
         410,
         411,
         412,
         413,
         369,
         369,
         369,
         2225,
         2225,
         2242,
         2243,
         2244,
         2245,
         369,
         369,
         369,
         369,
         395,
         370,
         383,
         370,
         370,
         396,
         370,
         405,
         370,
         414,
         415,
         416,
         417,
         370,
         418,
         419,
         420,
         421,
         370,
         370,
         370,
         2246,
         2247,
         2248,
         2249,
         2250,
         2251,
         370,
         370,
         370,
         370,
         396,
         371,
         384,
         371,
         371,
         397,
         371,
         406,
         414,
         371,
         422,
         423,
         424,
         371,
         425,
         426,
         427,
         428,
         371,
         371,
         371,
         2252,
         2253,
         2254,
         2255,
         2256,
         2257,
         371,
         371,
         371,
         371,
         397,
         372,
         385,
         372,
         372,
         398,
         372,
         407,
         415,
         422,
         372,
         429,
         430,
         372,
         431,
         432,
         433,
         434,
         372,
         372,
         372,
         2258,
         2259,
         2260,
         2261,
         2262,
         2263,
         372,
         372,
         372,
         372,
         398,
         373,
         386,
         373,
         373,
         399,
         373,
         408,
         416,
         423,
         429,
         373,
         435,
         373,
         436,
         437,
         438,
         439,
         373,
         373,
         373,
         2264,
         2265,
         2266,
         2267,
         2268,
         2269,
         373,
         373,
         373,
         373,
         399,
         374,
         387,
         374,
         374,
         400,
         374,
         409,
         417,
         424,
         430,
         435,
         374,
         374,
         440,
         441,
         442,
         443,
         374,
         374,
         374,
         2270,
         2271,
         2272,
         2273,
         2274,
         2275,
         374,
         374,
         374,
         374,
         400,
         25,
         388,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         375,
         389,
         375,
         375,
         401,
         375,
         410,
         418,
         425,
         431,
         436,
         440,
         375,
         375,
         444,
         445,
         446,
         375,
         375,
         375,
         2276,
         2277,
         2278,
         2279,
         2280,
         2281,
         375,
         375,
         375,
         375,
         401,
         376,
         390,
         376,
         376,
         402,
         376,
         411,
         419,
         426,
         432,
         437,
         441,
         376,
         444,
         376,
         447,
         448,
         376,
         376,
         376,
         2282,
         2283,
         2284,
         2285,
         2286,
         2287,
         376,
         376,
         376,
         376,
         402,
         377,
         391,
         377,
         377,
         403,
         377,
         412,
         420,
         427,
         433,
         438,
         442,
         377,
         445,
         447,
         377,
         449,
         377,
         377,
         377,
         2288,
         2289,
         2290,
         2291,
         2292,
         2293,
         377,
         377,
         377,
         377,
         403,
         378,
         392,
         378,
         378,
         404,
         378,
         413,
         421,
         428,
         434,
         439,
         443,
         378,
         446,
         448,
         449,
         378,
         378,
         378,
         378,
         2294,
         2295,
         2296,
         2297,
         2298,
         2299,
         378,
         378,
         378,
         378,
         404,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         450,
         450,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         450,
         25,
         450,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         450,
         450,
         450,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         368,
         2224,
         2230,
         2224,
         2224,
         2236,
         2224,
         2225,
         2246,
         2252,
         2258,
         2264,
         2270,
         2224,
         2276,
         2282,
         2288,
         2294,
         2224,
         2224,
         2224,
         2224,
         2225,
         2300,
         2301,
         2302,
         2303,
         2224,
         2224,
         2224,
         2224,
         2236,
         2225,
         2231,
         2225,
         2225,
         2237,
         2225,
         2225,
         2247,
         2253,
         2259,
         2265,
         2271,
         2225,
         2277,
         2283,
         2289,
         2295,
         2225,
         2225,
         2225,
         2225,
         2225,
         2304,
         2305,
         2306,
         2307,
         2225,
         2225,
         2225,
         2225,
         2237,
         2226,
         2232,
         2226,
         2226,
         2238,
         2226,
         2242,
         2248,
         2254,
         2260,
         2266,
         2272,
         2226,
         2278,
         2284,
         2290,
         2296,
         2226,
         2226,
         2226,
         2300,
         2304,
         2226,
         2308,
         2309,
         2310,
         2226,
         2226,
         2226,
         2226,
         2238,
         2227,
         2233,
         2227,
         2227,
         2239,
         2227,
         2243,
         2249,
         2255,
         2261,
         2267,
         2273,
         2227,
         2279,
         2285,
         2291,
         2297,
         2227,
         2227,
         2227,
         2301,
         2305,
         2308,
         2227,
         2311,
         2312,
         2227,
         2227,
         2227,
         2227,
         2239,
         2228,
         2234,
         2228,
         2228,
         2240,
         2228,
         2244,
         2250,
         2256,
         2262,
         2268,
         2274,
         2228,
         2280,
         2286,
         2292,
         2298,
         2228,
         2228,
         2228,
         2302,
         2306,
         2309,
         2311,
         2228,
         2313,
         2228,
         2228,
         2228,
         2228,
         2240,
         2229,
         2235,
         2229,
         2229,
         2241,
         2229,
         2245,
         2251,
         2257,
         2263,
         2269,
         2275,
         2229,
         2281,
         2287,
         2293,
         2299,
         2229,
         2229,
         2229,
         2303,
         2307,
         2310,
         2312,
         2313,
         2229,
         2229,
         2229,
         2229,
         2229,
         2241,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         2314,
         2314,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         2314,
         25,
         2314,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         2314,
         2314,
         2314,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2224,
         2225,
         2226,
         2227,
         2228,
         2229,
         25,
         25,
         25,
         25,
         3101,
         368,
         380,
         368,
         368,
         368,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         368,
         401,
         402,
         403,
         404,
         368,
         368,
         368,
         2236,
         2237,
         2238,
         2239,
         2240,
         2241,
         368,
         368,
         368,
         3101,
         368,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         27,
         27,
         27,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         9,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         15,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         20,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         4,
         4,
         3,
         20,
         3,
         3,
         3,
         20,
         3,
         20,
         3,
         3,
         3,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         22,
         7,
         18,
         0,
         19,
         19,
         19,
         19,
         23,
         19,
         0,
         0,
         18,
         18,
         0,
         18,
         18,
         0,
         0,
         2,
         2,
         2,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         19,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         0,
         0,
         0,
         0,
         18,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         28,
         29,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         29,
         29,
         1616,
         1617,
         1618,
         1619,
         1620,
         1621,
         1622,
         1623,
         1624,
         1625,
         29,
         1626,
         29,
         1623,
         2383,
         1616,
         2384,
         2385,
         2386,
         2387,
         3055,
         3056,
         3110,
         1610,
         1616,
         1610,
         1610,
         1610,
         1610,
         1610,
         1627,
         1628,
         1610,
         1629,
         1630,
         1610,
         1631,
         1610,
         1610,
         2388,
         1610,
         2389,
         2390,
         2391,
         2391,
         3057,
         3058,
         1610,
         28,
         1617,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1632,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         28,
         1618,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1632,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         28,
         1619,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         28,
         1620,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         1611,
         1621,
         1627,
         1611,
         1611,
         1611,
         1611,
         1633,
         1634,
         1611,
         1635,
         1636,
         1611,
         1637,
         1611,
         1611,
         2392,
         2393,
         2394,
         2395,
         2396,
         2396,
         3059,
         3060,
         1611,
         1612,
         1622,
         1628,
         1632,
         1632,
         1612,
         1612,
         1634,
         1612,
         1612,
         1638,
         1639,
         1612,
         1640,
         1612,
         1612,
         2397,
         1628,
         2398,
         2399,
         2400,
         2400,
         3061,
         3062,
         1612,
         28,
         1623,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         1613,
         1624,
         1629,
         1613,
         1613,
         1613,
         1613,
         1635,
         1638,
         1613,
         1613,
         1641,
         1613,
         1642,
         1613,
         1613,
         2379,
         1629,
         2401,
         2402,
         2403,
         2403,
         3063,
         3064,
         1613,
         1614,
         1625,
         1630,
         1614,
         1614,
         1614,
         1614,
         1636,
         1639,
         1614,
         1641,
         1643,
         1614,
         1644,
         1614,
         1614,
         2404,
         1630,
         2405,
         2406,
         2407,
         2407,
         3065,
         3066,
         1614,
         28,
         29,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         1645,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         1615,
         1626,
         1631,
         1615,
         1615,
         1615,
         1615,
         1637,
         1640,
         1615,
         1642,
         1644,
         1615,
         1615,
         1615,
         1615,
         2408,
         1631,
         2409,
         2410,
         2411,
         2411,
         3067,
         3068,
         1615,
         28,
         29,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         1646,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         28,
         1623,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         2412,
         2413,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
         2379,
         2383,
         2388,
         2379,
         2379,
         2379,
         2379,
         2392,
         2397,
         2379,
         2379,
         2404,
         2379,
         2408,
         2379,
         2413,
         2413,
         2388,
         2414,
         2415,
         2416,
         2416,
         3069,
         3070,
         2379,
         1610,
         1616,
         1610,
         1610,
         1610,
         1610,
         1610,
         2393,
         1628,
         1610,
         1629,
         1630,
         1610,
         1631,
         1610,
         1610,
         2388,
         1610,
         2389,
         2390,
         2391,
         2391,
         3071,
         3058,
         1610,
         2380,
         2384,
         2389,
         2380,
         2380,
         2380,
         2380,
         2394,
         2398,
         2380,
         2401,
         2405,
         2380,
         2409,
         2380,
         2380,
         2414,
         2389,
         2380,
         2381,
         2417,
         2417,
         3072,
         3054,
         2380,
         2381,
         2385,
         2390,
         2381,
         2381,
         2381,
         2381,
         2395,
         2399,
         2381,
         2402,
         2406,
         2381,
         2410,
         2381,
         2381,
         2415,
         2390,
         2381,
         2418,
         2419,
         2419,
         3073,
         3074,
         2381,
         2382,
         2386,
         2391,
         2382,
         2382,
         2382,
         2382,
         2396,
         2400,
         2382,
         2403,
         2407,
         2382,
         2411,
         2382,
         2382,
         2416,
         2391,
         2417,
         2419,
         2382,
         2382,
         3075,
         3076,
         2382,
         2382,
         2387,
         2391,
         2382,
         2382,
         2382,
         2382,
         2396,
         2400,
         2382,
         2403,
         2407,
         2382,
         2411,
         2382,
         2382,
         2416,
         2391,
         2417,
         2419,
         2382,
         2382,
         3075,
         3076,
         2382,
         3053,
         3055,
         3057,
         3053,
         3053,
         3053,
         3053,
         3059,
         3061,
         3053,
         3063,
         3065,
         3053,
         3067,
         3053,
         3053,
         3069,
         3071,
         3072,
         3073,
         3075,
         3075,
         3059,
         3077,
         3053,
         3054,
         3056,
         3058,
         3054,
         3054,
         3054,
         3054,
         3060,
         3062,
         3054,
         3064,
         3066,
         3054,
         3068,
         3054,
         3054,
         3070,
         3058,
         3054,
         3074,
         3076,
         3076,
         3077,
         3074,
         3054,
         28,
         3110,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2379,
         1610,
         2380,
         2381,
         2382,
         2382,
         3053,
         3054,
         28,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         30,
         31,
         1647,
         30,
         30,
         30,
         1648,
         30,
         31,
         31,
         1649,
         1650,
         1651,
         1652,
         1653,
         31,
         1647,
         1649,
         1647,
         1647,
         1647,
         1647,
         1654,
         1647,
         30,
         1650,
         1647,
         30,
         30,
         30,
         1648,
         30,
         30,
         1651,
         1647,
         30,
         30,
         30,
         1648,
         30,
         30,
         1652,
         1647,
         30,
         30,
         30,
         1648,
         30,
         1648,
         1653,
         1654,
         1648,
         1648,
         1648,
         1648,
         1648,
         30,
         31,
         1647,
         30,
         30,
         30,
         1648,
         1655,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         11,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         12,
         4,
         3,
         3,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         11,
         3,
         3,
         11,
         3,
         11,
         3,
         11,
         11,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         14,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         10,
         10,
         10,
         15,
         10,
         0,
         0,
         10,
         10,
         0,
         10,
         10,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         10,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         13,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         36,
         37,
         36,
         1665,
         1665,
         36,
         1666,
         36,
         36,
         36,
         36,
         1665,
         1665,
         1666,
         1666,
         36,
         1667,
         1668,
         1667,
         1669,
         1669,
         1667,
         1670,
         1667,
         1667,
         1667,
         1667,
         1669,
         1669,
         1670,
         1670,
         1667,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         1679,
         1680,
         1679,
         1681,
         1681,
         1679,
         1682,
         1679,
         1679,
         1679,
         1679,
         1681,
         1681,
         1682,
         1682,
         1679,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         2425,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         2426,
         2427,
         2426,
         2428,
         2428,
         2426,
         2429,
         2426,
         2426,
         2426,
         2426,
         2428,
         2428,
         2429,
         2429,
         2426,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         3079,
         3079,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1667,
         1668,
         1667,
         1669,
         1669,
         1667,
         1670,
         1667,
         1667,
         1667,
         1667,
         1669,
         1669,
         1670,
         1670,
         1667,
         1683,
         1684,
         1683,
         1685,
         1685,
         1683,
         1686,
         1683,
         1683,
         1683,
         1683,
         1685,
         1685,
         1686,
         1686,
         1683,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1688,
         1689,
         1688,
         1690,
         1690,
         1688,
         1691,
         1688,
         1688,
         1688,
         1688,
         1690,
         1690,
         1691,
         2430,
         1688,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         2431,
         2432,
         2431,
         2433,
         2433,
         2431,
         2434,
         2431,
         2431,
         2431,
         2431,
         2433,
         2433,
         2434,
         2434,
         2431,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         3080,
         3080,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         1679,
         1680,
         1679,
         1681,
         1681,
         1679,
         1682,
         1679,
         1679,
         1679,
         1679,
         1681,
         1681,
         1682,
         1682,
         1679,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         2425,
         34,
         1688,
         1689,
         1688,
         1690,
         1690,
         1688,
         1691,
         1688,
         1688,
         1688,
         1688,
         1690,
         1690,
         1691,
         2430,
         1688,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2436,
         2421,
         2437,
         2438,
         2437,
         2439,
         2439,
         2437,
         2440,
         2437,
         2437,
         2437,
         2437,
         2439,
         2439,
         2440,
         2441,
         2437,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         2442,
         2442,
         32,
         1657,
         32,
         32,
         32,
         32,
         2442,
         2442,
         1657,
         2420,
         32,
         32,
         33,
         32,
         2442,
         2442,
         32,
         1657,
         32,
         32,
         32,
         32,
         2442,
         2442,
         1657,
         2420,
         32,
         2437,
         2438,
         2437,
         2439,
         2439,
         2437,
         2440,
         2437,
         2437,
         2437,
         2437,
         3082,
         3082,
         2440,
         2441,
         2437,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2420,
         32,
         2443,
         2444,
         2443,
         2445,
         2445,
         2443,
         2446,
         2443,
         2443,
         2443,
         2443,
         2445,
         2445,
         2446,
         2446,
         2443,
         2447,
         2448,
         2447,
         2449,
         2449,
         2447,
         2450,
         2447,
         2447,
         2447,
         2447,
         2449,
         2449,
         2450,
         2450,
         2447,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         2426,
         2427,
         2426,
         2428,
         2428,
         2426,
         2429,
         2426,
         2426,
         2426,
         2426,
         2428,
         2428,
         2429,
         2429,
         2426,
         2431,
         2432,
         2431,
         2433,
         2433,
         2431,
         2434,
         2431,
         2431,
         2431,
         2431,
         2433,
         2433,
         2434,
         2434,
         2431,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2436,
         2421,
         2447,
         2448,
         2447,
         2449,
         2449,
         2447,
         2450,
         2447,
         2447,
         2447,
         2447,
         2449,
         2449,
         2450,
         2450,
         2447,
         2447,
         2448,
         2447,
         2449,
         2449,
         2447,
         2450,
         2447,
         2447,
         2447,
         2447,
         2449,
         2449,
         2450,
         2450,
         2447,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         3083,
         3083,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2437,
         2438,
         2437,
         2439,
         2439,
         2437,
         2440,
         2437,
         2437,
         2437,
         2437,
         2439,
         2439,
         2440,
         2441,
         2437,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2435,
         2435,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2435,
         2435,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         2442,
         2442,
         32,
         1657,
         32,
         32,
         32,
         32,
         2442,
         2442,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         2442,
         2442,
         32,
         1657,
         32,
         32,
         32,
         32,
         2442,
         2442,
         1657,
         2420,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         2423,
         2423,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         3079,
         3079,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         3080,
         3080,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         2437,
         2438,
         2437,
         2439,
         2439,
         2437,
         2440,
         2437,
         2437,
         2437,
         2437,
         3082,
         3082,
         2440,
         2441,
         2437,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         2421,
         2422,
         2421,
         2423,
         2423,
         2421,
         2424,
         2421,
         2421,
         2421,
         2421,
         3083,
         3083,
         2424,
         2424,
         2421,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3081,
         3081,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3078,
         3078,
         1657,
         1657,
         32,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         42,
         43,
         42,
         1697,
         1697,
         1698,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         1699,
         1700,
         1699,
         1701,
         1701,
         1702,
         1703,
         1704,
         1703,
         1705,
         1705,
         1706,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         1707,
         1708,
         1707,
         1709,
         1709,
         1710,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         1699,
         1700,
         1699,
         1701,
         1701,
         1702,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         1703,
         1704,
         1703,
         1705,
         1705,
         1706,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         12,
         13,
         14,
         15,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         25,
         26,
         27,
         26,
         27,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         30,
         30,
         31,
         32,
         33,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         13,
         12,
         12,
         13,
         13,
         14,
         14,
         15,
         14,
         15,
         14,
         15,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         18,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         17,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         46,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         47,
         32,
         32,
         48,
         49,
         32,
         32,
         31,
         31,
         31,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         33,
         33,
         33,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         27,
         26,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         12,
         12,
         12,
         55,
         13,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         16,
         16,
         16,
         16,
         16,
         16,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         19,
         18,
         18,
         18,
         18,
         18,
         23,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         28,
         29,
         32,
         34,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         25,
         0,
         18,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         18,
         18,
         18,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         13,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         13,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         13,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         45,
         45,
         1364,
         45,
         1365,
         1366,
         45,
         1367,
         1368,
         1369,
         45,
         45,
         45,
         1370,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         1371,
         45,
         1372,
         45,
         1373,
         45,
         1374,
         2524,
         2525,
         2526,
         2527,
         2528,
         45,
         45,
         2529,
         2530,
         2531,
         2532,
         3000,
         3001,
         45,
         45,
         45,
         3126,
         3128,
         3129,
         3136,
         3137,
         3138,
         3145,
         3146,
         3147,
         44,
         1364,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         1365,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         1366,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         2533,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1358,
         1367,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1377,
         1358,
         1378,
         1358,
         1379,
         1358,
         1380,
         2534,
         1376,
         1358,
         2535,
         2536,
         1358,
         1358,
         2537,
         2538,
         2539,
         2540,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1358,
         1368,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1377,
         1358,
         1378,
         1358,
         1379,
         1358,
         1380,
         2534,
         1376,
         1358,
         2535,
         2536,
         1358,
         1358,
         2537,
         2538,
         2539,
         2540,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1359,
         1369,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2541,
         1381,
         1359,
         2542,
         2543,
         1359,
         1359,
         2544,
         2545,
         2546,
         2547,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1386,
         44,
         44,
         44,
         44,
         44,
         44,
         1387,
         1387,
         1387,
         1387,
         1388,
         1388,
         1388,
         1388,
         1389,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         44,
         1370,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         1392,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2548,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1394,
         1394,
         1394,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1395,
         1396,
         1397,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1396,
         1398,
         1399,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1397,
         1399,
         1400,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1401,
         1401,
         1401,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1402,
         1403,
         1404,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1403,
         1405,
         1406,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1404,
         1406,
         1407,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1389,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1408,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1409,
         1409,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1409,
         1409,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         3120,
         3121,
         3122,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1410,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1411,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1412,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1414,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2549,
         1414,
         1414,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1413,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2550,
         1413,
         1413,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1413,
         44,
         1415,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2550,
         1413,
         1413,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1416,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1360,
         1371,
         1360,
         1360,
         1360,
         1360,
         1360,
         1377,
         1377,
         1382,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1416,
         1416,
         1360,
         1417,
         1360,
         1418,
         1360,
         1419,
         2551,
         1382,
         1360,
         2552,
         2553,
         1360,
         1360,
         2554,
         2555,
         2556,
         2557,
         1360,
         1360,
         1360,
         1360,
         1360,
         1382,
         1360,
         1360,
         1382,
         1360,
         1360,
         1382,
         1360,
         1360,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1420,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1361,
         1372,
         1361,
         1361,
         1361,
         1361,
         1361,
         1378,
         1378,
         1383,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1417,
         1420,
         1420,
         1361,
         1421,
         1361,
         1422,
         2558,
         1383,
         1361,
         2559,
         2560,
         1361,
         1361,
         2561,
         2562,
         2563,
         2564,
         1361,
         1361,
         1361,
         1361,
         1361,
         1383,
         1361,
         1361,
         1383,
         1361,
         1361,
         1383,
         1361,
         1361,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1423,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1362,
         1373,
         1362,
         1362,
         1362,
         1362,
         1362,
         1379,
         1379,
         1384,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1418,
         1362,
         1421,
         1423,
         1423,
         1362,
         1424,
         2565,
         1384,
         1362,
         2566,
         2567,
         1362,
         1362,
         2568,
         2569,
         2570,
         2571,
         1362,
         1362,
         1362,
         1362,
         1362,
         1384,
         1362,
         1362,
         1384,
         1362,
         1362,
         1384,
         1362,
         1362,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1425,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1363,
         1374,
         1363,
         1363,
         1363,
         1363,
         1363,
         1380,
         1380,
         1385,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1419,
         1363,
         1422,
         1363,
         1424,
         1425,
         1425,
         2572,
         1385,
         1363,
         2573,
         2574,
         1363,
         1363,
         2575,
         2576,
         2577,
         2578,
         1363,
         1363,
         1363,
         1363,
         1363,
         1385,
         1363,
         1363,
         1385,
         1363,
         1363,
         1385,
         1363,
         1363,
         2517,
         2524,
         2517,
         2517,
         2517,
         2517,
         2517,
         2534,
         2534,
         2541,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2517,
         2551,
         2517,
         2558,
         2517,
         2565,
         2517,
         2572,
         2541,
         2541,
         2517,
         2579,
         2580,
         2517,
         2517,
         2581,
         2582,
         2583,
         2584,
         2517,
         2517,
         2517,
         2517,
         2517,
         2541,
         2517,
         2517,
         2541,
         2517,
         2517,
         2541,
         2517,
         2517,
         1359,
         2525,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2541,
         1381,
         1359,
         2542,
         2543,
         1359,
         1359,
         2544,
         2545,
         2546,
         2547,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         2526,
         44,
         44,
         44,
         44,
         2533,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         2585,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         2518,
         2527,
         2518,
         2518,
         2518,
         2518,
         2518,
         2535,
         2535,
         2542,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2548,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2518,
         2552,
         2518,
         2559,
         2518,
         2566,
         2518,
         2573,
         2579,
         2542,
         2518,
         2548,
         2586,
         2518,
         2518,
         2587,
         2588,
         2589,
         2590,
         2518,
         2518,
         2548,
         2548,
         2548,
         2542,
         2518,
         2518,
         2542,
         2518,
         2518,
         2542,
         2518,
         2518,
         2519,
         2528,
         2519,
         2519,
         2519,
         2519,
         2519,
         2536,
         2536,
         2543,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2519,
         2549,
         2550,
         2550,
         2519,
         2553,
         2519,
         2560,
         2519,
         2567,
         2519,
         2574,
         2580,
         2543,
         2519,
         2586,
         2549,
         2549,
         2549,
         2591,
         2592,
         2593,
         2594,
         2519,
         2519,
         2519,
         2519,
         2519,
         2543,
         2519,
         2519,
         2543,
         2519,
         2519,
         2543,
         2519,
         2519,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1414,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2549,
         1414,
         2595,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1414,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2549,
         2595,
         1414,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         2520,
         2529,
         2520,
         2520,
         2520,
         2520,
         2520,
         2537,
         2537,
         2544,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2520,
         2554,
         2520,
         2561,
         2520,
         2568,
         2520,
         2575,
         2581,
         2544,
         2520,
         2587,
         2591,
         2520,
         2520,
         2520,
         2596,
         2597,
         2598,
         2520,
         2520,
         2520,
         2520,
         2520,
         2544,
         2520,
         2520,
         2544,
         2520,
         2520,
         2544,
         2520,
         2520,
         2521,
         2530,
         2521,
         2521,
         2521,
         2521,
         2521,
         2538,
         2538,
         2545,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2521,
         2555,
         2521,
         2562,
         2521,
         2569,
         2521,
         2576,
         2582,
         2545,
         2521,
         2588,
         2592,
         2521,
         2521,
         2596,
         2521,
         2599,
         2600,
         2521,
         2521,
         2521,
         2521,
         2521,
         2545,
         2521,
         2521,
         2545,
         2521,
         2521,
         2545,
         2521,
         2521,
         2522,
         2531,
         2522,
         2522,
         2522,
         2522,
         2522,
         2539,
         2539,
         2546,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2522,
         2556,
         2522,
         2563,
         2522,
         2570,
         2522,
         2577,
         2583,
         2546,
         2522,
         2589,
         2593,
         2522,
         2522,
         2597,
         2599,
         2522,
         2601,
         2522,
         2522,
         2522,
         2522,
         2522,
         2546,
         2522,
         2522,
         2546,
         2522,
         2522,
         2546,
         2522,
         2522,
         2523,
         2532,
         2523,
         2523,
         2523,
         2523,
         2523,
         2540,
         2540,
         2547,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2523,
         2557,
         2523,
         2564,
         2523,
         2571,
         2523,
         2578,
         2584,
         2547,
         2523,
         2590,
         2594,
         2523,
         2523,
         2598,
         2600,
         2601,
         2602,
         2523,
         2523,
         2523,
         2523,
         2523,
         2547,
         2523,
         2523,
         2547,
         2523,
         2523,
         2547,
         2523,
         2523,
         44,
         3000,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3001,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3120,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2548,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3121,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2548,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3122,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2548,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         3126,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2541,
         1381,
         1359,
         2542,
         2543,
         1359,
         1359,
         2544,
         2545,
         2546,
         2547,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         3128,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3129,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         3136,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2541,
         1381,
         1359,
         2542,
         2543,
         1359,
         1359,
         2544,
         2545,
         2546,
         2547,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         3137,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3138,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         3145,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2541,
         1381,
         1359,
         2542,
         2543,
         1359,
         1359,
         2544,
         2545,
         2546,
         2547,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         3146,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3147,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2517,
         1359,
         44,
         2518,
         2519,
         44,
         44,
         2520,
         2521,
         2522,
         2523,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         10,
         11,
         12,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         22,
         23,
         23,
         23,
         23,
         24,
         24,
         24,
         24,
         25,
         25,
         25,
         25,
         26,
         27,
         0,
         28,
         0,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         32,
         0,
         0,
         33,
         34,
         35,
         36,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         42,
         2,
         42,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         42,
         2,
         3,
         2,
         42,
         43,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         46,
         9,
         46,
         9,
         10,
         9,
         46,
         10,
         10,
         11,
         11,
         12,
         11,
         12,
         11,
         12,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         14,
         14,
         14,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         15,
         14,
         15,
         14,
         15,
         14,
         14,
         14,
         15,
         15,
         14,
         15,
         14,
         14,
         14,
         15,
         14,
         15,
         14,
         14,
         14,
         14,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         19,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         26,
         26,
         26,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         49,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         50,
         51,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         55,
         55,
         55,
         3,
         3,
         3,
         3,
         3,
         56,
         56,
         56,
         10,
         10,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         13,
         13,
         13,
         13,
         13,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         16,
         15,
         15,
         15,
         15,
         15,
         20,
         19,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         24,
         25,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         51,
         49,
         47,
         5,
         5,
         5,
         58,
         5,
         5,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         13,
         13,
         13,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         22,
         0,
         15,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         3,
         10,
         4,
         0,
         63,
         64,
         65,
         66,
         5,
         5,
         3,
         10,
         4,
         67,
         68,
         69,
         70,
         5,
         5,
         3,
         10,
         4,
         71,
         72,
         73,
         74,
         5,
         5,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         47,
         47,
         47,
         47,
         1435,
         1436,
         1437,
         47,
         47,
         47,
         47,
         47,
         47,
         1438,
         1439,
         1439,
         1439,
         1439,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         1440,
         47,
         47,
         1441,
         47,
         47,
         1442,
         47,
         1443,
         47,
         1444,
         47,
         47,
         47,
         47,
         47,
         1436,
         1437,
         47,
         47,
         2455,
         2456,
         2457,
         2458,
         47,
         47,
         47,
         47,
         47,
         1436,
         1436,
         1435,
         1435,
         47,
         47,
         1435,
         1435,
         47,
         47,
         1435,
         1435,
         47,
         47,
         1435,
         1435,
         47,
         47,
         46,
         47,
         46,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         2994,
         1427,
         1427,
         1426,
         1426,
         1445,
         46,
         1426,
         1426,
         1445,
         46,
         1426,
         1426,
         1445,
         46,
         1426,
         1426,
         1445,
         46,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         1445,
         2994,
         1427,
         1427,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2464,
         2465,
         2466,
         2467,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1427,
         1437,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2464,
         2465,
         2466,
         2467,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         1463,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         1464,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         1465,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2468,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2995,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         1466,
         1426,
         1426,
         46,
         1466,
         1426,
         1426,
         46,
         1466,
         1426,
         1426,
         46,
         1466,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2468,
         1446,
         1427,
         1427,
         1466,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2995,
         1466,
         1427,
         1427,
         1426,
         1426,
         1446,
         1466,
         1426,
         1426,
         1446,
         1466,
         1426,
         1426,
         1446,
         1466,
         1426,
         1426,
         1446,
         1466,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         1467,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         1467,
         1467,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1428,
         1438,
         1428,
         1428,
         1449,
         1456,
         1456,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1468,
         1469,
         1469,
         1469,
         1469,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1470,
         1428,
         1428,
         1471,
         1428,
         1428,
         1472,
         1428,
         1473,
         1428,
         1474,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1428,
         1428,
         2469,
         2470,
         2471,
         2472,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1475,
         1475,
         1475,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2473,
         2473,
         1429,
         1429,
         2474,
         2475,
         2476,
         2477,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1481,
         1482,
         1483,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2473,
         2473,
         1429,
         1429,
         2474,
         2475,
         2476,
         2477,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1482,
         1484,
         1485,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2473,
         2473,
         1429,
         1429,
         2474,
         2475,
         2476,
         2477,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1483,
         1485,
         1486,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2473,
         2473,
         1429,
         1429,
         2474,
         2475,
         2476,
         2477,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1487,
         1487,
         1487,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1488,
         1489,
         1490,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1489,
         1491,
         1492,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1490,
         1492,
         1493,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         1464,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         1494,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         1495,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         1496,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1497,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1498,
         1498,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1498,
         1498,
         1499,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1430,
         1440,
         1430,
         1430,
         1451,
         1458,
         1458,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1470,
         1476,
         1476,
         1476,
         1476,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1499,
         1500,
         1430,
         1430,
         1501,
         1430,
         1430,
         1502,
         1430,
         1503,
         1430,
         1504,
         1430,
         1430,
         1430,
         1430,
         1430,
         1458,
         1458,
         1430,
         1430,
         2478,
         2479,
         2480,
         2481,
         1430,
         1430,
         1430,
         1430,
         1430,
         1458,
         1458,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         1505,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1506,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1431,
         1441,
         1431,
         1431,
         1452,
         1459,
         1459,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1471,
         1477,
         1477,
         1477,
         1477,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1501,
         1431,
         1506,
         1506,
         1431,
         1431,
         1507,
         1431,
         1508,
         1431,
         1509,
         1431,
         1431,
         1431,
         1431,
         1431,
         1459,
         1459,
         1431,
         1431,
         2482,
         2483,
         2484,
         2485,
         1431,
         1431,
         1431,
         1431,
         1431,
         1459,
         1459,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         2486,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1510,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1432,
         1442,
         1432,
         1432,
         1453,
         1460,
         1460,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1472,
         1478,
         1478,
         1478,
         1478,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1502,
         1432,
         1432,
         1507,
         1432,
         1510,
         1510,
         1432,
         1511,
         1432,
         1512,
         1432,
         1432,
         1432,
         1432,
         1432,
         1460,
         1460,
         1432,
         1432,
         2487,
         2488,
         2489,
         2490,
         1432,
         1432,
         1432,
         1432,
         1432,
         1460,
         1460,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1513,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1433,
         1443,
         1433,
         1433,
         1454,
         1461,
         1461,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1473,
         1479,
         1479,
         1479,
         1479,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1503,
         1433,
         1433,
         1508,
         1433,
         1433,
         1511,
         1513,
         1513,
         1433,
         1514,
         1433,
         1433,
         1433,
         1433,
         1433,
         1461,
         1461,
         1433,
         1433,
         2491,
         2492,
         2493,
         2494,
         1433,
         1433,
         1433,
         1433,
         1433,
         1461,
         1461,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1515,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1434,
         1444,
         1434,
         1434,
         1455,
         1462,
         1462,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1474,
         1480,
         1480,
         1480,
         1480,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1504,
         1434,
         1434,
         1509,
         1434,
         1434,
         1512,
         1434,
         1514,
         1515,
         1515,
         1434,
         1434,
         1434,
         1434,
         1434,
         1462,
         1462,
         1434,
         1434,
         2495,
         2496,
         2497,
         2498,
         1434,
         1434,
         1434,
         1434,
         1434,
         1462,
         1462,
         1455,
         1455,
         1434,
         1434,
         1455,
         1455,
         1434,
         1434,
         1455,
         1455,
         1434,
         1434,
         1455,
         1455,
         1434,
         1434,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         1516,
         1516,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         1516,
         46,
         1516,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         1516,
         1516,
         1516,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         2468,
         2468,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         1445,
         1427,
         1427,
         2499,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         2996,
         1427,
         1427,
         1426,
         1426,
         1445,
         2468,
         1426,
         1426,
         1445,
         2468,
         1426,
         1426,
         1445,
         2468,
         1426,
         1426,
         1445,
         2468,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         2486,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2500,
         2501,
         46,
         46,
         46,
         1445,
         2994,
         2997,
         3102,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         2473,
         2473,
         2473,
         2473,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2464,
         2465,
         2466,
         2467,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1427,
         1437,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         2473,
         2473,
         2473,
         2473,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2464,
         2465,
         2466,
         2467,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         46,
         47,
         2459,
         2459,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2499,
         2459,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2998,
         46,
         1427,
         1427,
         1426,
         1426,
         2459,
         1466,
         1426,
         1426,
         2459,
         1466,
         1426,
         1426,
         2459,
         1466,
         1426,
         1426,
         2459,
         1466,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         2502,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2451,
         2455,
         2451,
         2451,
         2460,
         2464,
         2464,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2469,
         2474,
         2474,
         2474,
         2474,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2451,
         2478,
         2451,
         2451,
         2482,
         2451,
         2451,
         2487,
         2451,
         2491,
         2451,
         2495,
         2451,
         2451,
         2451,
         2451,
         2451,
         2464,
         2464,
         2451,
         2451,
         2451,
         2503,
         2504,
         2505,
         2451,
         2451,
         2451,
         2451,
         2451,
         2464,
         2464,
         2460,
         2460,
         2451,
         2451,
         2460,
         2460,
         2451,
         2451,
         2460,
         2460,
         2451,
         2451,
         2460,
         2460,
         2451,
         2451,
         2452,
         2456,
         2452,
         2452,
         2461,
         2465,
         2465,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2470,
         2475,
         2475,
         2475,
         2475,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2452,
         2479,
         2452,
         2452,
         2483,
         2452,
         2452,
         2488,
         2452,
         2492,
         2452,
         2496,
         2452,
         2452,
         2452,
         2452,
         2452,
         2465,
         2465,
         2452,
         2452,
         2503,
         2452,
         2506,
         2507,
         2452,
         2452,
         2452,
         2452,
         2452,
         2465,
         2465,
         2461,
         2461,
         2452,
         2452,
         2461,
         2461,
         2452,
         2452,
         2461,
         2461,
         2452,
         2452,
         2461,
         2461,
         2452,
         2452,
         2453,
         2457,
         2453,
         2453,
         2462,
         2466,
         2466,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2471,
         2476,
         2476,
         2476,
         2476,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2453,
         2480,
         2453,
         2453,
         2484,
         2453,
         2453,
         2489,
         2453,
         2493,
         2453,
         2497,
         2453,
         2453,
         2453,
         2453,
         2500,
         2466,
         2466,
         2453,
         2453,
         2504,
         2506,
         2453,
         2508,
         2453,
         2453,
         2453,
         2453,
         2453,
         2466,
         2466,
         2462,
         2462,
         2453,
         2453,
         2462,
         2462,
         2453,
         2453,
         2462,
         2462,
         2453,
         2453,
         2462,
         2462,
         2453,
         2453,
         2454,
         2458,
         2454,
         2454,
         2463,
         2467,
         2467,
         2454,
         2454,
         2454,
         2454,
         2454,
         2454,
         2472,
         2477,
         2477,
         2477,
         2477,
         2454,
         2454,
         2454,
         2454,
         2454,
         2454,
         2454,
         2454,
         2454,
         2454,
         2481,
         2454,
         2454,
         2485,
         2454,
         2454,
         2490,
         2454,
         2494,
         2454,
         2498,
         2454,
         2454,
         2454,
         2454,
         2501,
         2467,
         2467,
         2454,
         2454,
         2505,
         2507,
         2508,
         2509,
         2454,
         2454,
         2454,
         2454,
         2454,
         2467,
         2467,
         2463,
         2463,
         2454,
         2454,
         2463,
         2463,
         2454,
         2454,
         2463,
         2463,
         2454,
         2454,
         2463,
         2463,
         2454,
         2454,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         2510,
         2510,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         2510,
         46,
         2510,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         2510,
         2510,
         2510,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         2995,
         2995,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         1445,
         1427,
         1427,
         2998,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         46,
         2999,
         1427,
         1427,
         1426,
         1426,
         1445,
         2995,
         1426,
         1426,
         1445,
         2995,
         1426,
         1426,
         1445,
         2995,
         1426,
         1426,
         1445,
         2995,
         46,
         47,
         2994,
         2994,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2996,
         2994,
         1427,
         1427,
         46,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2999,
         46,
         1427,
         1427,
         1426,
         1426,
         2994,
         1466,
         1426,
         1426,
         2994,
         1466,
         1426,
         1426,
         2994,
         1466,
         1426,
         1426,
         2994,
         1466,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         2997,
         1427,
         1427,
         1427,
         1427,
         2464,
         2465,
         2466,
         2467,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         3102,
         1427,
         1427,
         1427,
         1427,
         2464,
         2465,
         2466,
         2467,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         3103,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         3103,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         1445,
         2994,
         1427,
         1427,
         1426,
         1426,
         1445,
         3104,
         1426,
         1426,
         1445,
         3104,
         1426,
         1426,
         1445,
         3104,
         1426,
         1426,
         1445,
         3104,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2468,
         1446,
         1427,
         1427,
         1466,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2995,
         1466,
         1427,
         1427,
         1426,
         1426,
         3104,
         1466,
         1426,
         1426,
         3104,
         1466,
         1426,
         1426,
         3104,
         1466,
         1426,
         1426,
         3104,
         1466,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         3132,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         3132,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         1445,
         2994,
         1427,
         1427,
         1426,
         1426,
         1445,
         3104,
         1426,
         1426,
         1445,
         3133,
         1426,
         1426,
         1445,
         3133,
         1426,
         1426,
         1445,
         3133,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2468,
         1446,
         1427,
         1427,
         1466,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2995,
         1466,
         1427,
         1427,
         1426,
         1426,
         3104,
         1466,
         1426,
         1426,
         3133,
         1466,
         1426,
         1426,
         3133,
         1466,
         1426,
         1426,
         3133,
         1466,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         3141,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         3141,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         1445,
         2994,
         1427,
         1427,
         1426,
         1426,
         1445,
         3104,
         1426,
         1426,
         1445,
         3133,
         1426,
         1426,
         1445,
         3142,
         1426,
         1426,
         1445,
         3142,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2468,
         1446,
         1427,
         1427,
         1466,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2995,
         1466,
         1427,
         1427,
         1426,
         1426,
         3104,
         1466,
         1426,
         1426,
         3133,
         1466,
         1426,
         1426,
         3142,
         1466,
         1426,
         1426,
         3142,
         1466,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         3150,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2460,
         2461,
         2462,
         2463,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         3150,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2459,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         1445,
         2994,
         1427,
         1427,
         1426,
         1426,
         1445,
         3104,
         1426,
         1426,
         1445,
         3133,
         1426,
         1426,
         1445,
         3142,
         1426,
         1426,
         1445,
         3151,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2468,
         1446,
         1427,
         1427,
         1466,
         46,
         2451,
         2452,
         2453,
         2454,
         46,
         46,
         46,
         2995,
         1466,
         1427,
         1427,
         1426,
         1426,
         3104,
         1466,
         1426,
         1426,
         3133,
         1466,
         1426,
         1426,
         3142,
         1466,
         1426,
         1426,
         3151,
         1466,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         48,
         1711,
         1712,
         1713,
         1714,
         2660,
         2661,
         2662,
         2663,
         2664,
         2665,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         49,
         49,
         49,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         51,
         52,
         51,
         51,
         1921,
         53,
         54,
         53,
         53,
         1922,
         1923,
         1924,
         1923,
         1923,
         1925,
         1926,
         1927,
         1926,
         1926,
         1928,
         51,
         52,
         51,
         51,
         1921,
         55,
         56,
         55,
         55,
         1929,
         57,
         58,
         57,
         57,
         1930,
         1931,
         1932,
         1931,
         1931,
         1933,
         1934,
         1935,
         1934,
         1934,
         1936,
         55,
         56,
         55,
         55,
         1929,
         51,
         52,
         51,
         51,
         1921,
         53,
         54,
         53,
         53,
         1922,
         1937,
         1938,
         1937,
         1937,
         1939,
         1926,
         1927,
         1926,
         1926,
         1928,
         51,
         52,
         51,
         51,
         1921,
         51,
         52,
         51,
         51,
         1921,
         53,
         54,
         53,
         53,
         1922,
         1923,
         1924,
         1923,
         1923,
         1925,
         1940,
         1941,
         1940,
         1940,
         1942,
         51,
         52,
         51,
         51,
         1921,
         51,
         52,
         51,
         51,
         1921,
         53,
         54,
         53,
         53,
         1922,
         1923,
         1924,
         1923,
         1923,
         1925,
         1926,
         1927,
         1926,
         1926,
         1928,
         51,
         52,
         51,
         51,
         1921,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         59,
         60,
         61,
         62,
         61,
         62,
         63,
         64,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         65,
         66,
         67,
         68,
         67,
         68,
         69,
         70,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         71,
         71,
         72,
         72,
         72,
         72,
         73,
         73,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         74,
         75,
         76,
         77,
         76,
         77,
         78,
         79,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         80,
         81,
         82,
         83,
         82,
         83,
         84,
         85,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         86,
         87,
         88,
         89,
         88,
         89,
         90,
         91,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         92,
         92,
         93,
         93,
         93,
         93,
         94,
         94,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         95,
         95,
         96,
         96,
         96,
         96,
         97,
         97,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         98,
         99,
         100,
         101,
         102,
         103,
         104,
         105,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         106,
         106,
         107,
         107,
         108,
         108,
         109,
         109,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         6,
         0,
         7,
         7,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         0,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         32,
         33,
         33,
         0,
         34,
         34,
         35,
         35,
         36,
         36,
         37,
         37,
         38,
         38,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         0,
         41,
         0,
         42,
         43,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         44,
         45,
         46,
         46,
         46,
         46,
         47,
         48,
         49,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         40,
         40,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         19,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         23,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         23,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         55,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         58,
         59,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         0,
         26,
         0,
         0,
         26,
         0,
         26,
         0,
         0,
         26,
         26,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         29,
         0,
         29,
         0,
         0,
         29,
         0,
         29,
         0,
         0,
         29,
         29,
         0,
         60,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         37,
         37,
         37,
         37,
         38,
         38,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         45,
         45,
         45,
         45,
         47,
         48,
         48,
         48,
         48,
         49,
         44,
         46,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         17,
         17,
         17,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         20,
         19,
         19,
         19,
         19,
         19,
         24,
         23,
         23,
         23,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         46,
         3,
         3,
         3,
         44,
         44,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         26,
         0,
         29,
         0,
         32,
         0,
         37,
         37,
         37,
         37,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         39,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         59,
         59,
         57,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         17,
         17,
         17,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         44,
         19,
         23,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         37,
         37,
         37,
         37,
         6,
         10,
         10,
         10,
         19,
         19,
         19,
         34,
         34,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         63,
         0,
         0,
         9,
         13,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
      },
      
      .num_filtered_states = 64,
      .table = (const uint16_t []) {
      
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         116,
         117,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         497,
         116,
         498,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         114,
         115,
         499,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         500,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         501,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         502,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         503,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         504,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         505,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         506,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         507,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         508,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         509,
         510,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         512,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         513,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         514,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         515,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         516,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         517,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         518,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         519,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         520,
         521,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         522,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         523,
         524,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         525,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         526,
         527,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         528,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         529,
         530,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         531,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         532,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         533,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         534,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         535,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         536,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         537,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         538,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         539,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         540,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         2747,
         2748,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2749,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2747,
         2750,
         2751,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2752,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2750,
         2753,
         2754,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2755,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2753,
         2756,
         2757,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2758,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         2756,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         544,
         545,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         546,
         544,
         547,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         541,
         542,
         548,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         549,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         550,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         551,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         552,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         553,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         554,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         555,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         556,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         557,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         558,
         559,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         560,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         561,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         562,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         563,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         564,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         565,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         566,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         567,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         568,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         569,
         570,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         573,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         574,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         575,
         576,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         577,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         581,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         582,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         583,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         584,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         585,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         586,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         587,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         588,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         589,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         2759,
         2760,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2761,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2759,
         2762,
         2763,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2764,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2762,
         2765,
         2766,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2767,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2765,
         2768,
         2769,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2770,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         2768,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         593,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         3127,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         597,
         598,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         599,
         597,
         600,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         594,
         595,
         601,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         602,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         603,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         604,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         605,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         606,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         607,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         608,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         609,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         610,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         611,
         612,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         613,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         614,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         615,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         616,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         617,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         618,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         619,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         620,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         621,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         622,
         623,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         624,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         625,
         626,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         627,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         628,
         629,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         630,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         631,
         632,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         633,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         634,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         635,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         636,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         637,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         638,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         639,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         640,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         641,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         642,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         2771,
         2772,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2773,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2771,
         2774,
         2775,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2776,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2774,
         2777,
         2778,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2779,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2777,
         2780,
         2781,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2782,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         2780,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         646,
         647,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         648,
         646,
         649,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         643,
         644,
         650,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         651,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         652,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         653,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         654,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         655,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         656,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         657,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         658,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         659,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         660,
         661,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         662,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         663,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         664,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         665,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         666,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         667,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         668,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         669,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         670,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         671,
         672,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         673,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         678,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         679,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         680,
         681,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         682,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         683,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         684,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         685,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         686,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         687,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         688,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         689,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         690,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         691,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         2783,
         2784,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2785,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2783,
         2786,
         2787,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2788,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2786,
         2789,
         2790,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2791,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2792,
         2793,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2794,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         695,
         696,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         697,
         695,
         698,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         699,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         692,
         693,
         700,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         701,
         702,
         701,
         703,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         704,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         692,
         693,
         692,
         692,
         705,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         706,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         707,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         708,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         709,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         710,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         711,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         712,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         713,
         714,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         715,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         716,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         717,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         718,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         719,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         720,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         721,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         722,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         723,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         724,
         725,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         726,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         727,
         728,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         729,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         730,
         731,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         732,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         733,
         734,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         735,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         736,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         737,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         738,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         739,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         740,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         741,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         742,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         743,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         744,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         2795,
         2796,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2797,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2795,
         2798,
         2799,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2800,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2798,
         2801,
         2802,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2803,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2801,
         2804,
         2805,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2806,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         2804,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         748,
         749,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         750,
         748,
         751,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         745,
         746,
         752,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         753,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         754,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         755,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         756,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         757,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         758,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         759,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         760,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         761,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         762,
         763,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         764,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         765,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         766,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         767,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         768,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         769,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         770,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         771,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         772,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         773,
         774,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         775,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         776,
         777,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         778,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         779,
         780,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         783,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         784,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         785,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         786,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         787,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         788,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         789,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         790,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         791,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         792,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         793,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         2807,
         2808,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2809,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2807,
         2810,
         2811,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2812,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2813,
         2814,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2815,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2816,
         2817,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2818,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         2816,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         798,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         799,
         797,
         800,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         801,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         794,
         795,
         802,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         803,
         804,
         803,
         805,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         806,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         794,
         795,
         794,
         794,
         807,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         808,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         809,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         810,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         812,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         813,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         814,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         815,
         816,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         817,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         818,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         819,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         821,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         822,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         823,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         824,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         825,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         829,
         830,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         831,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         832,
         833,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         834,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         835,
         836,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         837,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         838,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         839,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         840,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         841,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         842,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         843,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         844,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         845,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         846,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         2819,
         2820,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2821,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2819,
         2822,
         2823,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2824,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2822,
         2825,
         2826,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2827,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2825,
         2828,
         2829,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2830,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         2828,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         850,
         851,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         852,
         850,
         853,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         847,
         848,
         854,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         855,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         856,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         857,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         858,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         859,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         860,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         861,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         862,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         863,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         864,
         865,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         866,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         867,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         868,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         869,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         870,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         871,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         872,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         873,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         874,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         875,
         876,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         877,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         878,
         879,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         880,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         881,
         882,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         883,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         884,
         885,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         886,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         887,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         888,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         889,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         890,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         891,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         892,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         893,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         894,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         895,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         2831,
         2832,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2833,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2831,
         2834,
         2835,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2836,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2834,
         2837,
         2838,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2839,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2837,
         2840,
         2841,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2842,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         2840,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         899,
         900,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         901,
         899,
         902,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         896,
         897,
         903,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         904,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         905,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         906,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         907,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         908,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         909,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         910,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         911,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         912,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         913,
         914,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         915,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         916,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         917,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         918,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         919,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         920,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         921,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         922,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         923,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         924,
         925,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         926,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         927,
         928,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         929,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         930,
         931,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         932,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         933,
         934,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         935,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         936,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         937,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         938,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         939,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         940,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         941,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         942,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         943,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         944,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         2843,
         2844,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2845,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2843,
         2846,
         2847,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2848,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2846,
         2849,
         2850,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2851,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2849,
         2852,
         2853,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2854,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         2852,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         948,
         949,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         950,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         945,
         946,
         952,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         953,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         954,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         955,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         956,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         957,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         958,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         959,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         960,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         961,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         962,
         963,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         965,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         966,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         967,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         968,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         969,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         970,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         971,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         972,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         973,
         974,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         975,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         976,
         977,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         978,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         979,
         980,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         981,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         982,
         983,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         984,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         985,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         986,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         987,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         988,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         989,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         990,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         991,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         992,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         993,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         2855,
         2856,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2857,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2855,
         2858,
         2859,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2860,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2858,
         2861,
         2862,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2863,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2861,
         2864,
         2865,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2866,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         2864,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         997,
         998,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         999,
         997,
         1000,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         994,
         995,
         1001,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         1002,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         1003,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         1004,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         1005,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         1006,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1007,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1008,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1009,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1010,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1011,
         1012,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1013,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1014,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         1015,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1016,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1017,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1018,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1019,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1020,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1021,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1022,
         1023,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1029,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1030,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1031,
         1032,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1033,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1034,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1035,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1036,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1037,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1038,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1039,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1040,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1041,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1042,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         2867,
         2868,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2869,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2867,
         2870,
         2871,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2872,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2870,
         2873,
         2874,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2875,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2873,
         2876,
         2877,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2878,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         2876,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1046,
         1047,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1048,
         1046,
         1049,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1043,
         1044,
         1050,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1051,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1052,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1053,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1054,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1055,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1056,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1057,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1058,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1059,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1060,
         1061,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1062,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1063,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1064,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1065,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1066,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1067,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1068,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1069,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1070,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1071,
         1072,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1073,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1074,
         1075,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1076,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1077,
         1078,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1079,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1080,
         1081,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1082,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1083,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1084,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1085,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1086,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1087,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1088,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1089,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1090,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1091,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         2879,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         2880,
         2881,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2882,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2880,
         2883,
         2884,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2885,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2883,
         2886,
         2887,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2888,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2886,
         2889,
         2890,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2891,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         2889,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1095,
         1096,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1097,
         1095,
         1098,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1092,
         1093,
         1099,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1100,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1101,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1102,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1103,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1104,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1105,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1106,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1107,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1108,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1109,
         1110,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1111,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1112,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1113,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1114,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1115,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1116,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1117,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1118,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1119,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1120,
         1121,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1122,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1123,
         1124,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1125,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1126,
         1127,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1128,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1129,
         1130,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1131,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1132,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1133,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1134,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1135,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1136,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1137,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1138,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1139,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1140,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         2892,
         2893,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2894,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2892,
         2895,
         2896,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2897,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2895,
         2898,
         2899,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2900,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2898,
         2901,
         2902,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2903,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         2901,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1144,
         1145,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1146,
         1144,
         1147,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1141,
         1142,
         1148,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1149,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1150,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1151,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1152,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1153,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1154,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1155,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1156,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1157,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1158,
         1159,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1160,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1161,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1162,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1163,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1164,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1165,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1166,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1167,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1168,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1169,
         1170,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1171,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1172,
         1173,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1174,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1175,
         1176,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1177,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1178,
         1179,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1180,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1181,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1182,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1183,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1184,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1185,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1186,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1187,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1188,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1189,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         2904,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         2905,
         2906,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2907,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2905,
         2908,
         2909,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2910,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2908,
         2911,
         2912,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2913,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2911,
         2914,
         2915,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2916,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         2914,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2917,
         2918,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2919,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2920,
         2921,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2922,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2923,
         2924,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2925,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2926,
         2927,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2928,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1242,
         1243,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1244,
         1242,
         1245,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1239,
         1240,
         1246,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1247,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1248,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1249,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1250,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1251,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1252,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1253,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1254,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1255,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1256,
         1257,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1258,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1259,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1260,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1261,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1262,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1263,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1264,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1265,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1266,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1267,
         1268,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1269,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1270,
         1271,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1272,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1273,
         1274,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1275,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1276,
         1277,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1278,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1279,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1280,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1281,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1282,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1283,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1284,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1285,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1286,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1287,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         2929,
         2930,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2931,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2929,
         2932,
         2933,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2934,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2932,
         2935,
         2936,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2937,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2935,
         2938,
         2939,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2940,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         2938,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1291,
         1292,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1293,
         1291,
         1294,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1288,
         1289,
         1295,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1296,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1297,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1298,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1299,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1300,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1301,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1302,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1303,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1304,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1305,
         1306,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1307,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1308,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1309,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1310,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1311,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1312,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1313,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1314,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1315,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1316,
         1317,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1318,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1319,
         1320,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1321,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1322,
         1323,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1324,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1325,
         1326,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1327,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1328,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1329,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1330,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1331,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1332,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1333,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1334,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1335,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1336,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         2941,
         2942,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2943,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2941,
         2944,
         2945,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2946,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2944,
         2947,
         2948,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2949,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2947,
         2950,
         2951,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2952,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         2950,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1337,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1338,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1339,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2953,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2917,
         2918,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2919,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2920,
         2921,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2922,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2923,
         2924,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2925,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2926,
         2927,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2928,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2954,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2917,
         2918,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2919,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2920,
         2921,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2922,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2923,
         2924,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2925,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2926,
         2927,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2928,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2955,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2917,
         2918,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2919,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2917,
         2920,
         2921,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2922,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2920,
         2923,
         2924,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2925,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2923,
         2926,
         2927,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2928,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         2926,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2735,
         2736,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2737,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2735,
         2738,
         2739,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2740,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2738,
         2741,
         2742,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2743,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2741,
         2744,
         2745,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2746,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         2744,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         2,
         2,
         14,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         17,
         4,
         4,
         0,
         2,
         2,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         17,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         118,
         119,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         119,
         119,
         1717,
         1718,
         1719,
         1720,
         1721,
         1722,
         1723,
         1724,
         119,
         2365,
         2366,
         2367,
         1717,
         2368,
         2369,
         3084,
         1715,
         1717,
         1725,
         1715,
         1726,
         1726,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1725,
         1725,
         1726,
         1715,
         1726,
         118,
         1718,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         1716,
         1719,
         1726,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1726,
         1726,
         1716,
         1716,
         1716,
         1716,
         1720,
         1726,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1726,
         1726,
         1716,
         1716,
         1716,
         118,
         1721,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1722,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1723,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         1727,
         118,
         118,
         118,
         118,
         1715,
         2370,
         1716,
         118,
         1716,
         118,
         1724,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         119,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         1728,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         2365,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         2366,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         1715,
         2367,
         1725,
         1715,
         1726,
         1726,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1725,
         1725,
         1726,
         1715,
         1726,
         1715,
         1717,
         1725,
         1715,
         1726,
         1726,
         1715,
         1715,
         2370,
         1715,
         1715,
         1715,
         1715,
         1725,
         2371,
         1726,
         1715,
         1726,
         1716,
         2368,
         1726,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1726,
         1726,
         1716,
         1716,
         1716,
         118,
         2369,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         1716,
         3084,
         1726,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1726,
         1726,
         1716,
         1716,
         1716,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         120,
         2165,
         2166,
         2167,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         121,
      },
   },
   [nir_op_fround_even] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         122,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         123,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         124,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         125,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         126,
         2168,
         2169,
         2170,
         2171,
         2956,
         2957,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         127,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         128,
         2155,
         2156,
         2157,
         2155,
         2155,
         2156,
         2157,
         2156,
         2156,
         2156,
         2157,
         2157,
         2157,
         2157,
         2157,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         129,
         130,
         129,
         131,
         129,
         130,
         129,
         132,
         129,
         130,
         129,
         131,
         129,
         130,
         129,
         132,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         133,
         2158,
         2159,
         2158,
         2158,
         2159,
         2159,
         2159,
         2159,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         134,
         135,
         134,
         136,
         134,
         135,
         134,
         136,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         137,
         138,
         2160,
         138,
         138,
         2161,
         2160,
         2161,
         2160,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         139,
         140,
         139,
         139,
         141,
         142,
         141,
         141,
         139,
         140,
         139,
         1565,
         139,
         140,
         139,
         139,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         143,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         12,
         0,
         3,
         3,
         2,
         4,
         13,
         8,
         2,
         4,
         14,
         3,
         3,
         2,
         4,
         15,
         8,
         2,
         4,
         16,
         3,
         3,
         2,
         4,
         0,
         8,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         146,
         147,
         146,
         1541,
         146,
         1542,
         146,
         2361,
         146,
         146,
         1541,
         146,
         1541,
         146,
         1541,
         146,
         1541,
         1543,
         1544,
         1543,
         1545,
         1543,
         1546,
         1543,
         2362,
         1543,
         1543,
         1545,
         1543,
         1545,
         1543,
         1545,
         1543,
         1545,
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1547,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1548,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         2363,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         2364,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3034,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3125,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3131,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3135,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3140,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3144,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3149,
         144,
         1539,
         144,
         1540,
         144,
         2360,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         148,
         149,
         148,
         148,
         1549,
         148,
         150,
         151,
         150,
         150,
         1550,
         150,
         148,
         1551,
         148,
         148,
         1549,
         148,
         1552,
         1553,
         1552,
         1552,
         1554,
         1552,
         148,
         149,
         148,
         148,
         1549,
         148,
         148,
         1555,
         148,
         148,
         1549,
         148,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         5,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         12,
         12,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         23,
         21,
         21,
         21,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         8,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         152,
         1907,
         1908,
         1909,
         1910,
         1911,
         1912,
         1913,
         1914,
         1915,
         1916,
         1917,
         1918,
         1919,
         1920,
         2511,
         2512,
         2513,
         2514,
         2515,
         2516,
         3030,
         3031,
         3032,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         20,
         6,
         6,
         21,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         153,
         154,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         155,
         156,
         1732,
         1733,
         1734,
         155,
         155,
         1735,
         1736,
         1737,
         1738,
         1739,
         155,
         1732,
         1732,
         1732,
         155,
         155,
         2605,
         1732,
         155,
         155,
         1737,
         153,
         1740,
         1741,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1741,
         1741,
         1741,
         153,
         153,
         153,
         1741,
         153,
         153,
         1730,
         153,
         154,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         153,
         1742,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         1743,
         1744,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         1743,
         1748,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         153,
         154,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         153,
         1749,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         1750,
         1751,
         1752,
         1750,
         1750,
         1750,
         1750,
         1750,
         1750,
         1753,
         1750,
         1754,
         1750,
         1752,
         1752,
         1752,
         1750,
         1750,
         1750,
         1752,
         1750,
         1750,
         1753,
         153,
         1755,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         1756,
         1757,
         1758,
         1756,
         1756,
         1756,
         1756,
         1756,
         1756,
         1759,
         1756,
         1760,
         1756,
         1758,
         1758,
         1758,
         1756,
         1756,
         1756,
         1758,
         1756,
         1756,
         1759,
         153,
         154,
         1729,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         1761,
         1729,
         1729,
         1729,
         153,
         153,
         153,
         1729,
         153,
         153,
         1730,
         153,
         2606,
         1741,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1741,
         1741,
         1741,
         153,
         153,
         153,
         1741,
         153,
         153,
         1730,
         153,
         2607,
         1741,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1741,
         1741,
         1741,
         153,
         153,
         153,
         1741,
         153,
         153,
         1730,
         153,
         2608,
         1741,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1741,
         1741,
         1741,
         153,
         153,
         153,
         1741,
         153,
         153,
         1730,
         1743,
         2609,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         1743,
         2610,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         1743,
         1744,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         153,
         3087,
         1741,
         153,
         153,
         153,
         153,
         153,
         153,
         1730,
         153,
         1731,
         153,
         1741,
         1741,
         1741,
         153,
         153,
         153,
         1741,
         153,
         153,
         1730,
         1743,
         3105,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         1743,
         3106,
         1745,
         1743,
         1743,
         1743,
         1743,
         1743,
         1743,
         1746,
         1743,
         1747,
         1743,
         1745,
         1745,
         1745,
         1743,
         1743,
         1743,
         1745,
         1743,
         1743,
         1746,
         1750,
         3107,
         1752,
         1750,
         1750,
         1750,
         1750,
         1750,
         1750,
         1753,
         1750,
         1754,
         1750,
         1752,
         1752,
         1752,
         1750,
         1750,
         1750,
         1752,
         1750,
         1750,
         1753,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         157,
         158,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         159,
         160,
         1765,
         1766,
         1767,
         159,
         159,
         159,
         1768,
         1769,
         1770,
         1771,
         1772,
         159,
         1765,
         1765,
         1765,
         2611,
         1765,
         157,
         1773,
         1774,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1774,
         1774,
         1774,
         157,
         1774,
         157,
         158,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         157,
         1775,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         1776,
         1777,
         1778,
         1776,
         1776,
         1776,
         1776,
         1776,
         1776,
         1776,
         1779,
         1776,
         1780,
         1776,
         1778,
         1778,
         1778,
         1776,
         1778,
         1776,
         1781,
         1778,
         1776,
         1776,
         1776,
         1776,
         1776,
         1776,
         1776,
         1779,
         1776,
         1780,
         1776,
         1778,
         1778,
         1778,
         1776,
         1778,
         157,
         1782,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         157,
         1783,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         157,
         158,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         1784,
         1785,
         1786,
         1784,
         1784,
         1784,
         1784,
         1784,
         1784,
         1784,
         1787,
         1784,
         1788,
         1784,
         1786,
         1786,
         1786,
         1784,
         1786,
         157,
         1789,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1762,
         1762,
         1762,
         157,
         1762,
         1790,
         1791,
         1792,
         1790,
         1790,
         1790,
         1790,
         1790,
         1790,
         1790,
         1793,
         1790,
         1794,
         1790,
         1792,
         1792,
         1792,
         1790,
         1792,
         157,
         158,
         1762,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         1795,
         1762,
         1762,
         1762,
         157,
         1762,
         157,
         2612,
         1774,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1774,
         1774,
         1774,
         157,
         1774,
         157,
         2613,
         1774,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1774,
         1774,
         1774,
         157,
         1774,
         157,
         2614,
         1774,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1774,
         1774,
         1774,
         157,
         1774,
         1776,
         1777,
         1778,
         1776,
         1776,
         1776,
         1776,
         1776,
         1776,
         1776,
         1779,
         1776,
         1780,
         1776,
         1778,
         1778,
         1778,
         1776,
         1778,
         157,
         3088,
         1774,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1763,
         157,
         1764,
         157,
         1774,
         1774,
         1774,
         157,
         1774,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         13,
         2,
         2,
         2,
         2,
         2,
         14,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         17,
         4,
         4,
         0,
         2,
         2,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         17,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         161,
         162,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         162,
         162,
         1798,
         1799,
         1800,
         1801,
         1802,
         1803,
         1804,
         1805,
         162,
         2372,
         2373,
         2374,
         1798,
         2375,
         2376,
         3085,
         1796,
         1798,
         1806,
         1796,
         1807,
         1807,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1806,
         1806,
         1807,
         1796,
         1807,
         161,
         1799,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         1797,
         1800,
         1807,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1807,
         1807,
         1797,
         1797,
         1797,
         1797,
         1801,
         1807,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1807,
         1807,
         1797,
         1797,
         1797,
         161,
         1802,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         161,
         1803,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         161,
         1804,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         1808,
         161,
         161,
         161,
         161,
         1796,
         2377,
         1797,
         161,
         1797,
         161,
         1805,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         161,
         162,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         1809,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         161,
         2372,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         161,
         2373,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         1796,
         2374,
         1806,
         1796,
         1807,
         1807,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1796,
         1806,
         1806,
         1807,
         1796,
         1807,
         1796,
         1798,
         1806,
         1796,
         1807,
         1807,
         1796,
         1796,
         2377,
         1796,
         1796,
         1796,
         1796,
         1806,
         2378,
         1807,
         1796,
         1807,
         1797,
         2375,
         1807,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1807,
         1807,
         1797,
         1797,
         1797,
         161,
         2376,
         1796,
         161,
         1797,
         1797,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1796,
         1796,
         1797,
         161,
         1797,
         1797,
         3085,
         1807,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1797,
         1807,
         1807,
         1797,
         1797,
         1797,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         163,
         164,
         163,
         2076,
         2076,
         2077,
         2077,
         163,
         163,
         165,
         166,
         2078,
         2079,
         2080,
         2081,
         2082,
         2083,
         165,
         163,
         2084,
         163,
         2076,
         2076,
         2077,
         2077,
         163,
         163,
         2085,
         2086,
         2085,
         2087,
         2087,
         2088,
         2088,
         2085,
         2085,
         2085,
         2089,
         2085,
         2087,
         2087,
         2088,
         2088,
         2085,
         2085,
         2090,
         2091,
         2090,
         2092,
         2092,
         2093,
         2093,
         2090,
         2090,
         2090,
         2094,
         2090,
         2092,
         2092,
         2093,
         2093,
         2090,
         2090,
         163,
         2095,
         163,
         2076,
         2076,
         2077,
         2077,
         2096,
         163,
         163,
         2718,
         163,
         2076,
         2076,
         2077,
         2077,
         163,
         163,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         167,
         168,
         1974,
         167,
         167,
         1975,
         1975,
         1976,
         1976,
         167,
         167,
         169,
         170,
         1977,
         169,
         1978,
         1979,
         1980,
         1981,
         1982,
         1983,
         2719,
         167,
         168,
         1974,
         167,
         167,
         1975,
         1975,
         1976,
         1976,
         167,
         167,
         1984,
         1985,
         1986,
         1984,
         1984,
         1987,
         1987,
         1988,
         1988,
         1984,
         1984,
         167,
         1989,
         1974,
         167,
         167,
         1975,
         1975,
         1976,
         1976,
         167,
         167,
         1990,
         1991,
         1992,
         1990,
         1990,
         1993,
         1993,
         1994,
         1994,
         1990,
         1990,
         1990,
         1995,
         1992,
         1990,
         1990,
         1993,
         1993,
         1994,
         1994,
         1990,
         1990,
         1996,
         1997,
         1998,
         1996,
         1996,
         1999,
         1999,
         2000,
         2000,
         1996,
         1996,
         1996,
         2001,
         1998,
         1996,
         1996,
         1999,
         1999,
         2000,
         2000,
         1996,
         1996,
         167,
         2002,
         1974,
         167,
         167,
         1975,
         1975,
         1976,
         1976,
         2003,
         167,
         167,
         168,
         1974,
         167,
         167,
         1975,
         1975,
         1976,
         1976,
         167,
         167,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         171,
         172,
         171,
         2097,
         2097,
         2098,
         2098,
         171,
         171,
         171,
         171,
         171,
         173,
         174,
         2099,
         2100,
         2101,
         2102,
         2103,
         2104,
         173,
         173,
         173,
         173,
         171,
         2105,
         171,
         2097,
         2097,
         2098,
         2098,
         171,
         171,
         171,
         171,
         171,
         2106,
         2107,
         2106,
         2108,
         2108,
         2109,
         2109,
         2106,
         2106,
         2106,
         2106,
         2106,
         2106,
         2110,
         2106,
         2108,
         2108,
         2109,
         2109,
         2106,
         2106,
         2106,
         2106,
         2106,
         2111,
         2112,
         2111,
         2113,
         2113,
         2114,
         2114,
         2111,
         2111,
         2111,
         2111,
         2111,
         2111,
         2115,
         2111,
         2113,
         2113,
         2114,
         2114,
         2111,
         2111,
         2111,
         2111,
         2111,
         171,
         2116,
         171,
         2097,
         2097,
         2098,
         2098,
         2117,
         171,
         171,
         171,
         171,
         171,
         2118,
         171,
         2097,
         2097,
         2098,
         2098,
         171,
         171,
         171,
         171,
         171,
         171,
         2119,
         171,
         2097,
         2097,
         2098,
         2098,
         171,
         171,
         171,
         171,
         171,
         171,
         2120,
         171,
         2097,
         2097,
         2098,
         2098,
         171,
         171,
         171,
         171,
         171,
         171,
         2720,
         171,
         2097,
         2097,
         2098,
         2098,
         171,
         171,
         171,
         171,
         171,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         175,
         175,
         2004,
         175,
         175,
         2005,
         2005,
         2006,
         2006,
         175,
         176,
         176,
         2007,
         176,
         2008,
         2009,
         2010,
         2011,
         2012,
         2013,
         175,
         175,
         2004,
         175,
         175,
         2005,
         2005,
         2006,
         2006,
         175,
         2014,
         2014,
         2015,
         2014,
         2014,
         2016,
         2016,
         2017,
         2017,
         2014,
         175,
         2018,
         2004,
         175,
         175,
         2005,
         2005,
         2006,
         2006,
         175,
         2019,
         2019,
         2020,
         2019,
         2019,
         2021,
         2021,
         2022,
         2022,
         2019,
         2019,
         2023,
         2020,
         2019,
         2019,
         2021,
         2021,
         2022,
         2022,
         2019,
         2024,
         2024,
         2025,
         2024,
         2024,
         2026,
         2026,
         2027,
         2027,
         2024,
         2024,
         2028,
         2025,
         2024,
         2024,
         2026,
         2026,
         2027,
         2027,
         2024,
         175,
         2029,
         2004,
         175,
         175,
         2005,
         2005,
         2006,
         2006,
         2030,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         13,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         9,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         177,
         178,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         178,
         178,
         1944,
         1945,
         1946,
         1947,
         1948,
         1949,
         1950,
         1951,
         1952,
         1953,
         1954,
         1955,
         1956,
         2721,
         1943,
         1944,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         1943,
         177,
         1945,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1946,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1947,
         1943,
         177,
         177,
         1957,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1948,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1949,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1950,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1951,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         1958,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1952,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1959,
         177,
         177,
         177,
         177,
         177,
         177,
         1953,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1954,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1955,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1956,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         2721,
         1943,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         179,
         180,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         180,
         180,
         1961,
         1962,
         1963,
         1964,
         1965,
         1966,
         1967,
         1968,
         1969,
         1970,
         2722,
         1960,
         1961,
         1960,
         1960,
         1960,
         1960,
         1960,
         1960,
         1960,
         1960,
         1960,
         1960,
         1960,
         179,
         1962,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1963,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1964,
         1960,
         179,
         179,
         1971,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1965,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1966,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1967,
         1960,
         179,
         179,
         179,
         179,
         179,
         1972,
         179,
         179,
         179,
         179,
         179,
         1968,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         1973,
         179,
         179,
         179,
         179,
         1969,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1970,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         2722,
         1960,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         2723,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         181,
         182,
         1810,
         1811,
         181,
         181,
         1812,
         1813,
         1813,
         2615,
         1810,
         2616,
         2617,
         3035,
         3035,
         3036,
         182,
         182,
         1814,
         1815,
         1816,
         1817,
         1818,
         1819,
         1820,
         2618,
         1814,
         2619,
         2620,
         3037,
         3038,
         3039,
         1810,
         1814,
         1810,
         1821,
         1810,
         1810,
         1822,
         1823,
         1823,
         2615,
         1810,
         2616,
         2621,
         3040,
         3040,
         3036,
         1811,
         1815,
         1821,
         1811,
         1811,
         1811,
         1824,
         1825,
         1825,
         2622,
         1821,
         2623,
         2624,
         3041,
         3041,
         3042,
         181,
         1816,
         1810,
         1811,
         181,
         181,
         1812,
         1813,
         1813,
         2615,
         1810,
         2616,
         2617,
         3035,
         3035,
         3036,
         181,
         1817,
         1810,
         1811,
         181,
         1826,
         1812,
         1813,
         1813,
         2615,
         1810,
         2616,
         2617,
         3035,
         3035,
         3036,
         1812,
         1818,
         1822,
         1824,
         1812,
         1812,
         1812,
         1827,
         1827,
         2625,
         1822,
         2626,
         2617,
         3043,
         3043,
         3044,
         1813,
         1819,
         1823,
         1825,
         1813,
         1813,
         1827,
         1813,
         1813,
         2627,
         1823,
         2628,
         2629,
         3035,
         3035,
         3045,
         1813,
         1820,
         1823,
         1825,
         1813,
         1813,
         1827,
         1813,
         1813,
         2627,
         1823,
         2628,
         2629,
         3035,
         3035,
         3045,
         2615,
         2618,
         2615,
         2622,
         2615,
         2615,
         2625,
         2627,
         2627,
         2615,
         2615,
         2630,
         2631,
         3046,
         3046,
         3047,
         1810,
         1814,
         1810,
         1821,
         1810,
         1810,
         1822,
         1823,
         1823,
         2615,
         2632,
         2616,
         2621,
         3040,
         3040,
         3036,
         2616,
         2619,
         2616,
         2623,
         2616,
         2616,
         2626,
         2628,
         2628,
         2630,
         2616,
         2616,
         2633,
         3048,
         3048,
         3049,
         2617,
         2620,
         2621,
         2624,
         2617,
         2617,
         2617,
         2629,
         2629,
         2631,
         2621,
         2633,
         2617,
         3050,
         3050,
         3051,
         3035,
         3037,
         3040,
         3041,
         3035,
         3035,
         3043,
         3035,
         3035,
         3046,
         3040,
         3048,
         3050,
         3035,
         3035,
         3052,
         3035,
         3038,
         3040,
         3041,
         3035,
         3035,
         3043,
         3035,
         3035,
         3046,
         3040,
         3048,
         3050,
         3035,
         3035,
         3052,
         3036,
         3039,
         3036,
         3042,
         3036,
         3036,
         3044,
         3045,
         3045,
         3047,
         3036,
         3049,
         3051,
         3052,
         3052,
         3036,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         183,
         2139,
         2140,
         2141,
         2142,
         3123,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         184,
         185,
         1828,
         1829,
         184,
         184,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
         185,
         185,
         1831,
         1832,
         1833,
         185,
         1834,
         1835,
         2638,
         1831,
         2639,
         2640,
         2641,
         2642,
         2643,
         3108,
         3109,
         1828,
         1831,
         1828,
         1836,
         1828,
         1828,
         1828,
         1837,
         2634,
         1828,
         2635,
         1828,
         2644,
         2644,
         2645,
         1828,
         1828,
         1829,
         1832,
         1836,
         1829,
         1829,
         1829,
         1829,
         1838,
         2646,
         1836,
         2647,
         1829,
         2648,
         2648,
         2649,
         1829,
         1829,
         184,
         1833,
         1828,
         1829,
         184,
         184,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
         184,
         185,
         1828,
         1829,
         184,
         1839,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
         184,
         1834,
         1828,
         1829,
         184,
         184,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
         1830,
         1835,
         1837,
         1838,
         1830,
         1830,
         1830,
         1830,
         2650,
         1837,
         2651,
         1830,
         2652,
         2652,
         2637,
         1830,
         1830,
         2634,
         2638,
         2634,
         2646,
         2634,
         2634,
         2634,
         2650,
         2634,
         2634,
         2653,
         2634,
         2654,
         2654,
         2655,
         2634,
         2634,
         1828,
         1831,
         1828,
         1836,
         1828,
         1828,
         1828,
         1837,
         2634,
         2656,
         2635,
         1828,
         2644,
         2644,
         2645,
         1828,
         1828,
         2635,
         2639,
         2635,
         2647,
         2635,
         2635,
         2635,
         2651,
         2653,
         2635,
         2635,
         2635,
         2657,
         2657,
         2658,
         2635,
         2635,
         184,
         2640,
         1828,
         1829,
         184,
         184,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
         2636,
         2641,
         2644,
         2648,
         2636,
         2636,
         2636,
         2652,
         2654,
         2644,
         2657,
         2636,
         2636,
         2636,
         2659,
         2636,
         2636,
         2636,
         2642,
         2644,
         2648,
         2636,
         2636,
         2636,
         2652,
         2654,
         2644,
         2657,
         2636,
         2636,
         2636,
         2659,
         2636,
         2636,
         2637,
         2643,
         2645,
         2649,
         2637,
         2637,
         2637,
         2637,
         2655,
         2645,
         2658,
         2637,
         2659,
         2659,
         2637,
         2637,
         2637,
         184,
         3108,
         1828,
         1829,
         184,
         184,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
         184,
         3109,
         1828,
         1829,
         184,
         184,
         184,
         1830,
         2634,
         1828,
         2635,
         184,
         2636,
         2636,
         2637,
         184,
         184,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         8,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         186,
         187,
         1853,
         1854,
         1855,
         1856,
         1856,
         2688,
         1853,
         2689,
         3089,
         3089,
         187,
         187,
         1857,
         1858,
         1859,
         1860,
         1861,
         2690,
         1857,
         2691,
         3090,
         3091,
         1853,
         1857,
         1853,
         1862,
         1863,
         1864,
         1864,
         2688,
         1853,
         2692,
         3092,
         3092,
         1854,
         1858,
         1862,
         1854,
         1865,
         1866,
         1866,
         2693,
         1862,
         2694,
         3093,
         3093,
         1855,
         1859,
         1863,
         1865,
         1855,
         1867,
         1867,
         2695,
         1863,
         2689,
         3094,
         3094,
         1856,
         1860,
         1864,
         1866,
         1867,
         1856,
         1856,
         2696,
         1864,
         2697,
         3089,
         3089,
         1856,
         1861,
         1864,
         1866,
         1867,
         1856,
         1856,
         2696,
         1864,
         2697,
         3089,
         3089,
         2688,
         2690,
         2688,
         2693,
         2695,
         2696,
         2696,
         2688,
         2688,
         2698,
         3095,
         3095,
         1853,
         1857,
         1853,
         1862,
         1863,
         1864,
         1864,
         2688,
         2699,
         2692,
         3092,
         3092,
         2689,
         2691,
         2692,
         2694,
         2689,
         2697,
         2697,
         2698,
         2692,
         2689,
         3096,
         3096,
         3089,
         3090,
         3092,
         3093,
         3094,
         3089,
         3089,
         3095,
         3092,
         3096,
         3089,
         3089,
         3089,
         3091,
         3092,
         3093,
         3094,
         3089,
         3089,
         3095,
         3092,
         3096,
         3089,
         3089,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         7,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         188,
         189,
         1868,
         1869,
         188,
         1870,
         2700,
         1868,
         2701,
         2701,
         2702,
         189,
         189,
         1871,
         1872,
         1873,
         1874,
         2703,
         1871,
         2704,
         2705,
         2706,
         1868,
         1871,
         1868,
         1875,
         1868,
         1876,
         2700,
         1868,
         2707,
         2707,
         2708,
         1869,
         1872,
         1875,
         1869,
         1869,
         1877,
         2709,
         1875,
         2710,
         2710,
         2711,
         188,
         1873,
         1868,
         1869,
         188,
         1870,
         2700,
         1868,
         2701,
         2701,
         2702,
         1870,
         1874,
         1876,
         1877,
         1870,
         1870,
         2712,
         1876,
         2713,
         2713,
         2702,
         2700,
         2703,
         2700,
         2709,
         2700,
         2712,
         2700,
         2700,
         2714,
         2714,
         2715,
         1868,
         1871,
         1868,
         1875,
         1868,
         1876,
         2700,
         2716,
         2707,
         2707,
         2708,
         2701,
         2704,
         2707,
         2710,
         2701,
         2713,
         2714,
         2707,
         2701,
         2701,
         2717,
         2701,
         2705,
         2707,
         2710,
         2701,
         2713,
         2714,
         2707,
         2701,
         2701,
         2717,
         2702,
         2706,
         2708,
         2711,
         2702,
         2702,
         2715,
         2708,
         2717,
         2717,
         2702,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         5,
         2,
         5,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         6,
         3,
         6,
         3,
         6,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         190,
         191,
         2182,
         2183,
         190,
         2724,
         3097,
         191,
         191,
         2184,
         2185,
         191,
         2725,
         3098,
         2182,
         2184,
         2182,
         2186,
         2182,
         2724,
         3099,
         2183,
         2185,
         2186,
         2183,
         2183,
         2726,
         3097,
         190,
         191,
         2182,
         2183,
         2727,
         2724,
         3097,
         2724,
         2725,
         2724,
         2726,
         2724,
         2724,
         3100,
         3097,
         3098,
         3099,
         3097,
         3097,
         3100,
         3097,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         5,
         2,
         5,
         5,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         192,
         193,
         2187,
         192,
         2728,
         2729,
         193,
         193,
         2188,
         193,
         2730,
         2731,
         2187,
         2188,
         2187,
         2187,
         2732,
         2729,
         192,
         193,
         2187,
         2733,
         2728,
         2729,
         2728,
         2730,
         2732,
         2728,
         2728,
         2734,
         2729,
         2731,
         2729,
         2729,
         2734,
         2729,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         194,
         195,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         195,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1556,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1557,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1558,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1559,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1560,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1561,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1562,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         2958,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         196,
         1878,
         1879,
         1880,
         1881,
         1882,
         1883,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         197,
         1884,
         1885,
         1886,
         1887,
         1888,
         1889,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         198,
         1890,
         1891,
         1892,
         1893,
         1894,
         1895,
         1896,
         1897,
         1898,
         1899,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         199,
         2033,
         2034,
         2035,
         2036,
         2037,
         2038,
         2039,
         2040,
         2041,
         2042,
         2992,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         200,
         2043,
         2044,
         2045,
         2046,
         2047,
         2048,
         2049,
         2050,
         2051,
         2052,
         2053,
         2054,
         2055,
         2990,
         2991,
         3027,
         3028,
         3029,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         201,
         1900,
         1901,
         1902,
         1903,
         1904,
         1905,
         1906,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         202,
         2143,
         2144,
         2145,
         2146,
         2147,
         2148,
         2149,
         2150,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         203,
         204,
         203,
         203,
         203,
         204,
         203,
         203,
         203,
         1563,
         203,
         203,
         203,
         1564,
         203,
         203,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         205,
         206,
         205,
         206,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         207,
         208,
         207,
         207,
         207,
         207,
         208,
         207,
         207,
         207,
         207,
         2189,
         207,
         207,
         207,
         207,
         2190,
         207,
         207,
         207,
         207,
         2191,
         207,
         207,
         207,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         1521,
         210,
         1522,
         210,
         1523,
         210,
         1524,
         1525,
         2963,
         2964,
         2965,
         2966,
         209,
         210,
         209,
         1526,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         209,
         210,
         1526,
         1526,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         209,
         210,
         209,
         209,
         209,
         1527,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         209,
         210,
         209,
         209,
         1527,
         1527,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         1528,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         209,
         210,
         209,
         209,
         209,
         209,
         1528,
         1528,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1529,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         1517,
         1521,
         1517,
         1517,
         1517,
         1517,
         1517,
         1517,
         1529,
         1529,
         1517,
         1530,
         1517,
         1531,
         1517,
         1532,
         1517,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1533,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         1518,
         1522,
         1518,
         1518,
         1518,
         1518,
         1518,
         1518,
         1518,
         1530,
         1533,
         1533,
         1518,
         1534,
         1518,
         1535,
         1518,
         2971,
         2972,
         2973,
         2974,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1536,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         1519,
         1523,
         1519,
         1519,
         1519,
         1519,
         1519,
         1519,
         1519,
         1531,
         1519,
         1534,
         1536,
         1536,
         1519,
         1537,
         1519,
         2975,
         2976,
         2977,
         2978,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1538,
         209,
         2959,
         2960,
         2961,
         2962,
         1520,
         1524,
         1520,
         1520,
         1520,
         1520,
         1520,
         1520,
         1520,
         1532,
         1520,
         1535,
         1520,
         1537,
         1538,
         1538,
         1520,
         2979,
         2980,
         2981,
         2982,
         209,
         1525,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2959,
         2960,
         2961,
         2962,
         2959,
         2963,
         2959,
         2959,
         2959,
         2959,
         2959,
         2959,
         2959,
         2967,
         2959,
         2971,
         2959,
         2975,
         2959,
         2979,
         2959,
         2959,
         2983,
         2984,
         2985,
         2960,
         2964,
         2960,
         2960,
         2960,
         2960,
         2960,
         2960,
         2960,
         2968,
         2960,
         2972,
         2960,
         2976,
         2960,
         2980,
         2960,
         2983,
         2960,
         2986,
         2987,
         2961,
         2965,
         2961,
         2961,
         2961,
         2961,
         2961,
         2961,
         2961,
         2969,
         2961,
         2973,
         2961,
         2977,
         2961,
         2981,
         2961,
         2984,
         2986,
         2961,
         2988,
         2962,
         2966,
         2962,
         2962,
         2962,
         2962,
         2962,
         2962,
         2962,
         2970,
         2962,
         2974,
         2962,
         2978,
         2962,
         2982,
         2962,
         2985,
         2987,
         2988,
         2989,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         211,
         212,
         213,
         214,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         215,
         216,
         217,
         218,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         219,
         219,
         219,
         219,
         219,
         219,
         219,
         219,
         2192,
         2193,
         2194,
         2195,
         219,
         2192,
         219,
         219,
         219,
         219,
         219,
         2193,
         219,
         219,
         219,
         219,
         219,
         2194,
         219,
         219,
         219,
         219,
         219,
         2195,
         219,
         219,
         219,
         219,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         220,
         220,
         220,
         220,
         220,
         220,
         220,
         220,
         2196,
         2197,
         2198,
         2199,
         220,
         2196,
         220,
         220,
         220,
         220,
         220,
         2197,
         220,
         220,
         220,
         220,
         220,
         2198,
         220,
         220,
         220,
         220,
         220,
         2199,
         220,
         220,
         220,
         220,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         221,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         222,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         223,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         226,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         227,
         227,
         227,
         227,
         227,
         227,
         2122,
         2123,
         227,
         2122,
         227,
         227,
         227,
         2123,
         227,
         227,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         228,
         228,
         228,
         228,
         228,
         228,
         2124,
         2125,
         228,
         2124,
         228,
         228,
         228,
         2125,
         228,
         228,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         229,
         229,
         229,
         229,
         229,
         229,
         2126,
         2127,
         229,
         2126,
         229,
         229,
         229,
         2127,
         229,
         229,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         230,
         230,
         230,
         230,
         230,
         230,
         2172,
         2173,
         230,
         2172,
         230,
         230,
         230,
         2173,
         230,
         230,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         231,
         231,
         231,
         231,
         231,
         231,
         2174,
         2175,
         231,
         2174,
         231,
         231,
         231,
         2175,
         231,
         231,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         232,
         232,
         232,
         232,
         232,
         232,
         2176,
         2177,
         232,
         2176,
         232,
         232,
         232,
         2177,
         232,
         232,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         233,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         238,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         239,
         239,
         240,
         240,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         241,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         242,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         243,
         2217,
         2686,
         2687,
         3086,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         244,
         2206,
         2207,
         2208,
         2209,
         2210,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         245,
         246,
         245,
         245,
         247,
         248,
         247,
         247,
         245,
         2218,
         245,
         245,
         245,
         2682,
         245,
         245,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         249,
         2211,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         250,
         2212,
         2213,
         2214,
         2215,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         251,
         2216,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         252,
         252,
         253,
         253,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         254,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         255,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2200,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2201,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2202,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2203,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
         2205,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         257,
         2132,
         2133,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         258,
         2134,
         2135,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         259,
         2151,
         2152,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         260,
         2153,
         2154,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         261,
         261,
         261,
         261,
         261,
         1566,
         261,
         261,
         261,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         262,
         2056,
         2057,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         263,
         2219,
         2220,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         264,
         2221,
         2604,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         265,
         2223,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         266,
         2222,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         267,
         2058,
         2059,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         268,
         2060,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         269,
         2061,
         0,
         270,
         2061,
         2062,
         2063,
         2064,
         0,
         269,
         2061,
         0,
         270,
         2061,
         2062,
         2063,
         2064,
         0,
         269,
         2061,
         0,
         270,
         2061,
         2062,
         2063,
         2064,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         271,
         2065,
         0,
         272,
         2065,
         2066,
         2067,
         2068,
         0,
         271,
         2065,
         0,
         272,
         2065,
         2066,
         2067,
         2068,
         0,
         271,
         2065,
         0,
         272,
         2065,
         2066,
         2067,
         2068,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         273,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         274,
         2069,
         2070,
         2071,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         2072,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         2162,
         2163,
         2164,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         276,
         277,
         278,
         279,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         280,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         281,
         0,
         281,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         282,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         283,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         284,
      },
   },
   [nir_op_find_lsb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         285,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         286,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         287,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         288,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         289,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         290,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         291,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         294,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         295,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_usub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         298,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         299,
      },
   },
   [nir_op_isub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         302,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         303,
         0,
         0,
         303,
         0,
         2031,
         2032,
         2031,
         0,
         303,
         0,
         0,
         303,
         0,
         2031,
         2032,
         2031,
         0,
         303,
         0,
         0,
         303,
         0,
         2031,
         2032,
         2031,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         2073,
         2074,
         2075,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         310,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         311,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         312,
         2121,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         313,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         314,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         315,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         318,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         319,
         320,
         321,
         320,
         321,
         322,
         323,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         324,
         324,
         324,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         328,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         329,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2128,
         2129,
         0,
         2128,
         0,
         0,
         0,
         2129,
         0,
         0,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2178,
         2179,
         0,
         2178,
         0,
         0,
         0,
         2179,
         0,
         0,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2130,
         2131,
         0,
         2130,
         0,
         0,
         0,
         2131,
         0,
         0,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2180,
         2181,
         0,
         2180,
         0,
         0,
         0,
         2181,
         0,
         0,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         331,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         332,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         333,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         334,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         335,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         336,
         336,
         336,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         337,
         337,
         338,
         338,
         339,
         339,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         340,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   51,
   0,
   55,
   0,
   59,
   61,
   0,
   64,
   71,
   75,
   81,
   88,
   98,
   110,
   125,
   138,
   154,
   160,
   167,
   176,
   186,
   196,
   207,
   209,
   217,
   219,
   223,
   226,
   229,
   231,
   233,
   237,
   240,
   245,
   248,
   253,
   257,
   263,
   265,
   267,
   270,
   273,
   277,
   281,
   283,
   285,
   288,
   291,
   295,
   299,
   301,
   304,
   308,
   310,
   313,
   316,
   320,
   324,
   329,
   331,
   333,
   336,
   339,
   343,
   347,
   349,
   351,
   354,
   357,
   361,
   365,
   367,
   370,
   374,
   376,
   379,
   383,
   385,
   387,
   390,
   393,
   396,
   399,
   404,
   409,
   411,
   414,
   417,
   422,
   426,
   431,
   436,
   460,
   466,
   473,
   480,
   506,
   508,
   0,
   511,
   514,
   516,
   519,
   522,
   0,
   525,
   527,
   0,
   0,
   0,
   0,
   529,
   0,
   0,
   0,
   531,
   533,
   0,
   0,
   0,
   0,
   536,
   0,
   538,
   544,
   546,
   0,
   553,
   559,
   561,
   0,
   568,
   573,
   578,
   583,
   588,
   593,
   598,
   603,
   608,
   610,
   613,
   618,
   624,
   629,
   635,
   637,
   640,
   644,
   649,
   654,
   660,
   665,
   671,
   673,
   675,
   677,
   683,
   685,
   691,
   693,
   0,
   696,
   698,
   700,
   702,
   704,
   706,
   708,
   710,
   714,
   716,
   720,
   722,
   0,
   0,
   726,
   730,
   736,
   0,
   0,
   742,
   744,
   748,
   750,
   753,
   755,
   758,
   760,
   763,
   765,
   767,
   769,
   771,
   773,
   775,
   777,
   779,
   781,
   783,
   785,
   787,
   789,
   791,
   793,
   795,
   797,
   799,
   801,
   803,
   805,
   807,
   809,
   811,
   813,
   815,
   817,
   819,
   821,
   823,
   826,
   0,
   0,
   829,
   831,
   836,
   839,
   845,
   0,
   0,
   847,
   849,
   852,
   854,
   856,
   0,
   0,
   0,
   0,
   858,
   860,
   0,
   0,
   0,
   0,
   862,
   865,
   868,
   870,
   879,
   881,
   889,
   892,
   894,
   896,
   898,
   900,
   902,
   0,
   904,
   907,
   909,
   911,
   913,
   915,
   918,
   920,
   922,
   924,
   926,
   928,
   932,
   935,
   938,
   941,
   944,
   947,
   950,
   956,
   962,
   965,
   968,
   970,
   972,
   974,
   976,
   978,
   980,
   982,
   984,
   986,
   988,
   990,
   992,
   994,
   997,
   1000,
   1003,
   1005,
   1008,
   1012,
   1016,
   1021,
   1025,
   1027,
   1029,
   1031,
   1033,
   1037,
   1039,
   1041,
   1043,
   1045,
   1047,
   1049,
   1051,
   1053,
   1055,
   1058,
   1060,
   1062,
   1065,
   1068,
   1070,
   1072,
   1084,
   1097,
   1109,
   1121,
   1133,
   1146,
   1159,
   1171,
   1183,
   1187,
   1191,
   1194,
   1197,
   1199,
   1204,
   1208,
   1212,
   1216,
   1220,
   1223,
   1225,
   1230,
   0,
   1232,
   1234,
   1236,
   1238,
   1240,
   1243,
   1246,
   1249,
   1251,
   1253,
   1255,
   1258,
   1261,
   1265,
   1269,
   1273,
   1277,
   1281,
   1286,
   1289,
   1293,
   1297,
   1300,
   1303,
   1305,
   1308,
   1311,
   1314,
   1317,
   1320,
   1323,
   1327,
   1331,
   1335,
   1338,
   1341,
   1343,
   1345,
   1347,
   1349,
   1352,
   1355,
   1358,
   1360,
   1362,
   1365,
   1368,
   1371,
   1375,
   1379,
   1383,
   1386,
   1389,
   1392,
   1395,
   1399,
   1403,
   1407,
   1410,
   1413,
   1416,
   1420,
   1424,
   1428,
   1431,
   1434,
   1438,
   1442,
   1446,
   1449,
   1452,
   1457,
   1462,
   1466,
   1470,
   1475,
   1479,
   1483,
   1487,
   1491,
   1494,
   1496,
   1502,
   1509,
   1514,
   1522,
   1527,
   1532,
   1540,
   1548,
   1556,
   1564,
   1572,
   1578,
   1588,
   1594,
   1601,
   1613,
   1618,
   1625,
   1633,
   1641,
   1649,
   1657,
   1665,
   1673,
   1679,
   1686,
   1694,
   1700,
   1707,
   1715,
   1720,
   1726,
   1733,
   1738,
   1744,
   1751,
   1759,
   1764,
   1769,
   1777,
   1782,
   1787,
   1792,
   1797,
   1802,
   1810,
   1819,
   1826,
   1836,
   1843,
   1850,
   1860,
   1870,
   1880,
   1890,
   1900,
   1908,
   1920,
   1928,
   1937,
   1951,
   1958,
   1967,
   1977,
   1987,
   1997,
   2007,
   2017,
   2027,
   2035,
   2044,
   2054,
   2062,
   2071,
   2081,
   2088,
   2096,
   2105,
   2112,
   2120,
   2129,
   2139,
   2146,
   2153,
   2163,
   2170,
   2177,
   2184,
   2191,
   2198,
   2203,
   2209,
   2216,
   2222,
   2247,
   2255,
   2261,
   2270,
   2276,
   2282,
   2291,
   2300,
   2309,
   2318,
   2327,
   2334,
   2345,
   2352,
   2360,
   2373,
   2379,
   2387,
   2396,
   2405,
   2414,
   2423,
   2432,
   2441,
   2448,
   2456,
   2465,
   2472,
   2480,
   2489,
   2495,
   2502,
   2510,
   2516,
   2523,
   2531,
   2540,
   2546,
   2552,
   2561,
   2567,
   2573,
   2579,
   2585,
   2591,
   2596,
   2620,
   2627,
   2632,
   2637,
   2643,
   2650,
   2656,
   2681,
   2689,
   2695,
   2704,
   2710,
   2716,
   2725,
   2734,
   2743,
   2752,
   2761,
   2768,
   2779,
   2786,
   2794,
   2807,
   2813,
   2821,
   2830,
   2839,
   2848,
   2857,
   2866,
   2875,
   2882,
   2890,
   2899,
   2906,
   2914,
   2923,
   2929,
   2936,
   2944,
   2950,
   2957,
   2965,
   2974,
   2980,
   2986,
   2995,
   3001,
   3007,
   3013,
   3019,
   3025,
   3031,
   3038,
   3046,
   3053,
   3079,
   3088,
   3095,
   3105,
   3112,
   3119,
   3129,
   3139,
   3149,
   3159,
   3169,
   3177,
   3189,
   3197,
   3206,
   3220,
   3227,
   3236,
   3246,
   3256,
   3266,
   3276,
   3286,
   3296,
   3304,
   3313,
   3323,
   3331,
   3340,
   3350,
   3357,
   3365,
   3374,
   3381,
   3389,
   3398,
   3408,
   3415,
   3422,
   3432,
   3439,
   3446,
   3453,
   3460,
   3467,
   3474,
   3482,
   3491,
   3499,
   3526,
   3536,
   3544,
   3553,
   3564,
   3572,
   3581,
   3590,
   3600,
   3608,
   3619,
   3630,
   3641,
   3652,
   3663,
   3672,
   3685,
   3694,
   3704,
   3719,
   3727,
   3737,
   3748,
   3759,
   3770,
   3781,
   3792,
   3803,
   3812,
   3822,
   3833,
   3842,
   3852,
   3863,
   3871,
   3880,
   3890,
   3898,
   3907,
   3917,
   3928,
   3936,
   3944,
   3955,
   3963,
   3971,
   3979,
   3987,
   3995,
   4002,
   4010,
   4019,
   4027,
   4054,
   4064,
   4072,
   4083,
   4091,
   4099,
   4110,
   4121,
   4132,
   4143,
   4154,
   4163,
   4176,
   4185,
   4195,
   4210,
   4218,
   4228,
   4239,
   4250,
   4261,
   4272,
   4283,
   4294,
   4303,
   4313,
   4324,
   4333,
   4343,
   4354,
   4362,
   4371,
   4381,
   4389,
   4398,
   4408,
   4419,
   4427,
   4435,
   4446,
   4454,
   4462,
   4470,
   4478,
   4486,
   4494,
   4503,
   4513,
   4522,
   4550,
   4561,
   4570,
   4580,
   4592,
   4601,
   4611,
   4621,
   4632,
   4641,
   4653,
   4665,
   4677,
   4689,
   4701,
   4711,
   4725,
   4735,
   4746,
   4762,
   4771,
   4782,
   4794,
   4806,
   4818,
   4830,
   4842,
   4854,
   4864,
   4875,
   4887,
   4897,
   4908,
   4920,
   4929,
   4939,
   4950,
   4959,
   4969,
   4980,
   4992,
   5001,
   5010,
   5022,
   5031,
   5040,
   5049,
   5058,
   5067,
   5073,
   5080,
   5088,
   5095,
   5121,
   5130,
   5137,
   5147,
   5154,
   5161,
   5171,
   5181,
   5191,
   5201,
   5211,
   5219,
   5231,
   5239,
   5248,
   5262,
   5269,
   5278,
   5288,
   5298,
   5308,
   5318,
   5328,
   5338,
   5346,
   5355,
   5365,
   5373,
   5382,
   5392,
   5399,
   5407,
   5416,
   5423,
   5431,
   5440,
   5450,
   5457,
   5464,
   5474,
   5481,
   5488,
   5495,
   5502,
   5509,
   5516,
   5524,
   5533,
   5541,
   5568,
   5578,
   5586,
   5597,
   5605,
   5613,
   5624,
   5635,
   5646,
   5657,
   5668,
   5677,
   5690,
   5699,
   5709,
   5724,
   5732,
   5742,
   5753,
   5764,
   5775,
   5786,
   5797,
   5808,
   5817,
   5827,
   5838,
   5847,
   5857,
   5868,
   5876,
   5885,
   5895,
   5903,
   5912,
   5922,
   5933,
   5941,
   5949,
   5960,
   5968,
   5976,
   5984,
   5992,
   6000,
   6007,
   6015,
   6024,
   6032,
   6059,
   6069,
   6077,
   6088,
   6096,
   6104,
   6115,
   6126,
   6137,
   6148,
   6159,
   6168,
   6181,
   6190,
   6200,
   6215,
   6223,
   6233,
   6244,
   6255,
   6266,
   6277,
   6288,
   6299,
   6308,
   6318,
   6329,
   6338,
   6348,
   6359,
   6367,
   6376,
   6386,
   6394,
   6403,
   6413,
   6424,
   6432,
   6440,
   6451,
   6459,
   6467,
   6475,
   6483,
   6491,
   6499,
   6508,
   6518,
   6527,
   6555,
   6566,
   6575,
   6587,
   6596,
   6605,
   6617,
   6629,
   6641,
   6653,
   6665,
   6675,
   6689,
   6699,
   6710,
   6726,
   6735,
   6746,
   6758,
   6770,
   6782,
   6794,
   6806,
   6818,
   6828,
   6839,
   6851,
   6861,
   6872,
   6884,
   6893,
   6903,
   6914,
   6923,
   6933,
   6944,
   6956,
   6965,
   6974,
   6986,
   6995,
   7004,
   7013,
   7022,
   7031,
   7036,
   7042,
   7049,
   7055,
   7080,
   7088,
   7094,
   7103,
   7109,
   7115,
   7124,
   7133,
   7142,
   7151,
   7160,
   7167,
   7178,
   7185,
   7193,
   7206,
   7212,
   7220,
   7229,
   7238,
   7247,
   7256,
   7265,
   7274,
   7281,
   7289,
   7298,
   7305,
   7313,
   7322,
   7328,
   7335,
   7343,
   7349,
   7356,
   7364,
   7373,
   7379,
   7385,
   7394,
   7400,
   7406,
   7412,
   7418,
   7424,
   7429,
   7435,
   7442,
   7448,
   7473,
   7481,
   7487,
   7496,
   7502,
   7508,
   7517,
   7526,
   7535,
   7544,
   7553,
   7560,
   7571,
   7578,
   7586,
   7599,
   7605,
   7613,
   7622,
   7631,
   7640,
   7649,
   7658,
   7667,
   7674,
   7682,
   7691,
   7698,
   7706,
   7715,
   7721,
   7728,
   7736,
   7742,
   7749,
   7757,
   7766,
   7772,
   7778,
   7787,
   7793,
   7799,
   7805,
   7811,
   7817,
   7823,
   7830,
   7838,
   7845,
   7871,
   7880,
   7887,
   7897,
   7904,
   7911,
   7921,
   7931,
   7941,
   7951,
   7961,
   7969,
   7981,
   7989,
   7998,
   8012,
   8019,
   8028,
   8038,
   8048,
   8058,
   8068,
   8078,
   8088,
   8096,
   8105,
   8115,
   8123,
   8132,
   8142,
   8149,
   8157,
   8166,
   8173,
   8181,
   8190,
   8200,
   8207,
   8214,
   8224,
   8231,
   8238,
   8245,
   8252,
   8259,
   8264,
   8270,
   8277,
   8283,
   8308,
   8316,
   8322,
   8331,
   8337,
   8343,
   8352,
   8361,
   8370,
   8379,
   8388,
   8395,
   8406,
   8413,
   8421,
   8434,
   8440,
   8448,
   8457,
   8466,
   8475,
   8484,
   8493,
   8502,
   8509,
   8517,
   8526,
   8533,
   8541,
   8550,
   8556,
   8563,
   8571,
   8577,
   8584,
   8592,
   8601,
   8607,
   8613,
   8622,
   8628,
   8634,
   8640,
   8646,
   8652,
   8657,
   8663,
   8670,
   8676,
   8701,
   8709,
   8715,
   8724,
   8730,
   8736,
   8745,
   8754,
   8763,
   8772,
   8781,
   8788,
   8799,
   8806,
   8814,
   8827,
   8833,
   8841,
   8850,
   8859,
   8868,
   8877,
   8886,
   8895,
   8902,
   8910,
   8919,
   8926,
   8934,
   8943,
   8949,
   8956,
   8964,
   8970,
   8977,
   8985,
   8994,
   9000,
   9006,
   9015,
   9021,
   9027,
   9033,
   9039,
   9045,
   9051,
   9058,
   9066,
   9073,
   9099,
   9108,
   9115,
   9125,
   9132,
   9139,
   9149,
   9159,
   9169,
   9179,
   9189,
   9197,
   9209,
   9217,
   9226,
   9240,
   9247,
   9256,
   9266,
   9276,
   9286,
   9296,
   9306,
   9316,
   9324,
   9333,
   9343,
   9351,
   9360,
   9370,
   9377,
   9385,
   9394,
   9401,
   9409,
   9418,
   9428,
   9435,
   9442,
   9452,
   9459,
   9466,
   9473,
   9480,
   9487,
   9493,
   9500,
   9506,
   0,
   9511,
   9517,
   9519,
   9523,
   9530,
   9534,
   9541,
   9546,
   9553,
   9562,
   9567,
   9572,
   9579,
   9588,
   9593,
   9596,
   9600,
   9603,
   9606,
   9610,
   9614,
   9617,
   9620,
   9629,
   9642,
   9656,
   9665,
   9675,
   9684,
   9696,
   9706,
   9716,
   9725,
   9734,
   9737,
   9741,
   9746,
   9751,
   9755,
   9759,
   9763,
   9768,
   9773,
   9777,
   9781,
   9785,
   9789,
   9793,
   9796,
   9799,
   9802,
   9805,
   9808,
   9813,
   9819,
   9830,
   9842,
   9848,
   9860,
   9873,
   9877,
   9882,
   9893,
   9905,
   9910,
   9922,
   9935,
   9937,
   9942,
   9947,
   9951,
   9955,
   9958,
   9968,
   9974,
   9979,
   9985,
   9990,
   9995,
   10000,
   10005,
   10010,
   10014,
   10018,
   10022,
   10025,
   10028,
   10031,
   10033,
   10036,
   10040,
   10044,
   10047,
   10050,
   10055,
   10060,
   10066,
   10071,
   10075,
   10080,
   10086,
   10092,
   10097,
   10102,
   10105,
   10107,
   10111,
   10115,
   10119,
   10122,
   10126,
   10131,
   10136,
   10140,
   10144,
   10148,
   10151,
   10155,
   10160,
   10165,
   10169,
   10173,
   10175,
   10177,
   10180,
   10183,
   10186,
   10190,
   10193,
   10197,
   10202,
   10207,
   10211,
   10215,
   10220,
   10223,
   10227,
   10231,
   10234,
   10237,
   10243,
   10254,
   10266,
   10272,
   10284,
   10297,
   10301,
   10306,
   10316,
   10327,
   10332,
   10343,
   10355,
   10357,
   10361,
   10365,
   10369,
   10373,
   10378,
   10386,
   10391,
   10396,
   10400,
   10404,
   10414,
   10419,
   10425,
   10430,
   10435,
   10440,
   10445,
   10450,
   10454,
   10458,
   10462,
   10465,
   10469,
   10473,
   10476,
   10479,
   10484,
   10489,
   10493,
   10497,
   10501,
   10504,
   10507,
   10510,
   10515,
   10521,
   10526,
   10531,
   10536,
   10541,
   10546,
   10550,
   10554,
   10558,
   0,
   10563,
   10569,
   10571,
   10576,
   10587,
   10596,
   10601,
   10611,
   10618,
   10623,
   10629,
   0,
   10636,
   10642,
   10647,
   10657,
   10672,
   10687,
   10702,
   10707,
   10712,
   10717,
   10725,
   10740,
   0,
   10748,
   10751,
   10754,
   10757,
   10760,
   10763,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   10765,
   10768,
   10771,
   10773,
   10776,
   10779,
   10782,
   10785,
   10787,
   10789,
   10794,
   10796,
   10798,
   10803,
   10810,
   10818,
   10823,
   10829,
   10834,
   10840,
   10845,
   10849,
   10851,
   10853,
   10855,
   0,
   10857,
   0,
   0,
   10859,
   0,
   0,
   10862,
   10870,
   10878,
   10887,
   10895,
   10904,
   10911,
   10918,
   10926,
   10936,
   10943,
   10950,
   10952,
   10954,
   10958,
   10960,
   10962,
   0,
   0,
   10964,
   0,
   0,
   10967,
   0,
   0,
   10970,
   10973,
   10976,
   0,
   10978,
   10980,
   10982,
   10987,
   10993,
   11000,
   11007,
   11015,
   11022,
   11031,
   11038,
   11043,
   11051,
   11059,
   11072,
   11085,
   11092,
   11102,
   11110,
   11118,
   11127,
   11141,
   11155,
   11167,
   11182,
   11195,
   11208,
   11221,
   11237,
   11252,
   11266,
   11280,
   11297,
   11313,
   11328,
   11341,
   11357,
   11371,
   11385,
   11393,
   11404,
   11413,
   11422,
   11431,
   11438,
   11448,
   11456,
   11464,
   11471,
   11478,
   11488,
   11498,
   11506,
   11517,
   11528,
   11538,
   11549,
   11561,
   11572,
   11584,
   11597,
   11611,
   11624,
   11631,
   11639,
   11647,
   11655,
   11658,
   11662,
   11666,
   11670,
   11673,
   11676,
   11681,
   11685,
   11689,
   11694,
   11698,
   11702,
   11706,
   11710,
   11714,
   11718,
   11724,
   11730,
   11736,
   11742,
   11748,
   11755,
   11761,
   11767,
   11774,
   11780,
   11786,
   11792,
   11798,
   11804,
   11811,
   11817,
   11823,
   11829,
   11836,
   11843,
   11850,
   11857,
   11863,
   11869,
   11875,
   11882,
   11889,
   11896,
   11902,
   11908,
   11914,
   11921,
   11928,
   11935,
   11948,
   11954,
   11960,
   11966,
   11973,
   11979,
   11985,
   11991,
   11997,
   12003,
   12009,
   12015,
   12021,
   12028,
   12034,
   12040,
   12046,
   12053,
   12060,
   12067,
   12074,
   12081,
   12087,
   12093,
   12099,
   12106,
   12113,
   12120,
   12126,
   12132,
   12138,
   12145,
   12152,
   12159,
   12172,
   12175,
   12178,
   12183,
   12187,
   12191,
   12196,
   12200,
   12204,
   12208,
   12212,
   12216,
   12220,
   12226,
   12232,
   12235,
   12238,
   12241,
   12243,
   12247,
   12251,
   12255,
   12259,
   12263,
   12266,
   12271,
   12275,
   12279,
   12282,
   12286,
   12289,
   12292,
   12295,
   12298,
   12301,
   12304,
   12307,
   12311,
   12314,
   12318,
   12321,
   12325,
   12329,
   12333,
   12336,
   0,
   12338,
   12340,
   0,
   12345,
   12348,
   12351,
   12354,
   12360,
   12365,
   12375,
   12379,
   12383,
   12386,
   12389,
   12392,
   12394,
   12397,
   12400,
   12403,
   12405,
   12408,
   12412,
   12416,
   12419,
   12423,
   12426,
   12429,
   12432,
   12435,
   12438,
   12441,
   12444,
   12447,
   12450,
   12454,
   12458,
   12462,
   12466,
   12468,
   12470,
   12474,
   12478,
   12480,
   12484,
   12486,
   12488,
   12492,
   12496,
   12498,
   12505,
   12513,
   12518,
   12523,
   12528,
   12535,
   12543,
   12548,
   12553,
   12558,
   12560,
   12562,
   12564,
   12566,
   12568,
   12570,
   12572,
   12574,
   12576,
   0,
   12578,
   12580,
   12582,
   12584,
   12586,
   12588,
   12590,
   12592,
   12594,
   12596,
   12598,
   12603,
   12609,
   12615,
   12623,
   12632,
   12637,
   12644,
   12652,
   12658,
   12665,
   12672,
   12681,
   12691,
   12697,
   12705,
   12714,
   12723,
   12734,
   12746,
   12752,
   12760,
   12769,
   12772,
   12779,
   12793,
   12800,
   12807,
   12821,
   12835,
   12841,
   12853,
   12865,
   12871,
   12877,
   12884,
   12891,
   12897,
   12909,
   12921,
   12924,
   12931,
   12945,
   12952,
   12959,
   12973,
   12987,
   12999,
   13011,
   13018,
   13025,
   13031,
   13043,
   13055,
   13058,
   13061,
   13064,
   13069,
   13074,
   13079,
   13085,
   13090,
   13096,
   13106,
   13109,
   13113,
   13117,
   13121,
   13125,
   13129,
   13132,
   13136,
   13140,
   13144,
   13148,
   13153,
   13156,
   13160,
   13164,
   13168,
   13172,
   13177,
   13186,
   13208,
   13211,
   13214,
   13217,
   13220,
   13223,
   13226,
   13230,
   13233,
   13237,
   13245,
   13248,
   13252,
   13256,
   13260,
   13263,
   13266,
   13270,
   13274,
   13278,
   13282,
   13285,
   13289,
   13293,
   13297,
   13301,
   13309,
   13331,
   13333,
   13336,
   13348,
   13358,
   13365,
   13372,
   13379,
   13418,
   13437,
   13444,
   13451,
   13463,
   13469,
   13479,
   13486,
   13493,
   13500,
   13507,
   13513,
   13529,
   13571,
   13578,
   13585,
   13592,
   13604,
   13607,
   13610,
   13614,
   13619,
   13623,
   13625,
   13627,
   13630,
   13633,
   13635,
   13637,
   13640,
   13643,
   13646,
   13649,
   13653,
   13656,
   13658,
   13660,
   13663,
   13669,
   13675,
   13681,
   13687,
   13694,
   13700,
   13707,
   13718,
   13725,
   13731,
   13739,
   13746,
   13753,
   13762,
   13768,
   13776,
   13783,
   13790,
   13799,
   13811,
   13836,
   13842,
   13848,
   13854,
   13860,
   13867,
   13873,
   13880,
   13891,
   13898,
   13904,
   13912,
   13919,
   13926,
   13935,
   13941,
   13949,
   13956,
   13963,
   13972,
   13984,
   14009,
   14015,
   14021,
   14027,
   14030,
   14033,
   14036,
   14039,
   14042,
   14045,
   14048,
   14050,
   14052,
   14054,
   14056,
   14058,
   14060,
   14062,
   14064,
   14066,
   14070,
   14072,
   14074,
   14078,
   14082,
   14084,
   14087,
   14089,
   14091,
   14093,
   14095,
   14097,
   14099,
   14101,
   14103,
   14105,
   14107,
   14109,
   14113,
   14118,
   14124,
   14127,
   14131,
   14134,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   14138,
   14140,
   14143,
   14146,
   14149,
   14152,
   14155,
   14158,
   14160,
   14162,
   14164,
   14166,
   14169,
   14171,
   14176,
   14180,
   14183,
   14186,
   14191,
   14195,
   14199,
   14203,
   14207,
   14211,
   14215,
   14219,
   14223,
   14227,
   14231,
   14235,
   14238,
   14241,
   14245,
   14248,
   14251,
   14255,
   14257,
   14259,
   14261,
   14263,
   14265,
   14268,
   14270,
   14272,
   14274,
   14276,
   14278,
   14280,
   14286,
   14288,
   14290,
   14292,
   14294,
   14296,
   14298,
   14300,
   14304,
   14308,
   14312,
   14316,
   14320,
   14325,
   14330,
   14335,
   14340,
   14345,
   14349,
   14353,
   14358,
   14363,
   14368,
   14373,
   14377,
   14381,
   14385,
   14389,
   14392,
   14395,
   14400,
   14405,
   14410,
   14415,
   14418,
   14421,
   14426,
   14431,
   14436,
   14441,
   14444,
   14447,
   14452,
   14457,
   14462,
   14467,
   14470,
   14473,
   14478,
   14483,
   14488,
   14493,
   14497,
   14501,
   14507,
   14513,
   14519,
   14525,
   14529,
   14533,
   14539,
   14545,
   14551,
   14557,
   14561,
   14565,
   14571,
   14577,
   14583,
   14589,
   14592,
   14595,
   14600,
   14605,
   14610,
   14615,
   14618,
   14621,
   14626,
   14631,
   14636,
   14641,
   14646,
   14651,
   14656,
   14661,
   14666,
   14671,
   14676,
   14681,
   14688,
   14695,
   14702,
   14709,
   14716,
   14723,
   14725,
   14729,
   14733,
   14737,
   14741,
   14753,
   14766,
   14780,
   14794,
   14808,
   14822,
   14827,
   14832,
   14837,
   14842,
   14848,
   14854,
   14860,
   14866,
   14872,
   14878,
   14884,
   14890,
   14895,
   14900,
   14905,
   14910,
   14915,
   14920,
   14925,
   14930,
   14937,
   14944,
   14951,
   14958,
   14965,
   0,
   14972,
   14974,
   14979,
   14984,
   14988,
   14993,
   14998,
   15001,
   0,
   15005,
   15007,
   15012,
   15018,
   15025,
   15029,
   15033,
   15039,
   15044,
   15048,
   15052,
   15057,
   15061,
   15065,
   15071,
   15076,
   15080,
   15084,
   15089,
   0,
   0,
   15093,
   15095,
   15106,
   15113,
   15120,
   15129,
   15139,
   15144,
   15146,
   15148,
   15151,
   15155,
   0,
   0,
   15157,
   15159,
   0,
   0,
   15163,
   15166,
   15169,
   15172,
   15176,
   0,
   0,
   15180,
   15182,
   0,
   0,
   15186,
   15188,
   15190,
   15195,
   15199,
   15203,
   15208,
   0,
   15210,
   15212,
   15223,
   15231,
   15242,
   15251,
   15260,
   15276,
   15289,
   15305,
   15319,
   15333,
   15344,
   15352,
   15363,
   15372,
   15381,
   15391,
   15403,
   15413,
   15426,
   15437,
   15448,
   15462,
   15473,
   15481,
   15492,
   15501,
   15510,
   15519,
   15531,
   15541,
   15551,
   15556,
   15561,
   15566,
   15571,
   15578,
   15585,
   15592,
   15599,
   15603,
   15609,
   15615,
   15621,
   15627,
   15633,
   15639,
   15645,
   15651,
   15655,
   15661,
   15667,
   15673,
   15679,
   15686,
   15691,
   15696,
   15701,
   15706,
   15712,
   15718,
   15724,
   15730,
   15737,
   15744,
   15751,
   15758,
   15760,
   15767,
   15774,
   15781,
   15788,
   15794,
   15800,
   15806,
   15812,
   15818,
   15824,
   15830,
   15836,
   15842,
   15847,
   15852,
   15855,
   15863,
   15871,
   15879,
   15887,
   15895,
   15903,
   15908,
   15911,
   15913,
   15915,
   15917,
   15919,
   15921,
   15923,
   15926,
   15932,
   15934,
   15939,
   15944,
   15949,
   15954,
   15963,
   15972,
   15982,
   15994,
   16002,
   16013,
   16024,
   16035,
   16047,
   16049,
   16053,
   16060,
   16063,
   16069,
   16075,
   16081,
   16087,
   16091,
   16098,
   16101,
   16107,
   16113,
   16119,
   16125,
   16132,
   16142,
   16145,
   16150,
   16158,
   16162,
   16169,
   16176,
   16183,
   16190,
   16195,
   16203,
   16207,
   16214,
   16221,
   16228,
   16235,
   16239,
   16246,
   16249,
   16255,
   16261,
   16267,
   16273,
   16277,
   16284,
   16287,
   16293,
   16299,
   16305,
   16311,
   16318,
   16321,
   16327,
   16333,
   16339,
   16345,
   16348,
   16354,
   16363,
   16372,
   16381,
   16390,
   16395,
   16400,
   16405,
   16410,
   16421,
   16429,
   16437,
   16445,
   16453,
   16461,
   16469,
   16474,
   16477,
   16479,
   16485,
   16492,
   16499,
   16506,
   16513,
   16521,
   16527,
   16535,
   16542,
   16549,
   16553,
   16557,
   16561,
   16566,
   16571,
   16576,
   16581,
   16586,
   16591,
   16596,
   16601,
   16606,
   16610,
   16614,
   16618,
   16623,
   16629,
   16633,
   16639,
   16643,
   16647,
   16649,
   16653,
   16657,
   16661,
   16664,
   16666,
   16670,
   16674,
   16677,
   16682,
   16687,
   16692,
   16695,
   16700,
   16705,
   16710,
   16713,
   16718,
   16722,
   16728,
   16732,
   16736,
   16742,
   16746,
   16750,
   16754,
   16758,
   16762,
   16765,
   16769,
   16772,
   16775,
   16781,
   16787,
   16793,
   16799,
   16804,
   16810,
   16818,
   16827,
   16832,
   16837,
   16839,
   16841,
   16847,
   16849,
   0,
   0,
   0,
   16855,
   16857,
   16862,
   16866,
   16870,
   16874,
   16878,
   16883,
   16888,
   16893,
   16898,
   16902,
   16906,
   16912,
   16916,
   16920,
   16922,
   16926,
   16930,
   16932,
   16935,
   16939,
   16942,
   16947,
   16952,
   16955,
   16960,
   16965,
   16968,
   16972,
   16978,
   16982,
   16986,
   16993,
   16998,
   17005,
   17013,
   17021,
   17024,
   17028,
   17034,
   17038,
   17041,
   17043,
   17047,
   17051,
   17057,
   17060,
   17063,
   17067,
   17074,
   17082,
   17091,
   17098,
   17106,
   17115,
   17122,
   17130,
   17139,
   17146,
   17154,
   17163,
   17172,
   17182,
   17193,
   17202,
   17212,
   17223,
   17232,
   17242,
   17253,
   17262,
   17272,
   17283,
   17291,
   17300,
   17310,
   17318,
   17327,
   17337,
   17345,
   17354,
   17364,
   17372,
   17381,
   17391,
   17399,
   17408,
   17418,
   17426,
   17435,
   17445,
   17453,
   17462,
   17472,
   17480,
   17489,
   17499,
   17508,
   17518,
   17529,
   17538,
   17548,
   17559,
   17568,
   17578,
   17589,
   17598,
   17608,
   17619,
   17629,
   17640,
   17652,
   17662,
   17673,
   17685,
   17695,
   17706,
   17718,
   17728,
   17739,
   17751,
   17761,
   17772,
   17784,
   17794,
   17805,
   17817,
   17827,
   17838,
   17850,
   17860,
   17871,
   17883,
   17894,
   17906,
   17919,
   17930,
   17942,
   17955,
   17966,
   17978,
   17991,
   18002,
   18014,
   18027,
   18036,
   18046,
   18057,
   18066,
   18076,
   18087,
   18096,
   18106,
   18117,
   18126,
   18136,
   18147,
   18157,
   18168,
   18180,
   18190,
   18201,
   18213,
   18223,
   18234,
   18246,
   18256,
   18267,
   18279,
   18289,
   18300,
   18312,
   18322,
   18333,
   18345,
   18355,
   18366,
   18378,
   18388,
   18399,
   18411,
   18422,
   18434,
   18447,
   18458,
   18470,
   18483,
   18494,
   18506,
   18519,
   18530,
   18542,
   18555,
   18561,
   18569,
   18578,
   18588,
   18596,
   18605,
   18615,
   18623,
   18632,
   18642,
   18650,
   18659,
   18669,
   18677,
   18686,
   18696,
   18704,
   18713,
   18723,
   18731,
   18740,
   18750,
   18758,
   18767,
   18777,
   18784,
   18793,
   18803,
   18814,
   18823,
   18833,
   18844,
   18853,
   18863,
   18874,
   18883,
   18893,
   18904,
   18912,
   18921,
   18931,
   18939,
   18948,
   18958,
   18966,
   18975,
   18985,
   18993,
   19002,
   19012,
   19020,
   19029,
   19039,
   19047,
   19056,
   19066,
   19074,
   19083,
   19093,
   19101,
   19110,
   19120,
   19129,
   19139,
   19150,
   19159,
   19169,
   19180,
   19189,
   19199,
   19210,
   19219,
   19229,
   19240,
   19247,
   19254,
   19261,
   19263,
   19265,
   19270,
   19275,
   19280,
   19285,
   19290,
   19296,
   19302,
   19308,
   19314,
   19321,
   19328,
   19335,
   19342,
   19349,
   19356,
   19363,
   19370,
   19376,
   19382,
   19388,
   19394,
   19400,
   19406,
   19412,
   19418,
   19426,
   19434,
   19442,
   19450,
   19458,
   19466,
   19471,
   19514,
   19557,
   19577,
   19582,
   19586,
   19590,
   19596,
   19599,
   19605,
   19611,
   19624,
   19636,
   19640,
   19647,
   19654,
   19658,
   19668,
   19672,
   19677,
   19682,
   19690,
   19695,
   19703,
   19708,
   19716,
   19724,
   19735,
   19740,
   19748,
   19754,
   19763,
   19769,
   19778,
   19783,
   19791,
   0,
   19796,
   19804,
   19812,
   0,
   0,
   0,
   19820,
   19827,
   19833,
   19836,
   19839,
   19843,
   19849,
   19853,
   19857,
   19861,
   19865,
   19869,
   19873,
   19876,
   19881,
   19885,
   19890,
   19894,
   19899,
   19904,
   0,
   0,
   19908,
   19915,
   19922,
   19924,
   0,
   0,
   0,
   0,
   19926,
   19929,
   0,
   0,
   0,
   0,
   19932,
   19936,
   19940,
   0,
   0,
   0,
   19942,
   19944,
   0,
   19946,
   19957,
   19973,
   19984,
   19996,
   20010,
   20022,
   20027,
   20032,
   20034,
   20041,
   20048,
   20051,
   20054,
   20058,
   20062,
   20066,
   20070,
   20075,
   20080,
   20083,
   20088,
   20092,
   20097,
   20102,
   20106,
   20110,
   20112,
   20120,
   20129,
   20136,
   20139,
   20143,
   20151,
   20159,
   20164,
   20172,
   20183,
   20194,
   20208,
   20222,
   20227,
   20238,
   20241,
   20244,
   0,
   20248,
   20251,
   20257,
   20266,
   20274,
   20287,
   20299,
   20306,
   20312,
   20316,
   20318,
   20321,
   20327,
   20336,
   20349,
   20361,
   20368,
   20374,
   20378,
   20380,
   20383,
   20389,
   20398,
   20411,
   20423,
   20430,
   20436,
   20441,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[110];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(5484 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1913_0_0 -> 0 in the cache */
   /* search1913_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1913_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace1913_0_0 -> 5 in the cache */
   /* replace1913_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1913_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1914_0_0 -> 0 in the cache */
   /* search1914_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1914_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace1914_0_0 -> 5 in the cache */
   /* replace1914_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1914_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1915_0_0 -> 0 in the cache */
   /* search1915_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1915_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace1915_0_0 -> 5 in the cache */
   /* replace1915_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1915_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search1916_0_0 -> 5 in the cache */
   /* search1916_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1916_1_0 -> 5 in the cache */
   /* search1916_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace1916_0 -> 5 in the cache */
   /* replace1916_1_0 -> 8 in the cache */
   /* replace1916_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search1917_0_0 -> 5 in the cache */
   /* search1917_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1917_1_0 -> 5 in the cache */
   /* search1917_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace1917_0 -> 5 in the cache */
   /* replace1917_1_0 -> 8 in the cache */
   /* replace1917_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1918_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search1919_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1919_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1920_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace1920 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search1921_0 -> 39 in the cache */
   /* search1921_1_0_0 -> 39 in the cache */
   /* search1921_1_0 -> 40 in the cache */
   /* search1921_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace1921 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search1922_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1922_1_0 -> 39 in the cache */
   /* search1922_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace1922 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search1923_0 -> 39 in the cache */
   /* search1923_1_0_0 -> 39 in the cache */
   /* search1923_1_0 -> 46 in the cache */
   /* search1923_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace1923 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search1924_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search1924_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace1924_0_0 -> 51 in the cache */
   /* replace1924_0_1 -> 53 in the cache */
   /* replace1924_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace1924_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search1925_0_0 -> 39 in the cache */
   /* search1925_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search1925_1_0 -> 39 in the cache */
   /* search1925_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search1925_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace1925_0_0 -> 53 in the cache */
   /* replace1925_0_1 -> 51 in the cache */
   /* replace1925_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace1925_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search1926_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace1926_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace1926_1_0 -> 64 in the cache */
   /* replace1926_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[110];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 183
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmulz', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1927_0 -> 0 in the cache */
   /* replace1927_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search1928_0_0_0 -> 0 in the cache */
   /* search1928_0_0_1 -> 1 in the cache */
   /* search1928_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search1928_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1928_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace1928_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search1929_0 -> 3 in the cache */
   /* search1929_1_0 -> 0 in the cache */
   /* search1929_1_1 -> 1 in the cache */
   /* search1929_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1929_0_0 -> 0 in the cache */
   /* replace1929_0 -> 9 in the cache */
   /* replace1929_1 -> 1 in the cache */
   /* replace1929 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search1930_0 -> 3 in the cache */
   /* search1930_1_0_0 -> 0 in the cache */
   /* search1930_1_0_1 -> 1 in the cache */
   /* search1930_1_0 -> 2 in the cache */
   /* search1930_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1930_0 -> 0 in the cache */
   /* replace1930_1_0 -> 1 in the cache */
   /* replace1930_1 -> 5 in the cache */
   /* replace1930 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search1931_0_0 -> 0 in the cache */
   /* search1931_0_1 -> 1 in the cache */
   /* search1931_0 -> 2 in the cache */
   /* search1931_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1931_0 -> 0 in the cache */
   /* replace1931_1_0 -> 1 in the cache */
   /* replace1931_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1932_0_0_0 -> 0 in the cache */
   /* search1932_0_0_1 -> 1 in the cache */
   /* search1932_0_0 -> 2 in the cache */
   /* search1932_0 -> 7 in the cache */
   /* search1932_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1932_0_0 -> 0 in the cache */
   /* replace1932_0 -> 9 in the cache */
   /* replace1932_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1933_0 -> 3 in the cache */
   /* search1933_1_0 -> 0 in the cache */
   /* search1933_1_1 -> 1 in the cache */
   /* search1933_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1933_0_0 -> 0 in the cache */
   /* replace1933_0 -> 9 in the cache */
   /* replace1933_1 -> 1 in the cache */
   /* replace1933 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1934_0 -> 3 in the cache */
   /* search1934_1_0_0 -> 0 in the cache */
   /* search1934_1_0_1 -> 1 in the cache */
   /* search1934_1_0 -> 2 in the cache */
   /* search1934_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1934_0 -> 0 in the cache */
   /* replace1934_1_0 -> 1 in the cache */
   /* replace1934_1 -> 5 in the cache */
   /* replace1934 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1935_0_0 -> 0 in the cache */
   /* search1935_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1935_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1935_0 -> 0 in the cache */
   /* replace1935_1_0 -> 1 in the cache */
   /* replace1935_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1936_0_0 -> 0 in the cache */
   /* search1936_0_1 -> 1 in the cache */
   /* search1936_0 -> 19 in the cache */
   /* search1936_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1936_0 -> 0 in the cache */
   /* replace1936_1_0 -> 1 in the cache */
   /* replace1936_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1937_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search1937_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace1937_0 -> 0 in the cache */
   /* replace1937_1_0 -> 1 in the cache */
   /* replace1937_1 -> 5 in the cache */
   /* replace1937 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1938_0_0_0 -> 24 in the cache */
   /* search1938_0_0_1 -> 1 in the cache */
   /* search1938_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search1938_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace1938_0_0 -> 0 in the cache */
   /* replace1938_0 -> 9 in the cache */
   /* replace1938_1 -> 1 in the cache */
   /* replace1938 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1939_0 -> 3 in the cache */
   /* search1939_1_0 -> 24 in the cache */
   /* search1939_1_1 -> 1 in the cache */
   /* search1939_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace1939_0_0 -> 0 in the cache */
   /* replace1939_0 -> 9 in the cache */
   /* replace1939_1 -> 1 in the cache */
   /* replace1939 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1940_0 -> 3 in the cache */
   /* search1940_1_0_0 -> 24 in the cache */
   /* search1940_1_0_1 -> 1 in the cache */
   /* search1940_1_0 -> 25 in the cache */
   /* search1940_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace1940_0 -> 0 in the cache */
   /* replace1940_1_0 -> 1 in the cache */
   /* replace1940_1 -> 5 in the cache */
   /* replace1940 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1941_0_0 -> 24 in the cache */
   /* search1941_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search1941_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1941_0 -> 0 in the cache */
   /* replace1941_1_0 -> 1 in the cache */
   /* replace1941_1 -> 5 in the cache */
   /* replace1941 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1942_0_0 -> 24 in the cache */
   /* search1942_0_1 -> 1 in the cache */
   /* search1942_0 -> 31 in the cache */
   /* search1942_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1942_0 -> 0 in the cache */
   /* replace1942_1_0 -> 1 in the cache */
   /* replace1942_1 -> 5 in the cache */
   /* replace1942 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search1943_0_0 -> 0 in the cache */
   /* search1943_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1943_1_0_0 -> 0 in the cache */
   /* search1943_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1943_1_1_0 -> 1 in the cache */
   /* search1943_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace1943_0_0 -> 0 in the cache */
   /* replace1943_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace1943_1_0 -> 1 in the cache */
   /* replace1943_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1944_1_0 -> 42 in the cache */
   /* search1944_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace1944_0 -> 43 in the cache */
   /* replace1944_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search1945_0_0 -> 0 in the cache */
   /* search1945_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1945_1_0_0 -> 0 in the cache */
   /* search1945_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1945_1_1_0 -> 1 in the cache */
   /* search1945_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace1945_0_0_0 -> 0 in the cache */
   /* replace1945_0_0_1 -> 1 in the cache */
   /* replace1945_0_0 -> 39 in the cache */
   /* replace1945_0_1_0 -> 1 in the cache */
   /* replace1945_0_1_1 -> 0 in the cache */
   /* replace1945_0_1 -> 40 in the cache */
   /* replace1945_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search1946_0_0 -> 42 in the cache */
   /* search1946_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1946_1_0 -> 42 in the cache */
   /* search1946_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace1946_0_0 -> 43 in the cache */
   /* replace1946_0_1_0 -> 42 in the cache */
   /* replace1946_0_1 -> 47 in the cache */
   /* replace1946_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search1947_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace1947 -> 42 in the cache */

   /* ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 61, 62 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 63, 64 },
      -1,
   } },

   /* replace1948_0 -> 61 in the cache */
   /* replace1948_1 -> 62 in the cache */
   /* replace1948_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 61, 62, 64 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 67, 68 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 69, 70 },
      -1,
   } },

   /* replace1949_0 -> 67 in the cache */
   /* replace1949_1 -> 68 in the cache */
   /* replace1949_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 68, 70 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 73, 74 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 75, 76 },
      -1,
   } },

   /* replace1950_0 -> 73 in the cache */
   /* replace1950_1 -> 74 in the cache */
   /* replace1950_2 -> 76 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 76 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1951_0_0 -> 67 in the cache */
   /* search1951_0_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 67, 68 },
      -1,
   } },
   /* search1951_1 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 79, 70 },
      -1,
   } },

   /* replace1951_0 -> 67 in the cache */
   /* replace1951_1 -> 68 in the cache */
   /* replace1951_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 67, 68, 70 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search1952_0 -> 0 in the cache */
   /* search1952_1_0 -> 1 in the cache */
   /* search1952_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* replace1952_0 -> 0 in the cache */
   /* replace1952_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search1953_0 -> 42 in the cache */
   /* search1953 -> 59 in the cache */

   /* replace1953_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 42, 84 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search1954_0 -> 0 in the cache */
   /* search1954_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 86 },
      -1,
   } },

   /* replace1954_0 -> 0 in the cache */
   /* replace1954_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search1955_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace1955_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 90, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search1956_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace1956_0 -> 42 in the cache */
   /* replace1956_1_0 -> 42 in the cache */
   /* replace1956_1 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 42, 89 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 94, 95 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 96, 97 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 100, 101 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search1958_0_0 -> 94 in the cache */
   /* search1958_0_1 -> 95 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 94, 95 },
      0,
   } },
   /* search1958_1 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 103, 97 },
      -1,
   } },

   /* replace1958_0 -> 99 in the cache */
   /* replace1958_1_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },
   /* replace1958_2 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 105, 101 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search1959_0_0 -> 94 in the cache */
   /* search1959_0_1 -> 95 in the cache */
   /* search1959_0 -> 103 in the cache */
   /* search1959_1 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 103, 97 },
      -1,
   } },

   /* replace1959_0 -> 99 in the cache */
   /* replace1959_1_0 -> 100 in the cache */
   /* replace1959_1 -> 105 in the cache */
   /* replace1959_2_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 105, 108 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search1960_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 61 },
      -1,
   } },
   /* search1960_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 110, 62 },
      1,
   } },

   /* replace1960_0_0 -> 61 in the cache */
   /* replace1960_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 62 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 113, 114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 112, 115 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search1961_0 -> 61 in the cache */
   /* search1961_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 62 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 117 },
      1,
   } },

   /* replace1961_0_0 -> 61 in the cache */
   /* replace1961_0_1 -> 62 in the cache */
   /* replace1961_0 -> 112 in the cache */
   /* replace1961_1_0 -> 114 in the cache */
   /* replace1961_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 114, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 112, 119 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 122 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 121, 123 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1962_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 125, 122 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search1963_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 127, 128 },
      -1,
   } },

   /* replace1963_0 -> 0 in the cache */
   /* replace1963_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search1964_0_0 -> 0 in the cache */
   /* search1964_0 -> 127 in the cache */
   /* search1964_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 127, 128 },
      -1,
   } },

   /* replace1964_0 -> 0 in the cache */
   /* replace1964_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search1965_0_0 -> 0 in the cache */
   /* search1965_0 -> 127 in the cache */
   /* search1965_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 127, 128 },
      -1,
   } },

   /* replace1965_0 -> 0 in the cache */
   /* replace1965_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search1966_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 135, 136 },
      -1,
   } },

   /* replace1966_0 -> 42 in the cache */
   /* replace1966_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 42, 136 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 140 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 142, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 141, 144 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 145, 146 },
      -1,
   } },

   /* replace1967_0_0 -> 139 in the cache */
   /* replace1967_0_1_0 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 148 },
      -1,
   } },
   /* replace1967_1_0 -> 142 in the cache */
   /* replace1967_1_1_0 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 142, 150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 149, 151 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search1968_0_0 -> 0 in the cache */
   /* search1968_0 -> 9 in the cache */
   /* search1968_1_0 -> 1 in the cache */
   /* search1968_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1968_0 -> 1 in the cache */
   /* replace1968_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search1969_0_0 -> 0 in the cache */
   /* search1969_0 -> 9 in the cache */
   /* search1969_1_0 -> 1 in the cache */
   /* search1969_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1969_0 -> 1 in the cache */
   /* replace1969_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search1970_0_0 -> 0 in the cache */
   /* search1970_0 -> 9 in the cache */
   /* search1970_1_0 -> 1 in the cache */
   /* search1970_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1970_0 -> 1 in the cache */
   /* replace1970_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search1971_0_0 -> 0 in the cache */
   /* search1971_0 -> 9 in the cache */
   /* search1971_1_0 -> 1 in the cache */
   /* search1971_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1971_0 -> 1 in the cache */
   /* replace1971_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search1972_0_0 -> 42 in the cache */
   /* search1972_0 -> 59 in the cache */
   /* search1972_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 59, 84 },
      -1,
   } },

   /* replace1972_0 -> 136 in the cache */
   /* replace1972_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 136, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search1973_0 -> 84 in the cache */
   /* search1973_1_0 -> 42 in the cache */
   /* search1973_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 84, 59 },
      -1,
   } },

   /* replace1973_0 -> 42 in the cache */
   /* replace1973_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 42, 136 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search1974_0_0 -> 42 in the cache */
   /* search1974_0 -> 59 in the cache */
   /* search1974_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 59, 84 },
      -1,
   } },

   /* replace1974_0 -> 136 in the cache */
   /* replace1974_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 136, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search1975_0 -> 84 in the cache */
   /* search1975_1_0 -> 42 in the cache */
   /* search1975_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 84, 59 },
      -1,
   } },

   /* replace1975_0 -> 42 in the cache */
   /* replace1975_1 -> 136 in the cache */
   /* replace1975 -> 138 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search1976_0_0 -> 42 in the cache */
   /* search1976_0 -> 59 in the cache */
   /* search1976_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 59, 84 },
      -1,
   } },

   /* replace1976_0 -> 136 in the cache */
   /* replace1976_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 136, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search1977_0 -> 84 in the cache */
   /* search1977_1_0 -> 42 in the cache */
   /* search1977_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 84, 59 },
      -1,
   } },

   /* replace1977_0 -> 42 in the cache */
   /* replace1977_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 42, 136 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search1978_0 -> 42 in the cache */
   /* search1978_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1978 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search1979_0 -> 42 in the cache */
   /* search1979_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1979 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 174 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 175 },
      0,
   } },
   /* search1980_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 176, 136 },
      -1,
   } },

   /* replace1980_0_0 -> 136 in the cache */
   /* replace1980_0_1_0 -> 42 in the cache */
   /* replace1980_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 136, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 178 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search1981_0 -> 0 in the cache */
   /* search1981_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1981_0 -> 0 in the cache */
   /* replace1981_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search1982_0 -> 0 in the cache */
   /* search1982_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1982_0 -> 0 in the cache */
   /* replace1982_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search1983_0 -> 0 in the cache */
   /* search1983_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1983_0 -> 0 in the cache */
   /* replace1983_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search1984_0 -> 0 in the cache */
   /* search1984_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace1984_0 -> 0 in the cache */
   /* replace1984_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search1985_0_0 -> 139 in the cache */
   /* search1985_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 139, 140 },
      0,
   } },
   /* search1985_1_0 -> 139 in the cache */
   /* search1985_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 142 },
      0,
   } },
   /* search1985_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 188, 189, 143 },
      -1,
   } },

   /* replace1985_0_0 -> 140 in the cache */
   /* replace1985_0_1 -> 142 in the cache */
   /* replace1985_0_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 140, 142, 143 },
      -1,
   } },
   /* replace1985_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 191, 139 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search1986_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 194 },
      -1,
   } },

   /* replace1986_0 -> 194 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace1986_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 194, 196, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search1987_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search1987_2 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 198, 194 },
      -1,
   } },

   /* replace1987_0 -> 194 in the cache */
   /* replace1987_1 -> 196 in the cache */
   /* replace1987_2_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 194, 196, 200 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search1988_0 -> 67 in the cache */
   /* search1988_1 -> 198 in the cache */
   /* search1988_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 198, 196 },
      -1,
   } },

   /* replace1988_0 -> 196 in the cache */
   /* replace1988_1 -> 194 in the cache */
   /* replace1988_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 196, 194, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search1989_0 -> 67 in the cache */
   /* search1989_1 -> 193 in the cache */
   /* search1989_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 196 },
      -1,
   } },

   /* replace1989_0 -> 196 in the cache */
   /* replace1989_1 -> 194 in the cache */
   /* replace1989_2_0 -> 67 in the cache */
   /* replace1989_2 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 196, 194, 200 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search1990_0_0 -> 193 in the cache */
   /* search1990_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 193, 67 },
      0,
   } },
   /* search1990_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 206, 194 },
      -1,
   } },

   /* replace1990_0 -> 194 in the cache */
   /* replace1990_1 -> 196 in the cache */
   /* replace1990_2 -> 67 in the cache */
   /* replace1990 -> 197 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search1991_0_0 -> 198 in the cache */
   /* search1991_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 198, 67 },
      0,
   } },
   /* search1991_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 208, 194 },
      -1,
   } },

   /* replace1991_0 -> 194 in the cache */
   /* replace1991_1 -> 196 in the cache */
   /* replace1991_2_0 -> 67 in the cache */
   /* replace1991_2 -> 200 in the cache */
   /* replace1991 -> 201 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search1992_0_0 -> 198 in the cache */
   /* search1992_0_1 -> 67 in the cache */
   /* search1992_0 -> 208 in the cache */
   /* search1992_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 208, 196 },
      -1,
   } },

   /* replace1992_0 -> 196 in the cache */
   /* replace1992_1 -> 194 in the cache */
   /* replace1992_2 -> 67 in the cache */
   /* replace1992 -> 203 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search1993_0_0 -> 193 in the cache */
   /* search1993_0_1 -> 67 in the cache */
   /* search1993_0 -> 206 in the cache */
   /* search1993_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 206, 196 },
      -1,
   } },

   /* replace1993_0 -> 196 in the cache */
   /* replace1993_1 -> 194 in the cache */
   /* replace1993_2_0 -> 67 in the cache */
   /* replace1993_2 -> 200 in the cache */
   /* replace1993 -> 205 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 212, 214 },
      -1,
   } },
   /* search1994_1 -> 213 in the cache */
   /* search1994_2 -> 213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 215, 213, 213 },
      -1,
   } },

   /* replace1994_0 -> 213 in the cache */
   /* replace1994_1 -> 212 in the cache */
   /* replace1994_2 -> 213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 213, 212, 213 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search1995_0 -> 67 in the cache */
   /* search1995_1 -> 193 in the cache */
   /* search1995_2_0_0 -> 67 in the cache */
   /* search1995_2_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 67, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 218 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 219 },
      -1,
   } },

   /* replace1995_0 -> 67 in the cache */
   /* replace1995_1 -> 196 in the cache */
   /* replace1995_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 67, 196, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search1996_0 -> 67 in the cache */
   /* search1996_1 -> 193 in the cache */
   /* search1996_2_0_0 -> 67 in the cache */
   /* search1996_2_0 -> 200 in the cache */
   /* search1996_2_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 200, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 67, 193, 222 },
      -1,
   } },

   /* replace1996_0 -> 67 in the cache */
   /* replace1996_1 -> 196 in the cache */
   /* replace1996_2 -> 67 in the cache */
   /* replace1996 -> 221 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search1997_0 -> 67 in the cache */
   /* search1997_1_0 -> 67 in the cache */
   /* search1997_1 -> 200 in the cache */
   /* search1997_2_0 -> 193 in the cache */
   /* search1997_2_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 193, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 67, 200, 224 },
      -1,
   } },

   /* replace1997_0 -> 67 in the cache */
   /* replace1997_1 -> 196 in the cache */
   /* replace1997_2 -> 67 in the cache */
   /* replace1997 -> 221 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search1998_0 -> 67 in the cache */
   /* search1998_1_0 -> 193 in the cache */
   /* search1998_1_1_0 -> 67 in the cache */
   /* search1998_1_1 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 193, 200 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 67, 226 },
      -1,
   } },

   /* replace1998_0 -> 67 in the cache */
   /* replace1998_1 -> 196 in the cache */
   /* replace1998_2 -> 67 in the cache */
   /* replace1998 -> 221 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 228, 229 },
      0,
   } },
   /* search1999_1_0 -> 228 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 231 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 230, 232 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1999_1_0 -> 229 in the cache */
   /* replace1999_1_1 -> 231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 229, 231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 234, 235 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search2000_0_0 -> 228 in the cache */
   /* search2000_0_1 -> 229 in the cache */
   /* search2000_0 -> 230 in the cache */
   /* search2000_1_0 -> 228 in the cache */
   /* search2000_1_1 -> 231 in the cache */
   /* search2000_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 230, 232 },
      -1,
   } },

   /* replace2000_0 -> 234 in the cache */
   /* replace2000_1_0 -> 229 in the cache */
   /* replace2000_1_1 -> 231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 229, 231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 234, 238 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 240 },
      -1,
   } },
   /* search2001_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 241, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search2001_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 242, 243, 244 },
      -1,
   } },

   /* replace2001_0_0 -> 42 in the cache */
   /* replace2001_0 -> 244 in the cache */
   /* replace2001_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 244, 243 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 251, 252 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 249, 250, 253 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 247, 248, 254 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 255, 256 },
      -1,
   } },

   /* replace2002_0 -> 247 in the cache */
   /* replace2002_1 -> 248 in the cache */
   /* replace2002_2_0 -> 249 in the cache */
   /* replace2002_2_1 -> 250 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 258, 259, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 249, 250, 261 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 247, 248, 262 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 266, 267 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 264, 265, 268 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 269, 270 },
      -1,
   } },

   /* replace2003_0 -> 264 in the cache */
   /* replace2003_1 -> 265 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 272, 273, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 264, 265, 275 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2004_0_0_0 -> 247 in the cache */
   /* search2004_0_0_1 -> 248 in the cache */
   /* search2004_0_0_2_0 -> 249 in the cache */
   /* search2004_0_0_2_1 -> 250 in the cache */
   /* search2004_0_0_2_2_0 -> 251 in the cache */
   /* search2004_0_0_2_2_1 -> 252 in the cache */
   /* search2004_0_0_2_2 -> 253 in the cache */
   /* search2004_0_0_2 -> 254 in the cache */
   /* search2004_0_0 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 255 },
      -1,
   } },
   /* search2004_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 277, 256 },
      -1,
   } },

   /* replace2004_0_0 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 247 },
      -1,
   } },
   /* replace2004_1 -> 248 in the cache */
   /* replace2004_2_0_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 249 },
      -1,
   } },
   /* replace2004_2_1 -> 250 in the cache */
   /* replace2004_2_2_0_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 258 },
      -1,
   } },
   /* replace2004_2_2_1 -> 259 in the cache */
   /* replace2004_2_2_2 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 281, 259, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 280, 250, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 279, 248, 283 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2005_0_0 -> 67 in the cache */
   /* search2005_0_1 -> 68 in the cache */
   /* search2005_0_2_0 -> 70 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 286, 287 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 70, 285, 288 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 67, 68, 289 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 290, 291 },
      -1,
   } },

   /* replace2005_0 -> 67 in the cache */
   /* replace2005_1 -> 68 in the cache */
   /* replace2005_2_0 -> 70 in the cache */
   /* replace2005_2_1 -> 285 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 293, 294, 295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 70, 285, 296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 67, 68, 297 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2006_0_0 -> 67 in the cache */
   /* search2006_0_1 -> 68 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 299, 300 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 67, 68, 301 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 302, 303 },
      -1,
   } },

   /* replace2006_0 -> 67 in the cache */
   /* replace2006_1 -> 68 in the cache */
   /* replace2006_2_0 -> 70 in the cache */
   /* replace2006_2_1 -> 285 in the cache */
   /* replace2006_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 70, 285, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 67, 68, 305 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2007_0_0_0 -> 67 in the cache */
   /* search2007_0_0_1 -> 68 in the cache */
   /* search2007_0_0_2_0 -> 70 in the cache */
   /* search2007_0_0_2_1 -> 285 in the cache */
   /* search2007_0_0_2_2_0 -> 286 in the cache */
   /* search2007_0_0_2_2_1 -> 287 in the cache */
   /* search2007_0_0_2_2 -> 288 in the cache */
   /* search2007_0_0_2 -> 289 in the cache */
   /* search2007_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 290 },
      -1,
   } },
   /* search2007_1 -> 291 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 307, 291 },
      -1,
   } },

   /* replace2007_0_0 -> 67 in the cache */
   /* replace2007_0 -> 200 in the cache */
   /* replace2007_1 -> 68 in the cache */
   /* replace2007_2_0_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 70 },
      -1,
   } },
   /* replace2007_2_1 -> 285 in the cache */
   /* replace2007_2_2_0_0 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 293 },
      -1,
   } },
   /* replace2007_2_2_1 -> 294 in the cache */
   /* replace2007_2_2_2 -> 295 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 310, 294, 295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 309, 285, 311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 200, 68, 312 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2008_0 -> 67 in the cache */
   /* search2008_1 -> 68 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 67, 68, 314 },
      -1,
   } },

   /* replace2008 -> 314 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2009_0 -> 67 in the cache */
   /* search2009_1 -> 68 in the cache */
   /* search2009_2 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 67, 68, 314 },
      -1,
   } },

   /* replace2009 -> 314 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2010_0 -> 67 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 67, 317, 318 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace2010_0_1_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 320, 321 },
      -1,
   } },
   /* replace2010_1_0 -> 67 in the cache */
   /* replace2010_1_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 67, 68 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 322, 323 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2011_0 -> 67 in the cache */
   /* search2011_1 -> 317 in the cache */
   /* search2011_2 -> 318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 67, 317, 318 },
      -1,
   } },

   /* replace2011_0_0 -> 67 in the cache */
   /* replace2011_0_1_0_0 -> 68 in the cache */
   /* replace2011_0_1_0_1 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 68, 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 326 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 67, 327 },
      -1,
   } },
   /* replace2011_1_0 -> 70 in the cache */
   /* replace2011_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 328, 321 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2012_0 -> 42 in the cache */
   /* search2012_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2012 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2013_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 331 },
      -1,
   } },

   /* replace2013 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2014_0 -> 42 in the cache */
   /* search2014_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2014 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2015_0 -> 42 in the cache */
   /* search2015_1 -> 331 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 331 },
      -1,
   } },

   /* replace2015 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2016_0 -> 42 in the cache */
   /* search2016_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2016 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2017_0_0 -> 0 in the cache */
   /* search2017_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 336, 337 },
      -1,
   } },

   /* replace2017_0 -> 0 in the cache */
   /* replace2017_1 -> 1 in the cache */
   /* replace2017 -> 336 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2018_0_0 -> 0 in the cache */
   /* search2018_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2018_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 339, 337 },
      -1,
   } },

   /* replace2018_0 -> 0 in the cache */
   /* replace2018_1 -> 1 in the cache */
   /* replace2018 -> 336 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2019_0_0 -> 0 in the cache */
   /* search2019_0_1 -> 1 in the cache */
   /* search2019_0 -> 336 in the cache */
   /* search2019_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 336, 337 },
      -1,
   } },

   /* replace2019_0 -> 0 in the cache */
   /* replace2019_1 -> 1 in the cache */
   /* replace2019 -> 339 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2020_0_0 -> 0 in the cache */
   /* search2020_0_1 -> 1 in the cache */
   /* search2020_0 -> 339 in the cache */
   /* search2020_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 339, 337 },
      -1,
   } },

   /* replace2020_0 -> 0 in the cache */
   /* replace2020_1 -> 1 in the cache */
   /* replace2020 -> 339 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2021_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 343 },
      -1,
   } },

   /* replace2021_0 -> 61 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 61, 345 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2022_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 347 },
      -1,
   } },

   /* replace2022_0 -> 61 in the cache */
   /* replace2022_1 -> 345 in the cache */
   /* replace2022 -> 346 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2023_0_0 -> 61 in the cache */
   /* search2023_0 -> 343 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 343 },
      -1,
   } },

   /* replace2023_0 -> 61 in the cache */
   /* replace2023_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 61, 345 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2024_0_0 -> 61 in the cache */
   /* search2024_0 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 347 },
      -1,
   } },

   /* replace2024_0 -> 61 in the cache */
   /* replace2024_1 -> 345 in the cache */
   /* replace2024 -> 350 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2025_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 352 },
      -1,
   } },

   /* replace2025_0 -> 67 in the cache */
   /* replace2025_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2026_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 355 },
      -1,
   } },

   /* replace2026_0 -> 67 in the cache */
   /* replace2026_1 -> 314 in the cache */
   /* replace2026 -> 354 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2027_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 357 },
      -1,
   } },

   /* replace2027_0 -> 67 in the cache */
   /* replace2027_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2028_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 360 },
      -1,
   } },

   /* replace2028_0 -> 67 in the cache */
   /* replace2028_1 -> 314 in the cache */
   /* replace2028 -> 359 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2029_0_0 -> 67 in the cache */
   /* search2029_0 -> 352 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 352 },
      -1,
   } },

   /* replace2029_0 -> 67 in the cache */
   /* replace2029_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2030_0_0 -> 67 in the cache */
   /* search2030_0 -> 355 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 355 },
      -1,
   } },

   /* replace2030_0 -> 67 in the cache */
   /* replace2030_1 -> 314 in the cache */
   /* replace2030 -> 363 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2031_0_0 -> 67 in the cache */
   /* search2031_0 -> 357 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 357 },
      -1,
   } },

   /* replace2031_0 -> 67 in the cache */
   /* replace2031_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2032_0_0 -> 67 in the cache */
   /* search2032_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 360 },
      -1,
   } },

   /* replace2032_0 -> 67 in the cache */
   /* replace2032_1 -> 314 in the cache */
   /* replace2032 -> 366 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2033_0_0 -> 67 in the cache */
   /* search2033_0_1 -> 314 in the cache */
   /* search2033_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 368 },
      -1,
   } },

   /* replace2033_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 370 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2034_0_0 -> 67 in the cache */
   /* search2034_0_1 -> 314 in the cache */
   /* search2034_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 372 },
      -1,
   } },

   /* replace2034_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 374 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2035_0_0 -> 67 in the cache */
   /* search2035_0_1 -> 314 in the cache */
   /* search2035_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 376 },
      -1,
   } },

   /* replace2035_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 378 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2036_0_0 -> 67 in the cache */
   /* search2036_0_1 -> 368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 368 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 380, 381 },
      -1,
   } },

   /* replace2036_0 -> 67 in the cache */
   /* replace2036_1 -> 370 in the cache */
   /* replace2036 -> 371 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2037_0_0 -> 67 in the cache */
   /* search2037_0_1 -> 372 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 372 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 383, 384 },
      -1,
   } },

   /* replace2037_0 -> 67 in the cache */
   /* replace2037_1 -> 374 in the cache */
   /* replace2037 -> 375 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2038_0_0 -> 67 in the cache */
   /* search2038_0_1 -> 376 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 376 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 386, 387 },
      -1,
   } },

   /* replace2038_0 -> 67 in the cache */
   /* replace2038_1 -> 378 in the cache */
   /* replace2038 -> 379 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2039_0 -> 67 in the cache */
   /* search2039_1 -> 376 in the cache */
   /* search2039 -> 386 in the cache */

   /* replace2039_0 -> 67 in the cache */
   /* replace2039_1 -> 378 in the cache */
   /* replace2039 -> 379 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2040_0 -> 67 in the cache */
   /* search2040_1 -> 372 in the cache */
   /* search2040 -> 383 in the cache */

   /* replace2040_0 -> 67 in the cache */
   /* replace2040_1 -> 370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 67, 370 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2041_0_0 -> 0 in the cache */
   /* search2041_0_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 337 },
      -1,
   } },
   /* search2041_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 390, 1 },
      -1,
   } },

   /* replace2041_0 -> 0 in the cache */
   /* replace2041_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2042_0_0 -> 0 in the cache */
   /* search2042_0_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 337 },
      -1,
   } },
   /* search2042_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 393, 1 },
      -1,
   } },

   /* replace2042_0 -> 0 in the cache */
   /* replace2042_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 396, 397 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2043_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 399, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 398, 400 },
      -1,
   } },

   /* replace2043_0_0 -> 396 in the cache */
   /* replace2043_0_1 -> 399 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 396, 399 },
      -1,
   } },
   /* replace2043_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 402, 397 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2044_0_0 -> 396 in the cache */
   /* search2044_0_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 396, 397 },
      0,
   } },
   /* search2044_1_0 -> 399 in the cache */
   /* search2044_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 399, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 404, 405 },
      -1,
   } },

   /* replace2044_0_0 -> 396 in the cache */
   /* replace2044_0_1 -> 399 in the cache */
   /* replace2044_0 -> 402 in the cache */
   /* replace2044_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 402, 397 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2045_0_0 -> 61 in the cache */
   /* search2045_0_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 61, 345 },
      0,
   } },
   /* search2045_1_0 -> 62 in the cache */
   /* search2045_1_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 62, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 408, 409 },
      -1,
   } },

   /* replace2045_0_0 -> 61 in the cache */
   /* replace2045_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 61, 62 },
      -1,
   } },
   /* replace2045_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 411, 345 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2046_0_0 -> 61 in the cache */
   /* search2046_0_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 61, 345 },
      0,
   } },
   /* search2046_1_0 -> 62 in the cache */
   /* search2046_1_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 62, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 413, 414 },
      -1,
   } },

   /* replace2046_0_0 -> 61 in the cache */
   /* replace2046_0_1 -> 62 in the cache */
   /* replace2046_0 -> 411 in the cache */
   /* replace2046_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 411, 345 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2047_0_0 -> 67 in the cache */
   /* search2047_0_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 67, 314 },
      0,
   } },
   /* search2047_1_0 -> 68 in the cache */
   /* search2047_1_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 68, 314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 417, 418 },
      -1,
   } },

   /* replace2047_0_0 -> 67 in the cache */
   /* replace2047_0_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 67, 68 },
      -1,
   } },
   /* replace2047_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 420, 314 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2048_0_0 -> 67 in the cache */
   /* search2048_0_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 67, 314 },
      0,
   } },
   /* search2048_1_0 -> 68 in the cache */
   /* search2048_1_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 68, 314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 422, 423 },
      -1,
   } },

   /* replace2048_0_0 -> 67 in the cache */
   /* replace2048_0_1 -> 68 in the cache */
   /* replace2048_0 -> 420 in the cache */
   /* replace2048_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 420, 314 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2049_0_0 -> 73 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 73, 426 },
      0,
   } },
   /* search2049_1_0 -> 74 in the cache */
   /* search2049_1_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 74, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 427, 428 },
      -1,
   } },

   /* replace2049_0_0 -> 73 in the cache */
   /* replace2049_0_1 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 73, 74 },
      -1,
   } },
   /* replace2049_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 430, 426 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2050_0_0 -> 73 in the cache */
   /* search2050_0_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 73, 426 },
      0,
   } },
   /* search2050_1_0 -> 74 in the cache */
   /* search2050_1_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 74, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 432, 433 },
      -1,
   } },

   /* replace2050_0_0 -> 73 in the cache */
   /* replace2050_0_1 -> 74 in the cache */
   /* replace2050_0 -> 430 in the cache */
   /* replace2050_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 430, 426 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2051_0 -> 114 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2051_1_1_0 -> 62 in the cache */
   /* search2051_1_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 62, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 436, 437 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 114, 438 },
      -1,
   } },

   /* replace2051_0_0 -> 114 in the cache */
   /* replace2051_0_1_0 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 114, 440 },
      -1,
   } },
   /* replace2051_1_0 -> 62 in the cache */
   /* replace2051_1_1 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 62, 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 441, 442 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2052_1 -> 345 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 345, 447 },
      -1,
   } },

   /* replace2052_0_0_0 -> 444 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 444, 449 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2053_0 -> 196 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2053_1_1_0 -> 68 in the cache */
   /* search2053_1_1_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 68, 194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 453, 454 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 196, 455 },
      -1,
   } },

   /* replace2053_0_0 -> 196 in the cache */
   /* replace2053_0_1_0 -> 453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 196, 457 },
      -1,
   } },
   /* replace2053_1_0 -> 68 in the cache */
   /* replace2053_1_1 -> 453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 68, 453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 458, 459 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2054_0 -> 444 in the cache */
   /* search2054_1 -> 314 in the cache */
   /* search2054_2_0_0 -> 445 in the cache */
   /* search2054_2_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 314, 461 },
      -1,
   } },

   /* replace2054_0_0_0 -> 444 in the cache */
   /* replace2054_0_0_1 -> 449 in the cache */
   /* replace2054_0_0 -> 450 in the cache */
   /* replace2054_0 -> 451 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2055_1_1_0 -> 74 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 74, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 465, 467 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 464, 468 },
      -1,
   } },

   /* replace2055_0_0 -> 464 in the cache */
   /* replace2055_0_1_0 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 464, 470 },
      -1,
   } },
   /* replace2055_1_0 -> 74 in the cache */
   /* replace2055_1_1 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 74, 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 471, 472 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2056_0 -> 444 in the cache */
   /* search2056_1 -> 426 in the cache */
   /* search2056_2_0_0 -> 445 in the cache */
   /* search2056_2_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 426, 474 },
      -1,
   } },

   /* replace2056_0_0_0 -> 444 in the cache */
   /* replace2056_0_0_1 -> 449 in the cache */
   /* replace2056_0_0 -> 450 in the cache */
   /* replace2056_0 -> 451 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2057_0 -> 444 in the cache */
   /* search2057_1_0 -> 140 in the cache */
   /* search2057_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 142 },
      0,
   } },
   /* search2057_2_0 -> 140 in the cache */
   /* search2057_2_1 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 477, 478 },
      -1,
   } },

   /* replace2057_0 -> 140 in the cache */
   /* replace2057_1_0 -> 444 in the cache */
   /* replace2057_1_1 -> 142 in the cache */
   /* replace2057_1_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 142, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 480 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2058_0 -> 444 in the cache */
   /* search2058_1_0 -> 140 in the cache */
   /* search2058_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 142 },
      -1,
   } },
   /* search2058_2_0 -> 140 in the cache */
   /* search2058_2_1 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 143 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 482, 483 },
      -1,
   } },

   /* replace2058_0 -> 140 in the cache */
   /* replace2058_1_0 -> 444 in the cache */
   /* replace2058_1_1 -> 142 in the cache */
   /* replace2058_1_2 -> 143 in the cache */
   /* replace2058_1 -> 480 in the cache */
   /* replace2058 -> 481 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2059_0 -> 444 in the cache */
   /* search2059_1_0 -> 265 in the cache */
   /* search2059_1_1 -> 272 in the cache */
   /* search2059_1_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 273 },
      0,
   } },
   /* search2059_2_0 -> 265 in the cache */
   /* search2059_2_1 -> 272 in the cache */
   /* search2059_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 272, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 485, 486 },
      -1,
   } },

   /* replace2059_0 -> 265 in the cache */
   /* replace2059_1 -> 272 in the cache */
   /* replace2059_2_0 -> 444 in the cache */
   /* replace2059_2_1 -> 273 in the cache */
   /* replace2059_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 273, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 488 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2060_0 -> 444 in the cache */
   /* search2060_1_0 -> 265 in the cache */
   /* search2060_1_1 -> 272 in the cache */
   /* search2060_1_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 273 },
      -1,
   } },
   /* search2060_2_0 -> 265 in the cache */
   /* search2060_2_1 -> 272 in the cache */
   /* search2060_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 272, 274 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 490, 491 },
      -1,
   } },

   /* replace2060_0 -> 265 in the cache */
   /* replace2060_1 -> 272 in the cache */
   /* replace2060_2_0 -> 444 in the cache */
   /* replace2060_2_1 -> 273 in the cache */
   /* replace2060_2_2 -> 274 in the cache */
   /* replace2060_2 -> 488 in the cache */
   /* replace2060 -> 489 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2061_0 -> 444 in the cache */
   /* search2061_1_0 -> 265 in the cache */
   /* search2061_1_1 -> 272 in the cache */
   /* search2061_1_2 -> 273 in the cache */
   /* search2061_1 -> 485 in the cache */
   /* search2061_2_0 -> 265 in the cache */
   /* search2061_2_1 -> 274 in the cache */
   /* search2061_2_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 274, 273 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 485, 493 },
      -1,
   } },

   /* replace2061_0 -> 265 in the cache */
   /* replace2061_1_0 -> 444 in the cache */
   /* replace2061_1_1 -> 272 in the cache */
   /* replace2061_1_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 272, 274 },
      -1,
   } },
   /* replace2061_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 495, 273 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2062_0 -> 444 in the cache */
   /* search2062_1_0 -> 265 in the cache */
   /* search2062_1_1 -> 272 in the cache */
   /* search2062_1_2 -> 273 in the cache */
   /* search2062_1 -> 490 in the cache */
   /* search2062_2_0 -> 265 in the cache */
   /* search2062_2_1 -> 274 in the cache */
   /* search2062_2_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 274, 273 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 490, 497 },
      -1,
   } },

   /* replace2062_0 -> 265 in the cache */
   /* replace2062_1_0 -> 444 in the cache */
   /* replace2062_1_1 -> 272 in the cache */
   /* replace2062_1_2 -> 274 in the cache */
   /* replace2062_1 -> 495 in the cache */
   /* replace2062_2 -> 273 in the cache */
   /* replace2062 -> 496 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2063_0 -> 444 in the cache */
   /* search2063_1_0 -> 68 in the cache */
   /* search2063_1_1 -> 70 in the cache */
   /* search2063_1_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 285 },
      0,
   } },
   /* search2063_2_0 -> 68 in the cache */
   /* search2063_2_1 -> 70 in the cache */
   /* search2063_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 70, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 499, 500 },
      -1,
   } },

   /* replace2063_0 -> 68 in the cache */
   /* replace2063_1 -> 70 in the cache */
   /* replace2063_2_0 -> 444 in the cache */
   /* replace2063_2_1 -> 285 in the cache */
   /* replace2063_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 285, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 502 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2064_0 -> 444 in the cache */
   /* search2064_1_0 -> 68 in the cache */
   /* search2064_1_1 -> 70 in the cache */
   /* search2064_1_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 285 },
      -1,
   } },
   /* search2064_2_0 -> 68 in the cache */
   /* search2064_2_1 -> 70 in the cache */
   /* search2064_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 70, 293 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 504, 505 },
      -1,
   } },

   /* replace2064_0 -> 68 in the cache */
   /* replace2064_1 -> 70 in the cache */
   /* replace2064_2_0 -> 444 in the cache */
   /* replace2064_2_1 -> 285 in the cache */
   /* replace2064_2_2 -> 293 in the cache */
   /* replace2064_2 -> 502 in the cache */
   /* replace2064 -> 503 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2065_0 -> 444 in the cache */
   /* search2065_1_0 -> 68 in the cache */
   /* search2065_1_1 -> 70 in the cache */
   /* search2065_1_2 -> 285 in the cache */
   /* search2065_1 -> 499 in the cache */
   /* search2065_2_0 -> 68 in the cache */
   /* search2065_2_1 -> 293 in the cache */
   /* search2065_2_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 293, 285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 499, 507 },
      -1,
   } },

   /* replace2065_0 -> 68 in the cache */
   /* replace2065_1_0 -> 444 in the cache */
   /* replace2065_1_1 -> 70 in the cache */
   /* replace2065_1_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 70, 293 },
      -1,
   } },
   /* replace2065_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 509, 285 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2066_0 -> 444 in the cache */
   /* search2066_1_0 -> 68 in the cache */
   /* search2066_1_1 -> 70 in the cache */
   /* search2066_1_2 -> 285 in the cache */
   /* search2066_1 -> 504 in the cache */
   /* search2066_2_0 -> 68 in the cache */
   /* search2066_2_1 -> 293 in the cache */
   /* search2066_2_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 293, 285 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 504, 511 },
      -1,
   } },

   /* replace2066_0 -> 68 in the cache */
   /* replace2066_1_0 -> 444 in the cache */
   /* replace2066_1_1 -> 70 in the cache */
   /* replace2066_1_2 -> 293 in the cache */
   /* replace2066_1 -> 509 in the cache */
   /* replace2066_2 -> 285 in the cache */
   /* replace2066 -> 510 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2067_0_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 514 },
      -1,
   } },

   /* replace2067_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2068_0_0_0 -> 67 in the cache */
   /* search2068_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 517 },
      -1,
   } },

   /* replace2068_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2069_0_0_0 -> 67 in the cache */
   /* search2069_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 520 },
      -1,
   } },

   /* replace2069_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2070_0_0_0 -> 67 in the cache */
   /* search2070_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 523 },
      -1,
   } },

   /* replace2070_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2071_0_0_0 -> 67 in the cache */
   /* search2071_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 526 },
      -1,
   } },

   /* replace2071_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2072_0_0_0 -> 67 in the cache */
   /* search2072_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 529 },
      -1,
   } },

   /* replace2072_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2073_0_0_0 -> 67 in the cache */
   /* search2073_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 532 },
      -1,
   } },

   /* replace2073_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2074_0_0_0 -> 67 in the cache */
   /* search2074_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 535 },
      -1,
   } },

   /* replace2074_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2075_0_0_0 -> 67 in the cache */
   /* search2075_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 538 },
      -1,
   } },

   /* replace2075_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2076_0_0_0 -> 67 in the cache */
   /* search2076_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 541 },
      -1,
   } },

   /* replace2076_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2077_0_0_0 -> 67 in the cache */
   /* search2077_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 544 },
      -1,
   } },

   /* replace2077_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2078_0_0_0 -> 67 in the cache */
   /* search2078_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 547 },
      -1,
   } },

   /* replace2078_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2079_0_0_0 -> 67 in the cache */
   /* search2079_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 550 },
      -1,
   } },

   /* replace2079_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2080_0_0_0 -> 67 in the cache */
   /* search2080_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 553 },
      -1,
   } },

   /* replace2080_0 -> 67 in the cache */
   /* replace2080 -> 200 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2081_0_0_0 -> 67 in the cache */
   /* search2081_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 555 },
      -1,
   } },

   /* replace2081_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2082_0_0_0 -> 67 in the cache */
   /* search2082_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 558 },
      -1,
   } },

   /* replace2082_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2083_0_0_0 -> 67 in the cache */
   /* search2083_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 561 },
      -1,
   } },

   /* replace2083_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2084_0_0_0 -> 67 in the cache */
   /* search2084_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 564 },
      -1,
   } },

   /* replace2084_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2085_0_0_0 -> 67 in the cache */
   /* search2085_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 567 },
      -1,
   } },

   /* replace2085_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2086_0_0_0 -> 67 in the cache */
   /* search2086_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 570 },
      -1,
   } },

   /* replace2086_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2087_0_0_0 -> 67 in the cache */
   /* search2087_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 573 },
      -1,
   } },

   /* replace2087_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2088_0_0_0 -> 67 in the cache */
   /* search2088_0_0 -> 513 in the cache */
   /* search2088_0_1_0 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 68 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 577 },
      -1,
   } },

   /* replace2088_0 -> 67 in the cache */
   /* replace2088_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2089_0_0_0 -> 67 in the cache */
   /* search2089_0_0 -> 513 in the cache */
   /* search2089_0_1_0 -> 68 in the cache */
   /* search2089_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 580 },
      -1,
   } },

   /* replace2089_0 -> 67 in the cache */
   /* replace2089_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2090_0_0_0 -> 67 in the cache */
   /* search2090_0_0 -> 513 in the cache */
   /* search2090_0_1_0 -> 68 in the cache */
   /* search2090_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 583 },
      -1,
   } },

   /* replace2090_0 -> 67 in the cache */
   /* replace2090_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2091_0_0_0 -> 67 in the cache */
   /* search2091_0_0 -> 513 in the cache */
   /* search2091_0_1_0 -> 68 in the cache */
   /* search2091_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 586 },
      -1,
   } },

   /* replace2091_0 -> 67 in the cache */
   /* replace2091_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2092_0_0_0 -> 67 in the cache */
   /* search2092_0_0 -> 513 in the cache */
   /* search2092_0_1_0 -> 68 in the cache */
   /* search2092_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 589 },
      -1,
   } },

   /* replace2092_0 -> 67 in the cache */
   /* replace2092_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2093_0_0_0 -> 67 in the cache */
   /* search2093_0_0 -> 513 in the cache */
   /* search2093_0_1_0 -> 68 in the cache */
   /* search2093_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 592 },
      -1,
   } },

   /* replace2093_0 -> 67 in the cache */
   /* replace2093_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2094_0_0_0 -> 67 in the cache */
   /* search2094_0_0 -> 513 in the cache */
   /* search2094_0_1_0 -> 68 in the cache */
   /* search2094_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 595 },
      -1,
   } },

   /* replace2094_0 -> 67 in the cache */
   /* replace2094_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2095_0_0_0 -> 67 in the cache */
   /* search2095_0_0 -> 513 in the cache */
   /* search2095_0_1_0 -> 68 in the cache */
   /* search2095_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 598 },
      -1,
   } },

   /* replace2095_0 -> 67 in the cache */
   /* replace2095_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2096_0_0_0 -> 67 in the cache */
   /* search2096_0_0 -> 513 in the cache */
   /* search2096_0_1_0 -> 68 in the cache */
   /* search2096_0_1 -> 576 in the cache */
   /* search2096_0_2_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 513, 576, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 602 },
      -1,
   } },

   /* replace2096_0 -> 67 in the cache */
   /* replace2096_1 -> 68 in the cache */
   /* replace2096_2 -> 70 in the cache */
   /* replace2096 -> 72 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2097_0_0_0 -> 67 in the cache */
   /* search2097_0_0 -> 513 in the cache */
   /* search2097_0_1_0 -> 68 in the cache */
   /* search2097_0_1 -> 576 in the cache */
   /* search2097_0_2_0 -> 70 in the cache */
   /* search2097_0_2 -> 601 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 513, 576, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 604 },
      -1,
   } },

   /* replace2097_0 -> 67 in the cache */
   /* replace2097_1 -> 68 in the cache */
   /* replace2097_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 67, 68, 70 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2098_0_0 -> 67 in the cache */
   /* search2098_0 -> 513 in the cache */
   /* search2098_1_0 -> 68 in the cache */
   /* search2098_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 513, 576 },
      -1,
   } },

   /* replace2098_0 -> 67 in the cache */
   /* replace2098_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2099_0_0 -> 67 in the cache */
   /* search2099_0 -> 513 in the cache */
   /* search2099_1_0 -> 68 in the cache */
   /* search2099_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 513, 576 },
      -1,
   } },

   /* replace2099_0 -> 67 in the cache */
   /* replace2099_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2100_0_0 -> 67 in the cache */
   /* search2100_0 -> 513 in the cache */
   /* search2100_1_0 -> 68 in the cache */
   /* search2100_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 513, 576 },
      -1,
   } },

   /* replace2100_0 -> 67 in the cache */
   /* replace2100_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2101_0_0 -> 67 in the cache */
   /* search2101_0 -> 513 in the cache */
   /* search2101_1_0 -> 68 in the cache */
   /* search2101_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 513, 576 },
      -1,
   } },

   /* replace2101_0 -> 67 in the cache */
   /* replace2101_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2102_0 -> 67 in the cache */
   /* search2102 -> 513 in the cache */

   /* replace2102_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2103_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2103_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2104_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2104_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2105_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2105_0 -> 67 in the cache */
   /* replace2105 -> 360 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2106_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2106_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2107_0 -> 67 in the cache */
   /* search2107 -> 620 in the cache */

   /* replace2107_0 -> 67 in the cache */
   /* replace2107 -> 357 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2108_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2108_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2109_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2109_0_0 -> 42 in the cache */
   /* replace2109_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 47, 626 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 89, 91, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 92, 93, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 181, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 183, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 184, 185, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 187, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 197, 17 },
   { 199, 201, 17 },
   { 202, 203, 17 },
   { 204, 205, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 314, 0 },
   { 319, 324, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 0 },
   { 325, 329, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 42, 0 },
   { 332, 42, 0 },
   { 386, 379, 120 },
   { 383, 389, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 42, 0 },
   { 334, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 513, 615, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 616, 617, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 618, 619, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 620, 360, 0 },
   { 620, 357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 621, 622, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 623, 624, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 625, 627, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 124, 126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 161, 162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 611, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 155, 156, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 130, 0 },
   { 137, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 609, 610, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 158, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 607, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 159, 160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 192, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 479, 481, 0 },
   { 484, 481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 487, 489, 0 },
   { 492, 489, 0 },
   { 494, 496, 0 },
   { 498, 496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 503, 0 },
   { 506, 503, 0 },
   { 508, 510, 0 },
   { 512, 510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 207, 197, 17 },
   { 209, 201, 17 },
   { 210, 203, 17 },
   { 211, 205, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 80, 81, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 118, 120, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 116, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 116, 116 },
   { 118, 120, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { 382, 371, 120 },
   { 385, 375, 120 },
   { 388, 379, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { 401, 403, 0 },
   { 410, 412, 0 },
   { 419, 421, 0 },
   { 429, 431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { 406, 407, 0 },
   { 415, 416, 0 },
   { 424, 425, 0 },
   { 434, 435, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 98, 102, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 104, 106, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 112 },
   { 98, 102, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 98, 102, 115 },
   { 104, 106, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 112 },
   { 104, 106, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 109, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 340, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 341, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 42, 0 },
   { 332, 42, 0 },
   { 369, 371, 120 },
   { 373, 375, 120 },
   { 377, 379, 120 },
   { 386, 379, 120 },
   { 383, 389, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 346, 55 },
   { 353, 354, 55 },
   { 358, 359, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 346, 55 },
   { 356, 354, 55 },
   { 361, 359, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 55 },
   { 362, 363, 55 },
   { 365, 366, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 351, 350, 55 },
   { 364, 363, 55 },
   { 367, 366, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 163, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 161, 162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 167, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 220, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 221, 17 },
   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 197, 17 },
   { 199, 201, 17 },
   { 202, 203, 17 },
   { 204, 205, 17 },
   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 220, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 223, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 177, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 439, 443, 14 },
   { 456, 460, 16 },
   { 469, 473, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 207, 197, 17 },
   { 209, 201, 17 },
   { 210, 203, 17 },
   { 211, 205, 17 },
   { 439, 443, 14 },
   { 456, 460, 16 },
   { 469, 473, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 554, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 587, 588, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 605, 606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 593, 594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 584, 585, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 578, 579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 603, 72, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 565, 566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 574, 575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 562, 563, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 515, 516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 518, 519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 521, 522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 524, 525, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 527, 528, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 530, 531, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 533, 534, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 536, 537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 539, 540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 542, 543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 545, 546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 549, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 551, 552, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 557, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 559, 560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 568, 569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 571, 572, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 581, 582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 590, 591, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 596, 597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 599, 600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 448, 452, 0 },
   { 462, 463, 0 },
   { 475, 476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 245, 246, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 271, 276, 118 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 271, 276, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 304, 306, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 257, 263, 118 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 257, 263, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 292, 298, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         52,
         53,
         0,
         165,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         0,
         56,
         0,
         0,
         56,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         57,
         0,
         0,
         166,
         0,
         56,
         0,
         0,
         56,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         7,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         3,
         9,
         4,
         8,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         10,
         0,
         10,
         12,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         2,
         3,
         97,
         98,
         98,
         99,
         2,
         97,
         98,
         98,
         181,
         182,
         234,
         235,
         251,
         252,
         3,
         3,
         100,
         101,
         102,
         103,
         3,
         183,
         184,
         185,
         186,
         187,
         236,
         237,
         253,
         254,
         97,
         100,
         97,
         104,
         104,
         105,
         97,
         97,
         104,
         104,
         188,
         189,
         238,
         239,
         251,
         252,
         98,
         101,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         98,
         102,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         99,
         103,
         105,
         106,
         106,
         99,
         99,
         105,
         106,
         106,
         192,
         193,
         242,
         243,
         257,
         258,
         2,
         3,
         97,
         98,
         98,
         99,
         107,
         97,
         98,
         98,
         181,
         182,
         234,
         235,
         251,
         252,
         97,
         183,
         97,
         104,
         104,
         105,
         97,
         97,
         104,
         104,
         188,
         189,
         238,
         239,
         251,
         252,
         98,
         184,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         98,
         185,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         181,
         186,
         188,
         190,
         190,
         192,
         181,
         188,
         190,
         190,
         181,
         194,
         244,
         245,
         259,
         260,
         182,
         187,
         189,
         191,
         191,
         193,
         182,
         189,
         191,
         191,
         194,
         182,
         246,
         247,
         261,
         262,
         234,
         236,
         238,
         240,
         240,
         242,
         234,
         238,
         240,
         240,
         244,
         246,
         234,
         248,
         263,
         264,
         235,
         237,
         239,
         241,
         241,
         243,
         235,
         239,
         241,
         241,
         245,
         247,
         248,
         235,
         265,
         266,
         251,
         253,
         251,
         255,
         255,
         257,
         251,
         251,
         255,
         255,
         259,
         261,
         263,
         265,
         251,
         267,
         252,
         254,
         252,
         256,
         256,
         258,
         252,
         252,
         256,
         256,
         260,
         262,
         264,
         266,
         267,
         252,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         4,
         58,
         59,
         60,
         61,
         62,
         249,
         250,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         63,
         64,
         0,
         0,
         167,
         0,
         0,
         65,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         66,
         0,
         67,
         0,
         0,
         67,
         0,
         0,
         68,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         69,
         0,
         0,
         0,
         168,
         0,
         67,
         0,
         0,
         67,
         0,
         0,
         169,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         5,
         6,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         70,
         71,
         72,
         73,
         6,
         5,
         70,
         5,
         5,
         5,
         5,
         5,
         5,
         71,
         5,
         74,
         5,
         5,
         5,
         5,
         72,
         5,
         5,
         5,
         5,
         5,
         5,
         73,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         5,
         5,
         5,
         5,
         75,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         8,
         76,
         77,
         78,
         8,
         7,
         76,
         7,
         7,
         7,
         7,
         7,
         77,
         7,
         79,
         7,
         7,
         7,
         78,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         80,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         114,
         9,
         9,
         9,
         9,
         115,
         9,
         116,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         231,
         9,
         9,
         116,
         9,
         9,
         9,
         9,
         231,
         9,
         114,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         117,
         9,
         9,
         9,
         9,
         231,
         231,
         9,
         9,
         9,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         232,
         10,
         10,
         10,
         118,
         10,
         232,
         10,
         10,
         118,
         119,
         10,
         10,
         10,
         10,
         10,
         10,
         120,
         10,
         10,
         232,
         232,
         10,
         10,
         10,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         11,
         12,
         89,
         90,
         11,
         228,
         12,
         12,
         91,
         92,
         12,
         229,
         89,
         91,
         89,
         93,
         89,
         228,
         90,
         92,
         93,
         90,
         90,
         230,
         11,
         12,
         89,
         90,
         94,
         228,
         228,
         229,
         228,
         230,
         228,
         228,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         14,
         122,
         123,
         124,
         122,
         122,
         125,
         126,
         123,
         125,
         123,
         127,
         124,
         126,
         127,
         124,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         15,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         16,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         17,
         17,
         128,
         128,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         108,
         109,
         110,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         18,
         141,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         81,
         81,
         0,
         0,
         81,
         82,
         0,
         0,
         0,
         0,
         83,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         20,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         84,
         84,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         173,
         177,
         173,
         174,
         174,
         173,
         178,
         179,
         179,
         173,
         175,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         113,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         177,
         173,
         174,
         174,
         173,
         178,
         179,
         179,
         173,
         175,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         95,
         0,
         0,
         0,
         96,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         227,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         25,
         142,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         26,
         143,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         28,
         0,
         29,
         0,
         28,
         0,
         29,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         30,
         0,
         31,
         0,
         30,
         0,
         31,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         32,
         0,
         0,
         32,
         0,
         0,
         133,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         33,
         0,
         33,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         34,
         0,
         34,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         129,
         35,
         35,
         35,
         130,
         35,
         35,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         36,
         37,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         131,
         36,
         36,
         36,
         132,
         36,
         36,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         38,
         135,
         136,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         39,
         137,
         138,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         134,
         134,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         139,
         139,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         0,
         40,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         41,
         41,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         42,
         42,
         42,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         140,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         43,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         195,
         196,
         197,
         198,
         199,
         200,
         201,
         202,
         203,
         204,
         205,
         206,
         207,
         208,
         209,
         210,
         211,
         212,
         213,
         214,
         215,
         216,
         217,
         218,
         219,
         220,
         221,
         222,
         223,
         224,
         225,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         144,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         44,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         145,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         146,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         147,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         148,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         149,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         150,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         151,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         152,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         153,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         154,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         155,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         156,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         157,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         158,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         159,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         160,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         161,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         162,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         163,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         164,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         45,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         46,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         47,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         48,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         49,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   0,
   0,
   0,
   7,
   9,
   0,
   0,
   11,
   13,
   15,
   17,
   0,
   19,
   0,
   0,
   0,
   24,
   26,
   29,
   31,
   34,
   39,
   42,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   44,
   46,
   48,
   50,
   53,
   55,
   57,
   59,
   61,
   63,
   65,
   67,
   69,
   71,
   73,
   75,
   78,
   80,
   82,
   84,
   87,
   89,
   92,
   94,
   96,
   99,
   101,
   104,
   106,
   0,
   108,
   110,
   112,
   115,
   117,
   119,
   121,
   0,
   123,
   0,
   125,
   0,
   127,
   130,
   135,
   0,
   0,
   0,
   0,
   0,
   0,
   140,
   0,
   142,
   144,
   148,
   150,
   152,
   156,
   164,
   166,
   171,
   174,
   0,
   179,
   181,
   183,
   0,
   186,
   0,
   188,
   193,
   195,
   198,
   204,
   207,
   209,
   0,
   215,
   217,
   219,
   221,
   224,
   227,
   230,
   232,
   234,
   236,
   238,
   240,
   248,
   250,
   254,
   258,
   262,
   266,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   268,
   271,
   274,
   278,
   282,
   0,
   284,
   286,
   288,
   290,
   292,
   294,
   297,
   303,
   306,
   309,
   312,
   314,
   316,
   319,
   326,
   337,
   339,
   341,
   344,
   347,
   352,
   357,
   360,
   363,
   366,
   368,
   370,
   372,
   374,
   376,
   378,
   380,
   382,
   384,
   386,
   388,
   390,
   392,
   394,
   396,
   398,
   400,
   402,
   404,
   406,
   408,
   410,
   412,
   414,
   416,
   418,
   420,
   422,
   424,
   426,
   428,
   432,
   434,
   436,
   438,
   440,
   443,
   0,
   446,
   448,
   450,
   452,
   454,
   457,
   460,
   465,
   470,
   473,
   476,
   479,
   482,
   485,
   488,
   491,
   493,
   495,
   498,
   501,
   504,
   507,
   513,
   519,
   523,
   527,
   531,
   535,
   539,
   543,
   547,
   551,
   555,
   559,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[122];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(628 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;
   condition_flags[110] = options->has_fsub;
   condition_flags[111] = options->lower_fneg;
   condition_flags[112] = options->has_isub || options->lower_ineg;
   condition_flags[113] = options->lower_ineg;
   condition_flags[114] = options->lower_iabs;
   condition_flags[115] = options->has_iadd3;
   condition_flags[116] = options->vectorize_vec2_16bit;
   condition_flags[117] = options->fdot_replicates;
   condition_flags[118] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[119] = options->avoid_ternary_with_two_constants;
   condition_flags[120] = !options->lower_insert_byte;
   condition_flags[121] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2110_0 -> 0 in the cache */
   /* replace2110_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2111_0 -> 6 in the cache */
   /* replace2111_1 -> 8 in the cache */
   /* replace2111_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2112_0_0 -> 0 in the cache */
   /* search2112_0 -> 1 in the cache */
   /* search2112_1_0 -> 2 in the cache */
   /* search2112_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2112_0 -> 0 in the cache */
   /* replace2112_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2113_0_0 -> 0 in the cache */
   /* search2113_0 -> 1 in the cache */
   /* search2113_1_0 -> 2 in the cache */
   /* search2113_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2113_0 -> 0 in the cache */
   /* replace2113_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2114_0_0 -> 0 in the cache */
   /* search2114_0 -> 1 in the cache */
   /* search2114_1_0 -> 2 in the cache */
   /* search2114_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2114_0 -> 0 in the cache */
   /* replace2114_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2115 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2116_0_0 -> 0 in the cache */
   /* search2116_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2116_0_0 -> 0 in the cache */
   /* replace2116_0 -> 1 in the cache */
   /* replace2116_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2117_0_0 -> 0 in the cache */
   /* search2117_0_1 -> 2 in the cache */
   /* search2117_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2117_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2117_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2118_0_0 -> 6 in the cache */
   /* search2118_0_1 -> 8 in the cache */
   /* search2118_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2118_0_0 -> 6 in the cache */
   /* replace2118_0 -> 7 in the cache */
   /* replace2118_1 -> 8 in the cache */
   /* replace2118_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2119_0_0 -> 6 in the cache */
   /* search2119_0_1 -> 8 in the cache */
   /* search2119_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2119_0_0 -> 6 in the cache */
   /* replace2119_0 -> 7 in the cache */
   /* replace2119_1_0 -> 8 in the cache */
   /* replace2119_1 -> 9 in the cache */
   /* replace2119_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2120_0_0 -> 0 in the cache */
   /* search2120_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2120_0_0 -> 0 in the cache */
   /* replace2120_0 -> 1 in the cache */
   /* replace2120_1_0 -> 2 in the cache */
   /* replace2120_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2121_0_0 -> 0 in the cache */
   /* search2121_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2121_0_0 -> 0 in the cache */
   /* replace2121_0 -> 1 in the cache */
   /* replace2121_1_0 -> 2 in the cache */
   /* replace2121_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2122_0_0 -> 0 in the cache */
   /* search2122_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2122_0_0 -> 0 in the cache */
   /* replace2122_0 -> 1 in the cache */
   /* replace2122_1_0 -> 2 in the cache */
   /* replace2122_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2123_0_0 -> 0 in the cache */
   /* search2123_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2123_0_0 -> 0 in the cache */
   /* replace2123_0 -> 1 in the cache */
   /* replace2123_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2124_0_0 -> 0 in the cache */
   /* search2124_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2124_0_0 -> 0 in the cache */
   /* replace2124_0 -> 1 in the cache */
   /* replace2124_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2125_0_0 -> 0 in the cache */
   /* search2125_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2125_0_0 -> 0 in the cache */
   /* replace2125_0 -> 1 in the cache */
   /* replace2125_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2126_0_0 -> 0 in the cache */
   /* search2126_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2126_0 -> 0 in the cache */
   /* replace2126_1_0 -> 2 in the cache */
   /* replace2126_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2127_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2127_0_0 -> 19 in the cache */
   /* replace2127_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2128_0_0 -> 19 in the cache */
   /* search2128_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2128_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[122];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = options->lower_usub_sat64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;
   condition_flags[110] = options->has_fsub;
   condition_flags[111] = options->lower_fneg;
   condition_flags[112] = options->has_isub || options->lower_ineg;
   condition_flags[113] = options->lower_ineg;
   condition_flags[114] = options->lower_iabs;
   condition_flags[115] = options->has_iadd3;
   condition_flags[116] = options->vectorize_vec2_16bit;
   condition_flags[117] = options->fdot_replicates;
   condition_flags[118] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[119] = options->avoid_ternary_with_two_constants;
   condition_flags[120] = !options->lower_insert_byte;
   condition_flags[121] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

